
## **Pathways:**

**Degradation of the extracellular matrix:** Matrix metalloproteinases (MMPs), previously referred to as matrixins because of their role in degradation of the extracellular matrix (ECM), are zinc and calcium dependent proteases belonging to the metzincin family. They contain a characteristic zinc-binding motif HEXXHXXGXXH (Stocker & Bode 1995) and a conserved Methionine which forms a Met-turn. Humans have 24 MMP genes giving rise to 23 MMP proteins, as MMP23 is encoded by two identical genes. All MMPs contain an N-terminal secretory signal peptide and a prodomain with a conserved PRCGXPD motif that in the inactive enzyme is localized with the catalytic site, the cysteine acting as a fourth unpaired ligand for the catalytic zinc atom. Activation involves delocalization of the domain containing this cysteine by a conformational change or proteolytic cleavage, a mechanism referred to as the cysteine-switch (Van Wart & Birkedal-Hansen 1990). Most MMPs are secreted but the membrane type MT-MMPs are membrane anchored and some MMPs may act on intracellular proteins. Various domains determine substrate specificity, cell localization and activation (Hadler-Olsen et al. 2011). MMPs are regulated by transcription, cellular location (most are not activated until secreted), activating proteinases that can be other MMPs, and by metalloproteinase inhibitors such as the tissue inhibitors of metalloproteinases (TIMPs). MMPs are best known for their role in the degradation and removal of ECM molecules. In addition, cleavage of the ECM and other cell surface molecules can release ECM-bound growth factors, and a number of non-ECM proteins are substrates of MMPs (Nagase et al. 2006). MMPs can be divided into subgroups based on domain structure and substrate specificity but it is clear that these are somewhat artificial, many MMPs belong to more than one functional group (Vise & Nagase 2003, Somerville et al. 2003).

**HDL assembly:** HDL particles play a central role in the reverse transport of cholesterol, the process by which cholesterol in tissues other than the liver is returned to the liver for conversion to bile salts and excretion from the body and provided to tissues such as the adrenals and gonads for steroid hormone synthesis (Tall et al. 2008).

HDL particles are heterogeneous and can be fractionated into sub-populations based on their electrophoretic mobility, their density, or their content of various apolipoproteins (Kontush and Chapman 2006). All HDL particles share two key features: they are assembled on a protein scaffold provided by apolipoprotein A-I (apoA-I), and they are recycled to allow a net flow of lipids from peripheral tissues to the liver and steroidogenic tissues while allowing apoA-I molecules to be re-used.

Here, the assembly of nascent (discoidal) HDL particles on newly synthesized apoA-I, a process that in the body occurs primarily in the liver, and the loading of discoidal HDL with additional lipid through interaction with cells carrying excess cholesterol (transformation to spherical HDL) are annotated.

**Intrinsic Pathway of Fibrin Clot Formation:** The intrinsic pathway of blood clotting connects interactions among kininogen (high molecular weight kininogen, HK), prekallikrein (PK), and factor XII to the activation of clotting factor X by a series of reactions that is independent of the extrinsic pathway and that is not subject to inhibition by TFPI. It is thus essential for the prolongation of the clotting cascade: while the reactions of the extrinsic pathway appear to be sufficient to initiate clot formation, those of the intrinsic pathway are required to maintain it (Broze 1995; Davie et al. 1991; Monroe et al. 2002). The intrinsic pathway can be divided into three parts: 1) reactions involving interactions of kininogen, prekallikrein, and factor XII, leading to the activation of factor XII, 2) reactions involving factor XI, factor IX, factor VIII, and von Willebrand factor (vWF) leading to the activation of factors VIII and IX, and 3) reactions that inactivate factor XIIa and kallikrein.

Kininogen, prekallikrein, and factor XII were first identified as proteins needed for the rapid formation of clots when whole blood is exposed to negatively charged surfaces in vitro. Early studies in vitro identified several possible sets of interactions, in which small quantities of one or more of these proteins 'autoactivate' and then catalyze the formation of larger quantities of activated factors. Subsequent work, however, suggests that these factors form complexes on endothelial cell surfaces mediated by C1q binding protein (C1q bp), that the first activation event is the cleavage of prekallikrein by prolylcarboxypeptidase, and that the resulting kallikrein catalyzes the activation of factor XII (Schmaier 2004).

The second group of events, occurs in vivo on the surfaces of activated platelets (although most biochemical characterization of the reactions was originally done with purified proteins in solution). Factor XI binds to the platelet glycoprotein (GP) Ib:IX:V complex, where it can be activated by cleavage either by thrombin (generated by reactions of the common pathway) or by activated factor XII (generated in the first part of the intrinsic pathway). Activated factor XI in turn catalyzes the activation of factor IX. Simultaneously, factor VIII, complexed with vWF, is cleaved by thrombin, activating it and causing its release from vWF. Activated factors VIII and IX form a complex on the platelet surface that very efficiently converts factor X to activated factor X. (Activated factors X and V then form a complex that efficiently activates thrombin.)

While these two groups of events can be viewed as forming a single functional pathway (e.g., Davie et al. 1991), human clinical genetic data cast doubt on this view. Individuals deficient in kininogen, prekallikrein, or factor XII proteins exhibit normal blood clot formation in vivo. In contrast, deficiencies of factor XI can be associated with failure of blood clotting under some conditions, and deficiencies of vWF, factor VIII, or factor IX cause severe abnormalities - von Willebrand disease, hemophilia A, and hemophilia B, respectively. These data suggest that while the second group of events is essential for normal clot formation in vivo, the first group has a different function (e.g., Schmaier 2004).

Finally, reactions neutralize proteins activated in the first part of the intrinsic pathway. Kallikrein forms stable complexes with either C1 inhibitor (C1Inh) or with alpha2-macroglobulin, and factor XIIa forms stable complexes with C1Inh. The relevance of these neutralization events to the regulatory of blood clotting is unclear, however. The physiological abnormalities observed in individuals who lack C1Inh appear to be due entirely to abnormalities of complement activation; blood clotting appears to proceed normally. This observation is consistent with the hypothesis, above, that factor XIIa plays a limited role in normal blood clotting under physiological conditions.

**Plasma lipoprotein assembly:** Because of their hydrophobicity, lipids are found in the extracellular spaces of the human body primarily in the form of lipoprotein complexes. Chylomicrons form in the small intestine and transport dietary lipids to other tissues in the body. Very low density lipoproteins (VLDL) form in the liver and transport triacylglycerol synthesized there to other tissues of the body. High density lipoprotein (HDL) particles are formed primarily by the liver and shuttle several kinds of lipids between tissues and other lipoproteins (Vance & Vance 1990). The assembly of these three classes of lipoproteins is annotated here.

**Platelet degranulation:** Platelets function as exocytotic cells, secreting a plethora of effector molecules at sites of vascular injury. Platelets contain a number of distinguishable storage granules including alpha granules, dense granules and lysosomes. On activation platelets release a variety of proteins, largely from storage granules but also as the result of apparent cell lysis. These act in an autocrine or paracrine fashion to modulate cell signaling.

Alpha granules contain mainly polypeptides such as fibrinogen, von Willebrand factor, growth factors and protease inhibitors that supplement thrombin generation at the site of injury. Dense granules contain small molecules, particularly adenosine diphosphate (ADP), adenosine triphosphate (ATP), serotonin and calcium, all recruit platelets to the site of injury. The molecular mechanism which facilitates granule release involves soluble NSF attachment protein receptors (SNAREs), which assemble into complexes to form a universal membrane fusion apparatus. Although all cells use SNAREs for membrane fusion, different cells possess different SNARE isoforms. Platelets and chromaffin cells use many of the same chaperone proteins to regulate SNARE-mediated secretion (Fitch-Tewfik & Flaumenhaft 2013).

## GO terms:

**acute inflammatory response to antigenic stimulus** [An acute inflammatory response to an antigenic stimulus. An acute inflammatory response occurs within a matter of minutes or hours, and either resolves within a few days or becomes a chronic inflammatory response. GO:0002438]

**acute-phase response** [An acute inflammatory response that involves non-antibody proteins whose concentrations in the plasma increase in response to infection or injury of homeothermic animals. GO:0006953]

**embryonic liver development** [The process occurring during the embryonic phase whose specific outcome is the progression of the liver over time, from its formation to the mature structure. GO:1990402]

**luteinization** [The set of processes resulting in differentiation of theca and granulosa cells into luteal cells and in the formation of a corpus luteum after ovulation. GO:0001553]

**negative regulation of complement activation, lectin pathway** [Any process that stops, prevents, or reduces the rate of complement activation by the lectin pathway. GO:0001869]

**negative regulation of endopeptidase activity** [Any process that decreases the frequency, rate or extent of endopeptidase activity, the endohydrolysis of peptide bonds within proteins. GO:0010951]

**response to carbon dioxide** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a carbon dioxide (CO2) stimulus. GO:0010037]

**response to glucocorticoid** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a glucocorticoid stimulus. Glucocorticoids are hormonal C21 corticosteroids synthesized from cholesterol with the ability to bind with the cortisol receptor and trigger similar effects. Glucocorticoids act primarily on carbohydrate and protein metabolism, and have anti-inflammatory effects. GO:0051384]

**response to nutrient** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a nutrient stimulus. GO:0007584]

**response to prostaglandin E** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a prostagladin E stimulus. GO:0034695]

**stem cell differentiation** [The process in which a relatively unspecialized cell acquires specialized features of a stem cell. A stem cell is a cell that retains the ability to divide and proliferate throughout life to provide progenitor cells that can differentiate into specialized cells. GO:0048863]

## MSigDB Signatures:

**ZHAN_MULTIPLE_MYELOMA_DN**: Genes most significantly down-regulated in multiple myeloma samples, compared to normal bone marrow plasma cells.

**XIE_LT_HSC_S1PR3_OE_UP**: Genes upregulated in long-term hematopoietic stem cells (CD34+,CD38_,CD45RA_,CD90+,CD49f+) upon overexpression of Sphingosine-1-Phosphate Receptor 3 (S1PR3)

**RIGGI_EWING_SARCOMA_PROGENITOR_UP**: Genes up-regulated in mesenchymal stem cells (MSC) engineered to express EWS-FLI1 [GeneID=2130;2321] fusion protein.

**REACTOME_HEMOSTASIS**: Hemostasis

**REACTOME_EXTRACELLULAR_MATRIX_ORGANIZATION**: Extracellular matrix organization

**TAKEDA_TARGETS_OF_NUP98_HOXA9_FUSION_10D_DN**: Genes down-regulated in CD34+ [GeneID=947] hematopoetic cells by expression of NUP98-HOXA9 fusion [GeneID=4928;3205] off a retroviral vector at 10 days after transduction.

**ABRAHAM_ALPC_VS_MULTIPLE_MYELOMA_UP**: Genes up-regulated in immunoglobulin light chain amyloidosis plasma cells (ALPC) compared to multiple myeloma (MM) cells.

**TAVOR_CEBPA_TARGETS_DN**: Genes down-regulated in KCL22 cells (chronic myelogenous leukemia, CML, with BCR-ABL1 [GeneID=613;25] fusion) by expression of CEBPA [GeneID=1050].

**LENAOUR_DENDRITIC_CELL_MATURATION_UP**: Genes up-regulated during in vitro maturation of CD14+ [GeneID=929] monocytes (day 0) into immature (day 7) and mature dendritic cells (day 14).

**NABA_MATRISOME_ASSOCIATED**: Ensemble of genes encoding ECM-associated proteins including ECM-affiliated proteins, ECM regulators and secreted factors

**REACTOME_PLATELET_ACTIVATION_SIGNALING_AND_AGGREGATION**: Platelet activation, signaling, and aggregation

**REACTOME_DEGRADATION_OF_THE_EXTRACELLULAR_MATRIX**: Degradation of the extracellular matrix

**BOQUEST_STEM_CELL_CULTURED_VS_FRESH_UP**: Genes up-regulated in cultured stromal stem cells from adipose tissue, compared to the freshly isolated cells.

**REACTOME_HDL_ASSEMBLY**: HDL assembly

**BENPORATH_CYCLING_GENES**: Genes showing cell-cycle stage-specific expression [PMID: 12058064].

**KANG_IMMORTALIZED_BY_TERT_DN**: Down-regulated genes in the signature of adipose stromal cells (ADSC) immortalized by forced expression of telomerase (TERT) [GeneID=7015].

**NABA_MATRISOME**: Ensemble of genes encoding extracellular matrix and extracellular matrix-associated proteins

**REACTOME_RESPONSE_TO_ELEVATED_PLATELET_CYTOSOLIC_CA2**: Response to elevated platelet cytosolic Ca2+

**LINDVALL_IMMORTALIZED_BY_TERT_UP**: Genes up-regulated in BJ cells (foreskin fibroblasts) immortalized by expression of TERT [GeneID=7015].

**PICCALUGA_ANGIOIMMUNOBLASTIC_LYMPHOMA_UP**: Up-regulated genes in angioimmunoblastic lymphoma (AILT) compared to normal T lymphocytes.

**REACTOME_FORMATION_OF_FIBRIN_CLOT_CLOTTING_CASCADE**: Formation of Fibrin Clot (Clotting Cascade)

**REACTOME_INTRINSIC_PATHWAY_OF_FIBRIN_CLOT_FORMATION**: Intrinsic Pathway of Fibrin Clot Formation

**KINSEY_TARGETS_OF_EWSR1_FLII_FUSION_DN**: Genes down-regulated in TC71 and EWS502 cells (Ewing's sarcoma) by EWSR1-FLI1 [GeneID=2130;2314] as inferred from RNAi knockdown of this fusion protein.

**RODWELL_AGING_KIDNEY_NO_BLOOD_UP**: Genes whose expression increases with age in normal kidney, excluding those with higher expression in blood.

**PID_IL6_7_PATHWAY**: IL6-mediated signaling events

**CERVERA_SDHB_TARGETS_2**: Genes present but differentially expressed between Hep3B cells (hepatocellular carcinoma, HCC) with RNAi knockdown of SDHB [GeneID=6390] and control cells.

**BENPORATH_PROLIFERATION**: Set 'Proliferation Cluster': genes defined in human breast tumor expression data.

**DANG_REGULATED_BY_MYC_DN**: Genes down-regulated by MYC [GeneID=4609], according to the MYC Target Gene Database.

**NABA_ECM_REGULATORS**: Genes encoding enzymes and their regulators involved in the remodeling of the extracellular matrix

**WANG_CISPLATIN_RESPONSE_AND_XPC_UP**: Genes up-regulated in fibroblasts with defective XPC [GeneID=7508] in response to cisplatin [PubChem=2767].

**ISSAEVA_MLL2_TARGETS**: Genes down-regulated in HeLa cells upon knockdown of MLL2 [GeneID=8085] by RNAi.

**HERNANDEZ_ABERRANT_MITOSIS_BY_DOCETACEL_2NM_DN**: Genes down-regulated in MDA-MB-231 cells (breast cancer, mutated TP53 [GeneID=7157]) undergoing aberrant mitosis and necrosis after treatment with 2 nM docetaxel [PubChem=148124].

**ZWANG_TRANSIENTLY_UP_BY_2ND_EGF_PULSE_ONLY**: Genes transiently induced only by the second pulse of EGF [GeneID =1950] in 184A1 cells (mammary epithelium).

**ABE_VEGFA_TARGETS**: Genes most profoundly induced in HUVEC cells (endothelium) by VEGFA [GeneID=7422].

**RODWELL_AGING_KIDNEY_UP**: Genes whose expression increases with age in normal kidney.

**TANG_SENESCENCE_TP53_TARGETS_UP**: Genes up-regulated in WI-38 cells (senescent primary fibroblasts) after inactivation of TP53 [GeneID=7157] by GSE56 polypeptide.

**YOSHIMURA_MAPK8_TARGETS_UP**: Genes up-regulated in vascular smooth muscle cells (VSMC) by MAPK8 (JNK1) [GeneID=5599].

**SMITH_TERT_TARGETS_DN**: Genes consistently down-regulated in HMEC cells (primary mammary
