
## **Pathways:**

**Aflatoxin activation and detoxification:** Aflatoxins are among the principal mycotoxins produced as secondary metabolites by the molds Aspergillus flavus and Aspergillus parasiticus that contaminate economically important food and feed crops (Wild & Turner 2002). Aflatoxin B1 (AFB1) is the most potent naturally occurring carcinogen known and is also an immunosuppressant. It is a potent hepatocarcinogenic agent in many species, and has been implicated in the etiology of human hepatocellular carcinoma. Poultry, especially turkeys, are extremely sensitive to the toxic and carcinogenic action of AFB1 present in animal feed, resulting in multi-million dollar losses to the industry. Discerning the biochemical and molecular mechanisms of this extreme sensitivity of poultry to AFB1 will help with the development of new strategies to increase aflatoxin resistance (Rawal et al. 2010, Diaz & Murcia 2011).

AFB1 has one major genotoxic metabolic fate, conversion to AFXBO, and several others that are less mutagenic but that can still be quite toxic. AFB1 can be oxidised to the toxic AFB1 exo 8,9 epoxide (AFXBO) product by several cytochrome P450 enzymes, especially P450 3A4 in the liver. This 8,9 epoxide can react with the N7 atom of a guanyl base of DNA to produce adducts by intercalating between DNA base pairs. The exo epoxide is unstable in solution, however, and can react spontaneously to form a diol that is no longer reactive with DNA. The diol product in turn undergoes base-catalysed rearrangement to a dialdehyde that can react with protein lysine residues. AFB1 can also be metabolised to products (AFQ1, AFM1, AFM1E) which have far less genotoxic consequences than AFB1. The main route of detoxification of AFB1 is conjugation of its reactive 8,9-epoxide form with glutathione (GSH). This reaction is carried out by trimeric glutathione transferases (GSTs), providing a chemoprotective mechanism against toxicity. Glutathione conjugates are usually excreted as mercapturic acids in urine (Guengerich et al. 1998, Hamid et al. 2013) [[https://reactome.org/PathwayBrowser/#/R-HSA-5423646](https://reactome.org/PathwayBrowser/#/R-HSA-5423646)].

**Metapathway biotransformation Phase I and II**: Biotransformation is the chemical modification (or modifications) made by an organism on a chemical compound. If this modification ends in mineral compounds like CO2, NH4+, or H2O, the biotransformation is called mineralisation. Biotransformation means chemical alteration of chemicals such as nutrients, amino acids, toxins, and drugs in the body. It is also needed to render non-polar compounds polar so that they are not reabsorbed in renal tubules and are excreted. Biotransformation of xenobiotics can dominate toxicokinetics and the metabolites may reach higher concentrations in organisms than their parent compounds [[https://www.wikipathways.org/pathways/WP702.html](https://www.wikipathways.org/pathways/WP702.html)].

## GO terms:

**aflatoxin catabolic process** [The chemical reactions and pathways resulting in the breakdown of aflatoxin, a fungal metabolite found as a contaminant in moldy grains that induces liver cancer. Aflatoxin induces a G to T transversion at codon 249 of p53, leading to its inactivation. Aflatoxin is converted to a chemical carcinogen by P450. GO:0046223]

**aflatoxin metabolic process** [The chemical reactions and pathways involving aflatoxin, a fungal metabolite found as a contaminant in moldy grains that induces liver cancer. Aflatoxin induces a G to T transversion at codon 249 of p53, leading to its inactivation. Aflatoxin is converted to a chemical carcinogen by P450. GO:0046222]

## MSigDB Signatures:

**WP_AFLATOXIN_B1_METABOLISM**: Aflatoxin B1 metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_AFLATOXIN_B1_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_AFLATOXIN_B1_METABOLISM.html)

**WP_METAPATHWAY_BIOTRANSFORMATION_PHASE_I_AND_II**: Metapathway biotransformation Phase I and II [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_METAPATHWAY_BIOTRANSFORMATION_PHASE_I_AND_II.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_METAPATHWAY_BIOTRANSFORMATION_PHASE_I_AND_II.html)

**CARRILLOREIXACH_HEPATOBLASTOMA_VS_NORMAL_DN**: Genes down-regulated in hepatoblastoma (HB) tumors as compared with non-tumor (NT) adjacent tissue. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CARRILLOREIXACH_HEPATOBLASTOMA_VS_NORMAL_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CARRILLOREIXACH_HEPATOBLASTOMA_VS_NORMAL_DN.html)

**CARRILLOREIXACH_HEPATOBLASTOMA_VS_NORMAL_HYPERMETHYLATED_AND_DN**: Genes hypermethylated and downexpressed in hepatoblastoma (HB) tumors as compared with non-tumor (NT) adjacent tissue assessed by Infinium MethylationEPIC 850K array and Human Transcriptome Array 2.0 & RNA-sequencing. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CARRILLOREIXACH_HEPATOBLASTOMA_VS_NORMAL_HYPERMETHYLATED_AND_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CARRILLOREIXACH_HEPATOBLASTOMA_VS_NORMAL_HYPERMETHYLATED_AND_DN.html)

**REACTOME_AFLATOXIN_ACTIVATION_AND_DETOXIFICATION**: Aflatoxin activation and detoxification [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_AFLATOXIN_ACTIVATION_AND_DETOXIFICATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_AFLATOXIN_ACTIVATION_AND_DETOXIFICATION.html)

**REACTOME_BIOLOGICAL_OXIDATIONS**: Biological oxidations [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_BIOLOGICAL_OXIDATIONS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_BIOLOGICAL_OXIDATIONS.html)

**IBRAHIM_NRF2_DOWN**: Genes down-regulated in HEK293T cells overexpressing FLAG-NRF2 [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/IBRAHIM_NRF2_DOWN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/IBRAHIM_NRF2_DOWN.html)
