
## **Pathways:**

-   **Ethanol oxidation**: Ethanol and related alcohols can be ingested as part of the diet and are formed by microorganisms in the intestinal tract. Ethanol oxidation to acetate occurs primarily in liver cells in a multistep process first described by Racker (1949). First, in the cytosol, ethanol is oxidized to acetaldehyde, with the formation of NADH. Second, in the mitochondrion, acetaldehyde is oxidized to acetate with the formation of NADH. Finally, acetate in the mitochondrion can be condensed with coenzyme A to form acetyl CoA. Polymorphisms in the enzymes catalyzing the first two steps are associated with variation in the efficiency of alcohol catabolism in human populations (Chen et al. 1999; Lange et al. 1976; Jornvall 1985). The molecular mechanism by which cytosolic acetaldehyde enters the mitochondrial matrix is not known (Lemasters 2007). Cytosolic enzymes capable of oxidizing acetaldehyde to acetate have also been identified and characterized in vitro (Inoue et al. 1979) so a purely cytosolic pathway for ethanol oxidation to acetate and conversion to acetyl-CoA can be annotated. The role of this pathway in vivo is unclear, though limited attempts to correlate deficiencies in the cytosolic enzyme with alcohol intolerance have yielded suggestive data (Yoshida et al. 1989). Additional peroxisomal and microsomal pathways for the oxidation of ethanol to acetaldehyde have been described; their physiological significance is unclear and they are not annotated here [[https://reactome.org/PathwayBrowser/#/R-HSA-71384](https://reactome.org/PathwayBrowser/#/R-HSA-71384)].
-   **Fructose catabolism**: Fructose occurs naturally in foods as a free monosaccharide and as a component of the disaccharide sucrose. It is also widely used as a sweetener. In the body, fructose catabolism occurs in the liver and to a lesser extent in the kidney and small intestine. In these tissues, it is converted to dihydroxyacetone phosphate and D-glyceraldehyde 3-phosphate, two intermediates in the glycolytic pathway, in a sequence of three reactions. It is phosphorylated to form fructose 1-phosphate, which is cleaved by aldolase to yield dihydroxyacetone phosphate and D-glyceraldehyde, and the latter compound is phosphorylated to yield D-glyceraldehyde 3-phosphate. Other pathways exist for the conversion of D-glyceraldehyde to intermediates of glycolysis, but these appear to play only a minor role in normal fructose metabolism (Sillero et al. 1969) [[https://reactome.org/PathwayBrowser/#/R-HSA-70350](https://reactome.org/PathwayBrowser/#/R-HSA-70350)].
-   **RA biosynthesis pathway**: The major activated retinoid, all-trans-retinoic acid (atRA) is produced by the dehydrogenation of all-trans-retinol (atROL) by members of the short chain dehydrogenase/reductase (SDR) and aldehyde dehydrogenase (RALDH) gene families (Das et al. 2014, Napoli 2012) [[https://reactome.org/PathwayBrowser/#/R-HSA-5365859](https://reactome.org/PathwayBrowser/#/R-HSA-5365859)].

## GO terms:

**9-cis-retinoic acid biosynthetic process** [The chemical reactions and pathways resulting in the formation of 9-cis-retinoic acid, a metabolically active vitamin A derivative. GO:0042904]

**9-cis-retinoic acid metabolic process** [The chemical reactions and pathways involving 9-cis-retinoic acid, a metabolically active vitamin A derivative. GO:0042905]

**apoptotic process** [A programmed cell death process which begins when a cell receives an internal (e.g. DNA damage) or external signal (e.g. an extracellular death ligand), and proceeds through a series of biochemical events (signaling pathway phase) which trigger an execution phase. The execution phase is the last step of an apoptotic process, and is typically characterized by rounding-up of the cell, retraction of pseudopodes, reduction of cellular volume (pyknosis), chromatin condensation, nuclear fragmentation (karyorrhexis), plasma membrane blebbing and fragmentation of the cell into apoptotic bodies. When the execution phase is completed, the cell has died. GO:0006915]

**cellular detoxification of aldehyde** [Any process carried out at the cellular level that reduces or removes the toxicity of an aldehyde. These may include transport of aldehydes away from sensitive areas and to compartments or complexes whose purpose is sequestration of the toxic substance. GO:0110095]

**embryonic eye morphogenesis** [The process occurring in the embryo by which the anatomical structures of the post-embryonic eye are generated and organized. GO:0048048]

**estrous cycle** [A type of ovulation cycle, which occurs in most mammalian therian females, where the endometrium is resorbed if pregnancy does not occur. GO:0044849]

**fructosamine catabolic process** [The chemical reactions and pathways resulting in the breakdown of fructosamine, a fructose molecule containing an amino group in place of a hydroxyl group. GO:0030392]

**fructose catabolic process** [The chemical reactions and pathways resulting in the breakdown of fructose, the ketohexose arabino-2-hexulose. GO:0006001]

**gamma-aminobutyric acid biosynthetic process** [The chemical reactions and pathways resulting in the formation of gamma-aminobutyric acid (GABA, 4-aminobutyrate), an amino acid which acts as a neurotransmitter in some organisms.|See also the biological process term 'neurotransmitter biosynthetic process ; GO:0042136'. GO:0009449]

**kidney development** [The process whose specific outcome is the progression of the kidney over time, from its formation to the mature structure. The kidney is an organ that filters the blood and/or excretes the end products of body metabolism in the form of urine. GO:0001822]

**liver development** [The process whose specific outcome is the progression of the liver over time, from its formation to the mature structure. The liver is an exocrine gland which secretes bile and functions in metabolism of protein and carbohydrate and fat, synthesizes substances involved in the clotting of the blood, synthesizes vitamin A, detoxifies poisonous substances, stores glycogen, and breaks down worn-out erythrocytes. GO:0001889]

**maintenance of lens transparency** [A homeostatic process in which the lens is maintained in a highly refractive, transparent state to allow for optimal focusing of light on the retina. GO:0036438]

**midgut development** [The process whose specific outcome is the progression of the midgut over time, from its formation to the mature structure. The midgut is the middle part of the alimentary canal from the stomach, or entrance of the bile duct, to, or including, the large intestine. GO:0007494]

**negative regulation of cold-induced thermogenesis** [Any process that stops, prevents, or reduces the rate of cold-induced thermogenesis. GO:0120163]

**optic cup morphogenesis involved in camera-type eye development** [The invagination of the optic vesicle to form two-walled indentations, the optic cups, that will go on to form the retina. This process begins with the optic vesicle becoming a two-walled structure and its subsequent shape changes. It does not include the fate commitment of cells to become the pigmented retina and the neural retina. An example of this process is found in Mus musculus. GO:0002072]

**positive regulation of apoptotic process** [Any process that activates or increases the frequency, rate or extent of cell death by apoptotic process.|This term should only be used when it is not possible to determine which phase or subtype of the apoptotic process is positively regulated by a gene product. Whenever detailed information is available, the more granular children terms should be used. GO:0043065]

**response to estradiol** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of stimulus by estradiol, a C18 steroid hormone hydroxylated at C3 and C17 that acts as a potent estrogen. GO:0032355]

**response to ethanol** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an ethanol stimulus. GO:0045471]

**response to organic cyclic compound** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an organic cyclic compound stimulus. GO:0014070]

**response to oxidative stress** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of oxidative stress, a state often resulting from exposure to high levels of reactive oxygen species, e.g. superoxide anions, hydrogen peroxide (H2O2), and hydroxyl radicals. GO:0006979]

**response to retinoic acid** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a retinoic acid stimulus. GO:0032526]

**response to xenobiotic stimulus** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a xenobiotic, a compound foreign to the organim exposed to it. It may be synthesized by another organism (like ampicilin) or it can be a synthetic chemical. GO:0009410]

**retinoic acid biosynthetic process** [The chemical reactions and pathways resulting in the biosynthesis of retinoic acid, one of the three components that makes up vitamin A. GO:0002138]

**retinoic acid metabolic process** [The chemical reactions and pathways involving retinoic acid, one of the three components that makes up vitamin A. GO:0042573]

**retinoid metabolic process** [The chemical reactions and pathways involving retinoids, any member of a class of isoprenoids that contain or are derived from four prenyl groups linked head-to-tail. Retinoids include retinol and retinal and structurally similar natural derivatives or synthetic compounds, but need not have vitamin A activity. GO:0001523]

**retinol metabolic process** [The chemical reactions and pathways involving retinol, one of the three compounds that makes up vitamin A. GO:0042572]

## MSigDB Signatures:

**KEGG_RETINOL_METABOLISM**: Retinol metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_RETINOL_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_RETINOL_METABOLISM.html)

**WP_AMINO_ACID_METABOLISM**: Amino acid metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_AMINO_ACID_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_AMINO_ACID_METABOLISM.html)

**REACTOME_ETHANOL_OXIDATION**: Ethanol oxidation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ETHANOL_OXIDATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ETHANOL_OXIDATION.html)

**REACTOME_METABOLISM_OF_CARBOHYDRATES**: Metabolism of carbohydrates [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_METABOLISM_OF_CARBOHYDRATES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_METABOLISM_OF_CARBOHYDRATES.html)

**WP_DISORDERS_OF_FRUCTOSE_METABOLISM**: Disorders of fructose metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_DISORDERS_OF_FRUCTOSE_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_DISORDERS_OF_FRUCTOSE_METABOLISM.html)

**REACTOME_FRUCTOSE_METABOLISM**: Fructose metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_FRUCTOSE_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_FRUCTOSE_METABOLISM.html)

**WP_FATTY_ACID_OMEGA_OXIDATION**: Fatty acid omega oxidation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FATTY_ACID_OMEGA_OXIDATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FATTY_ACID_OMEGA_OXIDATION.html)

**WP_FOLATE_ALCOHOL_AND_CANCER_PATHWAY_HYPOTHESES**: Folate alcohol and cancer pathway hypotheses [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FOLATE_ALCOHOL_AND_CANCER_PATHWAY_HYPOTHESES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FOLATE_ALCOHOL_AND_CANCER_PATHWAY_HYPOTHESES.html)

**REACTOME_BIOLOGICAL_OXIDATIONS**: Biological oxidations [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_BIOLOGICAL_OXIDATIONS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_BIOLOGICAL_OXIDATIONS.html)

**WP_VITAMIN_A_AND_CAROTENOID_METABOLISM**: Vitamin A and carotenoid metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_VITAMIN_A_AND_CAROTENOID_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_VITAMIN_A_AND_CAROTENOID_METABOLISM.html)

**WP_ETHANOL_EFFECTS_ON_HISTONE_MODIFICATIONS**: Ethanol effects on histone modifications [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ETHANOL_EFFECTS_ON_HISTONE_MODIFICATIONS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ETHANOL_EFFECTS_ON_HISTONE_MODIFICATIONS.html)

**REACTOME_RA_BIOSYNTHESIS_PATHWAY**: RA biosynthesis pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RA_BIOSYNTHESIS_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RA_BIOSYNTHESIS_PATHWAY.html)

**REACTOME_FRUCTOSE_CATABOLISM**: Fructose catabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_FRUCTOSE_CATABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_FRUCTOSE_CATABOLISM.html)

**REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS**: Signaling by Nuclear Receptors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS.html)

**REACTOME_SIGNALING_BY_RETINOIC_ACID**: Signaling by Retinoic Acid [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_RETINOIC_ACID.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_RETINOIC_ACID.html)

**REACTOME_PHASE_I_FUNCTIONALIZATION_OF_COMPOUNDS**: Phase I - Functionalization of compounds [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PHASE_I_FUNCTIONALIZATION_OF_COMPOUNDS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PHASE_I_FUNCTIONALIZATION_OF_COMPOUNDS.html)
