
## **Pathways:**

**Metabolism of lipids**: Lipids are hydrophobic but otherwise chemically diverse molecules that play a wide variety of roles in human biology. They include ketone bodies, fatty acids, triacylglycerols, phospholipids and sphingolipids, eicosanoids, cholesterol, bile salts, steroid hormones, and fat-soluble vitamins. They function as a major source of energy (fatty acids, triacylglycerols, and ketone bodies), are major constituents of cell membranes (cholesterol and phospholipids), play a major role in their own digestion and uptake (bile salts), and participate in numerous signaling and regulatory processes (steroid hormones, eicosanoids, phosphatidylinositols, and sphingolipids) (Vance & Vance 2008 - URL).

The central steroid in human biology is cholesterol, obtained from animal fats consumed in the diet or synthesized de novo from acetyl-coenzyme A. (Vegetable fats contain various sterols but no cholesterol.) Cholesterol is an essential constituent of lipid bilayer membranes and is the starting point for the biosyntheses of bile acids and salts, steroid hormones, and vitamin D. Bile acids and salts are mostly synthesized in the liver. They are released into the intestine and function as detergents to solubilize dietary fats. Steroid hormones are mostly synthesized in the adrenal gland and gonads. They regulate energy metabolism and stress responses (glucocorticoids), salt balance (mineralocorticoids), and sexual development and function (androgens and estrogens). At the same time, chronically elevated cholesterol levels in the body are associated with the formation of atherosclerotic lesions and hence increased risk of heart attacks and strokes. The human body lacks a mechanism for degrading excess cholesterol, although an appreciable amount is lost daily in the form of bile salts and acids that escape recycling [[https://reactome.org/PathwayBrowser/#/R-HSA-556833](https://reactome.org/PathwayBrowser/#/R-HSA-556833)].

**Regulation of lipid metabolism by PPARalpha**: Peroxisome proliferator-activated receptor alpha (PPAR-alpha) is the major regulator of fatty acid oxidation in the liver. PPARalpha is also the target of fibrate drugs used to treat abnormal plasma lipid levels. PPAR-alpha is a type II nuclear receptor (its subcellular location does not depend on ligand binding). PPAR-alpha forms heterodimers with Retinoid X receptor alpha (RXR-alpha), another type II nuclear receptor. PPAR-alpha is activated by binding fatty acid ligands, especially polyunsaturated fatty acids having 18-22 carbon groups and 2-6 double bonds. The PPAR-alpha:RXR-alpha heterodimer binds peroxisome proliferator receptor elements (PPREs) in and around target genes. Binding of fatty acids and synthetic ligands causes a conformational change in PPAR-alpha such that it releases the corepressors and binds coactivators (CBP-SRC-HAT complex, ASC complex, and TRAP-Mediator complex) which initiate transcription of the target genes. Target genes of PPAR-alpha participate in fatty acid transport, fatty acid oxidation, triglyceride clearance, lipoprotein production, and cholesterol homeostasis[[https://reactome.org/PathwayBrowser/#/R-HSA-400206](https://reactome.org/PathwayBrowser/#/R-HSA-400206)].

**PPARA activates gene expression**: The set of genes regulated by PPAR-alpha is not fully known in humans, however many examples have been found in mice. Genes directly activated by PPAR-alpha contain peroxisome proliferator receptor elements (PPREs) in their promoters and include:1) genes involved in fatty acid oxidation and ketogenesis (Acox1, Cyp4a, Acadm, Hmgcs2); 2) genes involved in fatty acid transport (Cd36, , Slc27a1, Fabp1, Cpt1a, Cpt2); 3) genes involved in producing fatty acids and very low density lipoproteins (Me1, Scd1); 4) genes encoding apolipoproteins (Apoa1, Apoa2, Apoa5); 5) genes involved in triglyceride clearance ( Angptl4); 6) genes involved in glycerol metabolism (Gpd1 in mouse); 7) genes involved in glucose metabolism (Pdk4); 8) genes involved in peroxisome proliferation (Pex11a); 9) genes involved in lipid storage (Plin, Adfp). Many other genes are known to be regulated by PPAR-alpha but whether their regulation is direct or indirect remains to be found. These genes include: ACACA, FAS, SREBP1, FADS1, DGAT1, ABCA1, PLTP, ABCB4, UGT2B4, SULT2A1, Pnpla2, Acsl1, Slc27a4, many Acot genes, and others (reviewed in Rakhshandehroo et al. 2010) [[https://reactome.org/PathwayBrowser/#/R-HSA-1989781](https://reactome.org/PathwayBrowser/#/R-HSA-1989781)].

## GO terms:

**cardiac muscle tissue morphogenesis** [The process in which the anatomical structures of cardiac muscle tissue are generated and organized. GO:0055008]

**cellular response to hypoxia** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating lowered oxygen tension. Hypoxia, defined as a decline in O2 levels below normoxic levels of 20.8 - 20.95%, results in metabolic adaptation at both the cellular and organismal level.|Note that this term should not be confused with 'cellular response to anoxia ; GO:0071454'. Note that in laboratory studies, hypoxia is typically studied at O2 concentrations ranging from 0.1 - 5%. GO:0071456]

**cellular response to interleukin-1** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interleukin-1 stimulus. GO:0071347]

**cellular response to lipopolysaccharide** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lipopolysaccharide stimulus; lipopolysaccharide is a major component of the cell wall of gram-negative bacteria. GO:0071222]

**cellular response to mechanical stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a mechanical stimulus. GO:0071260]

**cellular response to organic cyclic compound** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an organic cyclic compound stimulus. GO:0071407]

**cellular response to transforming growth factor beta stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a transforming growth factor beta stimulus. GO:0071560]

**cellular response to tumor necrosis factor** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a tumor necrosis factor stimulus. GO:0071356]

**cellular response to xenobiotic stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a xenobiotic, a compound foreign to the organism exposed to it. It may be synthesized by another organism (like ampicilin) or it can be a synthetic chemical. GO:0071466]

**negative regulation of DNA biosynthetic process** [Any process that stops, prevents or reduces the frequency, rate or extent of DNA biosynthetic process. GO:2000279]

**negative regulation of DNA-templated transcription** [Any process that stops, prevents, or reduces the frequency, rate or extent of cellular DNA-templated transcription. GO:0045892]

**negative regulation of transcription by RNA polymerase II** [Any process that stops, prevents, or reduces the frequency, rate or extent of transcription mediated by RNA polymerase II. GO:0000122]

**positive regulation of DNA damage response, signal transduction by p53 class mediator** [Any process that activates, maintains or increases the rate of the cascade of processes induced by the cell cycle regulator phosphoprotein p53, or an equivalent protein, in response to the detection of DNA damage. GO:0043517]

**positive regulation of DNA-templated transcription** [Any process that activates or increases the frequency, rate or extent of cellular DNA-templated transcription. GO:0045893]

**positive regulation of apoptotic process** [Any process that activates or increases the frequency, rate or extent of cell death by apoptotic process.|This term should only be used when it is not possible to determine which phase or subtype of the apoptotic process is positively regulated by a gene product. Whenever detailed information is available, the more granular children terms should be used. GO:0043065]

**positive regulation of neuron projection development** [Any process that increases the rate, frequency or extent of neuron projection development. Neuron projection development is the process whose specific outcome is the progression of a neuron projection over time, from its formation to the mature structure. A neuron projection is any process extending from a neural cell, such as axons or dendrites (collectively called neurites). GO:0010976]

**positive regulation of protein secretion** [Any process that activates or increases the frequency, rate or extent of the controlled release of a protein from a cell. GO:0050714]

**protein kinase C signaling** [A series of reactions, mediated by the intracellular serine/threonine kinase protein kinase C, which occurs as a result of a single trigger reaction or compound. GO:0070528]

**regulation of transcription by RNA polymerase II** [Any process that modulates the frequency, rate or extent of transcription mediated by RNA polymerase II. GO:0006357]

**response to muscle stretch** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a myofibril being extended beyond its slack length. GO:0035994]

**skeletal muscle cell differentiation** [The process in which a relatively unspecialized cell acquires specialized features of a skeletal muscle cell, a somatic cell located in skeletal muscle. GO:0035914]

## MSigDB Signatures:

**WP_HYPERTROPHY_MODEL**: Hypertrophy model [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_HYPERTROPHY_MODEL.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_HYPERTROPHY_MODEL.html)

**WP_CARDIOMYOCYTE_SIGNALING_PATHWAYS_CONVERGING_ON_TITIN**: Cardiomyocyte signaling pathways converging on Titin [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_CARDIOMYOCYTE_SIGNALING_PATHWAYS_CONVERGING_ON_TITIN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_CARDIOMYOCYTE_SIGNALING_PATHWAYS_CONVERGING_ON_TITIN.html)

**WP_NUCLEAR_RECEPTORS_META_PATHWAY**: Nuclear receptors meta pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NUCLEAR_RECEPTORS_META_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NUCLEAR_RECEPTORS_META_PATHWAY.html)

**MA_RAT_AGING_UP**: Genes up-regulated across multiple cell types from nine tissues during rat aging. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MA_RAT_AGING_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MA_RAT_AGING_UP.html)

**REACTOME_METABOLISM_OF_LIPIDS**: Metabolism of lipids [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_METABOLISM_OF_LIPIDS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_METABOLISM_OF_LIPIDS.html)

**WP_GLUCOCORTICOID_RECEPTOR_PATHWAY**: Glucocorticoid receptor pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_GLUCOCORTICOID_RECEPTOR_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_GLUCOCORTICOID_RECEPTOR_PATHWAY.html)
