
## **Pathways:**

**Dissolution of Fibrin Clot:** The crosslinked fibrin multimers in a clot are broken down to soluble polypeptides by plasmin, a serine protease. Plasmin can be generated from its inactive precursor plasminogen and recruited to the site of a fibrin clot in two ways, by interaction with tissue plasminogen activator at the surface of a fibrin clot, and by interaction with urokinase plasminogen activator at a cell surface. The first mechanism appears to be the major one responsible for the dissolution of clots within blood vessels. The second, although capable of mediating clot dissolution, may normally play a major role in tissue remodeling, cell migration, and inflammation (Chapman 1997; Lijnen 2001).

Clot dissolution is regulated in two ways. First, efficient plasmin activation and fibrinolysis occur only in complexes formed at the clot surface or on a cell membrane - proteins free in the blood are inefficient catalysts and are rapidly inactivated. Second, both plasminogen activators and plasmin itself are inactivated by specific serpins, proteins that bind to serine proteases to form stable, enzymatically inactive complexes (Kohler and Grant 2000).

These events are outlined in the drawing: black arrows connect the substrates (inputs) and products (outputs) of individual reactions, and blue lines connect output activated enzymes to the other reactions that they catalyze [[https://reactome.org/PathwayBrowser/#/R-HSA-75205](https://reactome.org/PathwayBrowser/#/R-HSA-75205)].

**Gene and protein expression by JAK-STAT signaling after Interleukin-12 stimulation:** Experiments using human cord blood CD4(+) T cells show 22 protein spots and 20 protein spots, upregulated and downregulated proteins respectively, following Interleukin-12 stimulation (Rosengren [et.al](http://et.al), 2005). The identified upregulated proteins are: BOLA2, PSME2, MTAP, CA1, GSTA2, RALA, CNN2, CFL1, TCP1, HNRNPDL, MIF, AIP, SOD1, PPIA and PDCD4. And the identified downregulated proteins are: ANXA2, RPLP0, CAPZA1, SOD2, SNRPA1, LMNB1, LCP1, HSPA9, SERPINB2, HNRNPF, TALDO1, PAK2, TCP1, HNRNPA2B1, MSN, PITPNA, ARF1, SOD2, ANXA2, CDC42, RAP1B and GSTO1 [[https://reactome.org/PathwayBrowser/#/R-HSA-8950505](https://reactome.org/PathwayBrowser/#/R-HSA-8950505)].

**Neutrophil degranulation:** Neutrophils are the most abundant leukocytes (white blood cells), indispensable in defending the body against invading microorganisms. In response to infection, neutrophils leave the circulation and migrate towards the inflammatory focus. They contain several subsets of granules that are mobilized to fuse with the cell membrane or phagosomal membrane, resulting in the exocytosis or exposure of membrane proteins. Traditionally, neutrophil granule constituents are described as antimicrobial or proteolytic, but granules also introduce membrane proteins to the cell surface, changing how the neutrophil responds to its environment (Borregaard et al. 2007). Primed neutrophils actively secrete cytokines and other inflammatory mediators and can present antigens via MHC II, stimulating T-cells (Wright et al. 2010).

Granules form during neutrophil differentiation. Granule subtypes can be distinguished by their content but overlap in structure and composition. The differences are believed to be a consequence of changing protein expression and differential timing of granule formation during the terminal processes of neutrophil differentiation, rather than sorting (Le Cabec et al. 1996).

The classical granule subsets are Azurophil or primary granules (AG), secondary granules (SG) and gelatinase granules (GG). Neutrophils also contain exocytosable storage cell organelles, storage vesicles (SV), formed by endocytosis they contain many cell-surface markers and extracellular, plasma proteins (Borregaard et al. 1992). Ficolin-1-rich granules (FG) are like GGs highly exocytosable but gelatinase-poor (Rorvig et al. 2009) [[https://reactome.org/PathwayBrowser/#/R-HSA-6798695](https://reactome.org/PathwayBrowser/#/R-HSA-6798695)].

**Smooth Muscle Contraction:** Layers of smooth muscle cells can be found in the walls of numerous organs and tissues within the body. Smooth muscle tissue lacks the striated banding pattern characteristic of skeletal and cardiac muscle. Smooth muscle is triggered to contract by the autonomic nervous system, hormones, autocrine/paracrine agents, local chemical signals, and changes in load or length.

Actin:myosin cross bridging is used to develop force with the influx of calcium ions (Ca2+) initiating contraction. Two separate protein pathways, both triggered by calcium influx contribute to contraction, a calmodulin driven kinase pathway, and a caldesmon driven pathway.

Recent evidence suggests that actin, myosin, and intermediate filaments may be far more volatile then previously suspected, and that changes in these cytoskeletal elements along with alterations of the focal adhesions that anchor these proteins may contribute to the contractile cycle.

Contraction in smooth muscle generally uses a variant of the same sliding filament model found in striated muscle, except in smooth muscle the actin and myosin filaments are anchored to focal adhesions, and dense bodies, spread over the surface of the smooth muscle cell. When actin and myosin move across one another focal adhesions are drawn towards dense bodies, effectively squeezing the cell into a smaller conformation. The sliding is triggered by calcium:caldesmon binding, caldesmon acting in an analogous fashion to troponin in striated muscle. Phosphorylation of myosin light chains also is involved in the initiation of an effective contraction [[https://reactome.org/PathwayBrowser/#/R-HSA-445355](https://reactome.org/PathwayBrowser/#/R-HSA-445355)].

## GO terms:

**angiogenesis** [Blood vessel formation when new vessels emerge from the proliferation of pre-existing blood vessels. GO:0001525]

**body fluid secretion** [The controlled release of a fluid by a cell or tissue in an animal. GO:0007589]

**calcium ion transmembrane transport** [A process in which a calcium ion is transported from one side of a membrane to the other by means of some agent such as a transporter or pore.|Note that this term is not intended for use in annotating lateral movement within membranes. GO:0070588]

**cell adhesion** [The attachment of a cell, either to another cell or to an underlying substrate such as the extracellular matrix, via cell adhesion molecules. GO:0007155]

**cell-matrix adhesion** [The binding of a cell to the extracellular matrix via adhesion molecules. GO:0007160]

**collagen fibril organization** [Any process that determines the size and arrangement of collagen fibrils within an extracellular matrix. GO:0030199]

**epithelial cell apoptotic process** [Any apoptotic process in an epithelial cell. GO:1904019]

**fibrinolysis** [A process that solubilizes fibrin in the bloodstream of a multicellular organism, chiefly by the proteolytic action of plasmin. GO:0042730]

**lung development** [The process whose specific outcome is the progression of the lung over time, from its formation to the mature structure. In all air-breathing vertebrates the lungs are developed from the ventral wall of the oesophagus as a pouch which divides into two sacs. In amphibians and many reptiles the lungs retain very nearly this primitive sac-like character, but in the higher forms the connection with the esophagus becomes elongated into the windpipe and the inner walls of the sacs become more and more divided, until, in the mammals, the air spaces become minutely divided into tubes ending in small air cells, in the walls of which the blood circulates in a fine network of capillaries. In mammals the lungs are more or less divided into lobes, and each lung occupies a separate cavity in the thorax. GO:0030324]

**mRNA transcription by RNA polymerase II** [The cellular synthesis of messenger RNA (mRNA) from a DNA template by RNA polymerase II, originating at an RNA polymerase II promoter. GO:0042789]

**membrane raft assembly** [The aggregation, arrangement and bonding together of a set of components to form a membrane raft, a small (10-200 nm), heterogeneous, highly dynamic, sterol- and sphingolipid-enriched membrane domains that compartmentalizes cellular processes. GO:0001765]

**negative regulation of low-density lipoprotein particle receptor catabolic process** [Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways resulting in the breakdown of low-density lipoprotein receptors. GO:0032804]

**negative regulation of receptor internalization** [Any process that stops, prevents, or reduces the frequency, rate or extent of receptor internalization. GO:0002091]

**osteoclast development** [The process whose specific outcome is the progression of a osteoclast from its formation to the mature structure. Cell development does not include the steps involved in committing a cell to a specific fate. An osteoclast is a specialized phagocytic cell associated with the absorption and removal of the mineralized matrix of bone tissue. GO:0036035]

**positive regulation by host of viral process** [A process in which a host organism activates or increases the frequency, rate or extent of the release of a process being mediated by a virus with which it is infected. GO:0044794]

**positive regulation of fibroblast proliferation** [Any process that activates or increases the frequency, rate or extent of multiplication or reproduction of fibroblast cells. GO:0048146]

**positive regulation of low-density lipoprotein particle clearance** [Any process that activates or increases the frequency, rate or extent of low-density lipoprotein particle clearance. GO:1905581]

**positive regulation of plasminogen activation** [Any process that increases the rate, frequency or extent of plasminogen activation. Plasminogen activation is the process in which plasminogen is processed to plasmin. GO:0010756]

**positive regulation of protein phosphorylation** [Any process that activates or increases the frequency, rate or extent of addition of phosphate groups to amino acids within a protein. GO:0001934]

**positive regulation of receptor recycling** [Any process that activates or increases the frequency, rate or extent of receptor recycling. GO:0001921]

**positive regulation of receptor-mediated endocytosis involved in cholesterol transport** [Any process that activates or increases the frequency, rate or extent of receptor-mediated endocytosis involved in cholesterol transport. GO:1905602]

**positive regulation of transcription by RNA polymerase II** [Any process that activates or increases the frequency, rate or extent of transcription from an RNA polymerase II promoter. GO:0045944]

**positive regulation of vacuole organization** [Any process that activates or increases the frequency, rate or extent of a process involved in the formation, arrangement of constituent parts, or disassembly of a vacuole. GO:0044090]

**positive regulation of vesicle fusion** [Any process that activates or increases the frequency, rate or extent of vesicle fusion. GO:0031340]

**positive regulation of viral life cycle** [Any process that activates or increases the frequency, rate or extent of viral life cycle. GO:1903902]

**protein localization to plasma membrane** [A process in which a protein is transported to, or maintained in, a specific location in the plasma membrane. GO:0072659]

**regulation of fibrinolysis** [Any process that modulates the frequency, rate or extent of fibrinolysis, an ongoing process that solubilizes fibrin, resulting in the removal of small blood clots. GO:0051917]

**regulation of neurogenesis** [Any process that modulates the frequency, rate or extent of neurogenesis, the generation of cells in the nervous system. GO:0050767]

**response to activity** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an activity stimulus. GO:0014823]

**response to thyroid hormone** [A change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a thyroid hormone stimulus. GO:0097066]

**vesicle budding from membrane** [The evagination of a membrane, resulting in formation of a vesicle. GO:0006900]

## MSigDB Signatures:

**JIANG_TIP30_TARGETS_UP**: Up-regulated genes in HepG2 cells (liver cancer) overexpressing an oncogenic variant of tumor suppressor TIP30 [GeneID=10553] compared to its wild type form. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JIANG_TIP30_TARGETS_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JIANG_TIP30_TARGETS_UP.html)

**PATIL_LIVER_CANCER**: Genes up-regulated in hepatocellular carcinoma (HCC) compared to normal liver samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PATIL_LIVER_CANCER.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PATIL_LIVER_CANCER.html)

**REACTOME_HEMOSTASIS**: Hemostasis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HEMOSTASIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HEMOSTASIS.html)

**LIAO_METASTASIS**: Genes up-regulated in the samples with intrahepatic metastatic hepatocellular carcinoma (HCC) vs primary HCC. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LIAO_METASTASIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LIAO_METASTASIS.html)

**HEBERT_MATRISOME_TNBC_BONE_BRAIN_LIVER_LUNG_METASTASTASES**: Matrisome proteins found in significantly higher abundance in TNBC brain, bone, liver and lung metastatases compared to normal samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HEBERT_MATRISOME_TNBC_BONE_BRAIN_LIVER_LUNG_METASTASTASES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HEBERT_MATRISOME_TNBC_BONE_BRAIN_LIVER_LUNG_METASTASTASES.html)

**HSIAO_HOUSEKEEPING_GENES**: Housekeeping genes identified as expressed across 19 normal tissues. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HSIAO_HOUSEKEEPING_GENES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HSIAO_HOUSEKEEPING_GENES.html)

**WP_METABOLIC_PATHWAY_OF_LDL_HDL_AND_TG_INCLUDING_DISEASES**: Metabolic pathway of LDL HDL and TG including diseases [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_METABOLIC_PATHWAY_OF_LDL_HDL_AND_TG_INCLUDING_DISEASES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_METABOLIC_PATHWAY_OF_LDL_HDL_AND_TG_INCLUDING_DISEASES.html)

**REACTOME_INNATE_IMMUNE_SYSTEM**: Innate Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html)

**REACTOME_MUSCLE_CONTRACTION**: Muscle contraction [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_MUSCLE_CONTRACTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_MUSCLE_CONTRACTION.html)

**RODWELL_AGING_KIDNEY_NO_BLOOD_UP**: Genes whose expression increases with age in normal kidney, excluding those with higher expression in blood. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RODWELL_AGING_KIDNEY_NO_BLOOD_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RODWELL_AGING_KIDNEY_NO_BLOOD_UP.html)

**WP_PROSTAGLANDIN_SYNTHESIS_AND_REGULATION**: Prostaglandin synthesis and regulation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PROSTAGLANDIN_SYNTHESIS_AND_REGULATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PROSTAGLANDIN_SYNTHESIS_AND_REGULATION.html)

**REACTOME_NEUTROPHIL_DEGRANULATION**: Neutrophil degranulation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NEUTROPHIL_DEGRANULATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NEUTROPHIL_DEGRANULATION.html)

**KEGG_MEDICUS_PATHOGEN_SALMONELLA_SOPB_TO_ANXA2_S100A10_REGULATED_ACTIN_CYTOSKELETON**: Pathway Definition from KEGG: (SopB,SopE) -> (ANXA2+S100A10) == AHNAK == (ACTB,ACTG1) [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_PATHOGEN_SALMONELLA_SOPB_TO_ANXA2_S100A10_REGULATED_ACTIN_CYTOSKELETON.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_PATHOGEN_SALMONELLA_SOPB_TO_ANXA2_S100A10_REGULATED_ACTIN_CYTOSKELETON.html)

**HEBERT_MATRISOME_TNBC_BONE_BRAIN_LUNG_LIVER_METASTASTASES_TUMOR_CELL_DERIVED**: Tumor cell-derived matrisome proteins found in significantly higher abundance in TNBC brain, bone, liver and lung metastatases compared to normal samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HEBERT_MATRISOME_TNBC_BONE_BRAIN_LUNG_LIVER_METASTASTASES_TUMOR_CELL_DERIVED.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HEBERT_MATRISOME_TNBC_BONE_BRAIN_LUNG_LIVER_METASTASTASES_TUMOR_CELL_DERIVED.html)

**WINTER_HYPOXIA_METAGENE**: Genes regulated by hypoxia, based on literature searches. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WINTER_HYPOXIA_METAGENE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WINTER_HYPOXIA_METAGENE.html)

**RODWELL_AGING_KIDNEY_UP**: Genes whose expression increases with age in normal kidney. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RODWELL_AGING_KIDNEY_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RODWELL_AGING_KIDNEY_UP.html)

**REACTOME_DISSOLUTION_OF_FIBRIN_CLOT**: Dissolution of Fibrin Clot [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DISSOLUTION_OF_FIBRIN_CLOT.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DISSOLUTION_OF_FIBRIN_CLOT.html)

**BROWNE_HCMV_INFECTION_2HR_DN**: Genes down-regulated in primary fibroblast cell culture point after infection with HCMV (AD169 strain) at 2 h time point that were not down-regulated at the previous time point, 1 h. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_2HR_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_2HR_DN.html)

**REACTOME_SMOOTH_MUSCLE_CONTRACTION**: Smooth Muscle Contraction [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SMOOTH_MUSCLE_CONTRACTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SMOOTH_MUSCLE_CONTRACTION.html)

**MUELLER_PLURINET**: Genes constituting the PluriNet protein-protein network shared by the pluripotent cells (embryonic stem cells, embryonical carcinomas and induced pluripotent cells). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MUELLER_PLURINET.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MUELLER_PLURINET.html)

**BROWNE_HCMV_INFECTION_48HR_DN**: Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 48 h time point that were not down-regulated at the previous time point, 24 h. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_48HR_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_48HR_DN.html)

**BROWNE_HCMV_INFECTION_14HR_DN**: Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 14 h time point that were not down-regulated at the previous time point, 12 h. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_14HR_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_14HR_DN.html)

**ZHAN_VARIABLE_EARLY_DIFFERENTIATION_GENES_UP**: The vEDG up-regulated set: most variable early differentiation genes (EDG) with similar expression patterns in tonsil B lymphocytes (TBC) and multiple myeloma (MM) cells compared to the plasma cells from tonsil (TPC) and bone marrow (BPC). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZHAN_VARIABLE_EARLY_DIFFERENTIATION_GENES_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZHAN_VARIABLE_EARLY_DIFFERENTIATION_GENES_UP.html)

**BROWNE_HCMV_INFECTION_20HR_DN**: Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 20 h time point that were not down-regulated at the previous time point, 18 h. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_20HR_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_20HR_DN.html)

**BROWNE_HCMV_INFECTION_18HR_DN**: Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 18 h time point that were not down-regulated at the previous time point, 16 h. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_18HR_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_18HR_DN.html)

**REACTOME_GENE_AND_PROTEIN_EXPRESSION_BY_JAK_STAT_SIGNALING_AFTER_INTERLEUKIN_12_STIMULATION**: Gene and protein expression by JAK-STAT signaling after Interleukin-12 stimulation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_GENE_AND_PROTEIN_EXPRESSION_BY_JAK_STAT_SIGNALING_AFTER_INTERLEUKIN_12_STIMULATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_GENE_AND_PROTEIN_EXPRESSION_BY_JAK_STAT_SIGNALING_AFTER_INTERLEUKIN_12_STIMULATION.html)

**REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM**: Cytokine Signaling in Immune system [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM.html)

**DODD_NASOPHARYNGEAL_CARCINOMA_UP**: Genes up-regulated in nasopharyngeal carcinoma (NPC) compared to the normal tissue. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DODD_NASOPHARYNGEAL_CARCINOMA_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DODD_NASOPHARYNGEAL_CARCINOMA_UP.html)

**REACTOME_SIGNALING_BY_INTERLEUKINS**: Signaling by Interleukins [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_INTERLEUKINS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_INTERLEUKINS.html)

**NABA_MATRISOME_ASSOCIATED**: Ensemble of genes encoding ECM-associated proteins including ECM-affilaited proteins, ECM regulators and secreted factors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_ASSOCIATED.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_ASSOCIATED.html)

**REACTOME_INTERLEUKIN_12_FAMILY_SIGNALING**: Interleukin-12 family signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INTERLEUKIN_12_FAMILY_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INTERLEUKIN_12_FAMILY_SIGNALING.html)

**JINESH_BLEBBISHIELD_TRANSFORMED_STEM_CELL_SPHERES_UP**: Genes up-regulated in transformed spheres compared to blebbishields from RT4 cells [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JINESH_BLEBBISHIELD_TRANSFORMED_STEM_CELL_SPHERES_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JINESH_BLEBBISHIELD_TRANSFORMED_STEM_CELL_SPHERES_UP.html)

**RUTELLA_RESPONSE_TO_HGF_VS_CSF2RB_AND_IL4_DN**: Genes down-regulated in peripheral blood mononucleocytes by HGF [GeneID=3082] compared to those regulated by CSF2RB (GM-CSF) and IL4 [GeneID=1437;3565]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_VS_CSF2RB_AND_IL4_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_VS_CSF2RB_AND_IL4_DN.html)

**DI_MARTINO_MATRISOME_HIGHLY_PROLIFERATIVE_HNSCC**: Matrisome proteins detected exclusively in highly proliferative head-and-neck squamous cell carcinoma human-to-mouse xenografts (T-Hep3) compared to dormant head-and-neck squamous cell carcinoma human-to-mouse xenografts (D-Hep3). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DI_MARTINO_MATRISOME_HIGHLY_PROLIFERATIVE_HNSCC.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DI_MARTINO_MATRISOME_HIGHLY_PROLIFERATIVE_HNSCC.html)

**REACTOME_INTERLEUKIN_12_SIGNALING**: Interleukin-12 signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INTERLEUKIN_12_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INTERLEUKIN_12_SIGNALING.html)

**CONCANNON_APOPTOSIS_BY_EPOXOMICIN_UP**: Genes up-regulated in SH-SY5Y cells (neuroblastoma) after treatment with epoxomicin [PubChem=3035402], a protease inhibitor causing apoptosis. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CONCANNON_APOPTOSIS_BY_EPOXOMICIN_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CONCANNON_APOPTOSIS_BY_EPOXOMICIN_UP.html)

**GRABARCZYK_BCL11B_TARGETS_UP**: Genes up-regulated in Jurkat cells (transformed T lymphocytes) after knockdown of BCL11B [GeneID=64919] by RNAi. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/GRABARCZYK_BCL11B_TARGETS_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/GRABARCZYK_BCL11B_TARGETS_UP.html)

**NUTT_GBM_VS_AO_GLIOMA_UP**: Top 50 marker genes for glioblastoma multiforme (GBM), a class of high grade glioma. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NUTT_GBM_VS_AO_GLIOMA_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NUTT_GBM_VS_AO_GLIOMA_UP.html)

**CHICAS_RB1_TARGETS_CONFLUENT**: Genes up-regulated in confluent IMR90 cells (fibroblast) after knockdown of RB1 [GeneID=5925] by RNAi. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHICAS_RB1_TARGETS_CONFLUENT.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHICAS_RB1_TARGETS_CONFLUENT.html)

**RUTELLA_RESPONSE_TO_HGF_UP**: Genes up-regulated in peripheral blood monocytes by HGF [GeneID=3082]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_UP.html)

**KOINUMA_TARGETS_OF_SMAD2_OR_SMAD3**: Genes with promoters occupied by SMAD2 or SMAD3 [GeneID=4087, 4088] in HaCaT cells (keratinocyte) according to a ChIP-chip analysis. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KOINUMA_TARGETS_OF_SMAD2_OR_SMAD3.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KOINUMA_TARGETS_OF_SMAD2_OR_SMAD3.html)

**DI_MARTINO_MATRISOME_HIGHLY_PROLIFERATIVE_HNSCC_TUMOR_CELL_DERIVED**: Tumor-cell-derived matrisome proteins detected exclusively in highly proliferative head-and-neck squamous cell carcinoma human-to-mouse xenografts (T-Hep3) compared to dormant head-and-neck squamous cell carcinoma human-to-mouse xenografts (D-Hep3). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DI_MARTINO_MATRISOME_HIGHLY_PROLIFERATIVE_HNSCC_TUMOR_CELL_DERIVED.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DI_MARTINO_MATRISOME_HIGHLY_PROLIFERATIVE_HNSCC_TUMOR_CELL_DERIVED.html)

**WP_GASTRIN_SIGNALING_PATHWAY**: Gastrin signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_GASTRIN_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_GASTRIN_SIGNALING_PATHWAY.html)

**NGO_MALIGNANT_GLIOMA_1P_LOH**: Proteins with reduced expression in mulignant glioma cell line (A172) which bears loss of heterozygosity (LOH) in the 1p region. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NGO_MALIGNANT_GLIOMA_1P_LOH.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NGO_MALIGNANT_GLIOMA_1P_LOH.html)
