
## **Pathways:**

-   **Amyloid fiber formation**: Amyloid is a term used to describe deposits of fibrillar proteins, typically extracellular. The abnormal accumulation of amyloid, amyloidosis, is a term associated with tissue damage caused by amyloid deposition, seen in numerous diseases including neurodegenerative diseases such as Alzheimer's, Parkinson's and Huntington's. Amyloid deposits consist predominantly of amyloid fibrils, rigid, non-branching structures that form ordered assemblies, characteristically with a cross beta-sheet structure where the sheets run parallel to the direction of the fibril (Sawaya et al. 2007). Often the fibril has a left-handed twist (Nelson & Eisenberg 2006). At least 27 human proteins form amyloid fibrils (Sipe et al. 2010). Many of these proteins have non-pathological functions; the trigger that leads to abnormal aggregations differs between proteins and is not well understood but in many cases the peptides are abnormal fragments or mutant forms arising from polymorphisms, suggesting that the initial event may be aggregation of misfolded or unfolded peptides. Early studies of Amyloid-beta assembly led to a widely accepted model that assembly was a nucleation-dependent polymerization reaction (Teplow 1998) but it is now understood to be more complex, with multiple 'off-pathway' events leading to a variety of oligomeric structures in addition to fibrils (Roychaudhuri et al. 2008), though it is unclear whether these intermediate steps are required in vivo. An increasing body of evidence suggests that these oligomeric forms are primarily responsible for the neurotoxic effects of Amyloid-beta (Roychaudhuri et al. 2008), alpha-synuclein (Winner et al. 2011) and tau (Dance & Strobel 2009, Meraz-Rios et al. 2010). Amyloid oligomers are believed to have a common structural motif that is independent of the protein involved and not present in fibrils (Kayed et al. 2003). Conformation dependent, aggregation specific antibodies suggest that there are 3 general classes of amyloid oligomer structures (Glabe 2009) including annular structures which may be responsible for the widely reported membrane permeabilization effect of amyloid oligomers. Toxicity of amyloid oligomers preceeds the appearance of plaques in mouse models (Ferretti et al. 2011). Fibrils are often associated with other molecules, notably heparan sulfate proteoglycans and Serum Amyloid P-component, which are universally associated and seem to stabilize fibrils, possibly by protecting them from degradation [[https://reactome.org/PathwayBrowser/#/R-HSA-977225](https://reactome.org/PathwayBrowser/#/R-HSA-977225)].
-   **Metabolism of fat-soluble vitamins**: Vitamins A, D, E, and K are classified as fat-soluble. Metabolic pathways by which dietary precursors of vitamins A (Harrison 2005) and K (Shearer et al. 2012) are converted to active forms are annotated here. The conversion of 7-dehydrocholesterol is converted to active vitamin D (Dusso et al. 2005) is annotated as part of metabolism of steroids. (Vitamin E (tocopherol) is available in active form from the diet.) [[https://reactome.org/PathwayBrowser/#/R-HSA-6806667](https://reactome.org/PathwayBrowser/#/R-HSA-6806667)].
-   **Chylomicron assembly**: Chylomicrons transport triacylglycerol, phospholipid, and cholesterol derived from dietary lipid from the small intestine to other tissues of the body. Each chylomicron assembles around a single molecule of apolipoprotein B-48 (Phillips et al. 1997) which at the time the particle leaves the intestine and enters the lymphatic circulation is complexed with >200,000 molecules of triacylglycerol (TG), ~35,000 of phospholipid, ~11,000 of cholesterol ester, ~8,000 of free cholesterol, ~60 copies of apolipoprotein A-I, ~15 copies of apolipoprotein A-IV, and copies of apolipoprotein A-II (Bhattacharya and Redgrave 1981) [[https://reactome.org/PathwayBrowser/#/R-HSA-8963888](https://reactome.org/PathwayBrowser/#/R-HSA-8963888)].
-   **Chylomicron remodeling**: As chylomicrons circulate in the body, they acquire molecules of apolipoproteins C and E, and through interaction with endothelial lipases can lose a large fraction of their triacylglycerol. These changes convert them to chylomicron remnants which bind to LDL receptors, primarily on the surfaces of liver cells, clearing them from the circulation. This whole sequence of events is rapid: the normal lifespan of a chylomicron is 30 - 60 minutes (Redgrave 2004) [[https://reactome.org/PathwayBrowser/#/R-HSA-8963901](https://reactome.org/PathwayBrowser/#/R-HSA-8963901)].
-   **Assembly of active LPL and LIPC lipase complexes**: Lipoprotein lipase (LPL) and hepatic triacylglycerol lipase (LIPC) enzymes on the lumenal surfaces of capillary endothelia mediate the hydrolysis of triglyceride molecules in circulating lipoprotein particles. LPL is widely expressed in the body and is especially abundant in adipocytes and skeletal and cardiac myocytes. Activation of the protein requires glycosylation, dimerization, and glycosylphosphatidylinositol-anchored high density lipoprotein-binding protein 1 (GPIHBP1), which delivers it to heparan sulfate proteoglycan (HSPG) associated with the plasma membrane. It is inactivated by proteolytic cleavage (Berryman & Bensadoun 1995; Sukonina et al. 2006; Young et al. 2011). Expression of the LPL gene is transcriptionally regulated by Cyclic AMP-responsive element-binding protein 3-like protein 3 (CREB3L3), which also regulates the expression of APOA4, APOA5, APOC2, CIDEC and FGF21 (Lee et al. 2011). Maturation of LIPC enzyme requires association with LMF1 protein (or possibly, inferred from sequence similarity, LMF2). Heparin binding stabilizes LIPC in its active dimeric form (Babilonia-Rosa & Neher 2014; Ben-Zeev et al. 2011) [[https://reactome.org/PathwayBrowser/#/R-HSA-8963889](https://reactome.org/PathwayBrowser/#/R-HSA-8963889)].
-   **Retinoid metabolism and transport**: Vitamin A (all-trans-retinol) must be taken up, either as carotenes from plants, or as retinyl esters from animal food. The most prominent carotenes are alpha-carotene, lycopene, lutein, beta-cryptoxanthine, and especially beta-carotene. After uptake they are mostly broken down to retinal. Retinyl esters are hydrolysed like other fats. In enterocytes, retinoids bind to retinol-binding protein (RBP). Transport from enterocytes to the liver happens via chylomicrons (Harrison & Hussain 2001, Harrison 2005) [[https://reactome.org/PathwayBrowser/#/R-HSA-975634](https://reactome.org/PathwayBrowser/#/R-HSA-975634)].

## GO terms:

**cholesterol efflux** [The directed movement of cholesterol, cholest-5-en-3-beta-ol, out of a cell or organelle. GO:0033344]

**cholesterol homeostasis** [Any process involved in the maintenance of an internal steady state of cholesterol within an organism or cell. GO:0042632]

**cholesterol metabolic process** [The chemical reactions and pathways involving cholesterol, cholest-5-en-3 beta-ol, the principal sterol of vertebrates and the precursor of many steroids, including bile acids and steroid hormones. It is a component of the plasma membrane lipid bilayer and of plasma lipoproteins and can be found in all animal tissues. GO:0008203]

**high-density lipoprotein particle remodeling** [The acquisition, loss or modification of a protein or lipid within a high-density lipoprotein particle, including the hydrolysis of triglyceride by hepatic lipase, with the subsequent loss of free fatty acid, and the transfer of cholesterol esters from LDL to a triglyceride-rich lipoprotein particle by cholesteryl ester transfer protein (CETP), with the simultaneous transfer of triglyceride to LDL. GO:0034375]

**hydrogen peroxide catabolic process** [The chemical reactions and pathways resulting in the breakdown of hydrogen peroxide (H2O2). GO:0042744]

**innate immune response in mucosa** [Any process of the innate immune response that takes place in the mucosal tissues. GO:0002227]

**intermembrane lipid transfer** [The transport of lipids between membranes in which a lipid molecule is transported through an aqueous phase from the outer leaflet of a donor membrane to the outer leaflet of an acceptor membrane. This process does not require metabolic energy and can be either spontaneous or mediated by lipid transfer proteins (LTPs). GO:0120009]

**leukocyte cell-cell adhesion** [The attachment of a leukocyte to another cell via adhesion molecules. GO:0007159]

**lipid catabolic process** [The chemical reactions and pathways resulting in the breakdown of lipids, compounds soluble in an organic solvent but not, or sparingly, in an aqueous solvent. GO:0016042]

**lipid homeostasis** [Any process involved in the maintenance of an internal steady state of lipid within an organism or cell. GO:0055088]

**lipid transport** [The directed movement of lipids into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Lipids are compounds soluble in an organic solvent but not, or sparingly, in an aqueous solvent. GO:0006869]

**lipoprotein metabolic process** [The chemical reactions and pathways involving any conjugated, water-soluble protein in which the covalently attached nonprotein group consists of a lipid or lipids. GO:0042157]

**negative regulation of plasma lipoprotein oxidation** [Any process that stops, prevents, or reduces the frequency, rate or extent of lipoprotein particle oxidation, occurring in the blood plasma. GO:0034445]

**peripheral nervous system axon regeneration** [The regrowth of axons outside the central nervous system (outside the brain and spinal cord) following an axonal injury. GO:0014012]

**phosphatidylcholine metabolic process** [The chemical reactions and pathways involving phosphatidylcholines, any of a class of glycerophospholipids in which the phosphatidyl group is esterified to the hydroxyl group of choline. They are important constituents of cell membranes. GO:0046470]

**phospholipid efflux** [The directed movement of a phospholipid out of a cell or organelle. GO:0033700]

**positive regulation of fatty acid biosynthetic process** [Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of fatty acids. GO:0045723]

**positive regulation of triglyceride catabolic process** [Any process that increases the frequency, rate, or extent of the chemical reactions and pathways resulting in the breakdown of triglyceride. GO:0010898]

**protein-lipid complex assembly** [The aggregation, arrangement and bonding together of proteins and lipids to form a protein-lipid complex. GO:0065005]

**regulation of cholesterol transport** [Any process that modulates the frequency, rate or extent of the directed movement of cholesterol into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. GO:0032374]

**regulation of intestinal cholesterol absorption** [Any process that modulates the frequency, rate or extent of absorption of cholesterol into the blood, and the exclusion of other sterols from absorption. GO:0030300]

**removal of superoxide radicals** [Any process, acting at the cellular level, involved in removing superoxide radicals (O2-) from a cell or organism, e.g. by conversion to dioxygen (O2) and hydrogen peroxide (H2O2). GO:0019430]

**response to food** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a food stimulus; food is anything which, when taken into the body, serves to nourish or build up the tissues or to supply body heat. GO:0032094]

**response to lipid hydroperoxide** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lipid hydroperoxide stimulus. Lipid hydroperoxide is the highly reactive primary oxygenated products of polyunsaturated fatty acids. GO:0006982]

**response to stilbenoid** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of exposure to a stilbenoid. Stilbenoids are secondary products of heartwood formation in trees that can act as phytoalexins. Stilbenoids are hydroxylated derivatives of stilbene. They belong to the family of phenylpropanoids and share most of their biosynthesis pathway with chalcones. GO:0035634]

**response to triglyceride** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a triglyceride stimulus. GO:0034014]

**reverse cholesterol transport** [The directed movement of peripheral cell cholesterol, cholest-5-en-3-beta-ol, towards the liver for catabolism. GO:0043691]

**triglyceride homeostasis** [Any process involved in the maintenance of an internal steady state of triglyceride within an organism or cell. GO:0070328]

**very-low-density lipoprotein particle remodeling** [The acquisition, loss or modification of a protein or lipid within a very-low-density lipoprotein particle, including the hydrolysis of triglyceride by hepatic lipase or lipoprotein lipase and the subsequent loss of free fatty acid. GO:0034372]

## MSigDB Signatures:

**WP_FATTY_ACIDS_AND_LIPOPROTEINS_TRANSPORT_IN_HEPATOCYTES**: Fatty Acids and Lipoproteins Transport in Hepatocytes [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FATTY_ACIDS_AND_LIPOPROTEINS_TRANSPORT_IN_HEPATOCYTES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FATTY_ACIDS_AND_LIPOPROTEINS_TRANSPORT_IN_HEPATOCYTES.html)

**WP_CHOLESTEROL_METABOLISM**: Cholesterol metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_CHOLESTEROL_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_CHOLESTEROL_METABOLISM.html)

**REACTOME_CHYLOMICRON_ASSEMBLY**: Chylomicron assembly [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CHYLOMICRON_ASSEMBLY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CHYLOMICRON_ASSEMBLY.html)

**REACTOME_METABOLISM_OF_FAT_SOLUBLE_VITAMINS**: Metabolism of fat-soluble vitamins [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_METABOLISM_OF_FAT_SOLUBLE_VITAMINS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_METABOLISM_OF_FAT_SOLUBLE_VITAMINS.html)

**REACTOME_CHYLOMICRON_REMODELING**: Chylomicron remodeling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CHYLOMICRON_REMODELING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CHYLOMICRON_REMODELING.html)

**REACTOME_METABOLISM_OF_VITAMINS_AND_COFACTORS**: Metabolism of vitamins and cofactors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_METABOLISM_OF_VITAMINS_AND_COFACTORS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_METABOLISM_OF_VITAMINS_AND_COFACTORS.html)

**REACTOME_PLASMA_LIPOPROTEIN_ASSEMBLY**: Plasma lipoprotein assembly [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PLASMA_LIPOPROTEIN_ASSEMBLY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PLASMA_LIPOPROTEIN_ASSEMBLY.html)

**REACTOME_PLASMA_LIPOPROTEIN_ASSEMBLY_REMODELING_AND_CLEARANCE**: Plasma lipoprotein assembly, remodeling, and clearance [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PLASMA_LIPOPROTEIN_ASSEMBLY_REMODELING_AND_CLEARANCE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PLASMA_LIPOPROTEIN_ASSEMBLY_REMODELING_AND_CLEARANCE.html)

**WP_ENTEROCYTE_CHOLESTEROL_METABOLISM**: Enterocyte cholesterol metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ENTEROCYTE_CHOLESTEROL_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ENTEROCYTE_CHOLESTEROL_METABOLISM.html)

**WP_FAMILIAL_HYPERLIPIDEMIA_TYPE_1**: Familial hyperlipidemia type 1 [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FAMILIAL_HYPERLIPIDEMIA_TYPE_1.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FAMILIAL_HYPERLIPIDEMIA_TYPE_1.html)

**WP_FAMILIAL_HYPERLIPIDEMIA_TYPE_2**: Familial hyperlipidemia type 2 [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FAMILIAL_HYPERLIPIDEMIA_TYPE_2.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FAMILIAL_HYPERLIPIDEMIA_TYPE_2.html)

**WP_FAMILIAL_HYPERLIPIDEMIA_TYPE_5**: Familial hyperlipidemia type 5 [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FAMILIAL_HYPERLIPIDEMIA_TYPE_5.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FAMILIAL_HYPERLIPIDEMIA_TYPE_5.html)

**REACTOME_TRANSPORT_OF_SMALL_MOLECULES**: Transport of small molecules [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRANSPORT_OF_SMALL_MOLECULES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRANSPORT_OF_SMALL_MOLECULES.html)

**WP_FAMILIAL_HYPERLIPIDEMIA_TYPE_3**: Familial hyperlipidemia type 3 [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FAMILIAL_HYPERLIPIDEMIA_TYPE_3.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FAMILIAL_HYPERLIPIDEMIA_TYPE_3.html)

**REACTOME_PLASMA_LIPOPROTEIN_REMODELING**: Plasma lipoprotein remodeling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PLASMA_LIPOPROTEIN_REMODELING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PLASMA_LIPOPROTEIN_REMODELING.html)

**REACTOME_AMYLOID_FIBER_FORMATION**: Amyloid fiber formation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_AMYLOID_FIBER_FORMATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_AMYLOID_FIBER_FORMATION.html)

**WP_STATIN_INHIBITION_OF_CHOLESTEROL_PRODUCTION**: Statin inhibition of cholesterol production [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_STATIN_INHIBITION_OF_CHOLESTEROL_PRODUCTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_STATIN_INHIBITION_OF_CHOLESTEROL_PRODUCTION.html)

**WP_FAMILIAL_HYPERLIPIDEMIA_TYPE_4**: Familial hyperlipidemia type 4 [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FAMILIAL_HYPERLIPIDEMIA_TYPE_4.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FAMILIAL_HYPERLIPIDEMIA_TYPE_4.html)

**REACTOME_SENSORY_PERCEPTION**: Sensory Perception [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SENSORY_PERCEPTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SENSORY_PERCEPTION.html)

**REACTOME_ASSEMBLY_OF_ACTIVE_LPL_AND_LIPC_LIPASE_COMPLEXES**: Assembly of active LPL and LIPC lipase complexes [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ASSEMBLY_OF_ACTIVE_LPL_AND_LIPC_LIPASE_COMPLEXES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ASSEMBLY_OF_ACTIVE_LPL_AND_LIPC_LIPASE_COMPLEXES.html)

**REACTOME_VISUAL_PHOTOTRANSDUCTION**: Visual phototransduction [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_VISUAL_PHOTOTRANSDUCTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_VISUAL_PHOTOTRANSDUCTION.html)
