
## **Pathways:**

-   **Metabolism of amino acids and derivatives**: Cellular metabolism of amino acids and related molecules includes the pathways for the catabolism of amino acids, the biosynthesis of the nonessential amino acids (alanine, arginine, aspartate, asparagine, cysteine, glutamate, glutamine, glycine, proline, and serine) and selenocysteine, the synthesis of urea, and the metabolism of carnitine, creatine, choline, polyamides, melanin, and amine-derived hormones. The metabolism of amino acids provides a balanced supply of amino acids for protein synthesis. In the fasting state, the catabolism of amino acids derived from breakdown of skeletal muscle protein and other sources is coupled to the processes of gluconeogenesis and ketogenesis to meet the body's energy needs in the absence of dietary energy sources. These metabolic processes also provide the nitrogen atoms for the biosynthesis of nucleotides and heme, annotated as separate metabolic processes (Felig 1975; Haussinger 1990; Owen et al. 1979) [[https://reactome.org/PathwayBrowser/#/R-HSA-71291](https://reactome.org/PathwayBrowser/#/R-HSA-71291)].
-   **Neutrophil degranulation**: Neutrophils are the most abundant leukocytes (white blood cells), indispensable in defending the body against invading microorganisms. In response to infection, neutrophils leave the circulation and migrate towards the inflammatory focus. They contain several subsets of granules that are mobilized to fuse with the cell membrane or phagosomal membrane, resulting in the exocytosis or exposure of membrane proteins. Traditionally, neutrophil granule constituents are described as antimicrobial or proteolytic, but granules also introduce membrane proteins to the cell surface, changing how the neutrophil responds to its environment (Borregaard et al. 2007). Primed neutrophils actively secrete cytokines and other inflammatory mediators and can present antigens via MHC II, stimulating T-cells (Wright et al. 2010). Granules form during neutrophil differentiation. Granule subtypes can be distinguished by their content but overlap in structure and composition. The differences are believed to be a consequence of changing protein expression and differential timing of granule formation during the terminal processes of neutrophil differentiation, rather than sorting (Le Cabec et al. 1996). The classical granule subsets are Azurophil or primary granules (AG), secondary granules (SG) and gelatinase granules (GG). Neutrophils also contain exocytosable storage cell organelles, storage vesicles (SV), formed by endocytosis they contain many cell-surface markers and extracellular, plasma proteins (Borregaard et al. 1992). Ficolin-1-rich granules (FG) are like GGs highly exocytosable but gelatinase-poor (Rorvig et al. 2009) [[https://reactome.org/PathwayBrowser/#/R-HSA-6798695](https://reactome.org/PathwayBrowser/#/R-HSA-6798695)].
-   **Urea cycle**: The urea cycle yields urea, the major form in which excess nitrogen is excreted from the human body, and the amino acid arginine (Brusilow and Horwich 2001). It consists of four reactions: that of ornithine and carbamoyl phosphate to form citrulline, of citrulline and aspartate to form argininosuccinate, the cleavage of argininosuccinate to yield fumarate and arginine, and the cleavage of arginine to yield urea and re-form ornithine. The carbamoyl phosphate consumed in this cycle is synthesized in the mitochondria from bicarbonate and ammonia, and this synthesis in turn is dependent on the presence of N-acetylglutamate, which allosterically activates carbamoyl synthetase I enzyme. The synthesis of N-acetylglutamate is stimulated by high levels of arginine. Increased levels of free amino acids, indicated by elevated arginine levels, thus stimulate urea synthesis. Two enzymes catalyze the hydrolysis of arginine to yield ornithine and urea. Cytosolic ARG1 is the canonical urea cycle enzyme. Mitochondrial ARG2 likewise catalyzes urea production from arginine and may have a substantial sparing effect in patients lacking ARG1 enzyme, so its reaction is annotated here although the role of ARG2 under normal physiological conditions remains unclear [[https://reactome.org/PathwayBrowser/#/R-HSA-70635](https://reactome.org/PathwayBrowser/#/R-HSA-70635)].

## GO terms:

**adaptive immune response** [An immune response mediated by cells expressing specific receptors for antigens produced through a somatic diversification process, and allowing for an enhanced secondary response to subsequent exposures to the same antigen (immunological memory). GO:0002250]

**arginine catabolic process to ornithine** [The chemical reactions and pathways resulting in the breakdown of arginine into other compounds, including ornithine. GO:0019547]

**arginine metabolic process** [The chemical reactions and pathways involving arginine, 2-amino-5-(carbamimidamido)pentanoic acid. GO:0006525]

**cellular response to dexamethasone stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a dexamethasone stimulus. GO:0071549]

**cellular response to glucagon stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a glucagon stimulus. GO:0071377]

**cellular response to hydrogen peroxide** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a hydrogen peroxide (H2O2) stimulus. GO:0070301]

**cellular response to interleukin-4** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interleukin-4 stimulus. GO:0071353]

**cellular response to lipopolysaccharide** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lipopolysaccharide stimulus; lipopolysaccharide is a major component of the cell wall of gram-negative bacteria. GO:0071222]

**cellular response to transforming growth factor beta stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a transforming growth factor beta stimulus. GO:0071560]

**collagen biosynthetic process** [The chemical reactions and pathways resulting in the formation of collagen, any of a group of fibrous proteins of very high tensile strength that form the main component of connective tissue in animals. Collagen is highly enriched in glycine (some regions are 33% glycine) and proline, occurring predominantly as 3-hydroxyproline (about 20%). GO:0032964]

**defense response to protozoan** [Reactions triggered in response to the presence of a protozoan that act to protect the cell or organism. GO:0042832]

**female pregnancy** [The set of physiological processes that allow an embryo or foetus to develop within the body of a female animal. It covers the time from fertilization of a female ovum by a male spermatozoon until birth. GO:0007565]

**innate immune response** [Innate immune responses are defense responses mediated by germline encoded components that directly recognize components of potential pathogens. GO:0045087]

**liver development** [The process whose specific outcome is the progression of the liver over time, from its formation to the mature structure. The liver is an exocrine gland which secretes bile and functions in metabolism of protein and carbohydrate and fat, synthesizes substances involved in the clotting of the blood, synthesizes vitamin A, detoxifies poisonous substances, stores glycogen, and breaks down worn-out erythrocytes. GO:0001889]

**lung development** [The process whose specific outcome is the progression of the lung over time, from its formation to the mature structure. In all air-breathing vertebrates the lungs are developed from the ventral wall of the oesophagus as a pouch which divides into two sacs. In amphibians and many reptiles the lungs retain very nearly this primitive sac-like character, but in the higher forms the connection with the esophagus becomes elongated into the windpipe and the inner walls of the sacs become more and more divided, until, in the mammals, the air spaces become minutely divided into tubes ending in small air cells, in the walls of which the blood circulates in a fine network of capillaries. In mammals the lungs are more or less divided into lobes, and each lung occupies a separate cavity in the thorax. GO:0030324]

**mammary gland involution** [The tissue remodeling that removes differentiated mammary epithelia during weaning. GO:0060056]

**maternal process involved in female pregnancy** [A reproductive process occurring in the mother that allows an embryo or fetus to develop within it. GO:0060135]

**negative regulation of T cell proliferation** [Any process that stops, prevents or reduces the rate or extent of T cell proliferation. GO:0042130]

**negative regulation of T-helper 2 cell cytokine production** [Any process that stops, prevents or reduces the frequency, rate or extent of T-helper 2 cell cytokine production. GO:2000552]

**negative regulation of activated T cell proliferation** [Any process that stops, prevents or reduces the rate or extent of activated T cell proliferation. GO:0046007]

**negative regulation of type II interferon-mediated signaling pathway** [Any process that decreases the rate, frequency or extent of an interferon-gamma-mediated signaling pathway. GO:0060336]

**positive regulation of endothelial cell proliferation** [Any process that activates or increases the rate or extent of endothelial cell proliferation. GO:0001938]

**positive regulation of neutrophil mediated killing of fungus** [Any process that increases the frequency, rate or extent of the directed killing of a fungal cell by a neutrophil. GO:0070965]

**regulation of L-arginine import across plasma membrane** [Any process that modulates the frequency, rate or extent of L-arginine import across plasma membrane. GO:1905541]

**response to amine** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an amine stimulus. An amine is a compound formally derived from ammonia by replacing one, two or three hydrogen atoms by hydrocarbyl groups. GO:0014075]

**response to amino acid** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an amino acid stimulus. An amino acid is a carboxylic acids containing one or more amino groups. GO:0043200]

**response to axon injury** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an axon injury stimulus. GO:0048678]

**response to cadmium ion** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cadmium (Cd) ion stimulus. GO:0046686]

**response to herbicide** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a herbicide stimulus. Herbicides are chemicals used to kill or control the growth of plants. GO:0009635]

**response to lipopolysaccharide** [Any process that results in a change in state or activity of an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lipopolysaccharide stimulus; lipopolysaccharide is a major component of the cell wall of gram-negative bacteria. GO:0032496]

**response to manganese ion** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a manganese ion stimulus. GO:0010042]

**response to methylmercury** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a methylmercury stimulus. GO:0051597]

**response to peptide hormone** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a peptide hormone stimulus. A peptide hormone is any of a class of peptides that are secreted into the blood stream and have endocrine functions in living animals. GO:0043434]

**response to selenium ion** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from selenium ion. GO:0010269]

**response to steroid hormone** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a steroid hormone stimulus. GO:0048545]

**response to vitamin A** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a vitamin A stimulus. GO:0033189]

**response to vitamin E** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a vitamin E stimulus. GO:0033197]

**response to xenobiotic stimulus** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a xenobiotic, a compound foreign to the organism exposed to it. It may be synthesized by another organism (like ampicilin) or it can be a synthetic chemical. GO:0009410]

**response to zinc ion** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a zinc ion stimulus. GO:0010043]

**urea cycle** [The sequence of reactions by which arginine is synthesized from ornithine, then cleaved to yield urea and regenerate ornithine. The overall reaction equation is NH3 + CO2 + aspartate + 3 ATP + 2 H2O = urea + fumarate + 2 ADP + 2 phosphate + AMP + diphosphate. GO:0000050]

## MSigDB Signatures:

**REACTOME_NEUTROPHIL_DEGRANULATION**: Neutrophil degranulation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NEUTROPHIL_DEGRANULATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NEUTROPHIL_DEGRANULATION.html)

**WP_UREA_CYCLE_AND_RELATED_DISEASES**: Urea cycle and related diseases [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_UREA_CYCLE_AND_RELATED_DISEASES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_UREA_CYCLE_AND_RELATED_DISEASES.html)

**REACTOME_INNATE_IMMUNE_SYSTEM**: Innate Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html)

**WP_UREA_CYCLE_AND_ASSOCIATED_PATHWAYS**: Urea cycle and associated pathways [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_UREA_CYCLE_AND_ASSOCIATED_PATHWAYS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_UREA_CYCLE_AND_ASSOCIATED_PATHWAYS.html)

**REACTOME_UREA_CYCLE**: Urea cycle [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_UREA_CYCLE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_UREA_CYCLE.html)

**WP_SPINAL_CORD_INJURY**: Spinal cord injury [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_SPINAL_CORD_INJURY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_SPINAL_CORD_INJURY.html)

**KEGG_ARGININE_AND_PROLINE_METABOLISM**: Arginine and proline metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_ARGININE_AND_PROLINE_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_ARGININE_AND_PROLINE_METABOLISM.html)

**KEGG_MEDICUS_REFERENCE_UREA_CYCLE**: Pathway Definition from KEGG: NH3 -- CPS1 >> OTC >> ASS1 >> ASL >> ARG1/2 -> Urea+Ornithine [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_UREA_CYCLE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_UREA_CYCLE.html)
