
## **Pathways:**

**Glycosaminoglycan metabolism:** Glycosaminoglycans (GAGs) are long, unbranched polysaccharides containing a repeating disaccharide unit composed of a hexosamine (either N-acetylgalactosamine (GalNAc) or N-acetylglucosamine (GlcNAc)) and a uronic acid (glucuronate or iduronate). They can be heavily sulfated. GAGs are located primarily in the extracellular matrix (ECM) and on cell membranes, acting as a lubricating fluid for joints and as part of signalling processes. They have structural roles in connective tissue, cartilage, bone and blood vessels (Esko et al. 2009). GAGs are degraded in the lysosome as part of their natural turnover. Defects in the lysosomal enzymes responsible for the metabolism of membrane-associated GAGs lead to lysosomal storage diseases called mucopolysaccharidoses (MPS). MPSs are characterised by the accumulation of GAGs in lysosomes resulting in chronic, progressively debilitating disorders that in many instances lead to severe psychomotor retardation and premature death (Cantz & Gehler 1976, Clarke 2008). The biosynthesis and breakdown of the main GAGs (hyaluronate, keratan sulfate, chondroitin sulfate, dermatan sulfate and heparan sulfate) is described here. [[https://reactome.org/PathwayBrowser/#/R-HSA-1630316](https://reactome.org/PathwayBrowser/#/R-HSA-1630316)]

**Keratan sulfate biosynthesis:** Keratan sulfate (KSI) is the best characterised keratan sulfate. It is 10 times more abundant in cornea than cartilage. KSI is attached to an asparagine (Asn) residue on the core protein via an N-linked branched oligosaccharide (an N-glycan core structure used as a precursor in N-glycan biosynthesis). KSI is elongated by the alternate additions of galactose (Gal) and N-acetylglucosamine (GlcNAc), mediated by glycosyltransferases. Elongation is terminated by the addition of a single N-acetylneuraminic acid (sialyl) residue. KSI is also sulfated on Gal and GlcNAc residues by at least two sulfotransferases (Funderburgh 2000, Funderburgh 2002, Quantock et al. 2010). KSI can be attached to asparagine residues on core proteins, creating so called proteoglycans (PGs). Seven common core proteins found in corneal and skeletal tissues are used as examples here [[https://reactome.org/PathwayBrowser/#/R-HSA-2022854](https://reactome.org/PathwayBrowser/#/R-HSA-2022854)].

**N-Glycan antennae elongation:** N-glycans are further modified after the commitment to Complex or Hybrid N-glycans. The exact structure of the network of metabolic reactions involved is complex and not yet validated experimentally. Here we will show a generic reaction for each of the genes known to be involved in N-Glycosylation.

For a better annotation of the reactions and genes involved in the synthesis of Complex and Hybrid N-glycans we recommend the GlycoGene Database (Ito H. et al, 2010) ([http://riodb.ibase.aist.go.jp/rcmg/ggdb/textsearch.jsp](http://riodb.ibase.aist.go.jp/rcmg/ggdb/textsearch.jsp)) for annotations of genes, and the Consortium for Functional Genomics ([http://riodb.ibase.aist.go.jp/rcmg/ggdb/textsearch.jsp](http://riodb.ibase.aist.go.jp/rcmg/ggdb/textsearch.jsp)) for annotation of Glycan structures and reactions. Moreover, a computationally inferred prediction for the structure of this network is available through the software GlycoVis (Hossler P. et. al. 2006). [[https://reactome.org/PathwayBrowser/#/R-HSA-975577](https://reactome.org/PathwayBrowser/#/R-HSA-975577)]

## GO terms:

**carbohydrate metabolic process** [The chemical reactions and pathways involving carbohydrates, any of a group of organic compounds based of the general formula Cx(H2O)y. GO:0005975]

**glycosylation** [The covalent attachment and further modification of carbohydrate residues to a substrate molecule. GO:0070085]

**keratan sulfate biosynthetic process** [The chemical reactions and pathways resulting in the formation of keratan sulfate, a glycosaminoglycan with repeat units consisting of beta-1,4-linked D-galactopyranosyl-beta-(1,4)-N-acetyl-D-glucosamine 6-sulfate and with variable amounts of fucose, sialic acid and mannose units; keratan sulfate chains are covalently linked by a glycosidic attachment through the trisaccharide galactosyl-galactosyl-xylose to peptidyl-threonine or serine residues. GO:0018146]

**lactosylceramide biosynthetic process** [The chemical reactions and pathways resulting in the formation of lactosylceramides, Gal-beta-(1->4)-Glc-beta(1->1') ceramides, any compound formed by the replacement of the glycosidic C1 hydroxyl group of lactose by a ceramide group. They are the precursors of both gangliosides and globosides. GO:0001572]

**protein glycosylation** [A protein modification process that results in the addition of a carbohydrate or carbohydrate derivative unit to a protein amino acid, e.g. the addition of glycan chains to proteins. GO:0006486]

## MSigDB Signatures:

**AMBROSINI_FLAVOPIRIDOL_TREATMENT_TP53**: Genes down-regulated by flavopiridol [PubChem=5287969] in the HCT116 cells (colon cancer) depending on their TP53 [GeneID=7157] status: wild-type vs loss of the gene's function (LOF). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMBROSINI_FLAVOPIRIDOL_TREATMENT_TP53.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMBROSINI_FLAVOPIRIDOL_TREATMENT_TP53.html)

**REACTOME_KERATAN_SULFATE_KERATIN_METABOLISM**: Keratan sulfate/keratin metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_KERATAN_SULFATE_KERATIN_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_KERATAN_SULFATE_KERATIN_METABOLISM.html)

**KEGG_MEDICUS_REFERENCE_II_BLOOD_GROUP_ANTIGEN_BIOSYNTHESIS**: Pathway Definition from KEGG: nLc4Cer -- B3GNT2/3/4 >> B4GALT1/3/4 -> i_antigen -- GCNT2\*I -> I_antigen [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_II_BLOOD_GROUP_ANTIGEN_BIOSYNTHESIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_II_BLOOD_GROUP_ANTIGEN_BIOSYNTHESIS.html)

**KEGG_MEDICUS_REFERENCE_BLOOD_GROUP_H_O_ANTIGEN_TYPE_2_BIOSYNTHESIS**: Pathway Definition from KEGG: LacCer -- B3GNT5 >> B4GALT1/2/3/4 -> nLc4Cer -- FUT1*H -> TypeIIH // ABO*O [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_BLOOD_GROUP_H_O_ANTIGEN_TYPE_2_BIOSYNTHESIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_BLOOD_GROUP_H_O_ANTIGEN_TYPE_2_BIOSYNTHESIS.html)

**JINESH_BLEBBISHIELD_TRANSFORMED_STEM_CELL_SPHERES_UP**: Genes up-regulated in transformed spheres compared to blebbishields from RT4 cells [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JINESH_BLEBBISHIELD_TRANSFORMED_STEM_CELL_SPHERES_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JINESH_BLEBBISHIELD_TRANSFORMED_STEM_CELL_SPHERES_UP.html)

**REACTOME_GLYCOSAMINOGLYCAN_METABOLISM**: Glycosaminoglycan metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_GLYCOSAMINOGLYCAN_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_GLYCOSAMINOGLYCAN_METABOLISM.html)

**KEGG_GLYCOSAMINOGLYCAN_BIOSYNTHESIS_KERATAN_SULFATE**: Glycosaminoglycan biosynthesis - keratan sulfate [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_GLYCOSAMINOGLYCAN_BIOSYNTHESIS_KERATAN_SULFATE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_GLYCOSAMINOGLYCAN_BIOSYNTHESIS_KERATAN_SULFATE.html)

**REACTOME_KERATAN_SULFATE_BIOSYNTHESIS**: Keratan sulfate biosynthesis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_KERATAN_SULFATE_BIOSYNTHESIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_KERATAN_SULFATE_BIOSYNTHESIS.html)

**REACTOME_N_GLYCAN_ANTENNAE_ELONGATION**: N-Glycan antennae elongation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_N_GLYCAN_ANTENNAE_ELONGATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_N_GLYCAN_ANTENNAE_ELONGATION.html)

**REACTOME_POST_TRANSLATIONAL_PROTEIN_MODIFICATION**: Post-translational protein modification [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_POST_TRANSLATIONAL_PROTEIN_MODIFICATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_POST_TRANSLATIONAL_PROTEIN_MODIFICATION.html)

**ACEVEDO_LIVER_TUMOR_VS_NORMAL_ADJACENT_TISSUE_DN**: Genes down-regulated in liver tumor compared to the normal adjacent tissue. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ACEVEDO_LIVER_TUMOR_VS_NORMAL_ADJACENT_TISSUE_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ACEVEDO_LIVER_TUMOR_VS_NORMAL_ADJACENT_TISSUE_DN.html)

**AMIT_SERUM_RESPONSE_240_MCF10A**: Genes whose expression peaked at 240 min after stimulation of MCF10A cells with serum. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_SERUM_RESPONSE_240_MCF10A.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_SERUM_RESPONSE_240_MCF10A.html)

**AMIT_SERUM_RESPONSE_480_MCF10A**: Genes whose expression peaked at 480 min after stimulation of MCF10A cells with serum. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_SERUM_RESPONSE_480_MCF10A.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_SERUM_RESPONSE_480_MCF10A.html)

**PURBEY_TARGETS_OF_CTBP1_NOT_SATB1_UP**: Genes up-regulated in HEK-293 cells (fibroblast) upon knockdown of CTBP1 but not of SATB1 [GeneID=1487, 6304] by RNAi. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PURBEY_TARGETS_OF_CTBP1_NOT_SATB1_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PURBEY_TARGETS_OF_CTBP1_NOT_SATB1_UP.html)

**REACTOME_METABOLISM_OF_CARBOHYDRATES**: Metabolism of carbohydrates [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_METABOLISM_OF_CARBOHYDRATES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_METABOLISM_OF_CARBOHYDRATES.html)

**ZWANG_CLASS_1_TRANSIENTLY_INDUCED_BY_EGF**: Class I of genes transiently induced by EGF [GeneID =1950] in 184A1 cells (mammary epithelium). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZWANG_CLASS_1_TRANSIENTLY_INDUCED_BY_EGF.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZWANG_CLASS_1_TRANSIENTLY_INDUCED_BY_EGF.html)
