
## **Pathways:**

**RNA Polymerase II Transcription:** RNA polymerase II (Pol II) is the central enzyme that catalyses DNA- directed mRNA synthesis during the transcription of protein-coding genes. Pol II consists of a 10-subunit catalytic core, which alone is capable of elongating the RNA transcript, and a complex of two subunits, Rpb4/7, that is required for transcription initiation.

The transcription cycle is divided in three major phases: initiation, elongation, and termination. Transcription initiation include promoter DNA binding, DNA melting, and initial synthesis of short RNA transcripts. The transition from initiation to elongation, is referred to as promoter escape and leads to a stable elongation complex that is characterized by an open DNA region or transcription bubble. The bubble contains the DNA-RNA hybrid, a heteroduplex of eight to nine base pairs. The growing 3-end of the RNA is engaged with the polymerase complex active site. Ultimately transcription terminates and Pol II dissocitates from the template. [[https://reactome.org/PathwayBrowser/#/R-HSA-73857](https://reactome.org/PathwayBrowser/#/R-HSA-73857)]

**TP53 regulates transcription of additional cell cycle genes whose exact role in the p53 pathway remain uncertain:** BTG2 is induced by TP53, leading to cessation of cellular proliferation (Rouault et al. 1996, Duriez et al. 2002). BTG2 binds to the CCR4-NOT complex and promotes mRNA deadenylation activity of this complex. Interaction between BTG2 and CCR4-NOT is needed for the antiproliferative activity of BTG2, but the underlying mechanism has not been elucidated (Rouault et al. 1998, Mauxion et al. 2008, Horiuchi et al. 2009, Doidge et al. 2012, Ezzeddine et al. 2012). Two polo-like kinases, PLK2 and PLK3, are direct transcriptional targets of TP53. TP53-mediated induction of PLK2 may be important for prevention of mitotic catastrophe after spindle damage (Burns et al. 2003). PLK2 is involved in the regulation of centrosome duplication through phosphorylation of centrosome-related proteins CENPJ (Chang et al. 2010) and NPM1 (Krause and Hoffmann 2010). PLK2 is frequently transcriptionally silenced through promoter methylation in B-cell malignancies (Syed et al. 2006). Induction of PLK3 transcription by TP53 (Jen and Cheung 2005) may be important for coordination of M phase events through PLK3-mediated nuclear accumulation of CDC25C (Bahassi et al. 2004). RGCC is induced by TP53 and implicated in cell cycle regulation, possibly through its association with PLK1 (Saigusa et al. 2007). PLAGL1 (ZAC1) is a zinc finger protein directly transcriptionally induced by TP53 (Rozenfeld-Granot et al. 2002). PLAGL1 expression is frequently lost in cancer (Varrault et al. 1998) and PLAGL1 has been implicated in both cell cycle arrest and apoptosis (Spengler et al. 1997), but its mechanism of action remains unknown. [[https://reactome.org/PathwayBrowser/#/R-HSA-6804115](https://reactome.org/PathwayBrowser/#/R-HSA-6804115)]

## GO terms:

**DNA damage response** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating damage to its DNA from environmental insults or errors during metabolism. GO:0006974]

**anterior/posterior pattern specification** [The regionalization process in which specific areas of cell differentiation are determined along the anterior-posterior axis. The anterior-posterior axis is defined by a line that runs from the head or mouth of an organism to the tail or opposite end of the organism. GO:0009952]

**associative learning** [Learning by associating a stimulus (the cause) with a particular outcome (the effect). GO:0008306]

**central nervous system neuron development** [The process whose specific outcome is the progression of a neuron whose cell body is located in the central nervous system, from initial commitment of the cell to a neuronal fate, to the fully functional differentiated neuron. GO:0021954]

**dentate gyrus development** [The process whose specific outcome is the progression of the dentate gyrus over time, from its formation to the mature structure. The dentate gyrus is one of two interlocking gyri of the hippocampus. It contains granule cells, which project to the pyramidal cells and interneurons of the CA3 region of the ammon gyrus. GO:0021542]

**negative regulation of apoptotic process** [Any process that stops, prevents, or reduces the frequency, rate or extent of cell death by apoptotic process.|This term should only be used when it is not possible to determine which phase or subtype of the apoptotic process is negatively regulated by a gene product. Whenever detailed information is available, the more granular children terms should be used. GO:0043066]

**negative regulation of cell population proliferation** [Any process that stops, prevents or reduces the rate or extent of cell proliferation. GO:0008285]

**negative regulation of mitotic cell cycle** [Any process that stops, prevents or reduces the rate or extent of progression through the mitotic cell cycle. GO:0045930]

**negative regulation of neuroblast proliferation** [Any process that stops, prevents, or reduces the frequency, rate or extent of the proliferation of neuroblasts. GO:0007406]

**negative regulation of neuron apoptotic process** [Any process that stops, prevents, or reduces the frequency, rate or extent of cell death by apoptotic process in neurons. GO:0043524]

**negative regulation of transcription by RNA polymerase II** [Any process that stops, prevents, or reduces the frequency, rate or extent of transcription mediated by RNA polymerase II. GO:0000122]

**negative regulation of translation** [Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of proteins by the translation of mRNA or circRNA. GO:0017148]

**neural precursor cell proliferation** [The multiplication or reproduction of neural precursor cells, resulting in the expansion of a cell population. A neural precursor cell is either a nervous system stem cell or a nervous system progenitor cell. GO:0061351]

**neuroblast proliferation** [The expansion of a neuroblast population by cell division. A neuroblast is any cell that will divide and give rise to a neuron. GO:0007405]

**neuron differentiation** [The process in which a relatively unspecialized cell acquires specialized features of a neuron. GO:0030182]

**neuron projection development** [The process whose specific outcome is the progression of a neuron projection over time, from its formation to the mature structure. A neuron projection is any process extending from a neural cell, such as axons or dendrites (collectively called neurites). GO:0031175]

**positive regulation of nuclear-transcribed mRNA poly(A) tail shortening** [Any process that increases the frequency, rate or extent of poly(A) tail shortening of a nuclear-transcribed mRNA. Poly(A) tail shortening is the decrease in length of the poly(A) tail of an mRNA from full length to an oligo(A) length. GO:0060213]

**response to electrical stimulus** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an electrical stimulus. GO:0051602]

**response to mechanical stimulus** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a mechanical stimulus. GO:0009612]

**response to organic cyclic compound** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an organic cyclic compound stimulus. GO:0014070]

**response to organic substance** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an organic substance stimulus. GO:0010033]

**response to organonitrogen compound** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an organonitrogen stimulus. An organonitrogen compound is formally a compound containing at least one carbon-nitrogen bond. GO:0010243]

**response to peptide hormone** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a peptide hormone stimulus. A peptide hormone is any of a class of peptides that are secreted into the blood stream and have endocrine functions in living animals. GO:0043434]

**skeletal muscle cell differentiation** [The process in which a relatively unspecialized cell acquires specialized features of a skeletal muscle cell, a somatic cell located in skeletal muscle. GO:0035914]

## MSigDB Signatures:

**WP_SPINAL_CORD_INJURY**: Spinal cord injury [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_SPINAL_CORD_INJURY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_SPINAL_CORD_INJURY.html)
