
## **Pathways:**

**Endosomal Sorting Complex Required For Transport (ESCRT):** Many plasma membrane proteins are in a constant flux throughout the internal trafficking pathways of the cell. Some receptors are continuously internalized into recycling endosomes and returned to the cell surface. Others are sorted into intralumenal vesicles of morphologically distinctive endosomes that are known as multivesicular bodies (MVBs). These MVBs fuse with lysosomes, resulting in degradation of their cargo by lysosomal acidic hydrolases. Endosomes can be operationally defined as being either early or late, referring to the relative time it takes for endocytosed material to reach either stage. Ultrastructural studies indicate that early endosomes are predominantly tubulovesicular structures, which constitute a major sorting platform in the cell, whereas late endosomes show the characteristics of typical MVBs and are capable of fusing with lysosomes. A well characterized signal for shunting membrane proteins into the degradative MVB pathway is the ubiquitylation of these cargoes. At the center of a vast protein:protein and protein:lipid interaction network that underpins ubiquitin mediated sorting to the lysosome are the endosomal sorting complexes required for transport (ESCRTs), which are conserved throughout all major eukaryotic taxa.

**Late endosomal microautophagy:** Microautophagy (MI) is a non-selective autophagic pathway that involves internalization of cytosolic cargo through invaginations of the lysosomal membrane. MI can be induced by nitrogen starvation and complements other related self-eating processes such as Macroautophagy (MA) and Chaperone Mediated Autophagy (CMA). MI can degrade cell organelles and bulk cytosolic proteins directly via the lysosome and late endosome. MI can also target substrates with KFERQ motifs with the help of HSPA8 (Li W W et al. 2012).

**Budding and maturation of HIV virion:** With the virus components precariously assembled on the inner leaflet of the plasma membrane, the host cell machinery is required for viral budding. The virus takes advantage of the host ESCRT pathway to terminate Gag polymerization and catalyze release. The ESCRT pathway is normally responsible for membrane fission that creates cytoplasm filled vesicular bodies. In this case HIV (and other viruses) take advantage of the ESCRT cellular machinery to facilitate virion budding from the host.

**Membrane binding and targeting of GAG proteins:** One of the mysteries of Gag protein involvement in HIV virion assembly is how the proteins are targeted to the proper membrane for budding. Infectious retroviruses do not bud from all of the available membrane surfaces within an infected cell, but primarily from the plasma membrane, which constitutes a small proportion of the total membrane surface in most cells. In polarized cells, the sites of budding are further restricted to the basolateral membrane.

**HCMV Late Events:** Once Human Cytomegalovirus (HCMV) Immediate Early (IE) and Delayed Early (DE) gene products begin to appear the processes driving DNA replication, Late (L) gene expression, and virion assembly begin.

## GO terms:

**cell differentiation** [The cellular developmental process in which a relatively unspecialized cell, e.g. embryonic or regenerative cell, acquires specialized structural and/or functional features that characterize a specific cell. Differentiation includes the processes involved in commitment of a cell to a specific fate and its subsequent development to the mature state. GO:0030154]

**cell division** [The process resulting in division and partitioning of components of a cell to form more cells; may or may not be accompanied by the physical separation of a cell into distinct, individually membrane-bounded daughter cells.|Note that this term differs from 'cytokinesis ; GO:0000910' in that cytokinesis does not include nuclear division. GO:0051301]

**endosome to lysosome transport** [The directed movement of substances from endosomes to lysosomes. GO:0008333]

**exosomal secretion** [The process whereby a membrane-bounded vesicle is released into the extracellular region by fusion of the limiting endosomal membrane of a multivesicular body with the plasma membrane. GO:1990182]

**extracellular transport** [The transport of substances that occurs outside cells. GO:0006858]

**keratinocyte differentiation** [The process in which a relatively unspecialized cell acquires specialized features of a keratinocyte. GO:0030216]

**negative regulation of cell population proliferation** [Any process that stops, prevents or reduces the rate or extent of cell proliferation. GO:0008285]

**negative regulation of epidermal growth factor receptor signaling pathway** [Any process that stops, prevents, or reduces the frequency, rate or extent of epidermal growth factor receptor signaling pathway activity. GO:0042059]

**negative regulation of transcription by RNA polymerase II** [Any process that stops, prevents, or reduces the frequency, rate or extent of transcription mediated by RNA polymerase II. GO:0000122]

**positive regulation of DNA-templated transcription** [Any process that activates or increases the frequency, rate or extent of cellular DNA-templated transcription. GO:0045893]

**positive regulation of exosomal secretion** [Any process that activates or increases the frequency, rate or extent of exosomal secretion. GO:1903543]

**positive regulation of ubiquitin-dependent endocytosis** [Any process that activates or increases the frequency, rate or extent of ubiquitin-dependent endocytosis. GO:2000397]

**positive regulation of viral budding via host ESCRT complex** [Any process that activates or increases the frequency, rate or extent of viral budding via host ESCRT complex. GO:1903774]

**protein modification process** [The covalent alteration of one or more amino acids occurring in proteins, peptides and nascent polypeptides (co-translational, post-translational modifications). Includes the modification of charged tRNAs that are destined to occur in a protein (pre-translation modification). GO:0036211]

**protein monoubiquitination** [Addition of a single ubiquitin group to a protein. GO:0006513]

**protein transport** [The directed movement of proteins into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. GO:0015031]

**regulation of cell cycle** [Any process that modulates the rate or extent of progression through the cell cycle. GO:0051726]

**regulation of cell growth** [Any process that modulates the frequency, rate, extent or direction of cell growth. GO:0001558]

**regulation of extracellular exosome assembly** [Any process that modulates the frequency, rate or extent of extracellular vesicular exosome assembly. GO:1903551]

**ubiquitin-dependent protein catabolic process via the multivesicular body sorting pathway** [The chemical reactions and pathways resulting in the breakdown of a protein or peptide covalently tagged with ubiquitin, via the multivesicular body (MVB) sorting pathway; ubiquitin-tagged proteins are sorted into MVBs, and delivered to a lysosome/vacuole for degradation. GO:0043162]

**viral budding** [A viral process by which enveloped viruses acquire a host-derived membrane enriched in viral proteins to form their external envelope. The process starts when nucleocapsids, assembled or in the process of being built, induce formation of a membrane curvature in the host plasma or organelle membrane and wrap up in the forming bud. The process ends when the bud is eventually pinched off by membrane scission to release the enveloped particle into the lumenal or extracellular space. GO:0046755]

**viral release from host cell** [The dissemination of mature viral particles from a host cell, e.g. by cell lysis or the budding of virus particles from the cell membrane. GO:0019076]

## MSigDB Signatures:

**BLALOCK_ALZHEIMERS_DISEASE_DN**: Genes down-regulated in brain from patients with Alzheimer's disease.

**KIM_BIPOLAR_DISORDER_OLIGODENDROCYTE_DENSITY_CORR_UP**: Genes whose expression significantly and positively correlated with oligodendrocyte density in layer VI of BA9 brain region in patients with bipolar disorder.

**REACTOME_AUTOPHAGY**: Autophagy

**REACTOME_MEMBRANE_TRAFFICKING**: Membrane Trafficking

**REACTOME_INFECTIOUS_DISEASE**: Infectious disease

**REACTOME_HIV_INFECTION**: HIV Infection

**KEGG_ENDOCYTOSIS**: Endocytosis

**PID_REG_GR_PATHWAY**: Glucocorticoid receptor regulatory network

**PID_ERBB1_INTERNALIZATION_PATHWAY**: Internalization of ErbB1

**WHITFIELD_CELL_CYCLE_G2_M**: Genes periodically expressed in synchronized HeLa cells (cervical carcinoma), with peak during the G2/M phase of cell cycle.

**BENPORATH_CYCLING_GENES**: Genes showing cell-cycle stage-specific expression [PMID: 12058064].

**REACTOME_ASSEMBLY_OF_THE_HIV_VIRION**: Assembly Of The HIV Virion

**REACTOME_ENDOSOMAL_SORTING_COMPLEX_REQUIRED_FOR_TRANSPORT_ESCRT**: Endosomal Sorting Complex Required For Transport (ESCRT)

**REACTOME_VIRAL_INFECTION_PATHWAYS**: Viral Infection Pathways

**REACTOME_HCMV_INFECTION**: HCMV Infection

**REACTOME_BUDDING_AND_MATURATION_OF_HIV_VIRION**: Budding and maturation of HIV virion

**REACTOME_LATE_ENDOSOMAL_MICROAUTOPHAGY**: Late endosomal microautophagy

**REACTOME_HIV_LIFE_CYCLE**: HIV Life Cycle

**ACEVEDO_LIVER_TUMOR_VS_NORMAL_ADJACENT_TISSUE_UP**: Genes up-regulated in liver tumor compared to the normal adjacent tissue.

**WP_7Q11_23_COPY_NUMBER_VARIATION_SYNDROME**: 7q11 23 copy number variation syndrome

**REACTOME_VESICLE_MEDIATED_TRANSPORT**: Vesicle-mediated transport

**REACTOME_HCMV_LATE_EVENTS**: HCMV Late Events
