
## **Pathways:**

-   **Cell surface interactions at the vascular wall**: Leukocyte extravasation is a rigorously controlled process that guides white cell movement from the vascular lumen to sites of tissue inflammation. The powerful adhesive interactions that are required for leukocytes to withstand local flow at the vessel wall is a multistep process mediated by different adhesion molecules. Platelets adhered to injured vessel walls form strong adhesive substrates for leukocytes. For instance, the initial tethering and rolling of leukocytes over the site of injury are mediated by reversible binding of selectins to their cognate cell-surface glycoconjugates. Endothelial cells are tightly connected through various proteins, which regulate the organization of the junctional complex and bind to cytoskeletal proteins or cytoplasmic interaction partners that allow the transfer of intracellular signals. An important role for these junctional proteins in governing the transendothelial migration of leukocytes under normal or inflammatory conditions has been established. This pathway describes some of the key interactions that assist in the process of platelet and leukocyte interaction with the endothelium, in response to injury [[https://reactome.org/PathwayBrowser/#/R-HSA-202733](https://reactome.org/PathwayBrowser/#/R-HSA-202733)].
-   **Integrin cell surface interactions:** The extracellular matrix (ECM) is a network of macro-molecules that underlies all epithelia and endothelia and that surrounds all connective tissue cells. This matrix provides the mechanical strength and also influences the behavior and differentiation state of cells in contact with it. The ECM are diverse in composition, but they generally comprise a mixture of fibrillar proteins, polysaccharides synthesized, secreted and organized by neighboring cells. Collagens, fibronectin, and laminins are the principal components involved in cell matrix interactions; other components, such as vitronectin, thrombospondin, and osteopontin, although less abundant, are also important adhesive molecules. Integrins are the receptors that mediate cell adhesion to ECM. Integrins consists of one alpha and one beta subunit forming a noncovalently bound heterodimer. 18 alpha and 8 beta subunits have been identified in humans that combine to form 24 different receptors. The integrin dimers can be broadly divided into three families consisting of the beta1, beta2/beta7, and beta3/alphaV integrins. beta1 associates with 12 alpha-subunits and can be further divided into RGD-, collagen-, or laminin binding and the related alpha4/alpha9 integrins that recognise both matrix and vascular ligands. beta2/beta7 integrins are restricted to leukocytes and mediate cell-cell rather than cell-matrix interactions, although some recognize fibrinogen. The beta3/alphaV family members are all RGD receptors and comprise aIIbb3, an important receptor on platelets, and the remaining b-subunits, which all associate with alphaV. It is the collagen receptors and leukocyte-specific integrins that contain alpha A-domains [[https://reactome.org/PathwayBrowser/#/R-HSA-216083](https://reactome.org/PathwayBrowser/#/R-HSA-216083)].
-   **Degradation of the extracellular matrix:** Matrix metalloproteinases (MMPs), previously referred to as matrixins because of their role in degradation of the extracellular matrix (ECM), are zinc and calcium dependent proteases belonging to the metzincin family. They contain a characteristic zinc-binding motif HEXXHXXGXXH (Stocker & Bode 1995) and a conserved Methionine which forms a Met-turn. Humans have 24 MMP genes giving rise to 23 MMP proteins, as MMP23 is encoded by two identical genes. All MMPs contain an N-terminal secretory signal peptide and a prodomain with a conserved PRCGXPD motif that in the inactive enzyme is localized with the catalytic site, the cysteine acting as a fourth unpaired ligand for the catalytic zinc atom. Activation involves delocalization of the domain containing this cysteine by a conformational change or proteolytic cleavage, a mechanism referred to as the cysteine-switch (Van Wart & Birkedal-Hansen 1990). Most MMPs are secreted but the membrane type MT-MMPs are membrane anchored and some MMPs may act on intracellular proteins. Various domains determine substrate specificity, cell localization and activation (Hadler-Olsen et al. 2011). MMPs are regulated by transcription, cellular location (most are not activated until secreted), activating proteinases that can be other MMPs, and by metalloproteinase inhibitors such as the tissue inhibitors of metalloproteinases (TIMPs). MMPs are best known for their role in the degradation and removal of ECM molecules. In addition, cleavage of the ECM and other cell surface molecules can release ECM-bound growth factors, and a number of non-ECM proteins are substrates of MMPs (Nagase et al. 2006). MMPs can be divided into subgroups based on domain structure and substrate specificity but it is clear that these are somewhat artificial, many MMPs belong to more than one functional group (Vise & Nagase 2003, Somerville et al. 2003) [[https://reactome.org/PathwayBrowser/#/R-HSA-1474228](https://reactome.org/PathwayBrowser/#/R-HSA-1474228)].
-   **Neutrophil degranulation**: Neutrophils are the most abundant leukocytes (white blood cells), indispensable in defending the body against invading microorganisms. In response to infection, neutrophils leave the circulation and migrate towards the inflammatory focus. They contain several subsets of granules that are mobilized to fuse with the cell membrane or phagosomal membrane, resulting in the exocytosis or exposure of membrane proteins. Traditionally, neutrophil granule constituents are described as antimicrobial or proteolytic, but granules also introduce membrane proteins to the cell surface, changing how the neutrophil responds to its environment (Borregaard et al. 2007). Primed neutrophils actively secrete cytokines and other inflammatory mediators and can present antigens via MHC II, stimulating T-cells (Wright et al. 2010). Granules form during neutrophil differentiation. Granule subtypes can be distinguished by their content but overlap in structure and composition. The differences are believed to be a consequence of changing protein expression and differential timing of granule formation during the terminal processes of neutrophil differentiation, rather than sorting (Le Cabec et al. 1996). The classical granule subsets are Azurophil or primary granules (AG), secondary granules (SG) and gelatinase granules (GG). Neutrophils also contain exocytosable storage cell organelles, storage vesicles (SV), formed by endocytosis they contain many cell-surface markers and extracellular, plasma proteins (Borregaard et al. 1992). Ficolin-1-rich granules (FG) are like GGs highly exocytosable but gelatinase-poor (Rorvig et al. 2009) [[https://reactome.org/PathwayBrowser/#/R-HSA-6798695](https://reactome.org/PathwayBrowser/#/R-HSA-6798695)].
-   **Interferon gamma signaling**: Interferon-gamma (IFN-gamma) belongs to the type II interferon family and is secreted by activated immune cells-primarily T and NK cells, but also B-cells and APC. INFG exerts its effect on cells by interacting with the specific IFN-gamma receptor (IFNGR). IFNGR consists of two chains, namely IFNGR1 (also known as the IFNGR alpha chain) and IFNGR2 (also known as the IFNGR beta chain). IFNGR1 is the ligand binding receptor and is required but not sufficient for signal transduction, whereas IFNGR2 do not bind IFNG independently but mainly plays a role in IFNG signaling and is generally the limiting factor in IFNG responsiveness. Both IFNGR chains lack intrinsic kinase/phosphatase activity and thus rely on other signaling proteins like Janus-activated kinase 1 (JAK1), JAK2 and Signal transducer and activator of transcription 1 (STAT-1) for signal transduction. IFNGR complex in its resting state is a preformed tetramer and upon IFNG association undergoes a conformational change. This conformational change induces the phosphorylation and activation of JAK1, JAK2, and STAT1 which in turn induces genes containing the gamma-interferon activation sequence (GAS) in the promoter [[https://reactome.org/PathwayBrowser/#/R-HSA-877300](https://reactome.org/PathwayBrowser/#/R-HSA-877300)].
-   **Hyaluronan uptake and degradation:** Hyaluronan (HA) turnover can occur locally at the tissue of origin, where it is taken up by cells to be degraded, or released into the lymphatic and vascular systems, where it can be eliminated by the liver and kidneys. Uptake of HA into cells for degradation involves receptor-mediated processes. Once HA enters lysosomes, the acidic conditions favour hyaluronidases to cleave it into small oligosaccharides, the most common size being a tetrasaccharide. Beta-glucuronidases participate in degrading the small oligosaccharides in the lysosome. Ultimately, HA is degraded into its constituent sugars (glucuronic acid and N-acetylglucosamine) which can be used to reform many glycosaminoglycans (GAGs) when released from the lysosome. A third of the total HA content in humans is turned over daily and it has a short half life of minutes in circulation up to days in many tissues. The reasons why the body eliminates HA so rapidly are unknown but one possible explanation could be HA's role as a reactive oxygen species (ROS) scavenger. Removing these toxic compounds could explain the rapid elimination of HA (Lepperdinger et al. 2004, Menzel & Farr 1998, Erickson & Stern 2012, Stern 2003) [[https://reactome.org/PathwayBrowser/#/R-HSA-2160916](https://reactome.org/PathwayBrowser/#/R-HSA-2160916)].

## GO terms:

**T cell activation** [The change in morphology and behavior of a mature or immature T cell resulting from exposure to a mitogen, cytokine, chemokine, cellular ligand, or an antigen for which it is specific. GO:0042110]

**Wnt signaling pathway** [The series of molecular signals initiated by binding of a Wnt protein to a frizzled family receptor on the surface of the target cell and ending with a change in cell state. GO:0016055]

**blood vessel maturation** [A developmental process, independent of morphogenetic (shape) change, that is required for a blood vessel to attain its fully functional state. GO:0001955]

**branching involved in prostate gland morphogenesis** [The process in which the branching structure of the prostate gland is generated and organized. A branch is a division or offshoot from a main stem. GO:0060442]

**branching involved in ureteric bud morphogenesis** [The process in which the branching structure of the ureteric bud is generated and organized. The ureteric bud is an epithelial tube that grows out from the metanephric duct. The bud elongates and branches to give rise to the ureter and kidney collecting tubules. GO:0001658]

**cartilage development** [The process whose specific outcome is the progression of a cartilage element over time, from its formation to the mature structure. Cartilage elements are skeletal elements that consist of connective tissue dominated by extracellular matrix containing collagen type II and large amounts of proteoglycan, particularly chondroitin sulfate. GO:0051216]

**cell adhesion** [The attachment of a cell, either to another cell or to an underlying substrate such as the extracellular matrix, via cell adhesion molecules. GO:0007155]

**cell migration** [The controlled self-propelled movement of a cell from one site to a destination guided by molecular cues. GO:0016477]

**cellular response to fibroblast growth factor stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an fibroblast growth factor stimulus. GO:0044344]

**cytokine-mediated signaling pathway** [The series of molecular signals initiated by the binding of a cytokine to a receptor on the surface of a cell, and ending with the regulation of a downstream cellular process, e.g. transcription. GO:0019221]

**hyaluronan catabolic process** [The chemical reactions and pathways resulting in the breakdown of hyaluronan, the naturally occurring anionic form of hyaluronic acid, any member of a group of glycosaminoglycans, the repeat units of which consist of beta-1,4 linked D-glucuronyl-beta-(1,3)-N-acetyl-D-glucosamine. GO:0030214]

**inflammatory response** [The immediate defensive reaction (by vertebrate tissue) to infection or injury caused by chemical or physical agents. The process is characterized by local vasodilation, extravasation of plasma into intercellular spaces and accumulation of white blood cells and macrophages. GO:0006954]

**macrophage fusion** [The binding and fusion of a macrophage to one or more other cells to form a multinucleated cell. GO:0034238]

**monocyte aggregation** [The adhesion of one monocyte to one or more other monocytes via adhesion molecules. GO:0070487]

**negative regulation of CD4-positive, alpha-beta T cell proliferation** [Any process that stops, prevents or reduces the frequency, rate or extent of CD4-positive, alpha-beta T cell proliferation. GO:2000562]

**negative regulation of DNA damage response, signal transduction by p53 class mediator** [Any process that stops, prevents, or reduces the frequency, rate or extent of the cascade of processes induced by the cell cycle regulator phosphoprotein p53, or an equivalent protein, in response to the detection of DNA damage. GO:0043518]

**negative regulation of apoptotic process** [Any process that stops, prevents, or reduces the frequency, rate or extent of cell death by apoptotic process.|This term should only be used when it is not possible to determine which phase or subtype of the apoptotic process is negatively regulated by a gene product. Whenever detailed information is available, the more granular children terms should be used. GO:0043066]

**negative regulation of inflammatory response** [Any process that stops, prevents, or reduces the frequency, rate or extent of the inflammatory response. GO:0050728]

**negative regulation of intrinsic apoptotic signaling pathway in response to DNA damage by p53 class mediator** [Any process that stops, prevents or reduces the frequency, rate or extent of intrinsic apoptotic signaling pathway in response to DNA damage by p53 class mediator. GO:1902166]

**negative regulation of mature B cell apoptotic process** [Any process that stops, prevents, or reduces the frequency, rate, or extent of mature B cell apoptotic process. GO:0002906]

**negative regulation of regulatory T cell differentiation** [Any process that stops, prevents, or reduces the rate of differentiation of regulatory T cells.|Note that immunologists typically use the word 'development' to refer to cells of B or T cell lineages undergoing the process that GO describes as 'cell differentiation'. GO:0045590]

**neuron projection development** [The process whose specific outcome is the progression of a neuron projection over time, from its formation to the mature structure. A neuron projection is any process extending from a neural cell, such as axons or dendrites (collectively called neurites). GO:0031175]

**positive regulation of ERK1 and ERK2 cascade** [Any process that activates or increases the frequency, rate or extent of signal transduction mediated by the ERK1 and ERK2 cascade. GO:0070374]

**positive regulation of gene expression** [Any process that increases the frequency, rate or extent of gene expression. Gene expression is the process in which a gene's coding sequence is converted into a mature gene product (protein or RNA). GO:0010628]

**positive regulation of heterotypic cell-cell adhesion** [Any process that activates or increases the frequency, rate, or extent of heterotypic cell-cell adhesion. GO:0034116]

**positive regulation of monocyte aggregation** [Any process that activates or increases the frequency, rate or extent of monocyte aggregation. GO:1900625]

**positive regulation of neutrophil apoptotic process** [Any process that activates or increases the frequency, rate, or extent of neutrophil apoptotic process. GO:0033031]

**positive regulation of peptidyl-serine phosphorylation** [Any process that activates or increases the frequency, rate or extent of the phosphorylation of peptidyl-serine. GO:0033138]

**positive regulation of peptidyl-tyrosine phosphorylation** [Any process that activates or increases the frequency, rate or extent of the phosphorylation of peptidyl-tyrosine. GO:0050731]

**receptor-mediated endocytosis** [An endocytosis process in which cell surface receptors ensure specificity of transport. A specific receptor on the cell surface binds tightly to the extracellular macromolecule (the ligand) that it recognizes; the plasma-membrane region containing the receptor-ligand complex then undergoes endocytosis, forming a transport vesicle containing the receptor-ligand complex and excluding most other plasma-membrane proteins. Receptor-mediated endocytosis generally occurs via clathrin-coated pits and vesicles. GO:0006898]

**regulation of cell growth** [Any process that modulates the frequency, rate, extent or direction of cell growth. GO:0001558]

**regulation of lamellipodium morphogenesis** [Any process that modulates the frequency, rate or extent of lamellipodium morphogenesis. GO:2000392]

**response to nutrient levels** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus reflecting the presence, absence, or concentration of nutrients. GO:0031667]

**response to organic cyclic compound** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an organic cyclic compound stimulus. GO:0014070]

**response to vitamin A** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a vitamin A stimulus. GO:0033189]

**wound healing involved in inflammatory response** [The series of events that restore integrity to damaged tissue that contribute to an inflammatory response. GO:0002246]

**wound healing, spreading of cells** [The migration of a cell along or through a wound gap that contributes to the reestablishment of a continuous surface. GO:0044319]

## MSigDB Signatures:

**REACTOME_GLYCOSAMINOGLYCAN_METABOLISM**: Glycosaminoglycan metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_GLYCOSAMINOGLYCAN_METABOLISM.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_GLYCOSAMINOGLYCAN_METABOLISM.html)]

**REACTOME_HEMOSTASIS**: Hemostasis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HEMOSTASIS.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HEMOSTASIS.html)]

**REACTOME_INNATE_IMMUNE_SYSTEM**: Innate Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html)]

**REACTOME_NEUTROPHIL_DEGRANULATION**: Neutrophil degranulation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NEUTROPHIL_DEGRANULATION.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NEUTROPHIL_DEGRANULATION.html)]

**WP_PLEURAL_MESOTHELIOMA**: Pleural mesothelioma [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PLEURAL_MESOTHELIOMA.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PLEURAL_MESOTHELIOMA.html)]

**BIOCARTA_NEUTROPHIL_PATHWAY**: Neutrophil and Its Surface Molecules [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_NEUTROPHIL_PATHWAY.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_NEUTROPHIL_PATHWAY.html)]

**REACTOME_EXTRACELLULAR_MATRIX_ORGANIZATION**: Extracellular matrix organization [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_EXTRACELLULAR_MATRIX_ORGANIZATION.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_EXTRACELLULAR_MATRIX_ORGANIZATION.html)]

**BIOCARTA_MONOCYTE_PATHWAY**: Monocyte and its Surface Molecules [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_MONOCYTE_PATHWAY.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_MONOCYTE_PATHWAY.html)]

**KEGG_ECM_RECEPTOR_INTERACTION**: ECM-receptor interaction [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_ECM_RECEPTOR_INTERACTION.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_ECM_RECEPTOR_INTERACTION.html)]

**REACTOME_DEGRADATION_OF_THE_EXTRACELLULAR_MATRIX**: Degradation of the extracellular matrix [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEGRADATION_OF_THE_EXTRACELLULAR_MATRIX.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEGRADATION_OF_THE_EXTRACELLULAR_MATRIX.html)]

**REACTOME_CELL_SURFACE_INTERACTIONS_AT_THE_VASCULAR_WALL**: Cell surface interactions at the vascular wall [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELL_SURFACE_INTERACTIONS_AT_THE_VASCULAR_WALL.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELL_SURFACE_INTERACTIONS_AT_THE_VASCULAR_WALL.html)]

**REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM**: Cytokine Signaling in Immune system [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM.html)]

**REACTOME_HYALURONAN_METABOLISM**: Hyaluronan metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HYALURONAN_METABOLISM.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HYALURONAN_METABOLISM.html)]

**WP_CKAP4_SIGNALING_PATHWAY_MAP**: CKAP4 signaling pathway map [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_CKAP4_SIGNALING_PATHWAY_MAP.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_CKAP4_SIGNALING_PATHWAY_MAP.html)]

**REACTOME_HYALURONAN_UPTAKE_AND_DEGRADATION**: Hyaluronan uptake and degradation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HYALURONAN_UPTAKE_AND_DEGRADATION.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HYALURONAN_UPTAKE_AND_DEGRADATION.html)]
