
## **Pathways:**

**HCMV Infection:** Herpesviruses have a unique four-layered structure: a core containing the large, double-stranded DNA genome is enclosed by an icosapentahedral capsid which is composed of capsomers. The capsid is surrounded by an amorphous protein coat called the tegument. It is encased in a glycoprotein-bearing lipid bilayer envelope.

Herpesviruses are divided into three groups: alpha-herpesviruses, beta-herpesviruses, and gamma-herpesviruses. The beta herpesviruses have a restricted host range. Their reproductive life cycle is long (days), with infection progressing slowly in cell culture systems. These viruses cause their host cells to enlarge, as exemplified by a human cytomegalovirus (HCMV) infection. These viruses can establish latent infection in secretory glands, cells of the reticuloendothelial system, and the kidneys.

Human Cytomegalovirus, or HCMV, is a common virus that infects people of all ages. In the United States, nearly one in three children are already infected with HCMV by age 5 years. Over half of adults by age 40 have been infected with HCMV. Once HCMV is in a person's body, it stays there for life and can reactivate.

Cytomegalovirus causes three clinical syndromes: (1) Congenital cytomegalovirus infection (when symptomatic) causes hepatosplenomegaly, retinitis, rash, and central nervous system involvement. (2) In about 10 per cent of older children and adults, primary cytomegalovirus infection causes a mononucleosis syndrome with fever, malaise, atypical lymphocytosis, and pharyngitis. (3) Immunocompromised hosts (transplant recipients and human immunodeficiency virus [HIV]-infected individuals) may develop life-threatening disseminated disease involving the lungs, gastrointestinal tract, liver, retina, and central nervous system.

Experimentally HCMV can be propagated in multiple cell lines. When propagated in human fibroblasts, HCMV clinical isolates acquire mutations in a manner that suggests a process of adaptation. Two strains of HCMV AD169 (grown from cultures of adenoid tissue taken from a 7-year-old girl) and Towne (developed as an attenuated vaccine by passaging 125 times in vitro) were initially used as the primary clinical strains. As only 26 % of HCMV canonical genes (45/171) are essential for viral replication in vitro it became important that a model strain be developed.

The Merlin BAC was derived for this use. Produced using a bacterial artificial chromosome (BAC) cloning system (to avoid adaptation/degradation of the genome with each passage) the Merlin strain contains a complete HCMV genome that is thought to accurately to represent the original clinical agent from which it was derived. It is also a reproducible source of clonal virus (via transfection) and is capable of reconstituting phenotypically wild-type viruses.

The lifecycle represented here uses the Merlin strain where possible. Infectious Human Cytomegalovirus (HCMV) particles enter the cell through interaction with cellular receptors. Once in the cytoplasm capsid and tegument proteins are delivered to the cytosol. The capsid travels to the nucleus, where the genome is delivered and circularized. Tegument proteins regulate host cell responses and initiate the expression of viral I immediate early genes. This is followed by delayed early genes, which initiate viral genome replication, then late genes. Late gene expression initiates capsid assembly in the nucleus, followed by nuclear egress to the cytosol. Capsids associate with tegument proteins in the cytosol and are trafficked to the viral assembly complex that contains components from the endoplasmic reticulum, Golgi apparatus, and endosomal machinery. The capsids acquire additional tegument proteins and a viral envelope by budding into intracellular vesicles. These vesicles fuse with the plasma membrane to release enveloped infectious particles along with non-infectious dense bodies [[https://reactome.org/PathwayBrowser/#/R-HSA-9609646&PATH=R-HSA-1643685,R-HSA-5663205,R-HSA-9824446](https://reactome.org/PathwayBrowser/#/R-HSA-9609646&PATH=R-HSA-1643685,R-HSA-5663205,R-HSA-9824446)].

**HCMV Late Events:** Once Human Cytomegalovirus (HCMV) Immediate Early (IE) and Delayed Early (DE) gene products begin to appear the processes driving DNA replication, Late (L) gene expression, and virion assembly begin [[https://reactome.org/PathwayBrowser/#/R-HSA-9609646&SEL=R-HSA-9610379&PATH=R-HSA-1643685,R-HSA-5663205,R-HSA-9824446](https://reactome.org/PathwayBrowser/#/R-HSA-9609646&SEL=R-HSA-9610379&PATH=R-HSA-1643685,R-HSA-5663205,R-HSA-9824446)].

**Interleukin-4 and Interleukin-13 signaling:** Interleukin-4 (IL4) is a principal regulatory cytokine during the immune response, crucially important in allergy and asthma (Nelms et al. 1999). When resting T cells are antigen-activated and expand in response to Interleukin-2 (IL2), they can differentiate as Type 1 (Th1) or Type 2 (Th2) T helper cells. The outcome is influenced by IL4. Th2 cells secrete IL4, which both stimulates Th2 in an autocrine fashion and acts as a potent B cell growth factor to promote humoral immunity (Nelms et al. 1999).  
Interleukin-13 (IL13) is an immunoregulatory cytokine secreted predominantly by activated Th2 cells. It is a key mediator in the pathogenesis of allergic inflammation. IL13 shares many functional properties with IL4, stemming from the fact that they share a common receptor subunit. IL13 receptors are expressed on human B cells, basophils, eosinophils, mast cells, endothelial cells, fibroblasts, monocytes, macrophages, respiratory epithelial cells, and smooth muscle cells, but unlike IL4, not T cells. Thus IL13 does not appear to be important in the initial differentiation of CD4 T cells into Th2 cells, rather it is important in the effector phase of allergic inflammation (Hershey et al. 2003). IL4 and IL13 induce "alternative activation" of macrophages, inducing an anti-inflammatory phenotype by signaling through IL4R alpha in a STAT6 dependent manner. This signaling plays an important role in the Th2 response, mediating anti-parasitic effects and aiding wound healing (Gordon & Martinez 2010, Loke et al. 2002) There are two types of IL4 receptor complex (Andrews et al. 2006). Type I IL4R (IL4R1) is predominantly expressed on the surface of hematopoietic cells and consists of IL4R and IL2RG, the common gamma chain. Type II IL4R (IL4R2) is predominantly expressed on the surface of nonhematopoietic cells, it consists of IL4R and IL13RA1 and is also the type II receptor for IL13. (Obiri et al. 1995, Aman et al. 1996, Hilton et al. 1996, Miloux et al. 1997, Zhang et al. 1997). The second receptor for IL13 consists of IL4R and Interleukin-13 receptor alpha 2 (IL13RA2), sometimes called Interleukin-13 binding protein (IL13BP). It has a high affinity receptor for IL13 (Kd = 250 pmol/L) but is not sufficient to render cells responsive to IL13, even in the presence of IL4R (Donaldson et al. 1998). It is reported to exist in soluble form (Zhang et al. 1997) and when overexpressed reduces JAK-STAT signaling (Kawakami et al. 2001). Its function may be to prevent IL13 signaling via the functional IL4R:IL13RA1 receptor. IL13RA2 is overexpressed and enhances cell invasion in some human cancers (Joshi & Puri 2012).  
The first step in the formation of IL4R1 (IL4:IL4R:IL2RB) is the binding of IL4 with IL4R (Hoffman et al. 1995, Shen et al. 1996, Hage et al. 1999). This is also the first step in formation of IL4R2 (IL4:IL4R:IL13RA1). After the initial binding of IL4 and IL4R, IL2RB binds (LaPorte et al. 2008), to form IL4R1. Alternatively, IL13RA1 binds, forming IL4R2. In contrast, the type II IL13 complex (IL13R2) forms with IL13 first binding to IL13RA1 followed by recruitment of IL4R (Wang et al. 2009).  
Crystal structures of the IL4:IL4R:IL2RG, IL4:IL4R:IL13RA1 and IL13:IL4R:IL13RA1 complexes have been determined (LaPorte et al. 2008). Consistent with these structures, in monocytes IL4R is tyrosine phosphorylated in response to both IL4 and IL13 (Roy et al. 2002, Gordon & Martinez 2010) while IL13RA1 phosphorylation is induced only by IL13 (Roy et al. 2002, LaPorte et al. 2008) and IL2RG phosphorylation is induced only by IL4 (Roy et al. 2002). Both IL4 receptor complexes signal through Jak/STAT cascades. IL4R is constitutively associated with JAK2 (Roy et al. 2002) and associates with JAK1 following binding of IL4 (Yin et al. 1994) or IL13 (Roy et al. 2002). IL2RG constitutively associates with JAK3 (Boussiotis et al. 1994, Russell et al. 1994). IL13RA1 constitutively associates with TYK2 (Umeshita-Suyama et al. 2000, Roy et al. 2002, LaPorte et al. 2008, Bhattacharjee et al. 2013).  
IL4 binding to IL4R1 leads to phosphorylation of JAK1 (but not JAK2) and STAT6 activation (Takeda et al. 1994, Ratthe et al. 2007, Bhattacharjee et al. 2013). IL13 binding increases activating tyrosine-99 phosphorylation of IL13RA1 but not that of IL2RG. IL4 binding to IL2RG leads to its tyrosine phosphorylation (Roy et al. 2002). IL13 binding to IL4R2 leads to TYK2 and JAK2 (but not JAK1) phosphorylation (Roy & Cathcart 1998, Roy et al. 2002). Phosphorylated TYK2 binds and phosphorylates STAT6 and possibly STAT1 (Bhattacharjee et al. 2013).  
A second mechanism of signal transduction activated by IL4 and IL13 leads to the insulin receptor substrate (IRS) family (Kelly-Welch et al. 2003). IL4R1 associates with insulin receptor substrate 2 and activates the PI3K/Akt and Ras/MEK/Erk pathways involved in cell proliferation, survival, and translational control. IL4R2 does not associate with insulin receptor substrate 2 and consequently the PI3K/Akt and Ras/MEK/Erk pathways are not activated (Busch-Dienstfertig & Gonzalez-Rodriguez 2013) [[https://reactome.org/PathwayBrowser/#/R-HSA-6785807](https://reactome.org/PathwayBrowser/#/R-HSA-6785807)].

**Transcriptional regulation of white adipocyte differentiation:** Adipogenesis is the process of cell differentiation by which preadipocytes become adipocytes. During this process the preadipocytes cease to proliferate, begin to accumulate lipid droplets, and develop morphologic and biochemical characteristics of mature adipocytes such as hormone responsive lipogenenic and lipolytic programs. The most intensively studied model system for adipogenesis is differentiation of the mouse 3T3-L1 preadipocyte cell line by an induction cocktail of containing mitogens (insulin/IGF1), glucocorticoid (dexamethasone), an inducer of cAMP (IBMX), and fetal serum (Cao et al. 1991, reviewed in Farmer 2006). More recently additional cellular models have become available to study adipogenesis that involve almost all stages of development (reviewed in Rosen and MacDougald 2006). In vivo knockout mice lacking putative adipogenic factors have also been extensively studied. Human pathways are traditionally inferred from those discovered in mouse but are now beginning to be validated in cellular models derived from human adipose progenitors (Fischer-Posovszky et al. 2008, Wdziekonski et al. 2011).  
Adipogenesis is controlled by a cascade of transcription factors (Yeh et al. 1995, reviewed in Farmer 2006, Gesta et al. 2007). One of the first observable events during adipocyte differentiation is a transient increase in expression of the CEBPB (CCAAT/Enhancer Binding Protein Beta, C/EBPB) and CEBPD (C/EBPD) transcription factors (Cao et al. 1991, reviewed in Lane et al. 1999). This occurs prior to the accumulation of lipid droplets. However, it is the subsequent inductions of CEBPA and PPARG that are critical for morphological, biochemical, and functional adipocytes.  
Ectopic expression of CEBPB alone is capable of inducing substantial adipocyte differentiation in fibroblasts while CEBPD has a minimal effect. CEBPB is upregulated in response to intracellular cAMP (possibly via pCREB) and serum mitogens (possibly via Krox20). CEBPD is upregulated in response to glucocorticoids. The exact mechanisms that upregulate the CEBPs are not fully known. CEBPB and CEBPD act directly on the Peroxisome Proliferator-activated Receptor Gamma (PPARG) gene by binding its promoter and activating transcription. CEBPB and CEBPD also directly activate the EBF1 gene (and possibly other EBFs) and KLF5 (Jimenez et al. 2007, Oishi 2005). The EBF1 and KLF5 proteins, in turn bind, and activate the PPARG promoter. Other hormones, such as insulin, affect PPARG expression and other transcription factors, such as ADD1/SREBP1c, bind the PPARG promoter. This is an area of ongoing research.  
During adipogenesis the PPARG gene is transcribed to yield 2 variants. The adipogenic variant 2 mRNA encodes 30 additional amino acids at the N-terminus compared to the widely expressed variant 1 mRNA. PPARG encodes a type II nuclear hormone receptor (remains in the nucleus in the absence of ligand) that forms a heterodimer with the Retinoid X Receptor Alpha (RXRA). The heterodimer was initially identified as a complex regulating the aP2/FABP4 gene and named ARF6 (Tontonoz et al. 1994). The PPARG:RXRA heterodimer binds a recognition sequence that consists of two hexanucleotide motifs (DR1 motifs) separated by 1 nucleotide. Binding occurs even in the absence of ligands, such as fatty acids, that activate PPARG. In the absence of activating ligands, the PPARG:RXRA complex recruits repressors of transcription such as SMRT/NCoR2, NCoR1, and HDAC3 (Tontonoz and Spiegelman 2008).  
Each molecule of PPARG can bind 2 molecules of activating ligands. Although, the identity of the endogenous ligands of PPARG is unknown, exogenous activators include fatty acids and the thiazolidinedione class of antidiabetic drugs (reviewed in Berger et al. 2005, Heikkinen et al. 2007, Lemberger et al. 1996). The most potent activators of PPARG in vitro are oxidized derivatives of unsaturated fatty acids. Upon binding activating ligands PPARG causes a rearrangement of adjacent factors: Corepressors such as SMRT/NCoR2 are lost and coactivators such as TIF2, PRIP, CBP, and p300 are recruited (Tontonoz and Spiegelman). PPARG also binds directly to the TRAP220 subunit of the TRAP/Mediator complex that recruits RNA polymerase II. Thus binding of activating ligand by PPARG causes transcription of PPARG target genes. Targets of PPARG include genes involved in differentiation (PGAR/HFARP, Perilipin, aP2/FABP4, CEBPA), fatty acid transport (LPL, FAT/CD36), carbohydrate metabolism (PEPCK-C, AQP7, GK, GLUT4 (SLC2A4)), and energy homeostasis (LEPTIN and ADIPONECTIN) (Perera et al. 2006).  
Within 10 days of differentiation CEBPB and CEBPD are no longer located at the PPARG promoter. Instead CEBPA is present. EBF1 and PPARG bind the CEBPA promoter and activate transcription of CEBPA, one of the key transcription factors in adipogenesis. A current hypothesis posits a self-reinforcing loop that maintains PPARG expression and the differentiated state: PPARG activates CEBPA and CEBPA activates PPARG. Additionally, EBF1 (and possibly other EBFs) activates CEBPA, CEBPA activates EBF1, and EBF1 activates PPARG. [[https://reactome.org/PathwayBrowser/#/R-HSA-381340](https://reactome.org/PathwayBrowser/#/R-HSA-381340)].

## GO terms:

**DNA-templated transcription** [The synthesis of an RNA transcript from a DNA template. GO:0006351]

**fat cell differentiation** [The process in which a relatively unspecialized cell acquires specialized features of an adipocyte, an animal connective tissue cell specialized for the synthesis and storage of fat. GO:0045444]

**hematopoietic progenitor cell differentiation** [The process in which precursor cell type acquires the specialized features of a hematopoietic progenitor cell, a class of cell types including myeloid progenitor cells and lymphoid progenitor cells. GO:0002244]

**inner ear development** [The process whose specific outcome is the progression of the inner ear over time, from its formation to the mature structure. GO:0048839]

**negative regulation of DNA-templated transcription** [Any process that stops, prevents, or reduces the frequency, rate or extent of cellular DNA-templated transcription. GO:0045892]

**positive regulation of osteoblast differentiation** [Any process that activates or increases the frequency, rate or extent of osteoblast differentiation. GO:0045669]

**positive regulation of transcription by RNA polymerase II** [Any process that activates or increases the frequency, rate or extent of transcription from an RNA polymerase II promoter. GO:0045944]

**regulation of cell differentiation** [Any process that modulates the frequency, rate or extent of cell differentiation, the process in which relatively unspecialized cells acquire specialized structural and functional features. GO:0045595]

**regulation of transcription by RNA polymerase II** [Any process that modulates the frequency, rate or extent of transcription mediated by RNA polymerase II. GO:0006357]

## MSigDB Signatures:

**WP_INFLUENCE_OF_LAMINOPATHIES_ON_WNT_SIGNALING**: Influence of laminopathies on Wnt signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_INFLUENCE_OF_LAMINOPATHIES_ON_WNT_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_INFLUENCE_OF_LAMINOPATHIES_ON_WNT_SIGNALING.html)

**WP_OVERLAP_BETWEEN_SIGNAL_TRANSDUCTION_PATHWAYS_CONTRIBUTING_TO_LMNA_LAMINOPATHIES**: Overlap between signal transduction pathways contributing to LMNA laminopathies [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_OVERLAP_BETWEEN_SIGNAL_TRANSDUCTION_PATHWAYS_CONTRIBUTING_TO_LMNA_LAMINOPATHIES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_OVERLAP_BETWEEN_SIGNAL_TRANSDUCTION_PATHWAYS_CONTRIBUTING_TO_LMNA_LAMINOPATHIES.html)

**REACTOME_DEVELOPMENTAL_BIOLOGY**: Developmental Biology [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEVELOPMENTAL_BIOLOGY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEVELOPMENTAL_BIOLOGY.html)

**WP_WHITE_FAT_CELL_DIFFERENTIATION**: White fat cell differentiation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_WHITE_FAT_CELL_DIFFERENTIATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_WHITE_FAT_CELL_DIFFERENTIATION.html)

**WP_ADIPOGENESIS**: Adipogenesis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ADIPOGENESIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ADIPOGENESIS.html)

**WP_TRANSCRIPTIONAL_CASCADE_REGULATING_ADIPOGENESIS**: Transcriptional cascade regulating adipogenesis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TRANSCRIPTIONAL_CASCADE_REGULATING_ADIPOGENESIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TRANSCRIPTIONAL_CASCADE_REGULATING_ADIPOGENESIS.html)

**WP_IL_17_SIGNALING_PATHWAY**: IL 17 signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_IL_17_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_IL_17_SIGNALING_PATHWAY.html)

**REACTOME_SIGNALING_BY_INTERLEUKINS**: Signaling by Interleukins [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_INTERLEUKINS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_INTERLEUKINS.html)

**REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM**: Cytokine Signaling in Immune system [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM.html)

**REACTOME_INTERLEUKIN_4_AND_INTERLEUKIN_13_SIGNALING**: Interleukin-4 and Interleukin-13 signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INTERLEUKIN_4_AND_INTERLEUKIN_13_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INTERLEUKIN_4_AND_INTERLEUKIN_13_SIGNALING.html)

**REACTOME_TRANSCRIPTIONAL_REGULATION_OF_WHITE_ADIPOCYTE_DIFFERENTIATION**: Transcriptional regulation of white adipocyte differentiation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRANSCRIPTIONAL_REGULATION_OF_WHITE_ADIPOCYTE_DIFFERENTIATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRANSCRIPTIONAL_REGULATION_OF_WHITE_ADIPOCYTE_DIFFERENTIATION.html)

**WP_TRANSCRIPTION_FACTOR_REGULATION_IN_ADIPOGENESIS**: Transcription factor regulation in adipogenesis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TRANSCRIPTION_FACTOR_REGULATION_IN_ADIPOGENESIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TRANSCRIPTION_FACTOR_REGULATION_IN_ADIPOGENESIS.html)

**REACTOME_HCMV_INFECTION**: HCMV Infection [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HCMV_INFECTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HCMV_INFECTION.html)

**REACTOME_INFECTIOUS_DISEASE**: Infectious disease [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INFECTIOUS_DISEASE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INFECTIOUS_DISEASE.html)
