
## **Pathways:**

-   **Antimicrobial peptides**: Antimicrobial peptides (AMPs) are small molecular weight proteins with broad spectrum of antimicrobial activity against bacteria, viruses, and fungi (Zasloff M 2002; Radek K & Gallo R 2007). The majority of known AMPs are cationic peptides with common structural characteristics where domains of hydrophobic and cationic amino acids are spatially arranged into an amphipathic design, which facilitates their interaction with bacterial membranes (Shai Y 2002; Yeaman MR & Yount NY 2003; Brown KL & Hancock RE 2006; Dennison SR et al. 2005; Zelezetsky I & Tossi A 2006). It is generally excepted that the electrostatic interaction facilitates the initial binding of the positively charged peptides to the negatively charged bacterial membrane. Moreover, the structural amphiphilicity of AMPs is thought to promote their integration into lipid bilayers of pathogenic cells, leading to membrane disintegration and finally to the microbial cell death. In addition to cationic AMPs a few anionic antimicrobial peptides have been found in humans, however their mechanism of action remains to be clarified (Lai Y et al. 2007; Harris F et al. 2009; Paulmann M et al. 2012). Besides the direct neutralizing effects on bacteria AMPs may modulate cells of the adaptive immunity (neutrophils, T-cells, macrophages) to control inflammation and/or to increase bacterial clearance. AMPs have also been referred to as cationic host defense peptides, anionic antimicrobial peptides/proteins, cationic amphipathic peptides, cationic AMPs, host defense peptides and alpha-helical antimicrobial peptides (Brown KL & Hancock RE 2006; Harris F et al. 2009; Groenink J et al. 1999; Bradshaw J 2003; Riedl S et al. 2011; Huang Y et al. 2010). The Reactome module describes the interaction events of various types of human AMPs, such as cathelicidin, histatins and neutrophil serine proteases, with conserved patterns of microbial membranes at the host-pathogen interface. The module includes also proteolytic processing events for dermcidin (DCD) and cathelicidin (CAMP) that become functional upon cleavage. In addition, the module highlights an AMP-associated ability of the host to control metal quota at inflammation sites to influence host-pathogen interactions [[https://reactome.org/PathwayBrowser/#/R-HSA-6803157](https://reactome.org/PathwayBrowser/#/R-HSA-6803157)].
-   **Regulation of Complement cascade**: Two inherent features of complement activation make its regulation very important: 1. There is an inherent positive feedback loop because the product of C3 activation forms part of an enzyme that causes more C3 activation. 2. There is continuous low-level activation of the alternative pathway (see Spontaneous hydrolysis of C3 thioester). Complement cascade activation is regulated by a family of related proteins termed the regulators of complement activation (RCA). These are expressed on healthy host cells. Most pathogens do not express RCA proteins on their surface, but many have found ways to evade the complement system by stably binding the RCA that circulates in human plasma (Lambris et al. 2008); trapping RCA is by far the most widely employed strategy for avoiding the complement response. RCA recruitment is common in bacteria such as E. coli and streptococci (Kraiczy & Wurzner 2006) and has also been described for viruses, fungi and parasites. RCA deposition and the complement system also have an important role in tissue homeostasis, clearing dead cells and debris, and preventing damage from oxidative stress (Weismann et al. 2011). RCA proteins control complement activation in two different ways; by promoting the irreversible dissociation (decay acceleration) of complement convertases and by acting as cofactors for Complement factor I (CFI)-mediated cleavage of C3b and C4b. Decay accelerating factor (DAF, CD55), Complement factor H (FH), Membrane Cofactor Protein (MCP) and Complement receptor 1 (CR1) are composed of arrays of tandem globular domains termed CCPs (complement control protein repeats) or SCRs (short consensus repeats). CR1, MCP and FH are cofactors for the CFI-mediated cleavage of C3b, generating iC3b. CR1 and MCP are also cofactors for C4b cleavage. C4BP is an additional cofactor for the CFI-mediated cleavage of C4b [[https://reactome.org/PathwayBrowser/#/R-HSA-977606](https://reactome.org/PathwayBrowser/#/R-HSA-977606)].
-   **Terminal pathway of complement**: After cleavage of C5, C5b undergoes conformational changes and exposes a binding site for C6. C5b6 binds C7 resulting in the exposure of membrane binding sites and incorporation into target membranes. The membrane-bound C5b-7 complex can then bind C8. C5b-8 acts as a polymerizing agent for C9. The first C9 bound to C5b-8 undergoes major structural changes enabling formation of an elongated molecule and allows binding of additional C9 molecules and insertion of C9 cylinders into the target membrane. The number of C9 molecules varies from 1-12 in the membrane, although polymers containing up to fifteen C9 molecules are also possible [[https://reactome.org/PathwayBrowser/#/R-HSA-166665](https://reactome.org/PathwayBrowser/#/R-HSA-166665)].
-   **Platelet degranulation**: Platelets function as exocytotic cells, secreting a plethora of effector molecules at sites of vascular injury. Platelets contain a number of distinguishable storage granules including alpha granules, dense granules and lysosomes. On activation platelets release a variety of proteins, largely from storage granules but also as the result of apparent cell lysis. These act in an autocrine or paracrine fashion to modulate cell signaling. Alpha granules contain mainly polypeptides such as fibrinogen, von Willebrand factor, growth factors and protease inhibitors that that supplement thrombin generation at the site of injury. Dense granules contain small molecules, particularly adenosine diphosphate (ADP), adenosine triphosphate (ATP), serotonin and calcium, all recruit platelets to the site of injury. The molecular mechanism which facilitates granule release involves soluble NSF attachment protein receptors (SNAREs), which assemble into complexes to form a universal membrane fusion apparatus. Although all cells use SNAREs for membrane fusion, different cells possess different SNARE isoforms. Platelets and chromaffin cells use many of the same chaperone proteins to regulate SNARE-mediated secretion (Fitch-Tewfik & Flaumenhaft 2013) [[https://reactome.org/PathwayBrowser/#/R-HSA-114608](https://reactome.org/PathwayBrowser/#/R-HSA-114608)].

## GO terms:

**cell morphogenesis** [The developmental process in which the size or shape of a cell is generated and organized. GO:0000902]

**cellular response to growth factor stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a growth factor stimulus. GO:0071363]

**central nervous system myelin maintenance** [The process in which the structure and material content of mature central nervous system myelin is kept in a functional state. GO:0032286]

**chaperone-mediated protein complex assembly** [The aggregation, arrangement and bonding together of a set of components to form a protein complex, mediated by chaperone molecules that do not form part of the finished complex. GO:0051131]

**chaperone-mediated protein folding** [The process of inhibiting aggregation and assisting in the covalent and noncovalent assembly of single chain polypeptides or multisubunit complexes into the correct tertiary structure that is dependent on interaction with a chaperone. GO:0061077]

**endocrine pancreas development** [The process whose specific outcome is the progression of the endocrine pancreas over time, from its formation to the mature structure. The endocrine pancreas is made up of islet cells that produce insulin, glucagon and somatostatin. GO:0031018]

**estrous cycle** [A type of ovulation cycle, which occurs in most mammalian therian females, where the endometrium is resorbed if pregnancy does not occur. GO:0044849]

**immune complex clearance** [A process directed at removing immune complexes from the body. Immune complexes are clusters of antibodies bound to antigen, to which complement may also be fixed, and which may precipitate or remain in solution. GO:0002434]

**intrinsic apoptotic signaling pathway** [The series of molecular signals in which an intracellular signal is conveyed to trigger the apoptotic death of a cell. The pathway starts with reception of an intracellular signal (e.g. DNA damage, endoplasmic reticulum stress, oxidative stress etc.), and ends when the execution phase of apoptosis is triggered. The intrinsic apoptotic signaling pathway is crucially regulated by permeabilization of the mitochondrial outer membrane (MOMP).|The signals that start intrinsic apoptosis may come from extracellular sources (e.g. oxidative stress, UV exposure), but the reception of the signal and thus the signaling pathway start inside the cell (as a result of DNA damage, redox imbalance, etc.). Examples are ZPR9 (ZNF622) and ASK1 (MAP3K5) (UniProt symbols Q969S3 and Q99683) in PMID: 21771788. A diagram of the intrinsic apoptotic pathway including examples of molecular players can be found in Figure 2 in PMID: 21760595. GO:0097193]

**microglial cell activation** [The change in morphology and behavior of a microglial cell resulting from exposure to a cytokine, chemokine, cellular ligand, or soluble factor. GO:0001774]

**microglial cell proliferation** [The expansion of a microglial cell population by cell division. GO:0061518]

**negative regulation of amyloid fibril formation** [Any process that stops, prevents or reduces the frequency, rate or extent of amyloid fibril formation.|Although deposition of amyloid fibrils is associated with diseases, e.g. Alzheimer's disease, amyloid formation is a normal process. Disease occurs when the balance between amyloid formation and clearance is disrupted (reviewed e.g. in PMID: 29654159 and PMID: 28937655). An example of a normal amyloid complex is composed of human RIP1 and RIP3 kinases (PMID: 22817896). GO:1905907]

**negative regulation of amyloid-beta formation** [Any process that stops, prevents or reduces the frequency, rate or extent of amyloid-beta formation. GO:1902430]

**negative regulation of apoptotic process** [Any process that stops, prevents, or reduces the frequency, rate or extent of cell death by apoptotic process.|This term should only be used when it is not possible to determine which phase or subtype of the apoptotic process is negatively regulated by a gene product. Whenever detailed information is available, the more granular children terms should be used. GO:0043066]

**negative regulation of intrinsic apoptotic signaling pathway in response to DNA damage** [Any process that stops, prevents or reduces the frequency, rate or extent of intrinsic apoptotic signaling pathway in response to DNA damage. GO:1902230]

**negative regulation of neuron apoptotic process** [Any process that stops, prevents, or reduces the frequency, rate or extent of cell death by apoptotic process in neurons. GO:0043524]

**negative regulation of protein-containing complex assembly** [Any process that stops, prevents, or reduces the frequency, rate or extent of protein complex assembly. GO:0031333]

**negative regulation of response to endoplasmic reticulum stress** [Any process that stops, prevents or reduces the frequency, rate or extent of a response to endoplasmic reticulum stress. GO:1903573]

**neuron projection morphogenesis** [The process in which the anatomical structures of a neuron projection are generated and organized. A neuron projection is any process extending from a neural cell, such as axons or dendrites. GO:0048812]

**positive regulation of amyloid-beta formation** [Any process that activates or increases the frequency, rate or extent of amyloid-beta formation. GO:1902004]

**positive regulation of apoptotic process** [Any process that activates or increases the frequency, rate or extent of cell death by apoptotic process.|This term should only be used when it is not possible to determine which phase or subtype of the apoptotic process is positively regulated by a gene product. Whenever detailed information is available, the more granular children terms should be used. GO:0043065]

**positive regulation of cell differentiation** [Any process that activates or increases the frequency, rate or extent of cell differentiation. GO:0045597]

**positive regulation of cell population proliferation** [Any process that activates or increases the rate or extent of cell proliferation. GO:0008284]

**positive regulation of gene expression** [Any process that increases the frequency, rate or extent of gene expression. Gene expression is the process in which a gene's coding sequence is converted into a mature gene product (protein or RNA). GO:0010628]

**positive regulation of intrinsic apoptotic signaling pathway** [Any process that activates or increases the frequency, rate or extent of intrinsic apoptotic signaling pathway. GO:2001244]

**positive regulation of neurofibrillary tangle assembly** [Any process that activates or increases the frequency, rate or extent of neurofibrillary tangle assembly. GO:1902998]

**positive regulation of nitric oxide biosynthetic process** [Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of nitric oxide. GO:0045429]

**positive regulation of proteasomal ubiquitin-dependent protein catabolic process** [Any process that activates or increases the frequency, rate or extent of the breakdown of a protein or peptide by hydrolysis of its peptide bonds, initiated by the covalent attachment of ubiquitin, and mediated by the proteasome. GO:0032436]

**positive regulation of protein-containing complex assembly** [Any process that activates or increases the frequency, rate or extent of protein complex assembly. GO:0031334]

**positive regulation of receptor-mediated endocytosis** [Any process that activates or increases the frequency, rate or extent of receptor mediated endocytosis, the uptake of external materials by cells, utilizing receptors to ensure specificity of transport. GO:0048260]

**positive regulation of tumor necrosis factor production** [Any process that activates or increases the frequency, rate or extent of tumor necrosis factor production.|Note that this term refers only to the specific, original 'tumor necrosis factor' protein (TNF) and not other members of the tumor necrosis factor superfamily (those with the gene symbol root 'TNFSF'). GO:0032760]

**positive regulation of ubiquitin-dependent protein catabolic process** [Any process that activates or increases the frequency, rate or extent of ubiquitin-dependent protein catabolic process. GO:2000060]

**protein import** [The targeting and directed movement of proteins into a cell or organelle. Not all import involves an initial targeting event. GO:0017038]

**protein stabilization** [Any process involved in maintaining the structure and integrity of a protein and preventing it from degradation or aggregation. GO:0050821]

**protein targeting to lysosome involved in chaperone-mediated autophagy** [The targeting of a protein to the lysosome process in which an input protein binds to a chaperone and subsequently to a lysosomal receptor. GO:0061740]

**regulation of amyloid-beta clearance** [Any process that modulates the frequency, rate or extent of amyloid-beta clearance. GO:1900221]

**regulation of apoptotic process** [Any process that modulates the occurrence or rate of cell death by apoptotic process.|This term should only be used when it is not possible to determine which phase or subtype of the apoptotic process is regulated by a gene product. Whenever detailed information is available, the more granular children terms should be used. GO:0042981]

**regulation of cell population proliferation** [Any process that modulates the frequency, rate or extent of cell proliferation. GO:0042127]

**regulation of neuronal signal transduction** [Any process that modulates the frequency, rate or extent of neuronal signal transduction. GO:1902847]

**response to light stimulus** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a light stimulus, electromagnetic radiation of wavelengths classified as infrared, visible or ultraviolet light. GO:0009416]

**response to misfolded protein** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a misfolded protein stimulus. GO:0051788]

**response to potassium ion** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a potassium ion stimulus. GO:0035864]

**response to virus** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a virus. GO:0009615]

**spermatogenesis** [The developmental process by which male germ line stem cells self renew or give rise to successive cell types resulting in the development of a spermatozoa. GO:0007283]

## MSigDB Signatures:

**REACTOME_HEMOSTASIS**: Hemostasis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HEMOSTASIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HEMOSTASIS.html)

**REACTOME_INNATE_IMMUNE_SYSTEM**: Innate Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html)

**REACTOME_COMPLEMENT_CASCADE**: Complement cascade [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_COMPLEMENT_CASCADE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_COMPLEMENT_CASCADE.html)

**WP_MALE_INFERTILITY**: Male infertility [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_MALE_INFERTILITY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_MALE_INFERTILITY.html)

**KEGG_MEDICUS_REFERENCE_REGULATION_OF_COMPLEMENT_CASCADE_MAC_INHIBITION**: Pathway Definition from KEGG: (CD59,CLU,VTN) -| (C5b+C6+C7+C8+C9) [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_REGULATION_OF_COMPLEMENT_CASCADE_MAC_INHIBITION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_REGULATION_OF_COMPLEMENT_CASCADE_MAC_INHIBITION.html)

**WP_COMPLEMENT_AND_COAGULATION_CASCADES**: Complement and coagulation cascades [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_COMPLEMENT_AND_COAGULATION_CASCADES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_COMPLEMENT_AND_COAGULATION_CASCADES.html)

**REACTOME_TERMINAL_PATHWAY_OF_COMPLEMENT**: Terminal pathway of complement [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TERMINAL_PATHWAY_OF_COMPLEMENT.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TERMINAL_PATHWAY_OF_COMPLEMENT.html)
