
## **Pathways:**

-   **Activation of Matrix Metalloproteinases:** The matrix metalloproteinases (MMPs), previously known as matrixins, are classically known to be involved in the turnover of extracellular matrix (ECM) components. However, recent high throughput proteomics analyses have revealed that ~80% of MMP substrates are non-ECM proteins including cytokines, growth factor binding protiens, and receptors. It is now clear that MMPs regulate ECM turnover not only by cleaving ECM components, but also by the regulation of cell signalling, and that some MMPs are beneficial and may be drug anti-targets. Thus, MMPs have important roles in many processes including embryo development, morphogenesis, tissue homeostasis and remodeling. They are implicated in several diseases such as arthritis, periodontitis, glomerulonephritis, atherosclerosis, tissue ulceration, and cancer cell invasion and metastasis. All MMPs are synthesized as preproenzymes. Alternate splice forms are known, leading to nuclear localization of select MMPs. Most are secreted from the cell, or in the case of membrane type (MT) MMPs become plasma membrane associated, as inactive proenzymes. Their subsequent activation is a key regulatory step, with requirements specific to MMP subtype. [[https://reactome.org/PathwayBrowser/#/R-HSA-1592389](https://reactome.org/PathwayBrowser/#/R-HSA-1592389)].
-   **Degradation of the extracellular matrix:** Matrix metalloproteinases (MMPs), previously referred to as matrixins because of their role in degradation of the extracellular matrix (ECM), are zinc and calcium dependent proteases belonging to the metzincin family. They contain a characteristic zinc-binding motif HEXXHXXGXXH (Stocker & Bode 1995) and a conserved Methionine which forms a Met-turn. Humans have 24 MMP genes giving rise to 23 MMP proteins, as MMP23 is encoded by two identical genes. All MMPs contain an N-terminal secretory signal peptide and a prodomain with a conserved PRCGXPD motif that in the inactive enzyme is localized with the catalytic site, the cysteine acting as a fourth unpaired ligand for the catalytic zinc atom. Activation involves delocalization of the domain containing this cysteine by a conformational change or proteolytic cleavage, a mechanism referred to as the cysteine-switch (Van Wart & Birkedal-Hansen 1990). Most MMPs are secreted but the membrane type MT-MMPs are membrane anchored and some MMPs may act on intracellular proteins. Various domains determine substrate specificity, cell localization and activation (Hadler-Olsen et al. 2011). MMPs are regulated by transcription, cellular location (most are not activated until secreted), activating proteinases that can be other MMPs, and by metalloproteinase inhibitors such as the tissue inhibitors of metalloproteinases (TIMPs). MMPs are best known for their role in the degradation and removal of ECM molecules. In addition, cleavage of the ECM and other cell surface molecules can release ECM-bound growth factors, and a number of non-ECM proteins are substrates of MMPs (Nagase et al. 2006). MMPs can be divided into subgroups based on domain structure and substrate specificity but it is clear that these are somewhat artificial, many MMPs belong to more than one functional group (Vise & Nagase 2003, Somerville et al. 2003). [[https://reactome.org/PathwayBrowser/#/R-HSA-1474228&PATH=R-HSA-1474244](https://reactome.org/PathwayBrowser/#/R-HSA-1474228&PATH=R-HSA-1474244)].
-   **MHC class II antigen presentation:** Antigen presenting cells (APCs) such as B cells, dendritic cells (DCs) and monocytes/macrophages express major histocompatibility complex class II molecules (MHC II) at their surface and present exogenous antigenic peptides to CD4+ T helper cells. CD4+ T cells play a central role in immune protection. On their activation they stimulate differentiation of B cells into antibody-producing B-cell blasts and initiate adaptive immune responses. MHC class II molecules are transmembrane glycoprotein heterodimers of alpha and beta subunits. Newly synthesized MHC II molecules present in the endoplasmic reticulum bind to a chaperone protein called invariant (Ii) chain. The binding of Ii prevents the premature binding of self-antigens to the nascent MHC molecules in the ER and also guides MHC molecules to endocytic compartments. In the acidic endosomal environment, Ii is degraded in a stepwise manner, ultimately to free the class II peptide-binding groove for loading of antigenic peptides. Exogenous antigens are internalized by the APC by receptor mediated endocytosis, phagocytosis or pinocytosis into endocytic compartments of MHC class II positive cells, where engulfed antigens are degraded in a low pH environment by multiple acidic proteases, generating MHC class II epitopes. Antigenic peptides are then loaded into the class II ligand-binding groove. The resulting class II peptide complexes then move to the cell surface, where they are scanned by CD4+ T cells for specific recognition (Berger & Roche 2009, Zhou & Blum 2004, Watts 2004, Landsverk et al. 2009). [[https://reactome.org/PathwayBrowser/#/R-HSA-2132295](https://reactome.org/PathwayBrowser/#/R-HSA-2132295)].
-   **Collagen degradation:** Collagen fibril diameter and spatial organisation are dependent on the species, tissue type and stage of development (Parry 1988). The lengths of collagen fibrils in mature tissues are largely unknown but in tendon can be measured in millimetres (Craig et al. 1989). Collagen fibrils isolated from adult bovine corneal stroma had ~350 collagen molecules in transverse section, tapering down to three molecules at the growing tip (Holmes & Kadler 2005). The classical view of collagenases is that they actively unwind the triple helical chain, a process termed molecular tectonics (Overall 2002, Bode & Maskos 2003), before preferentially cleaving the alpha2 chain followed by the remaining chains (Chung et al. 2004). More recently it has been suggested that collagen fibrils exist in an equilibrium between protected and vulnerable states (Stultz 2002, Nerenberg & Stultz 2008). The prototypical triple-helical structure of collagen does not fit into the active site of collagenase MMPs. In addition, the scissile bonds are not solvent-exposed and are therefore inaccessible to the collagenase active site (Chung et al. 2004, Stultz 2002). It was realized that collagen must locally unfold into non-triple helical regions to allow collagenolysis. Observations using circular dichroism and differential scanning calorimetry confirm that there is considerable heterogeneity along collagen fibres (Makareeva et al. 2008) allowing access for MMPs at physiological temperatures (Salsas-Escat et al. 2010). Collagen fibrils with cut chains are unstable and accessible to proteinases that cannot cleave intact collagen strands (Woessner & Nagase 2000, Somerville et al. 2003). Continued degradation leads to the formation of gelatin (Lovejoy et al. 1999). Degradation of collagen types other than I-III is less well characterized but believed to occur in a similar manner. Metalloproteinases (MMPs) play a major part in the degradation of several extracellular macromolecules including collagens. MMP1 (Welgus et al. 1981), MMP8 (Hasty et al. 1987), and MMP13 (Knauper et al. 1996), sometimes referred to as collagenases I, II and III respectively, are able to initiate the intrahelical cleavage of the major fibril forming collagens I, II and III at neutral pH, and thus thought to define the rate-limiting step in normal tissue remodeling events. All can cleave additional substrates including other collagen subtypes. Collagenases cut collagen alpha chains at a single conserved Gly-Ile/Leu site approximately 3/4 of the molecule's length from the N-terminus (Fields 1991, Chung et al. 2004). The cleavage site is characterised by the motif G(I/L)(A/L); the G-I/L bond is cleaved. In collagen type I this corresponds to G953-I954 in the Uniprot canonical alpha chain sequences (often given as G775-I776 in literature). It is not clear why only this bond is cleaved, as the motif occurs at several other places in the chain. MMP14, a membrane-associated MMP also known as Membrane-type matrix metalloproteinase 1 (MT-MMP1), is able to cleave collagen types I, II and III (Ohuchi et al. 1997). [[https://reactome.org/PathwayBrowser/#/R-HSA-1442490](https://reactome.org/PathwayBrowser/#/R-HSA-1442490)].
-   **RNA Polymerase II Transcription:** RNA polymerase II (Pol II) is the central enzyme that catalyses DNA- directed mRNA synthesis during the transcription of protein-coding genes. Pol II consists of a 10-subunit catalytic core, which alone can elongate the RNA transcript, and a complex of two subunits, Rpb4/7, that is required for transcription initiation. The transcription cycle is divided in three major phases: initiation, elongation, and termination. Transcription initiation includes promoter DNA binding, DNA melting, and initial synthesis of short RNA transcripts. The transition from initiation to elongation is referred to as promoter escape and leads to a stable elongation complex that is characterized by an open DNA region or transcription bubble. The bubble contains the DNA-RNA hybrid, a heteroduplex of eight to nine base pairs. The growing 3-end of the RNA is engaged with the polymerase complex active site. Ultimately transcription terminates and Pol II dissociates from the template. [[https://reactome.org/PathwayBrowser/#/R-HSA-73857&PATH=R-HSA-74160](https://reactome.org/PathwayBrowser/#/R-HSA-73857&PATH=R-HSA-74160)].
-   **RUNX1 regulates transcription of genes involved in differentiation of keratinocytes:** The RUNX1:CBFB complex directly inhibits transcription of the SERPINB13 gene (Nomura et al. 2005), a gene involved in keratinocyte differentiation that is frequently down-regulated in head and neck cancers (Boyapati et al. 2011). RUNX1 also inhibits transcription of STAT3 inhibitors SOCS3 and SOCS4, resulting in elevated STAT3 activity. RUNX1-mediated increase in STAT3 activity, first discovered in keratinocytes, is thought to be involved in the maintenance of epithelial stem cells and contributes to development of epithelial cancers, including squamous cell carcinoma (SCC) of the skin (Scheitz et al. 2012). [[https://reactome.org/PathwayBrowser/#/R-HSA-8939242](https://reactome.org/PathwayBrowser/#/R-HSA-8939242)].
-   **Toll-like Receptor Cascades:** In human, ten members of the Toll-like receptor (TLR) family (TLR1-TLR10) have been identified (TLR11 has been found in mouse, but not in human). All TLRs have a similar Toll/IL-1 receptor (TIR) domain in their cytoplasmic region and an Ig-like domain in the extracellular region, where each is enriched with a varying number of leucine-rich repeats (LRRs). Each TLR can recognize specific microbial pathogen components. The binding pathogenic component to TLR initializes signaling pathways that lead to induction of Interferon alpha/beta and inflammatory cytokines. There are two main signaling pathways. The first is a MyD88-dependent pathway that is common to all TLRs, except TLR3; the second is a TRIF(TICAM1)-dependent pathway that is peculiar to TLR3 and TLR4. TLR4-mediated signaling pathway via TRIF requires adapter molecule TRAM (TRIF-related adapter molecule or TICAM2). TRAM is thought to bridge between the activated TLR4 complex and TRIF. (Takeda & Akira 2004; Akira 2003; Takeda & Akira 2005; Kawai 2005; Heine & Ulmer 2005). This pathway is organized as trafficking and processing of TLR, various TLR cascades (TLR10, TLR3, TLR5, TLR7/8, TLR9, TLR4, TLR2) and their regulation. [[https://reactome.org/PathwayBrowser/#/R-HSA-168898](https://reactome.org/PathwayBrowser/#/R-HSA-168898)].
-   **Trafficking and processing of endosomal TLR:** Mammalian TLR3, TLR7, TLR8, TLR9 are endosomal receptors that sense nucleic acids that have been released from endocytosed/phagocytosed bacteria, viruses or parasites. These TLRs have a ligand-recognition domain that faces the lumen of the endosome (which is topologically equivalent to the outside of the cell), a transmembrane domain, and a signaling domain that faces the cytosol. Under normal conditions, self-nucleic acids are not recognized by TLRs due to multiple levels of regulation including receptor compartmentalization, trafficking and proteolytic processing (Barton GM et al 2006, Ewald SE et al 2008). At steady state TLR3, TLR7, TLR8, TLR9 reside primarily in the endoplasmic reticulum (ER), however, their activation by specific ligands only occurs within acidified endolysosomal compartments (Hacker H et al 1998, Funami K et al 2004, Gibbard RJ et al 2006). Several chaperon proteins associate with TLRs in the ER to provide efficient translocation to endolysosome. Upon reaching endolysosomal compartments the ectodomains of TLR7 and TLR9 are proteolytically cleaved by cysteine endoproteases. Both full-length and cleaved C-terminus of TLR9 bind CpG-oligodeoxynucleotides, however it has been proposed that only the processed receptor is functional. Although similar cleavage of TLR3 has been reported by Ewald et al 2011, other studies demonstrated that the N-terminal region of TLR3 ectodomain was implicated in ligand binding, thus TLR3 may function as a full-length receptor (Liu L et al 2008, Tokisue T et al 2008). There is no data on TLR8 processing, although the cell biology of TLR8 is probably similar to TLR9 and TLR7 (Gibbard RJ et al 2006, Wei T et al 2009). [[https://reactome.org/PathwayBrowser/#/R-HSA-1679131](https://reactome.org/PathwayBrowser/#/R-HSA-1679131)].

## GO terms:

**apoptotic process** [A programmed cell death process which begins when a cell receives an internal (e.g. DNA damage) or external signal (e.g. an extracellular death ligand), and proceeds through a series of biochemical events (signaling pathway phase) which trigger an execution phase. The execution phase is the last step of an apoptotic process, and is typically characterized by rounding-up of the cell, retraction of pseudopodes, reduction of cellular volume (pyknosis), chromatin condensation, nuclear fragmentation (karyorrhexis), plasma membrane blebbing and fragmentation of the cell into apoptotic bodies. When the execution phase is completed, the cell has died. GO:0006915]

**bone resorption** [The process in which specialized cells known as osteoclasts degrade the organic and inorganic portions of bone, and endocytose and transport the degradation products. GO:0045453]

**cellular response to transforming growth factor beta stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a transforming growth factor beta stimulus. GO:0071560]

**cellular response to tumor necrosis factor** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a tumor necrosis factor stimulus. GO:0071356]

**cellular response to zinc ion starvation** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of deprivation of zinc ions. GO:0034224]

**collagen catabolic process** [The proteolytic chemical reactions and pathways resulting in the breakdown of collagen in the extracellular matrix, usually carried out by proteases secreted by nearby cells. GO:0030574]

**immune response** [Any immune system process that functions in the calibrated response of an organism to a potential internal or invasive threat. GO:0006955]

**intramembranous ossification** [Direct ossification that occurs within mesenchyme or an accumulation of relatively unspecialized cells.|An instance of intramembranous ossification may also be classified as metaplastic; the former classifies based on tissue type location, and the latter based on mechanism/cell division. GO:0001957]

**mononuclear cell differentiation** [The process in which a relatively unspecialized cell acquires the specialized features of a mononuclear cell. GO:1903131]

**negative regulation of cartilage development** [Any process that decreases the rate, frequency, or extent of cartilage development, the process whose specific outcome is the progression of the cartilage over time, from its formation to the mature structure. Cartilage is a connective tissue dominated by extracellular matrix containing collagen type II and large amounts of proteoglycan, particularly chondroitin sulfate. GO:0061037]

**positive regulation of apoptotic signaling pathway** [Any process that activates or increases the frequency, rate or extent of apoptotic signaling pathway. GO:2001235]

**proteolysis** [The hydrolysis of proteins into smaller polypeptides and/or amino acids by cleavage of their peptide bonds.|This term was intentionally placed under 'protein metabolic process ; GO:0019538' rather than 'protein catabolic process ; GO:0030163' to cover all processes centered on breaking peptide bonds, including those involved in protein processing. GO:0006508]

**proteolysis involved in protein catabolic process** [The hydrolysis of a peptide bond or bonds within a protein as part of the chemical reactions and pathways resulting in the breakdown of a protein by individual cells. GO:0051603]

**response to ethanol** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an ethanol stimulus. GO:0045471]

**response to insulin** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an insulin stimulus. Insulin is a polypeptide hormone produced by the islets of Langerhans of the pancreas in mammals, and by the homologous organs of other organisms. GO:0032868]

**response to organic cyclic compound** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an organic cyclic compound stimulus. GO:0014070]

**thyroid hormone generation** [The formation of either of the compounds secreted by the thyroid gland, mainly thyroxine and triiodothyronine. This is achieved by the iodination and joining of tyrosine molecules to form the precursor thyroglobin, proteolysis of this precursor gives rise to the thyroid hormones.|Note that this term does not fall under the general GO definition for biosynthetic processes, which is 'The chemical reactions and pathways resulting in the formation of... ', because thyroid hormones can only be formed by the proteolysis of a larger molecule (see term definition). The word 'generation' is therefore used in place of biosynthesis. GO:0006590]

## MSigDB Signatures:

**REACTOME_INNATE_IMMUNE_SYSTEM**: Innate Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html)

**REACTOME_ADAPTIVE_IMMUNE_SYSTEM**: Adaptive Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ADAPTIVE_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ADAPTIVE_IMMUNE_SYSTEM.html)

**KEGG_LYSOSOME**: Lysosome [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_LYSOSOME.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_LYSOSOME.html)

**REACTOME_COLLAGEN_DEGRADATION**: Collagen degradation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_COLLAGEN_DEGRADATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_COLLAGEN_DEGRADATION.html)

**REACTOME_EXTRACELLULAR_MATRIX_ORGANIZATION**: Extracellular matrix organization [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_EXTRACELLULAR_MATRIX_ORGANIZATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_EXTRACELLULAR_MATRIX_ORGANIZATION.html)

**REACTOME_DEGRADATION_OF_THE_EXTRACELLULAR_MATRIX**: Degradation of the extracellular matrix [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEGRADATION_OF_THE_EXTRACELLULAR_MATRIX.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEGRADATION_OF_THE_EXTRACELLULAR_MATRIX.html)

**NABA_MATRISOME_ASSOCIATED**: Ensemble of genes encoding ECM-associated proteins including ECM-affilaited proteins, ECM regulators and secreted factors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_ASSOCIATED.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_ASSOCIATED.html)

**REACTOME_TRANSCRIPTIONAL_REGULATION_BY_RUNX1**: Transcriptional regulation by RUNX1 [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRANSCRIPTIONAL_REGULATION_BY_RUNX1.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRANSCRIPTIONAL_REGULATION_BY_RUNX1.html)

**NABA_MATRISOME**: Ensemble of genes encoding extracellular matrix and extracellular matrix-associated proteins [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME.html)

**WP_OSTEOCLAST_SIGNALING**: Osteoclast signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_OSTEOCLAST_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_OSTEOCLAST_SIGNALING.html)

**REACTOME_RNA_POLYMERASE_II_TRANSCRIPTION**: RNA Polymerase II Transcription [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RNA_POLYMERASE_II_TRANSCRIPTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RNA_POLYMERASE_II_TRANSCRIPTION.html)

**REACTOME_ACTIVATION_OF_MATRIX_METALLOPROTEINASES**: Activation of Matrix Metalloproteinases [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ACTIVATION_OF_MATRIX_METALLOPROTEINASES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ACTIVATION_OF_MATRIX_METALLOPROTEINASES.html)

**WP_IL_26_SIGNALING_PATHWAYS**: IL 26 signaling pathways [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_IL_26_SIGNALING_PATHWAYS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_IL_26_SIGNALING_PATHWAYS.html)

**CARRILLOREIXACH_MRS3_VS_LOWER_RISK_HEPATOBLASTOMA_DN**: Genes significantly down-regulated in the high-risk Molecular Risk Stratification (MRS-3) hepatoblastoma (HB) as compared with intermediate-risk (MRS-2) and low-risk (MRS-1) molecular HBs, assessed by Human Transcriptome Array (HTA). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CARRILLOREIXACH_MRS3_VS_LOWER_RISK_HEPATOBLASTOMA_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CARRILLOREIXACH_MRS3_VS_LOWER_RISK_HEPATOBLASTOMA_DN.html)

**REACTOME_RUNX1_REGULATES_TRANSCRIPTION_OF_GENES_INVOLVED_IN_DIFFERENTIATION_OF_KERATINOCYTES**: RUNX1 regulates transcription of genes involved in differentiation of keratinocytes [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RUNX1_REGULATES_TRANSCRIPTION_OF_GENES_INVOLVED_IN_DIFFERENTIATION_OF_KERATINOCYTES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RUNX1_REGULATES_TRANSCRIPTION_OF_GENES_INVOLVED_IN_DIFFERENTIATION_OF_KERATINOCYTES.html)

**KEGG_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY**: Toll-like receptor signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY.html)

**REACTOME_MHC_CLASS_II_ANTIGEN_PRESENTATION**: MHC class II antigen presentation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_MHC_CLASS_II_ANTIGEN_PRESENTATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_MHC_CLASS_II_ANTIGEN_PRESENTATION.html)
