
## **Pathways:**

**RNA Polymerase II Transcription**: RNA polymerase II (Pol II) is the central enzyme that catalyzes DNA- directed mRNA synthesis during the transcription of protein-coding genes. Pol II consists of a 10-subunit catalytic core, which alone is capable of elongating the RNA transcript, and a complex of two subunits, Rpb4/7, that is required for transcription initiation.

The transcription cycle is divided in three major phases: initiation, elongation, and termination. Transcription initiation include promoter DNA binding, DNA melting, and initial synthesis of short RNA transcripts. The transition from initiation to elongation, is referred to as promoter escape and leads to a stable elongation complex that is characterized by an open DNA region or transcription bubble. The bubble contains the DNA-RNA hybrid, a heteroduplex of eight to nine base pairs. The growing 3-end of the RNA is engaged with the polymerase complex active site. Ultimately transcription terminates and Pol II dissocitate from the template. [[https://reactome.org/PathwayBrowser/#/R-HSA-73857](https://reactome.org/PathwayBrowser/#/R-HSA-73857)].

**Transcriptional Regulation by TP53**: While the p53 tumor suppressor protein (TP53) is known to inhibit cell growth by inducing apoptosis, senescence and cell cycle arrest, recent studies have found that p53 is also able to influence cell metabolism to prevent tumor development. TP53 regulates transcription of many genes involved in the metabolism of carbohydrates, nucleotides and amino acids, protein synthesis and aerobic respiration.

TP53 stimulates transcription of TIGAR, a D-fructose 2,6-bisphosphatase. TIGAR activity decreases glycolytic rate and lowers ROS (reactive oxygen species) levels in cells (Bensaad et al. 2006). TP53 may also negatively regulate the rate of glycolysis by inhibiting the expression of glucose transporters GLUT1, GLUT3 and GLUT4 (Kondoh et al. 2005, Schwartzenberg-Bar-Yoseph et al. 2004, Kawauchi et al. 2008).

TP53 negatively regulates several key points in PI3K/AKT signaling and downstream mTOR signaling, decreasing the rate of protein synthesis and, hence, cellular growth. TP53 directly stimulates transcription of the tumor suppressor PTEN, which acts to inhibit PI3K-mediated activation of AKT (Stambolic et al. 2001). TP53 stimulates transcription of sestrin genes, SESN1, SESN2, and SESN3 (Velasco-Miguel et al. 1999, Budanov et al. 2002, Brynczka et al. 2007). One of sestrin functions may be to reduce and reactivate overoxidized peroxiredoxin PRDX1, thereby reducing ROS levels (Budanov et al. 2004, Papadia et al. 2008, Essler et al. 2009). Another function of sestrins is to bind the activated AMPK complex and protect it from AKT-mediated inactivation. By enhancing AMPK activity, sestrins negatively regulate mTOR signaling (Budanov and Karin 2008, Cam et al. 2014). The expression of DDIT4 (REDD1), another negative regulator of mTOR signaling, is directly stimulated by TP63 and TP53. DDIT4 prevents AKT-mediated inactivation of TSC1:TSC2 complex, thus inhibiting mTOR cascade (Cam et al. 2014, Ellisen et al. 2002, DeYoung et al. 2008). TP53 may also be involved, directly or indirectly, in regulation of expression of other participants of PI3K/AKT/mTOR signaling, such as PIK3CA (Singh et al. 2002), TSC2 and AMPKB (Feng et al. 2007).

TP53 regulates mitochondrial metabolism through several routes. TP53 stimulates transcription of SCO2 gene, which encodes a mitochondrial cytochrome c oxidase assembly protein (Matoba et al. 2006). TP53 stimulates transcription of RRM2B gene, which encodes a subunit of the ribonucleotide reductase complex, responsible for the conversion of ribonucleotides to deoxyribonucleotides and essential for the maintenance of mitochondrial DNA content in the cell (Tanaka et al. 2000, Bourdon et al. 2007, Kulawiec et al. 2009). TP53 also transactivates mitochondrial transcription factor A (TFAM), a nuclear-encoded gene important for mitochondrial DNA (mtDNA) transcription and maintenance (Park et al. 2009). Finally, TP53 stimulates transcription of the mitochondrial glutaminase GLS2, leading to increased mitochondrial respiration rate and reduced ROS levels (Hu et al. 2010).

The great majority of tumor cells generate energy through aerobic glycolysis, rather than the much more efficient aerobic mitochondrial respiration, and this metabolic change is known as the Warburg effect (Warburg 1956). Since the majority of tumor cells have impaired TP53 function, and TP53 regulates a number of genes involved in glycolysis and mitochondrial respiration, it is likely that TP53 inactivation plays an important role in the metabolic derangement of cancer cells such as the Warburg effect and the concomitant increased tumorigenicity (reviewed by Feng and Levine 2010). On the other hand, some mutations of TP53 in Li-Fraumeni syndrome may result in the retention of its wild-type metabolic activities while losing cell cycle and apoptosis functions (Wang et al. 2013). Consistent with such human data, some mutations of p53, unlike p53 null state, retain the ability to regulate energy metabolism while being inactive in regulating its classic gene targets involved in cell cycle, apoptosis and senescence. Retention of metabolic and antioxidant functions of p53 protects p53 mutant mice from early onset tumorigenesis (Li et al. 2012). [[https://reactome.org/PathwayBrowser/#/R-HSA-5628897](https://reactome.org/PathwayBrowser/#/R-HSA-5628897)].

**mTOR Signaling:** The mammalian Target of Rapamycin (mTOR) Complex is the central cellular regulator of anabolic and catabolic cellular metabolism and survival. mTOR forms at least two distinct multi-protein complexes (mTORCs) with additional regulatory proteins. mTORC1 includes mTOR, Raptor, Pras40, Deptor, and GBL/mLST8 while mTORC2 includes mTOR, Rictor, mSin1, Proctor/PRR5, Deptor, and GBL/mLST8. mTOR activity is regulated in response to both extracellular and intracellular cues. Extracellular signaling factors, including Wnts, TNF-alpha, and growth factors, signal through a variety of intracellular pathways to TSC1/2, to regulate mTORC1 activity. In addition to responding to extracellular cues, mTORC1 activity is also regulated by intracellular cues including energy availability, oxygen levels, and amino acid availability. In the presence of available amino acids, the mTOR Complex 1 (mTORC1) is recruited to the lysosomal membrane where it initiates anabolic activities including protein synthesis, lipid synthesis, autophagy, and mitochondrial metabolism and biogenesis.

Less is known about the upstream signals and cellular functions that regulate mTORC2. mTORC2 activity is strongly correlated with AKT activity. mTORC2 has been shown to regulate cytoskeletal rearrangement, as well as cell survival and proliferation. [[https://www.rndsystems.com/pathways/mtor-signaling-pathway](https://www.rndsystems.com/pathways/mtor-signaling-pathway)].

## GO terms:

**apoptotic process** [A programmed cell death process which begins when a cell receives an internal (e.g. DNA damage) or external signal (e.g. an extracellular death ligand), and proceeds through a series of biochemical events (signaling pathway phase) which trigger an execution phase. The execution phase is the last step of an apoptotic process, and is typically characterized by rounding-up of the cell, retraction of pseudopodes, reduction of cellular volume (pyknosis), chromatin condensation, nuclear fragmentation (karyorrhexis), plasma membrane blebbing and fragmentation of the cell into apoptotic bodies. When the execution phase is completed, the cell has died. GO:0006915]

**brain development** [The process whose specific outcome is the progression of the brain over time, from its formation to the mature structure. Brain development begins with patterning events in the neural tube and ends with the mature structure that is the center of thought and emotion. The brain is responsible for the coordination and control of bodily activities and the interpretation of information from the senses (sight, hearing, smell, etc.). GO:0007420]

**cellular response to dexamethasone stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a dexamethasone stimulus. GO:0071549]

**defense response to virus** [Reactions triggered in response to the presence of a virus that act to protect the cell or organism. GO:0051607]

**intracellular signal transduction** [The process in which a signal is passed on to downstream components within the cell, which become activated themselves to further propagate the signal and finally trigger a change in the function or state of the cell. GO:0035556]

**intrinsic apoptotic signaling pathway in response to DNA damage by p53 class mediator** [The series of molecular signals in which an intracellular signal is conveyed to trigger the apoptotic death of a cell. The pathway is induced by the cell cycle regulator phosphoprotein p53, or an equivalent protein, in response to the detection of DNA damage, and ends when the execution phase of apoptosis is triggered. GO:0042771]

**negative regulation of TOR signaling** [Any process that stops, prevents, or reduces the frequency, rate or extent of TOR signaling. GO:0032007]

**negative regulation of glycolytic process** [Any process that stops, prevents, or reduces the frequency, rate or extent of glycolysis. GO:0045820]

**neuron differentiation** [The process in which a relatively unspecialized cell acquires specialized features of a neuron. GO:0030182]

**neuron migration** [The characteristic movement of an immature neuron from germinal zones to specific positions where they will reside as they mature. GO:0001764]

**neurotrophin TRK receptor signaling pathway** [The series of molecular signals initiated by neurotrophin binding to its receptor on the surface of a target cell where the receptor possesses tyrosine kinase activity, and ending with the regulation of a downstream cellular process, e.g. transcription. GO:0048011]

**protein-containing complex disassembly** [The disaggregation of a protein-containing macromolecular complex into its constituent components. GO:0032984]

**reactive oxygen species metabolic process** [The chemical reactions and pathways involving a reactive oxygen species, any molecules or ions formed by the incomplete one-electron reduction of oxygen. They contribute to the microbicidal activity of phagocytes, regulation of signal transduction and gene expression, and the oxidative damage to biopolymers. GO:0072593]

**response to hypoxia** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating lowered oxygen tension. Hypoxia, defined as a decline in O2 levels below normoxic levels of 20.8 - 20.95%, results in metabolic adaptation at both the cellular and organismal level.|Note that this term should not be confused with 'response to anoxia ; GO:0034059'. Note that in laboratory studies, hypoxia is typically studied at O2 concentrations ranging from 0.1 - 5%. GO:0001666]

## MSigDB Signatures:

**KEGG_MTOR_SIGNALING_PATHWAY**: mTOR signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MTOR_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MTOR_SIGNALING_PATHWAY.html)

**WP_TARGET_OF_RAPAMYCIN_SIGNALING**: Target of rapamycin signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TARGET_OF_RAPAMYCIN_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TARGET_OF_RAPAMYCIN_SIGNALING.html)

**WP_FOCAL_ADHESION_PI3K_AKT_MTOR_SIGNALING_PATHWAY**: Focal adhesion PI3K Akt mTOR signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FOCAL_ADHESION_PI3K_AKT_MTOR_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FOCAL_ADHESION_PI3K_AKT_MTOR_SIGNALING_PATHWAY.html)

**WP_PI3K_AKT_SIGNALING_PATHWAY**: PI3K Akt signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PI3K_AKT_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PI3K_AKT_SIGNALING_PATHWAY.html)

**WP_TAR_SYNDROME**: TAR syndrome [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TAR_SYNDROME.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TAR_SYNDROME.html)

**REACTOME_RNA_POLYMERASE_II_TRANSCRIPTION**: RNA Polymerase II Transcription [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RNA_POLYMERASE_II_TRANSCRIPTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RNA_POLYMERASE_II_TRANSCRIPTION.html)

**REACTOME_TP53_REGULATES_METABOLIC_GENES**: TP53 Regulates Metabolic Genes [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TP53_REGULATES_METABOLIC_GENES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TP53_REGULATES_METABOLIC_GENES.html)
