
## **Pathways:**

**Activation of anterior HOX genes in hindbrain development during early embryogenesis:** In mammals, anterior Hox genes may be defined as paralog groups 1 to 4 (Natale et al. 2011), which are involved in development of the hindbrain through sequential expression in the rhombomeres, transient segments of the neural tube that form during development of the hindbrain (reviewed in Alexander et al. 2009, Soshnikova and Duboule 2009, Tumpel et al. 2009, Mallo et al. 2010, Andrey and Duboule 2014). Hox gene activation during mammalian development has been most thoroughly studied in mouse embryos and the results have been extended to human development by in vitro experiments with human embryonal carcinoma cells and human embryonic stem cells.

Expression of a typical anterior Hox gene has an anterior boundary located at the junction between two rhombomeres and continues caudally to regulate segmentation and segmental fate in ectoderm, mesoderm, and endoderm. Anterior boundaries of expression of successive Hox paralog groups are generally separated from each other by 2 rhombomeres. For example, HOXB2 is expressed in rhombomere 3 (r3) and caudally while HOXB3 is expressed in r5 and caudally. Exceptions exist, however, as HOXA1, HOXA2, and HOXB1 do not follow the rule and HOXD1 and HOXC4 are not expressed in rhombomeres. Hox genes within a Hox cluster are expressed colinearly: the gene at the 3' end of the cluster is expressed earliest, and hence most anteriorly, then genes 5' are activated sequentially in the same order as they occur in the cluster.

Activation of expression occurs epigenetically by loss of polycomb repressive complexes and change of bivalent chromatin to active chromatin through, in part, the actions of trithorax family proteins (reviewed in Soshnikova and Duboule 2009). Hox gene expression initiates in the posterior primitive streak that will contribute to extraembryonic mesoderm. Expression then extends anteriorly into the cells that will become the embryo, where expression is first observed in presumptive lateral plate mesoderm and is transmitted to both paraxial mesoderm and neurectoderm formed by gastrulation along the primitive streak (reviewed in Deschamps et al. 1999, Casaca et al. 2014).

Prior to establishment of the rhombomeres, expression of HOXA1 and HOXB1 is initiated near the future site of r3 and caudally by a gradient of retinoic acid (RA). (Mechanisms of retinoic acid signaling are reviewed in Cunningham and Duester 2015.) The RA is generated by the ALDH1A2 (RALDH2) enzyme located in somites flanking the caudal hindbrain and degraded by CYP26 enzymes expressed initially in anterior neural ectoderm of the early gastrula and then throughout most of the hindbrain (reviewed in White and Schilling 2008). HOXA1 with PBX1,2 and MEIS2 directly activate transcription of ALDH1A2 to maintain retinoic acid synthesis in the somitic mesoderm (Vitobello et al. 2011). Differentiation of embryonal carcinoma cells and embryonic stem cells in response to retinoic acid is used to model the process of differentiation in vitro (reviewed in Soprano et al. 2007, Gudas et al. 2013).

HOXA1 appears to set the anterior limit of HOXB1 expression (Barrow et al. 2000). HOXB1 initiates expression of EGR2 (KROX20) in presumptive r3. EGR2 then activates HOXA2 expression in r3 and r5 while HOXB1, together with PBX1 and MEIS:PKNOX1 (MEIS:PREP), activates expression of HOXA2 in r4 and caudal rhombomeres. AP-2 transcription factors maintain expression of HOXA2 in neural crest cells (Maconochie et al. 1999). HOXB1 also activates expression of HOXB2 in r3 and caudal rhombomeres. EGR2 negatively regulates HOXB1 so that by the time rhombomeres appear, HOXB1 is restricted to r4 and HOXA1 is no longer detectable (Barrow et al. 2000). EGR2 and MAFB (Kreisler) then activate HOXA3 and HOXB3 in r5 and caudal rhombomeres. Retinoic acid activates HOXA4, HOXB4, and HOXD4 in r7, the final rhombomere. HOX proteins, in turn, activate expression of genes in combination with other factors, notably members of the TALE family of transcription factors (PBX, PREP, and MEIS, reviewed in Schulte and Frank 2014, Rezsohazy et al. 2015). HOX proteins also participate in non-transcriptional interactions (reviewed in Rezsohazy 2014). In zebrafish, Xenopus, and chicken factors such as Meis3, Fgf3, Fgf8, and vHNF regulate anterior hox genes (reviewed in Schulte and Frank 2014), however less is known about the roles of homologous factors in mammals.

Mutations in HOXA1 in humans have been observed to cause developmental abnormalities located mostly in the head and neck region (Tischfield et al. 2005, Bosley et al. 2008). A missense mutation in HOXA2 causes microtia, hearing impairment, and partially cleft palate (Alasti et al. 2008). A missense mutation in HOXB1 causes a similar phenotype to the Hoxb1 null mutation in mice: bilateral facial palsy, hearing loss, and strabismus (improper alignment of the eyes) (Webb et al. 2012).[[https://reactome.org/PathwayBrowser/#/R-HSA-5617472](https://reactome.org/PathwayBrowser/#/R-HSA-5617472)].

**EGR2 and SOX10-mediated initiation of Schwann cell myelination:** Schwann cells are glial cells of the peripheral nervous system that ensheath the peripheral nerves within a compacted lipid-rich myelin structure that is required for optimal transduction of nerve signals in motor and sensory nerves. Schwann cells develop from the neural crest in a differentiation process driven by factors derived from the Schwann cell itself, from the adjacent neuron or from the extracellular matrix (reviewed in Jessen and Mirsky, 2005). Upon peripheral nerve injury, mature Schwann cells can form repair cells that allow peripheral nerve regeneration through myelin phagocytosis and remyelination of the peripheral nerve. This process in some ways recapitulates the maturation of immature Schwann cells during development (reviewed in Jessen and Mirsky, 2016). Mature, fully myelinated Schwann cells exhibit longitudinal and radial polarization. The axon-distal abaxonal membrane interacts with elements of the basal lamina through integrins and lamins and in this way resembles the basolateral domain of polarized epithelial cells. In contrast, the axon-proximal adaxonal membrane resembles the apical domain of an epithelial cell, and is enriched with adhesion molecules and receptors that mediate interaction with ligands from the axon (reviewed in Salzer, 2015).

Schwann cells express a number of Schwann-cell specific proteins, including components of the myelin sheath such as myelin basic protein (MBP) and myelin protein zero (MPZ). In addition, Schwann cells have high lipid content relative to other membranes, and are enriched in galactosphingolipids, cholesterol and saturated long chain fatty acids (reviewed in Garbay et al, 2000). This protein and lipid profile is driven by a Schwann cell myelination transcriptional program controlled by master regulators SOX10, POU3F1 and EGR2, among others (reviewed in Svaren and Meijer, 2008; Stolt and Wegner, 2016) [[https://reactome.org/PathwayBrowser/#/R-HSA-9619665](https://reactome.org/PathwayBrowser/#/R-HSA-9619665)].

**NGF-stimulated transcription:** NGF stimulation induces expression of a wide array of transcriptional targets. In rat PC12 cells, a common model for NGF signaling, stimulation with NGF causes cells to exit the cell cycle and undergo a differentiation program leading to neurite outgrowth. This program is driven by the expression of immediate early genes (IEGs), which frequently encode transcription factors regulating the activity of NGF-specific delayed response genes (reviewed in Sheng and Greenberg, 1990; Flavell and Grennberg, 2008; Santiago and Bashaw, 2014) [[https://reactome.org/PathwayBrowser/#/R-HSA-9031628](https://reactome.org/PathwayBrowser/#/R-HSA-9031628)].

**Transcriptional regulation of white adipocyte differentiation:** Adipogenesis is the process of cell differentiation by which preadipocytes become adipocytes. During this process the preadipocytes cease to proliferate, begin to accumulate lipid droplets and develop morphologic and biochemical characteristics of mature adipocytes such as hormone responsive lipogenenic and lipolytic programs. The most intensively studied model system for adipogenesis is differentiation of the mouse 3T3-L1 preadipocyte cell line by an induction cocktail of containing mitogens (insulin/IGF1), glucocorticoid (dexamethasone), an inducer of cAMP (IBMX), and fetal serum (Cao et al. 1991, reviewed in Farmer 2006). More recently additional cellular models have become available to study adipogenesis that involve almost all stages of development (reviewed in Rosen and MacDougald 2006). In vivo knockout mice lacking putative adipogenic factors have also been extensively studied. Human pathways are traditionally inferred from those discovered in mouse but are now beginning to be validated in cellular models derived from human adipose progenitors (Fischer-Posovszky et al. 2008, Wdziekonski et al. 2011).

Adipogenesis is controlled by a cascade of transcription factors (Yeh et al. 1995, reviewed in Farmer 2006, Gesta et al. 2007). One of the first observable events during adipocyte differentiation is a transient increase in expression of the CEBPB (CCAAT/Enhancer Binding Protein Beta, C/EBPB) and CEBPD (C/EBPD) transcription factors (Cao et al. 1991, reviewed in Lane et al. 1999). This occurs prior to the accumulation of lipid droplets. However, it is the subsequent inductions of CEBPA and PPARG that are critical for morphological, biochemical and functional adipocytes.

Ectopic expression of CEBPB alone is capable of inducing substantial adipocyte differentiation in fibroblasts while CEBPD has a minimal effect. CEBPB is upregulated in response to intracellular cAMP (possibly via pCREB) and serum mitogens (possibly via Krox20). CEBPD is upregulated in response to glucocorticoids. The exact mechanisms that upregulate the CEBPs are not fully known.

CEBPB and CEBPD act directly on the Peroxisome Proliferator-activated Receptor Gamma (PPARG) gene by binding its promoter and activating transcription. CEBPB and CEBPD also directly activate the EBF1 gene (and possibly other EBFs) and KLF5 (Jimenez et al. 2007, Oishi 2005). The EBF1 and KLF5 proteins, in turn bind, and activate the PPARG promoter. Other hormones, such as insulin, affect PPARG expression and other transcription factors, such as ADD1/SREBP1c, bind the PPARG promoter. This is an area of ongoing research.

During adipogenesis the PPARG gene is transcribed to yield 2 variants. The adipogenic variant 2 mRNA encodes 30 additional amino acids at the N-terminus compared to the widely expressed variant 1 mRNA.

PPARG encodes a type II nuclear hormone receptor (remains in the nucleus in the absence of ligand) that forms a heterodimer with the Retinoid X Receptor Alpha (RXRA). The heterodimer was initially identified as a complex regulating the aP2/FABP4 gene and named ARF6 (Tontonoz et al. 1994).

The PPARG:RXRA heterodimer binds a recognition sequence that consists of two hexanucleotide motifs (DR1 motifs) separated by 1 nucleotide. Binding occurs even in the absence of ligands, such as fatty acids, that activate PPARG. In the absence of activating ligands, the PPARG:RXRA complex recruits repressors of transcription such as SMRT/NCoR2, NCoR1, and HDAC3 (Tontonoz and Spiegelman 2008).

Each molecule of PPARG can bind 2 molecules of activating ligands. Although, the identity of the endogenous ligands of PPARG is unknown, exogenous activators include fatty acids and the thiazolidinedione class of antidiabetic drugs (reviewed in Berger et al. 2005, Heikkinen et al. 2007, Lemberger et al. 1996). The most potent activators of PPARG in vitro are oxidized derivatives of unsaturated fatty acids.. Upon binding activating ligands PPARG causes a rearrangement of adjacent factors: Corepressors such as SMRT/NCoR2 are lost and coactivators such as TIF2, PRIP, CBP, and p300 are recruited (Tontonoz and Spiegelman). PPARG also binds directly to the TRAP220 subunit of the TRAP/Mediator complex that recruits RNA polymerase II. Thus binding of activating ligand by PPARG causes transcription of PPARG target genes. Targets of PPARG include genes involved in differentiation (PGAR/HFARP, Perilipin, aP2/FABP4, CEBPA), fatty acid transport (LPL, FAT/CD36), carbohydrate metabolism (PEPCK-C, AQP7, GK, GLUT4 (SLC2A4)), and energy homeostasis (LEPTIN and ADIPONECTIN) (Perera et al. 2006).

Within 10 days of differentiation CEBPB and CEBPD are no longer located at the PPARG promoter. Instead CEBPA is present. EBF1 and PPARG bind the CEBPA promoter and activate transcription of CEBPA, one of the key transcription factors in adipogenesis. A current hypothesis posits a self-reinforcing loop that maintains PPARG expression and the differentiated state: PPARG activates CEBPA and CEBPA activates PPARG. Additionally EBF1 (and possibly other EBFs) activates CEBPA, CEBPA activates EBF1, and EBF1 activates PPARG [[https://reactome.org/PathwayBrowser/#/R-HSA-381340](https://reactome.org/PathwayBrowser/#/R-HSA-381340)].

## GO terms:

**Schwann cell differentiation** [The process in which a relatively unspecialized cell acquires the specialized features of a Schwann cell. Schwann cells are found in the peripheral nervous system, where they insulate neurons and axons, and regulate the environment in which neurons function. GO:0014037]

**aorta development** [The progression of the aorta over time, from its initial formation to the mature structure. An aorta is an artery that carries blood from the heart to other parts of the body. GO:0035904]

**brain segmentation** [Division of the brain into a series of semi-repetitive parts or segments. GO:0035284]

**cellular response to organic substance** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an organic substance stimulus. GO:0071310]

**facial nerve structural organization** [The process that contributes to the act of creating the structural organization of the facial nerve. This process pertains to the physical shaping of a rudimentary structure. This sensory and motor nerve supplies the muscles of facial expression and the expression and taste at the anterior two-thirds of the tongue. The principal branches are the superficial opthalmic, buccal, palatine and hyomandibular. The main trunk synapses within pterygopalatine ganglion in the parotid gland and this ganglion then gives of nerve branches which supply the lacrimal gland and the mucous secreting glands of the nasal and oral cavities. GO:0021612]

**fat cell differentiation** [The process in which a relatively unspecialized cell acquires specialized features of an adipocyte, an animal connective tissue cell specialized for the synthesis and storage of fat. GO:0045444]

**gene expression** [The process in which a gene's sequence is converted into a mature gene product (protein or RNA). This includes the production of an RNA transcript and its processing, as well as translation and maturation for protein-coding genes. GO:0010467]

**learning or memory** [The acquisition and processing of information and/or the storage and retrieval of this information over time. GO:0007611]

**motor neuron axon guidance** [The process in which the migration of an axon growth cone of a motor neuron is directed to a specific target site in response to a combination of attractive and repulsive cues. GO:0008045]

**myelination** [The process in which myelin sheaths are formed and maintained around neurons. Oligodendrocytes in the brain and spinal cord and Schwann cells in the peripheral nervous system wrap axons with compact layers of their plasma membrane. Adjacent myelin segments are separated by a non-myelinated stretch of axon called a node of Ranvier. GO:0042552]

**positive regulation of DNA-templated transcription** [Any process that activates or increases the frequency, rate or extent of cellular DNA-templated transcription. GO:0045893]

**positive regulation of Schwann cell differentiation** [Any process that activates or increases the frequency, rate or extent of Schwann cell differentiation. GO:0014040]

**positive regulation of myelination** [Any process that activates or increases the frequency, rate or extent of the formation of a myelin sheath around nerve axons. GO:0031643]

**positive regulation of transcription by RNA polymerase II** [Any process that activates or increases the frequency, rate or extent of transcription from an RNA polymerase II promoter. GO:0045944]

**protein export from nucleus** [The directed movement of a protein from the nucleus into the cytoplasm. GO:0006611]

**protein sumoylation** [The process in which a SUMO protein (small ubiquitin-related modifier) is conjugated to a target protein via an isopeptide bond between the carboxy-terminus of SUMO with an epsilon-amino group of a lysine residue of the target protein. GO:0016925]

**regulation of DNA-templated transcription** [Any process that modulates the frequency, rate or extent of cellular DNA-templated transcription. GO:0006355]

**regulation of neuronal synaptic plasticity** [A process that modulates neuronal synaptic plasticity, the ability of neuronal synapses to change as circumstances require. They may alter function, such as increasing or decreasing their sensitivity, or they may increase or decrease in actual numbers.|Note that the syntax of the definition of this term is different from the usual regulation syntax because it describes regulation of a trait rather than regulation of a process. GO:0048168]

**regulation of ossification** [Any process that modulates the frequency, rate or extent of ossification, the formation of bone or of a bony substance or the conversion of fibrous tissue or of cartilage into bone or a bony substance. GO:0030278]

**regulation of transcription by RNA polymerase II** [Any process that modulates the frequency, rate or extent of transcription mediated by RNA polymerase II. GO:0006357]

**response to insulin** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an insulin stimulus. Insulin is a polypeptide hormone produced by the islets of Langerhans of the pancreas in mammals, and by the homologous organs of other organisms. GO:0032868]

**rhombomere 3 development** [The process whose specific outcome is the progression of rhombomere 3 over time, from its formation to the mature structure. Rhombomeres are transverse segments of the developing rhombencephalon. Rhombomeres are lineage restricted, express different genes from one another, and adopt different developmental fates. Rhombomeres are numbered in anterior to posterior order. GO:0021569]

**rhombomere 3 formation** [The process that gives rise to rhombomere 3. This process pertains to the initial formation of a structure from unspecified parts. Rhombomeres are transverse segments of the developing rhombencephalon. Rhombomeres are lineage restricted, express different genes from one another, and adopt different developmental fates. Rhombomeres are numbered in anterior to posterior order. GO:0021660]

**rhombomere 3 structural organization** [The process that contributes to creating the structural organization of rhombomere 3. This process pertains to the physical shaping of a rudimentary structure. Rhombomeres are transverse segments of the developing rhombencephalon. Rhombomeres are lineage restricted, express different genes from one another, and adopt different developmental fates. Rhombomeres are numbered in an anterior to posterior order. GO:0021659]

**rhombomere 5 formation** [The process that gives rise to rhombomere 5. This process pertains to the initial formation of a structure from unspecified parts. Rhombomeres are transverse segments of the developing rhombencephalon. Rhombomeres are lineage restricted, express different genes from one another, and adopt different developmental fates. Rhombomeres are numbered in anterior to posterior order. GO:0021666]

**rhombomere 5 structural organization** [The process that contributes to creating the structural organization of rhombomere 5. This process pertains to the physical shaping of a rudimentary structure. Rhombomeres are transverse segments of the developing rhombencephalon. Rhombomeres are lineage restricted, express different genes from one another, and adopt different developmental fates. Rhombomeres are numbered in an anterior to posterior order. GO:0021665]

**rhythmic behavior** [The specific behavior of an organism that recur with measured regularity. GO:0007622]

**skeletal muscle cell differentiation** [The process in which a relatively unspecialized cell acquires specialized features of a skeletal muscle cell, a somatic cell located in skeletal muscle. GO:0035914]

## MSigDB Signatures:

**WP_HEPATITIS_B_INFECTION**: Hepatitis B infection [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_HEPATITIS_B_INFECTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_HEPATITIS_B_INFECTION.html)

**CHIANG_LIVER_CANCER_SUBCLASS_CTNNB1_DN**: Top 200 marker genes down-regulated in the 'CTNNB1' subclass of hepatocellular carcinoma (HCC); characterized by activated CTNNB1 [GeneID=1499]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHIANG_LIVER_CANCER_SUBCLASS_CTNNB1_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHIANG_LIVER_CANCER_SUBCLASS_CTNNB1_DN.html)

**WP_ADIPOGENESIS**: Adipogenesis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ADIPOGENESIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ADIPOGENESIS.html)

**WP_WHITE_FAT_CELL_DIFFERENTIATION**: White fat cell differentiation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_WHITE_FAT_CELL_DIFFERENTIATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_WHITE_FAT_CELL_DIFFERENTIATION.html)

**REACTOME_NUCLEAR_EVENTS_KINASE_AND_TRANSCRIPTION_FACTOR_ACTIVATION**: Nuclear Events (kinase and transcription factor activation) [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NUCLEAR_EVENTS_KINASE_AND_TRANSCRIPTION_FACTOR_ACTIVATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NUCLEAR_EVENTS_KINASE_AND_TRANSCRIPTION_FACTOR_ACTIVATION.html)

**PID_NFAT_TFPATHWAY**: Calcineurin-regulated NFAT-dependent transcription in lymphocytes [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_NFAT_TFPATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_NFAT_TFPATHWAY.html)

**BROWNE_HCMV_INFECTION_30MIN_UP**: Genes up-regulated in primary fibroblast cell culture at 30 min time point after infection with HCMV (AD169 strain). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_30MIN_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_30MIN_UP.html)

**REACTOME_NERVOUS_SYSTEM_DEVELOPMENT**: Nervous system development [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NERVOUS_SYSTEM_DEVELOPMENT.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NERVOUS_SYSTEM_DEVELOPMENT.html)

**WP_TRANSCRIPTIONAL_CASCADE_REGULATING_ADIPOGENESIS**: Transcriptional cascade regulating adipogenesis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TRANSCRIPTIONAL_CASCADE_REGULATING_ADIPOGENESIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TRANSCRIPTIONAL_CASCADE_REGULATING_ADIPOGENESIS.html)

**REACTOME_DEVELOPMENTAL_BIOLOGY**: Developmental Biology [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEVELOPMENTAL_BIOLOGY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEVELOPMENTAL_BIOLOGY.html)

**BENPORATH_ES_WITH_H3K27ME3**: Set 'H3K27 bound': genes posessing the trimethylated H3K27 (H3K27me3) mark in their promoters in human embryonic stem cells, as identified by ChIP on chip. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BENPORATH_ES_WITH_H3K27ME3.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BENPORATH_ES_WITH_H3K27ME3.html)

**CHASSOT_SKIN_WOUND**: List of the transcription factors up-regulated 1 hr after wounding HDF cells (dermal fibroblasts). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHASSOT_SKIN_WOUND.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHASSOT_SKIN_WOUND.html)

**WP_HAIR_FOLLICLE_DEVELOPMENT_CYTODIFFERENTIATION_PART_3_OF_3**: Hair follicle development cytodifferentiation part 3 of 3 [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_HAIR_FOLLICLE_DEVELOPMENT_CYTODIFFERENTIATION_PART_3_OF_3.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_HAIR_FOLLICLE_DEVELOPMENT_CYTODIFFERENTIATION_PART_3_OF_3.html)

**REACTOME_SIGNALING_BY_NTRKS**: Signaling by NTRKs [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NTRKS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NTRKS.html)

**BENPORATH_SUZ12_TARGETS**: Set 'Suz12 targets': genes identified by ChIP on chip as targets of the Polycomb protein SUZ12 [GeneID=23512] in human embryonic stem cells. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BENPORATH_SUZ12_TARGETS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BENPORATH_SUZ12_TARGETS.html)

**REACTOME_SIGNALING_BY_RECEPTOR_TYROSINE_KINASES**: Signaling by Receptor Tyrosine Kinases [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_RECEPTOR_TYROSINE_KINASES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_RECEPTOR_TYROSINE_KINASES.html)

**ABE_VEGFA_TARGETS**: Genes most profoundly induced in HUVEC cells (endothelium) by VEGFA [GeneID=7422]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ABE_VEGFA_TARGETS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ABE_VEGFA_TARGETS.html)

**PID_TAP63_PATHWAY**: Validated transcriptional targets of TAp63 isoforms [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_TAP63_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_TAP63_PATHWAY.html)

**PID_IL4_2PATHWAY**: IL4-mediated signaling events [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_IL4_2PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_IL4_2PATHWAY.html)

**ZWANG_CLASS_1_TRANSIENTLY_INDUCED_BY_EGF**: Class I of genes transiently induced by EGF [GeneID =1950] in 184A1 cells (mammary epithelium). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZWANG_CLASS_1_TRANSIENTLY_INDUCED_BY_EGF.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZWANG_CLASS_1_TRANSIENTLY_INDUCED_BY_EGF.html)

**REACTOME_NGF_STIMULATED_TRANSCRIPTION**: NGF-stimulated transcription [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NGF_STIMULATED_TRANSCRIPTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NGF_STIMULATED_TRANSCRIPTION.html)

**DIRMEIER_LMP1_RESPONSE_EARLY**: Clusters 1 and 2: genes up-regulated in B2264-19/3 cells (primary B lymphocytes) within 30-60 min after activation of LMP1 (an oncogene encoded by Epstein-Barr virus, EBV). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DIRMEIER_LMP1_RESPONSE_EARLY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DIRMEIER_LMP1_RESPONSE_EARLY.html)

**REACTOME_EGR2_AND_SOX10_MEDIATED_INITIATION_OF_SCHWANN_CELL_MYELINATION**: EGR2 and SOX10-mediated initiation of Schwann cell myelination [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_EGR2_AND_SOX10_MEDIATED_INITIATION_OF_SCHWANN_CELL_MYELINATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_EGR2_AND_SOX10_MEDIATED_INITIATION_OF_SCHWANN_CELL_MYELINATION.html)
