
## **Pathways:**

**Phase I - Functionalization of compounds**: Phase 1 of metabolism is concerned with functionalization, that is the introduction or exposure of functional groups on the chemical structure of a compound. This provides a 'handle' for phase 2 conjugating species with which to react with. Many xenobiotics are lipophilic and almost chemically inert (e.g. PAHs) so would not necessarily undergo a phase 2 reaction. Making them more chemically reactive would facilitate their excretion but also increases their chance of reacting with cellular macromolecules (e.g. proteins, DNA). There is a fine balance between producing a more reactive metabolite and conjugation reactions.

There are two groups of enzymes in phase 1 - oxidoreductases and hydrolases. Oxidoreductases introduce an oxygen atom into or remove electrons from their substrates. The major oxidoreductase enzyme system is called the P450 monooxygenases. Other systems include flavin-containing monooxygenases (FMO), cyclooxygenases (COX) and monoamine oxidases (MAO). Hydrolases hydrolyse esters, amides, epoxides and glucuronides. [[https://reactome.org/PathwayBrowser/#/R-HSA-211945](https://reactome.org/PathwayBrowser/#/R-HSA-211945)].

**Biological oxidations:** All organisms are constantly exposed to foreign chemicals every day. These can be man-made (drugs, industrial chemicals) or natural (alkaloids, toxins from plants and animals). Uptake is usually via ingestion but inhalation and transdermal routes are also common. The very nature of many chemicals that make them suitable for uptake by these routes, in other words their lipophilicty (favours fat solubility) is also the main reason organisms have developed mechanisms that convert them to hydrophilic (favours water solubility) compounds which are readily excreted via bile and urine. Otherwise, lipophilic chemicals would accumulate in the body and overwhelm defense mechanisms. This process is called biotransformation and is catalyzed by enzymes mainly in the liver of higher organisms but a number of other organs have considerable ability to process xenobiotica such as kidneys, gut and lungs. As well as xenobiotics, many endogenous compounds are commonly eliminated by this process. This mechanism is of ancient origin and a major factor for its development in animals is plants. Most animals are plant eaters and thus are subject to a huge variety of chemical compounds which plants produce to stop themselves being eaten. This complex set of enzymes have several features which make them ideal for biotransformation: (1) metabolites of the parent chemical are usually made more water soluble so it favours rapid excretion via bile and urine, (2) the enzymes possess broad and overlapping specificity to be able to deal with newly exposed chemicals, (3) metabolites of the parent generally don't have adverse biological effects.

In the real world however, all these criteria have exceptions. Many chemicals are transformed into reactive metabolites. In pharmacology, the metabolites of some parent drugs exert the desired pharmacological effect but in the case of polycyclic aromatic hydrocarbons (PAHs), which can undergo epoxidation, it results in the formation of an electrophile which can attack proteins and DNA.

Metabolism of xenobiotica occurs in several steps called Phase 1 (functionalization) and Phase 2 (conjugation). To improve water solubility, a functional group is added to or exposed on the chemical in one or more steps (Phase 1) to which hydrophilic conjugating species can be added (Phase 2). Functional groups can either be electrophilic (epoxides, carbonyl groups) or nucleophilic (hydroxyls, amino and sulfhydryl groups, carboxylic groups) (see picture).

Once chemicals undergo functionalization, the electrophilic or nucleophilic species can be detrimental to biological systems. Electrophiles can react with electron-rich macromolecules such as proteins, DNA and RNA by covalent interaction whilst nucleophiles have the potential to interact with biological receptors. That's why conjugation is so important as it mops up these potentially reactive species. Many chemicals, when exposed to certain metabolizing enzymes can induce those enzymes, a process called enzyme induction. The effect of this is that these chemicals accelerate their own biotransformation and excretion. The reverse is also true where some chemicals cause enzyme inhibition. Some other factors that alter enzyme levels are sex, age and genetic predisposition. Between species, there can be considerable differences in biotransformation ability which is a problem faced by drug researchers interpreting toxicological results to humans. [[https://reactome.org/PathwayBrowser/#/R-HSA-211859&PATH=R-HSA-1430728](https://reactome.org/PathwayBrowser/#/R-HSA-211859&PATH=R-HSA-1430728)].

## GO terms:

**arachidonic acid metabolic process** [The chemical reactions and pathways involving arachidonic acid, a straight chain fatty acid with 20 carbon atoms and four double bonds per molecule. Arachidonic acid is the all-Z-(5,8,11,14)-isomer. GO:0019369]

**aromatic compound catabolic process** [The chemical reactions and pathways resulting in the breakdown of aromatic compounds, any substance containing an aromatic carbon ring. GO:0019439]

**cellular aromatic compound metabolic process** [The chemical reactions and pathways involving aromatic compounds, any organic compound characterized by one or more planar rings, each of which contains conjugated double bonds and delocalized pi electrons, as carried out by individual cells. GO:0006725]

**cellular response to glucocorticoid stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a glucocorticoid stimulus. Glucocorticoids are hormonal C21 corticosteroids synthesized from cholesterol with the ability to bind with the cortisol receptor and trigger similar effects. Glucocorticoids act primarily on carbohydrate and protein metabolism, and have anti-inflammatory effects. GO:0071385]

**cellular response to organic substance** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an organic substance stimulus. GO:0071310]

**diol biosynthetic process** [The chemical reactions and pathways resulting in the formation of a diol, any alcohol containing two hydroxyl groups attached to saturated carbon atoms. GO:0034312]

**epoxide metabolic process** [The chemical reactions and pathways involving epoxides, compounds in which an oxygen atom is directly attached to two adjacent or non-adjacent carbon atoms of a carbon chain or ring system; thus cyclic ethers. GO:0097176]

**liver development** [The process whose specific outcome is the progression of the liver over time, from its formation to the mature structure. The liver is an exocrine gland which secretes bile and functions in metabolism of protein and carbohydrate and fat, synthesizes substances involved in the clotting of the blood, synthesizes vitamin A, detoxifies poisonous substances, stores glycogen, and breaks down worn-out erythrocytes. GO:0001889]

**response to organic cyclic compound** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an organic cyclic compound stimulus. GO:0014070]

**response to toxic substance** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a toxic stimulus. GO:0009636]

## MSigDB Signatures:

**WP_CHOLESTASIS**: Cholestasis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_CHOLESTASIS.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_CHOLESTASIS.html)]

**WP_AFLATOXIN_B1_METABOLISM**: Aflatoxin B1 metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_AFLATOXIN_B1_METABOLISM.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_AFLATOXIN_B1_METABOLISM.html)]

**WP_METAPATHWAY_BIOTRANSFORMATION_PHASE_I_AND_II**: Metapathway biotransformation Phase I and II [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_METAPATHWAY_BIOTRANSFORMATION_PHASE_I_AND_II.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_METAPATHWAY_BIOTRANSFORMATION_PHASE_I_AND_II.html)]

**KEGG_MEDICUS_ENV_FACTOR_BENZO_A_PYRENRE_TO_CYP_MEDIATED_METABOLISM**: Pathway Definition from KEGG: B[a]P -- (CYP1A1,CYP1B1) >> EH >> AKR -> C22355 -> Semiquinone -> Superoxide [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_ENV_FACTOR_BENZO_A_PYRENRE_TO_CYP_MEDIATED_METABOLISM.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_ENV_FACTOR_BENZO_A_PYRENRE_TO_CYP_MEDIATED_METABOLISM.html)]

**WP_BENZO_A_PYRENE_METABOLISM**: Benzo a pyrene metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_BENZO_A_PYRENE_METABOLISM.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_BENZO_A_PYRENE_METABOLISM.html)]

**KEGG_METABOLISM_OF_XENOBIOTICS_BY_CYTOCHROME_P450**: Metabolism of xenobiotics by cytochrome P450 [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_METABOLISM_OF_XENOBIOTICS_BY_CYTOCHROME_P450.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_METABOLISM_OF_XENOBIOTICS_BY_CYTOCHROME_P450.html)]

**BIOCARTA_EICOSANOID_PATHWAY**: Eicosanoid Metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_EICOSANOID_PATHWAY.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_EICOSANOID_PATHWAY.html)]

**REACTOME_BIOLOGICAL_OXIDATIONS**: Biological oxidations [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_BIOLOGICAL_OXIDATIONS.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_BIOLOGICAL_OXIDATIONS.html)]

**WP_BENZENE_METABOLISM**: Benzene metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_BENZENE_METABOLISM.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_BENZENE_METABOLISM.html)]

**REACTOME_PHASE_I_FUNCTIONALIZATION_OF_COMPOUNDS**: Phase I - Functionalization of compounds [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PHASE_I_FUNCTIONALIZATION_OF_COMPOUNDS.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PHASE_I_FUNCTIONALIZATION_OF_COMPOUNDS.html)]
