
## **Pathways:**

**Metabolism of lipids**: Lipids are hydrophobic but otherwise chemically diverse molecules that play a wide variety of roles in human biology. They include ketone bodies, fatty acids, triacylglycerols, phospholipids and sphingolipids, eicosanoids, cholesterol, bile salts, steroid hormones, and fat-soluble vitamins. They function as a major source of energy (fatty acids, triacylglycerols, and ketone bodies), are major constituents of cell membranes (cholesterol and phospholipids), play a major role in their own digestion and uptake (bile salts), and participate in numerous signaling and regulatory processes (steroid hormones, eicosanoids, phosphatidylinositols, and sphingolipids) (Vance & Vance 2008 - URL).

The central steroid in human biology is cholesterol, obtained from animal fats consumed in the diet or synthesized de novo from acetyl-coenzyme A. (Vegetable fats contain various sterols but no cholesterol.) Cholesterol is an essential constituent of lipid bilayer membranes and is the starting point for the biosyntheses of bile acids and salts, steroid hormones, and vitamin D. Bile acids and salts are mostly synthesized in the liver. They are released into the intestine and function as detergents to solubilize dietary fats. Steroid hormones are mostly synthesized in the adrenal gland and gonads. They regulate energy metabolism and stress responses (glucocorticoids), salt balance (mineralocorticoids), and sexual development and function (androgens and estrogens). At the same time, chronically elevated cholesterol levels in the body are associated with the formation of atherosclerotic lesions and hence increased risk of heart attacks and strokes. The human body lacks a mechanism for degrading excess cholesterol, although an appreciable amount is lost daily in the form of bile salts and acids that escape recycling. [[http://www.reactome.org/PathwayBrowser/#/R-HSA-556833](http://www.reactome.org/PathwayBrowser/#/R-HSA-556833)].

**Neutrophil degranulation**: Neutrophils are the most abundant leukocytes (white blood cells), indispensable in defending the body against invading microorganisms. In response to infection, neutrophils leave the circulation and migrate towards the inflammatory focus. They contain several subsets of granules that are mobilized to fuse with the cell membrane or phagosomal membrane, resulting in the exocytosis or exposure of membrane proteins. Traditionally, neutrophil granule constituents are described as antimicrobial or proteolytic, but granules also introduce membrane proteins to the cell surface, changing how the neutrophil responds to its environment (Borregaard et al. 2007). Primed neutrophils actively secrete cytokines and other inflammatory mediators and can present antigens via MHC II, stimulating T-cells (Wright et al. 2010).

Granules form during neutrophil differentiation. Granule subtypes can be distinguished by their content but overlap in structure and composition. The differences are believed to be a consequence of changing protein expression and differential timing of granule formation during the terminal processes of neutrophil differentiation, rather than sorting (Le Cabec et al. 1996).

The classical granule subsets are Azurophil or primary granules (AG), secondary granules (SG) and gelatinase granules (GG). Neutrophils also contain exocytosable storage cell organelles, storage vesicles (SV), formed by endocytosis they contain many cell-surface markers and extracellular, plasma proteins (Borregaard et al. 1992). Ficolin-1-rich granules (FG) are like GGs highly exocytosable but gelatinase-poor (Rorvig et al. 2009). [[http://www.reactome.org/PathwayBrowser/#/R-HSA-6798695](http://www.reactome.org/PathwayBrowser/#/R-HSA-6798695)].

**Signaling by Nuclear Receptors**: Nuclear receptors (NRs) are ligand-activated transcription factors that bind to small lipid-based molecules to regulate gene expression and other cellular process. This family includes receptors for steroid hormones and derivatives (such as estrogen, progesterone, glucocorticoids, Vitamin D, oxysterols and bile acids, among others) as well as receptors for retinoic acids, thyroid hormones and fatty acids and their derivatives. These ligands are able to diffuse directly through cellular membranes as a result of their lipophilic nature (reviewed in Beato et al, 1996; Holzer et al, 2017). The 48 human nuclear receptors share a conserved modular structure that consists of a sequence specific DNA-binding domain and a ligand-binding domain, in addition to various other protein-protein interaction domains. Upon interaction with ligand, NRs bind to the regulatory regions of target genes as homo- or heterodimers, or more rarely, as monomers. At the promoter, NRs interact with other activators and repressors to regulate gene expression (reviewed Beato et al, 1996; Simons et al, 2014; Hah and Kraus, 2010). A number of nuclear receptors are cytoplasmic in the absence of ligand and exist as part of a heat shock protein complex that regulates their cellular location, protein stability, competency to bind steroid hormones and transcriptional activity (Echeverria and Picard, 2010). Ligand-binding to these receptors promotes dimerization and nuclear translocation. Other nuclear receptors are contstitutively nuclear, and their chromatin-modifying activities are regulated by ligand binding (reviewed in Beato et al, 1996). In addition to the classic transcriptional response, NRs also have a role in rapid, non-nuclear signaling originating from receptors localized at the plasma membrane. Ligand-binding to these receptors intitiates downstream phospholipase- and kinase-based signaling cascades (reviewed in Schwartz et al, 2016; Levin and Hammes, 2016). [[http://www.reactome.org/PathwayBrowser/#/R-HSA-9006931](http://www.reactome.org/PathwayBrowser/#/R-HSA-9006931)].

**Signaling by Retinoic Acid:** Vitamin A (retinol) can be metabolised into active retinoid metabolites that function either as a chromophore in vision or in regulating gene expression transcriptionally and post-transcriptionally. Genes regulated by retinoids are essential for reproduction, embryonic development, growth, and multiple processes in the adult, including energy balance, neurogenesis, and the immune response. The retinoid used as a cofactor in the visual cycle is 11-cis-retinal (11cRAL). The non-visual cycle effects of retinol are mediated by retinoic acid (RA), generated by two-step conversion from retinol (Napoli 2012). All-trans-retinoic acid (atRA) is the major activated metabolite of retinol. An isomer, 9-cis-retinoic acid (9cRA) has biological activity, but has not been detected in vivo, except in the pancreas. An alternative route involves BCO1 cleavage of carotenoids into retinal, which is then reduced into retinol in the intestine (Harrison 2012). The two isomers of RA serve as ligands for retinoic acid receptors (RAR) that regulate gene expression. (Das et al. 2014). RA is catabolised to oxidised metabolites such as 4-hydroxy-, 18-hydroxy- or 4-oxo-RA by CYP family enzymes, these metabolites then becoming substrates for Phase II conjugation enzymes (Ross & Zolfaghari 2011). [[http://www.reactome.org/PathwayBrowser/#/R-HSA-5362517](http://www.reactome.org/PathwayBrowser/#/R-HSA-5362517)]

**Triglyceride catabolism**: Triacylglycerol is a major energy store in the body and its hydrolysis to yield fatty acids and glycerol is a tightly regulated part of energy metabolism. A central part in this regulation is played by hormone-sensitive lipase (HSL), a neutral lipase abundant in adipocytes and skeletal and cardiac muscle, but also abundant in ovarian and adrenal tissue, where it mediates cholesterol ester hydrolysis, yielding cholesterol for steroid biosynthesis. The hormones to which it is sensitive include catecholamines (e.g., epinephrine), ACTH, and glucagon, all of which trigger signaling cascades that lead to its phosphorylation and activation, and insulin, which sets off events leading to its dephosphorylation and inactivation (Holm et al. 2000; Kraemer and Shen 2002).

The processes of triacylglycerol and cholesterol ester hydrolysis are also regulated by subcellular compartmentalization: these lipids are packaged in cytosolic particles and the enzymes responsible for their hydrolysis, and perhaps for additional steps in their metabolism, are organized at the surfaces of these particles (e.g., Brasaemle et al. 2004). This organization is dynamic: the inactive form of HSL is not associated with the particles, but is translocated there after being phosphorylated. Conversely, perilipin, a major constituent of the particle surface, appears to block access of enzymes to the lipids within the particle; its phosphorylation allows greater access.

Here, HSL-mediated triacylglycerol hydrolysis is described as a pathway containing twelve reactions. The first six of these involve activation: phosphorylation of HSL, dimerization of HSL, disruption of CGI-58:perilipin complexes at the surfaces of cytosolic lipid particles, phosphorylation of perilipin, association of phosphorylated HSL with FABP, and translocation of HSL from the cytosol to the surfaces of lipid particles. The next four reactions are the hydrolysis reactions themselves: the hydrolysis of cholesterol esters, and the successive removal of three fatty acids from triacylglycerol. The last two reactions, dephosphorylation of perilipin and HSL, negatively regulate the pathway. These events are outlined in the figure below. Inputs (substrates) and outputs (products) of individual reactions are connected by black arrows; blue lines connect output activated enzymes to the other reactions that they catalyze.

Despite the undoubted importance of these reactions in normal human energy metabolism and in the pathology of diseases such as type II diabetes, they have been studied only to a limited extent in human cells and tissues. Most experimental data are derived instead from two rodent model systems: primary adipocytes from rats, and mouse 3T3-L1 cells induced to differentiate into adipocytes. [[http://www.reactome.org/PathwayBrowser/#/R-HSA-163560](http://www.reactome.org/PathwayBrowser/#/R-HSA-163560)].

## GO terms:

**fatty acid transport** [The directed movement of fatty acids into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. Fatty acids are aliphatic monocarboxylic acids liberated from naturally occurring fats and oils by hydrolysis. GO:0015908]

**glucose homeostasis** [Any process involved in the maintenance of an internal steady state of glucose within an organism or cell. GO:0042593]

**glucose metabolic process** [The chemical reactions and pathways involving glucose, the aldohexose gluco-hexose. D-glucose is dextrorotatory and is sometimes known as dextrose; it is an important source of energy for living organisms and is found free as well as combined in homo- and hetero-oligosaccharides and polysaccharides. GO:0006006]

**lipid metabolic process** [The chemical reactions and pathways involving lipids, compounds soluble in an organic solvent but not, or sparingly, in an aqueous solvent. Includes fatty acids; neutral fats, other fatty-acid esters, and soaps; long-chain (fatty) alcohols and waxes; sphingoids and other long-chain bases; glycolipids, phospholipids and sphingolipids; and carotenes, polyprenols, sterols, terpenes and other isoprenoids. GO:0006629]

**lipid transport across blood-brain barrier** [The directed movement of lipid molecules passing through the blood-brain barrier. GO:1990379]

**long-chain fatty acid transport** [The directed movement of a long-chain fatty acid into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. A long-chain fatty acid is a fatty acid with an aliphatic tail of 13 to 21 carbons. GO:0015909]

**negative regulation of glucose transmembrane transport** [Any process that decreases the frequency, rate or extent of glucose transport across a membrane. Glucose transport is the directed movement of the hexose monosaccharide glucose into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. GO:0010829]

**phosphatidylcholine biosynthetic process** [The chemical reactions and pathways resulting in the formation of phosphatidylcholines, any of a class of glycerophospholipids in which the phosphatidyl group is esterified to the hydroxyl group of choline. GO:0006656]

**positive regulation of cold-induced thermogenesis** [Any process that activates or increases the frequency, rate or extent of cold-induced thermogenesis. GO:0120162]

**positive regulation of peroxisome proliferator activated receptor signaling pathway** [Any process that activates or increases the frequency, rate or extent of the peroxisome proliferator activated receptor signaling pathway. GO:0035360]

**regulation of prostaglandin biosynthetic process** [Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of prostaglandin. GO:0031392]

**regulation of retrograde trans-synaptic signaling by endocanabinoid** [Any process that modulates the frequency, rate or extent of retrograde trans-synaptic signaling by an endocannabinoid. GO:0099178]

**regulation of sensory perception of pain** [Any process that modulates the frequency, rate or extent of the sensory perception of pain, the series of events required for an organism to receive a painful stimulus, convert it to a molecular signal, and recognize and characterize the signal. GO:0051930]

## MSigDB Signatures:

**REACTOME_METABOLISM_OF_LIPIDS**: Metabolism of lipids [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_METABOLISM_OF_LIPIDS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_METABOLISM_OF_LIPIDS.html)

**REACTOME_TRIGLYCERIDE_CATABOLISM**: Triglyceride catabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRIGLYCERIDE_CATABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRIGLYCERIDE_CATABOLISM.html)

**REACTOME_TRIGLYCERIDE_METABOLISM**: Triglyceride metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRIGLYCERIDE_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRIGLYCERIDE_METABOLISM.html)

**CARRILLOREIXACH_HEPATOBLASTOMA_VS_NORMAL_UP**: Genes up-regulated in hepatoblastoma (HB) tumors as compared with non-tumor (NT) adjacent tissue. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CARRILLOREIXACH_HEPATOBLASTOMA_VS_NORMAL_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CARRILLOREIXACH_HEPATOBLASTOMA_VS_NORMAL_UP.html)

**KEGG_PPAR_SIGNALING_PATHWAY**: PPAR signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_PPAR_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_PPAR_SIGNALING_PATHWAY.html)

**WP_PPAR_SIGNALING_PATHWAY**: PPAR signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PPAR_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PPAR_SIGNALING_PATHWAY.html)

**WP_FATTY_ACID_TRANSPORTERS**: Fatty acid transporters [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FATTY_ACID_TRANSPORTERS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FATTY_ACID_TRANSPORTERS.html)

**REACTOME_INNATE_IMMUNE_SYSTEM**: Innate Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html)

**REACTOME_NEUTROPHIL_DEGRANULATION**: Neutrophil degranulation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NEUTROPHIL_DEGRANULATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NEUTROPHIL_DEGRANULATION.html)

**REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS**: Signaling by Nuclear Receptors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS.html)

**REACTOME_SIGNALING_BY_RETINOIC_ACID**: Signaling by Retinoic Acid [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_RETINOIC_ACID.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_RETINOIC_ACID.html)

**RIEGE_DELTANP63_DIRECT_TARGETS_UP**: Genes directly up-regulated by DeltaNp63, the p63 isoform that lacks the canonical transactivation domain and is predominantly expressed in stratifying epithelia, identified through a meta-analysis of both cell lines and primary cells. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RIEGE_DELTANP63_DIRECT_TARGETS_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RIEGE_DELTANP63_DIRECT_TARGETS_UP.html)
