
## **Pathways:**

**Epithelial to mesenchymal transition in colorectal cancer:** Epithelial to mesenchymal transition (EMT) is a process during which cells lose their epithelial characteristics, and gain mesenchymal properties, such as increased motility. In colorectal cancer (CRC), EMT is associated with an invasive or metastatic phenotype. During EMT, tumor cells undergo tight junction dissolution, disruption of apical-basal polarity, and reorganization of the cytoskeletal architecture, which enable cells to develop an invasive phenotype. In cancer cells, EMT is abnormally regulated by extracellular stimuli derived from the tumor microenvironment, including growth factors and inflammatory cytokines, along with intra-tumoral physical stresses such as hypoxia. Therefore, EMT programming allows tumor cells to adapt to the constant changes of the human tumor microenvironment, and thus to successfully metastasize. This pathway summarizes the major signaling pathways and inducers that promote EMT in CRC. A set of core transcription factors regulate EMT: SNAIL family of zinc-finger transcription factors SNAIL/SLUG; the zinc finger E-box binding homeobox (ZEB) family of transcription factors ZEB1/ZEB2, and the TWIST family of basic helix-loop-helix (bHLH) transcription factors TWIST1/TWIST2. [[https://www.wikipathways.org/pathways/WP4239.html](https://www.wikipathways.org/pathways/WP4239.html)].

**Apoptosis:** Apoptosis is a distinct form of cell death that is functionally and morphologically different from necrosis. Nuclear chromatin condensation, cytoplasmic shrinking, dilated endoplasmic reticulum, and membrane blebbing characterize apoptosis in general. Mitochondria remain morphologically unchanged. In 1972 Kerr et al introduced the concept of apoptosis as a distinct form of "cell-death", and the mechanisms of various apoptotic pathways are still being revealed today. The two principal pathways of apoptosis are (1) the Bcl-2 inhibitable or intrinsic pathway induced by various forms of stress like intracellular damage, developmental cues, and external stimuli and (2) the caspase 8/10 dependent or extrinsic pathway initiated by the engagement of death receptors.

The caspase 8/10 dependent or extrinsic pathway is a death receptor mediated mechanism that results in the activation of caspase-8 and caspase-10. Activation of death receptors like Fas/CD95, TNFR1, and the TRAIL receptor is promoted by the TNF family of ligands including FASL (APO1L OR CD95L), TNF, LT-alpha, LT-beta, CD40L, LIGHT, RANKL, BLYS/BAFF, and APO2L/TRAIL. These ligands are released in response to microbial infection, or as part of the cellular, humoral immunity responses during the formation of lymphoid organs, activation of dendritic cells, stimulation or survival of T, B, and natural killer (NK) cells, cytotoxic response to viral infection or oncogenic transformation.

The Bcl-2 inhibitable or intrinsic pathway of apoptosis is a stress-inducible process, and acts through the activation of caspase-9 via Apaf-1 and cytochrome c. The rupture of the mitochondrial membrane, a rapid process involving some of the Bcl-2 family proteins, releases these molecules into the cytoplasm. Examples of cellular processes that may induce the intrinsic pathway in response to various damage signals include: auto reactivity in lymphocytes, cytokine deprivation, calcium flux or cellular damage by cytotoxic drugs like taxol, deprivation of nutrients like glucose and growth factors like EGF, anoikis, transactivation of target genes by tumor suppressors including p53.

In many non-immune cells, death signals initiated by the extrinsic pathway are amplified by connections to the intrinsic pathway. The connecting link appears to be the truncated BID (tBID) protein a proteolytic cleavage product mediated by caspase-8 or other enzymes. [[https://reactome.org/PathwayBrowser/#/R-HSA-109581&PATH=R-HSA-5357801](https://reactome.org/PathwayBrowser/#/R-HSA-109581&PATH=R-HSA-5357801)].

**Autophagy**: Autophagy is an intracellular degradation process that is triggered by cellular stresses. There are three primary types of autophagy - macroautophagy, chaperone-mediated autophagy (CMA) and late endosomal microautophagy. Despite being morphologically distinct, all three processes culminate in the delivery of cargo to the lysosome for degradation and recycling (Parzych KR et al, 2014). In macroautophagy a double membrane compartment sequesters the cargo and delivers it to the lysosome. Chaperones are used to deliver specific cargo proteins to the lysosome in CMA. In microautophagy invaginations of the endosomal membrane are used to capture cargo from the cytosol. Autophagy can target a wide range of entities ranging from bulk proteins and lipids to cell organelles and pathogens giving rise to several subclasses such as mitophagy, lipophagy, xenophagy, etc. (Shibutani ST 2014 et al).[ [https://reactome.org/PathwayBrowser/#/R-HSA-9612973](https://reactome.org/PathwayBrowser/#/R-HSA-9612973)].

**NF-kappaB Signaling**: Nuclear factor kappa B (NF-kappa-B) is activated by a diverse range of stimuli including cytokines, ligands of pattern-recognition receptors (PRRs) such as Toll-like receptors (TLRs) in myeloid cells, antigen-activated TCR in T-cells and by DNA damage (reviewed in Yu H et al. 2020; Zhang T et al. 2021). NF-kappaB regulates the transcription of genes that are involved in immune and inflammatory responses, cell cycle, cell proliferation and apoptosis (Bhatt D & Ghosh S 2014; Liu T et al. 2017; Yu H et al. 2020). In unstimulated cells, NF-kappaB is sequestered in the cytosol through interactions with a class of inhibitor proteins, called NF-kappaB inhibitors (IkBs, such as NFKBIA or NFKBIB) (Jacobs MD & Harrison SC 1998). IkBs mask the nuclear localization signal (NLS) of NF-kappaB preventing its nuclear translocation (Cervantes CF et al. 2011). A key event in NF-kappaB activation involves phosphorylation of IkBs by the I kappa B kinase (IKK) complex which consists of CHUK, IKBKB and IKBKG subunits (Israel A 2010). The activated NF-kappaB signaling is tightly controlled at multiple levels (Dorrington MG & Fraser IDC 2019; Prescott JA et al. 2021). Dysregulated NF-kappaB activity can cause tissue damage associated with inflammatory diseases and is also linked to tumorigenesis (Aggarwal BB & Sung B 2011; Liu T et al.2017; Barnabei L et al. 2021). The regulation of NF-kappaB is cell-type-, context- , and stimulus-dependent and is crucial for orchestrating specific cellular responses (Mussbacher M et al. 2019). [[https://reactome.org/PathwayBrowser/#/R-HSA-445989&SEL=R-HSA-9758274&PATH=R-HSA-168256,R-HSA-168249,R-HSA-168898,R-HSA-168164)](https://reactome.org/PathwayBrowser/#/R-HSA-445989&SEL=R-HSA-9758274&PATH=R-HSA-168256,R-HSA-168249,R-HSA-168898,R-HSA-168164)].

**Signaling by WNT**: WNT signaling pathways control a wide range of developmental and adult process in metozoans including cell proliferation, cell fate decisions, cell polarity and stem cell maintenance (reviewed in Saito-Diaz et al, 2013; MacDonald et al, 2009). The pathway is named for the WNT ligands, a large family of secreted cysteine-rich glycoproteins. At least 19 WNT members have been identified in humans and mice with distinct expression patterns during development (reviewed in Willert and Nusse, 2012). These ligands can activate at least three different downstream signaling cascades depending on which receptors they engage.

In the so-called 'canonical' WNT signaling pathway, WNT ligands bind one of the 10 human Frizzled (FZD) receptors in conjunction with the LRP5/6 co-receptors to activate a transcriptional cascade that controls processes such as cell fate, proliferation and self-renenwal of stem cells. Engagement of the FZD-LRP receptor by WNT ligand results in the stabilization and translocation of cytosolic beta-catenin to the nucleus where it is a co-activator for LEF (lymphoid enhancer-binding factor)- and TCF (T cell factor) -dependent transcription. In the absence of WNT ligand, cytosolic beta-catenin is phosphorylated by a degradation complex consisting of glycogen synthase kinase 3 (GSK3), casein kinase 1 (CK1), Axin and Adenomatous polyposis coli (APC), and subsequently ubiquitinated and degraded by the 26S proteasome (reviewed in Saito-Diaz et al, 2013; Kimmelman and Xu, 2006).

In addition to the beta-catenin-dependent transcriptional response, WNT signaling can also activate distinct non-transcriptional pathways that regulate cell migration and polarity. These beta-catenin-independent 'non-canonical' pathways signal through Frizzled receptors independently of LRP5/6, or occur through the tyrosine kinase receptors ROR and RYK (reviewed in Veeman et al, 2003; James et al, 2009). Non-canonical WNT pathways are best studied in Drosophila where the planar cell polarity (PCP) pathway controls the orientation of wing hairs and eye facets, but are also involved in processes such as convergent extension, neural tube closure, inner ear development and hair orientation in vertebrates and mammals(reviewed in Seifert and Mlodzik, 2007; Simons and Mlodzik, 2008). In the PCP pathway, binding of WNT ligand to the FZD receptor leads to activation of small Rho GTPases and JNK, which regulate the cytoskeleton and coordinate cell migration and polarity (reviewed in Lai et al, 2009; Schlessinger et al, 2009). In some cases, a FZD-WNT interaction increases intracellular calcium concentration and activates CaMK II and PKC; this WNT calcium pathway promotes cell migration and inhibits the canonical beta-catenin dependent transcriptional pathway (reviewed in Kuhl et al, 2000; Kohn and Moon, 2005; Rao et al 2010). Binding of WNT to ROR or RYK receptors also regulates cell migration, apparently through activation of JNK or SRC kinases, respectively, however the details of these pathways remain to be worked out (reviewed in Minami et al, 2010).

Although the WNT signaling pathways were originally viewed as discrete, linear pathways controlled by defined subsets of 'canonical' or 'non-canonical' ligands and receptors, the emerging evidence is challenging this notion. Instead, the specificity and the downstream response appear to depend on the particular cellular context and vary with species, tissue and stage of development (reviewed in van Amerongen and Nusse, 2009; Rao et al, 2010). [[https://reactome.org/PathwayBrowser/#/R-HSA-195721&PATH=R-HSA-162582](https://reactome.org/PathwayBrowser/#/R-HSA-195721&PATH=R-HSA-162582)].

**Signaling by NOTCH**: The Notch Signaling Pathway (NSP) is a highly conserved pathway for cell-cell communication. NSP is involved in the regulation of cellular differentiation, proliferation, and specification. For example, it is utilised by continually renewing adult tissues such as blood, skin, and gut epithelium not only to maintain stem cells in a proliferative, pluripotent, and undifferentiated state but also to direct the cellular progeny to adopt different developmental cell fates. Analogously, it is used during embryonic development to create fine-grained patterns of differentiated cells, notably during neurogenesis where the NSP controls patches such as that of the vertebrate inner ear where individual hair cells are surrounded by supporting cells.

This process is known as lateral inhibition: a molecular mechanism whereby individual cells within a field are stochastically selected to adopt particular cell fates and the NSP inhibits their direct neighbours from doing the same. The NSP has been adopted by several other biological systems for binary cell fate choice. In addition, the NSP is also used during vertebrate segmentation to divide the growing embryo into regular blocks called somites which eventually form the vertebrae. The core of this process relies on regular pulses of Notch signaling generated from a molecular oscillator in the presomatic mesoderm.

The Notch receptor is synthesized in the rough endoplasmic reticulum as a single polypeptide precursor. Newly synthesized Notch receptor is proteolytically cleaved in the trans-golgi network, creating a heterodimeric mature receptor comprising of non-covalently associated extracellular and transmembrane subunits. This assembly travels to the cell surface ready to interact with specific ligands. Following ligand activation and further proteolytic cleavage, an intracellular domain is released and translocate to the nucleus where it regulates gene expression. [[https://reactome.org/PathwayBrowser/#/R-HSA-157118](https://reactome.org/PathwayBrowser/#/R-HSA-157118)].

**Signaling by Hedgehog**: Hedgehog (Hh) is a secreted morphogen that regulates developmental processes in vertebrates including limb bud formation, neural tube patterning, cell growth and differentiation (reviewed in Hui and Angers, 2011). Hh signaling also contributes to stem cell homeostasis in adult tissues. Downregulation of Hh signaling can lead to neonatal abnormalities, while upregulation of signaling is associated with the development of various cancers (Beachy et al, 2004; Jiang and Hui, 2008; Hui and Angers, 2011).

Hh signaling is switched between 'off' and an 'on' states to differentially regulate an intracellular signaling cascade that targets the Gli transcription factors. In the absence of Hh ligand, cytosolic Gli proteins are cleaved to yield a truncated form that translocate into the nucleus and represses target gene transcription. Binding of Hh to the Patched (PTC) receptor on the cell surface stabilizes the Gli proteins in their full-length transcriptional activator form, stimulating Hh-dependent gene expression (reviewed in Hui and Angers, 2011; Briscoe and Therond, 2013). [[https://reactome.org/PathwayBrowser/#/R-HSA-5358351&PATH=R-HSA-162582](https://reactome.org/PathwayBrowser/#/R-HSA-5358351&PATH=R-HSA-162582)].

**Signaling to ERKs**: Neurotrophins utilize multiple pathways to activate ERKs (ERK1 and ERK2), a subgroup of the large MAP kinase (MAPK) family, from the plasma membrane. The major signalling pathways to ERKs are via RAS, occurring from caveolae in the plasma membrane or from clathrin-coated vesicles, and via RAP1, taking place in early endosomes. Whereas RAS activation by NGF is transient, RAP1 activation by NGF is sustained for hours. [[https://reactome.org/PathwayBrowser/#/R-HSA-187037&SEL=R-HSA-187687&PATH=R-HSA-162582,R-HSA-9006934,R-HSA-166520](https://reactome.org/PathwayBrowser/#/R-HSA-187037&SEL=R-HSA-187687&PATH=R-HSA-162582,R-HSA-9006934,R-HSA-166520)].

## GO terms:

**SMAD protein signal transduction** [An intracellular signal transduction pathway that starts with the activation of a SMAD protein, leading to the formation of a complex with co-SMADs, which translocate to the nucleus, where it regulates transcription of specific target genes. Note that the upstream receptor and its ligand regulate the pathway (and are not part of the SMAD pathway), since it is an intracellular signaling pathway. GO:0060395]

**glial cell-derived neurotrophic factor receptor signaling pathway** [The series of molecular signals initiated by a ligand binding to a glial cell-derived neurotrophic factor receptor. GO:0035860]

**negative regulation of growth hormone receptor signaling pathway** [Any process that decreases the rate, frequency or extent of the growth hormone receptor signaling pathway. The growth hormone receptor signaling pathway is the series of molecular signals generated as a consequence of growth hormone receptor binding to its physiological ligand. GO:0060400]

**negative regulation of multicellular organism growth** [Any process that stops, prevents, or reduces the frequency, rate or extent of growth of an organism to reach its usual body size. GO:0040015]

**positive regulation of MAPK cascade** [Any process that activates or increases the frequency, rate or extent of signal transduction mediated by the MAPK cascade. GO:0043410]

**positive regulation of myoblast fusion** [Any process that activates or increases the frequency, rate or extent of myoblast fusion. GO:1901741]

**positive regulation of phosphatidylinositol 3-kinase/protein kinase B signal transduction** [Any process that activates or increases the frequency, rate or extent of phosphatidylinositol 3-kinase/protein kinase B signal transduction. GO:0051897]

**reduction of food intake in response to dietary excess** [An eating behavior process whereby detection of a dietary excess results in a decrease in intake of nutrients. GO:0002023]

## MSigDB Signatures:

**NABA_MATRISOME_ASSOCIATED**: Ensemble of genes encoding ECM-associated proteins including ECM-affiliated proteins, ECM regulators and secreted factors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_ASSOCIATED.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_ASSOCIATED.html)

**NABA_MATRISOME**: Ensemble of genes encoding extracellular matrix and extracellular matrix-associated proteins [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME.html)

**WP_EPITHELIAL_TO_MESENCHYMAL_TRANSITION_IN_COLORECTAL_CANCER**: Epithelial to mesenchymal transition in colorectal cancer [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_EPITHELIAL_TO_MESENCHYMAL_TRANSITION_IN_COLORECTAL_CANCER.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_EPITHELIAL_TO_MESENCHYMAL_TRANSITION_IN_COLORECTAL_CANCER.html)

**NABA_SECRETED_FACTORS**: Genes encoding secreted soluble factors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_SECRETED_FACTORS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_SECRETED_FACTORS.html)

**FOROUTAN_PRODRANK_TGFB_EMT_DN**: Genes down-regulated in the epithelial-mesenchymal transition (EMT) upon transforming growth factor beta (TGFB) stimulation derived from multiple datasets using a product of ranks meta-analysis approach. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FOROUTAN_PRODRANK_TGFB_EMT_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FOROUTAN_PRODRANK_TGFB_EMT_DN.html)

**FOROUTAN_TGFB_EMT_DN**: Genes down-regulated in the epithelial-mesenchymal transition (EMT) upon transforming growth factor beta (TGFB) stimulation derived from multiple datasets by combining results from an integrative approach and a product of ranks meta-analysis approach. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FOROUTAN_TGFB_EMT_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FOROUTAN_TGFB_EMT_DN.html)

**FOROUTAN_INTEGRATED_TGFB_EMT_DN**: Genes down-regulated in the epithelial-mesenchymal transition (EMT) upon transforming growth factor beta (TGFB) stimulation derived from multiple datasets by integrating them. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FOROUTAN_INTEGRATED_TGFB_EMT_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FOROUTAN_INTEGRATED_TGFB_EMT_DN.html)
