
## **Pathways:**

**Azathioprine ADME:** Thiopurines were originally developed for cancer treatment in the early 1950s, with 6-mercaptopurine (6MP) being the first thiopurine approved by the FDA for the treatment of leukaemia, just two years after its discovery. Azathioprine (AZA), a prodrug of 6MP, was developed by the addition of a nitroimidazol group a few years later to bypass the high first-pass metabolism of 6MP due to oxidation in intestinal cells by xanthine oxidase (XDH). AZA is a thiopurine prodrug, and its pharmacological action is based on the release of the active metabolite 6-mercaptopurine (6MP) which is further metabolised to pharmacoligically active 6-thioguanine nucleotides (6-TGNs). These 6-TGNs achieve their cytotoxic effects in one of four ways: 1. Incorporation of 6-thioguanosine triphosphate (6TGTP) into RNA, 2. Incorporation of 6-thiodeoxyguanosine triphosphate (6TdGTP) into DNA, 3. Inhibition of de novo purine synthesis by methylmercaptopurine nucleotides such as methylthioinosine monophosphate (meTIMP), 4. Inhibition of RAC1 by 6TGTP which induces apoptosis in activated T-cells. While AZA has been supplanted as an antitumour drug, it remains useful as an immunosuppressant antimetabolite drug indicated to treat rheumatoid arthritis, Crohn's disease, ulcerative colitis, cancer and to prevent rejection in kidney transplant patients (Axelrad et al. 2016, Tominaga et al. 2021).

The molecular steps of AZA metabolism are described in this pathway (Cuffari et al. 1996, Dubinsky 2004). Briefly, oral AZA is rapidly converted to 6MP. Initial 6MP metabolism occurs along competing catabolic (XDH, TPMT) and anabolic (HPRT) enzymatic pathways. Once formed, 6-thiosine 5'-monophosphate (6TIMP) is further metabolized by inosine monophosphate dehydrogenase (IMPDH) and guanosine monophosphate synthetase (GMPS) to 6-thioguanosine 5'monophosphate (6TGMP). 6TGMP is then converted to the pharmacologically-active di- and tri- derivatives by their respective kinases. [[https://reactome.org/PathwayBrowser/#/R-HSA-9748787](https://reactome.org/PathwayBrowser/#/R-HSA-9748787)].

**Glutathione conjugation:** Glutathione S-Transferases (GSTs; EC 2.5.1.18) are another major set of phase II conjugation enzymes. They can be found in the cytosol as well as being microsomal membrane-bound. Cytosolic GSTs are encoded by at least 5 gene families (alpha, mu, pi, theta and zeta GST) whereas membrane-bound enzymes are encoded by single genes. Soluble GSTs are homo- or hetero-dimeric enzymes (approximately 25KDa subunits) which can act on a wide range of endogenous and exogenous electrophiles. GSTs mediate conjugation using glutathione (GSH), a tripeptide synthesized from its precursor amino acids gamma-glutamate, cysteine and glycine.

Glutathione conjugates are excreted in bile and converted to cysteine and mercapturic acid conjugates in the intestine and kidneys. GSH is the major, low molecular weight, non-protein thiol synthesized de novo in mammalian cells. As well as taking part in conjugation reactions, GSH also has antioxidant ability and can metabolize endogenous and exogenous compounds. The nucleophilic GSH attacks the electrophilic substrate forming a thioether bond between the cysteine residue of GSH and the electrophile. The result is generally a less reactive and more water-soluble conjugate that can be easily excreted. In some cases, GSTs can activate compounds to reactive species such as certain haloalkanes and haloalkenes. Substrates for GSTs include epoxides, alkenes and compounds with electrophilic carbon, sulfur or nitrogen centers. There are two types of conjugation reaction with glutathione: displacement reactions where glutathione displaces an electron-withdrawing group and addition reactions where glutathione is added to activated double bond structures or strained ring systems [[https://reactome.org/PathwayBrowser/#/R-HSA-156590](https://reactome.org/PathwayBrowser/#/R-HSA-156590)].

**Paracetamol ADME**: Paracetamol (APAP, aka acetaminophen or N-acetyl-p-aminophenol) is an analgesic drug used for to treat mild to moderate pain and as an antipyretic agent. It is one of the most widely used drugs in the world and is available alone or in combination with other drugs for pain relief, fever and allergy. It is thought to act through the inhibition of cyclooxygenases 1 and 2 (Graham et al. 2013, Esh et al. 2021). Paracetamol is generally safe at therapeutic doses but in overdose cases, it causes mitochondrial dysfunction and centrilobular necrosis in the liver which can lead to death.

APAP has a high oral bioavailability (~88%), is well absorbed and reaches peak blood concentrations after 90 minutes after ingestion. APAP binds plasma proteins to a small extent and has a plasma half-life of 1.5-3 hours. Most of the drug is eliminated by glucuronidate and sulfate conjugation (~55% and ~30% respectively) in the liver or as unchanged drug (~5%) (Forrest et al. 1982). A small amount (5-15%) is oxidised to the reactive metabolite N-acetyl-para-benzoquinone imine (NAPQI). NAPQI is usually detoxified by binding to liver glutathione but in overdose cases, glutathione is depleted and NAPQI instead, binds to sulfhydryl groups on proteins, leading to liver damage. ABCC2, ABCC3, ABCC4 and ABCG2 transporters mediate the efflux of APAP metabolites out of cells (McGill & Jaeschke 2013) [[https://reactome.org/PathwayBrowser/#/R-HSA-9753281](https://reactome.org/PathwayBrowser/#/R-HSA-9753281)].

**NRF2 pathway**: NRF2 is part of a group of transcription factors called nuclear receptors. It is activated under oxidative stress conditions and subsequently activates several antioxidative genes and proteins [[https://pubchem.ncbi.nlm.nih.gov/pathway/WikiPathways:WP2884](https://pubchem.ncbi.nlm.nih.gov/pathway/WikiPathways:WP2884)].

## GO terms:

**cellular detoxification of nitrogen compound** [Any cellular process that reduces or removes the toxicity of nitrogenous compounds which are dangerous or toxic. This includes the aerobic conversion of toxic compounds to harmless substances. GO:0070458]

**cellular response to xenobiotic stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a xenobiotic, a compound foreign to the organism exposed to it. It may be synthesized by another organism (like ampicillin) or it can be a synthetic chemical. GO:0071466]

**glutathione derivative biosynthetic process** [The chemical reactions and pathways resulting in the formation of glutathione derivative. GO:1901687]

**glutathione metabolic process** [The chemical reactions and pathways involving glutathione, the tripeptide glutamylcysteinylglycine, which acts as a coenzyme for some enzymes and as an antioxidant in the protection of sulfhydryl groups in enzymes and other proteins; it has a specific role in the reduction of hydrogen peroxide (H2O2) and oxidized ascorbate, and it participates in the gamma-glutamyl cycle. GO:0006749]

**hepoxilin biosynthetic process** [The chemical reactions and pathways resulting in the formation of hepoxilins, a class of bioactive icosanoids with roles in the regulation of cell physiology. GO:0051122]

**nitrobenzene metabolic process** [The chemical reactions and pathways involving nitrobenzene (nitrobenzol), a derivative of benzene with an NO2 group attached to the ring. It is a yellow aromatic liquid used in perfumery and manufactured in large quantities in the preparation of aniline. GO:0018916]

**prostaglandin metabolic process** [The chemical reactions and pathways involving prostaglandins, any of a group of biologically active metabolites which contain a cyclopentane ring due to the formation of a bond between two carbons of a fatty acid. They have a wide range of biological activities. GO:0006693]

**response to amino acid** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an amino acid stimulus. An amino acid is a carboxylic acids containing one or more amino groups. GO:0043200]

**response to axon injury** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an axon injury stimulus. GO:0048678]

**response to ethanol** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an ethanol stimulus. GO:0045471]

**response to lead ion** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lead ion stimulus. GO:0010288]

**response to metal ion** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a metal ion stimulus. GO:0010038]

**response to xenobiotic stimulus** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a xenobiotic, a compound foreign to the organism exposed to it. It may be synthesized by another organism (like ampicillin) or it can be a synthetic chemical. GO:0009410]

**sensory perception of smell** [The series of events required for an organism to receive an olfactory stimulus, convert it to a molecular signal, and recognize and characterize the signal. Olfaction involves the detection of chemical composition of an organism's ambient medium by chemoreceptors. This is a neurological process. GO:0007608]

**xenobiotic catabolic process** [The chemical reactions and pathways resulting in the breakdown of a xenobiotic compound, a compound foreign to the organism exposed to it. It may be synthesized by another organism (like ampicillin) or it can be a synthetic chemical. GO:0042178]

## MSigDB Signatures:

**KEGG_DRUG_METABOLISM_CYTOCHROME_P450**: Drug metabolism - cytochrome P450 [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_DRUG_METABOLISM_CYTOCHROME_P450.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_DRUG_METABOLISM_CYTOCHROME_P450.html)]

**WP_AFLATOXIN_B1_METABOLISM**: Aflatoxin B1 metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_AFLATOXIN_B1_METABOLISM.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_AFLATOXIN_B1_METABOLISM.html)]

**WP_METAPATHWAY_BIOTRANSFORMATION_PHASE_I_AND_II**: Metapathway biotransformation Phase I and II [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_METAPATHWAY_BIOTRANSFORMATION_PHASE_I_AND_II.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_METAPATHWAY_BIOTRANSFORMATION_PHASE_I_AND_II.html)]

**KEGG_GLUTATHIONE_METABOLISM**: Glutathione metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_GLUTATHIONE_METABOLISM.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_GLUTATHIONE_METABOLISM.html)]

**WP_GLUTATHIONE_METABOLISM**: Glutathione metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_GLUTATHIONE_METABOLISM.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_GLUTATHIONE_METABOLISM.html)]

**WP_NRF2_PATHWAY**: NRF2 pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NRF2_PATHWAY.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NRF2_PATHWAY.html)]

**REACTOME_GLUTATHIONE_CONJUGATION**: Glutathione conjugation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_GLUTATHIONE_CONJUGATION.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_GLUTATHIONE_CONJUGATION.html)]

**WP_NUCLEAR_RECEPTORS_META_PATHWAY**: Nuclear receptors meta pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NUCLEAR_RECEPTORS_META_PATHWAY.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NUCLEAR_RECEPTORS_META_PATHWAY.html)]

**KEGG_METABOLISM_OF_XENOBIOTICS_BY_CYTOCHROME_P450**: Metabolism of xenobiotics by cytochrome P450 [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_METABOLISM_OF_XENOBIOTICS_BY_CYTOCHROME_P450.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_METABOLISM_OF_XENOBIOTICS_BY_CYTOCHROME_P450.html)]

**KEGG_MEDICUS_ENV_FACTOR_TCDD_TO_AHR_SIGNALING_PATHWAY**: Pathway Definition from KEGG: TCDD -> (AHR+ARNT) => (CYP1A1,CYP1B1,GST) [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_ENV_FACTOR_TCDD_TO_AHR_SIGNALING_PATHWAY.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_ENV_FACTOR_TCDD_TO_AHR_SIGNALING_PATHWAY.html)]

**KEGG_MEDICUS_REFERENCE_KEAP1_NRF2_SIGNALING_PATHWAY**: Pathway Definition from KEGG: (O2-,HO2,H2O2,OH,ACRL,4HNE,NO) -| KEAP1 -| NRF2 => (HMOX1,NQO1,GST,TXNRD1) [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_KEAP1_NRF2_SIGNALING_PATHWAY.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_KEAP1_NRF2_SIGNALING_PATHWAY.html)]

**WP_ESTROGEN_METABOLISM_WP697**: Estrogen metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ESTROGEN_METABOLISM_WP697.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ESTROGEN_METABOLISM_WP697.html)]

**REACTOME_PARACETAMOL_ADME**: Paracetamol ADME [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PARACETAMOL_ADME.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PARACETAMOL_ADME.html)]

**REACTOME_BIOLOGICAL_OXIDATIONS**: Biological oxidations [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_BIOLOGICAL_OXIDATIONS.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_BIOLOGICAL_OXIDATIONS.html)]

**KEGG_MEDICUS_ENV_FACTOR_DCE_TO_DNA_ADDUCTS**: Pathway Definition from KEGG: DCE -- GST -> C20304 -> C14874 == DNA [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_ENV_FACTOR_DCE_TO_DNA_ADDUCTS.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_ENV_FACTOR_DCE_TO_DNA_ADDUCTS.html)]

**REACTOME_PHASE_II_CONJUGATION_OF_COMPOUNDS**: Phase II - Conjugation of compounds [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PHASE_II_CONJUGATION_OF_COMPOUNDS.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PHASE_II_CONJUGATION_OF_COMPOUNDS.html)]

**WP_BENZENE_METABOLISM**: Benzene metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_BENZENE_METABOLISM.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_BENZENE_METABOLISM.html)]

**REACTOME_DRUG_ADME**: Drug ADME [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DRUG_ADME.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DRUG_ADME.html)]

**REACTOME_AZATHIOPRINE_ADME**: Azathioprine ADME [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_AZATHIOPRINE_ADME.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_AZATHIOPRINE_ADME.html)]
