
## **Pathways:**

-   **glutathione-mediated detoxification**: In this important detoxification mechanism GSH binds to electrophilic chemicals, forming conjugates which are exported from the cell. These conjugation reactions have been demonstrated for a multitude of foreign chemicals, as well as endogenous reactive intermediates. GSH has been shown to form thioether conjugates with leukotrienes, prostaglandins, hepoxilin, nitric oxide, hydroxyalkenals, L-ascorbate, L-dopa, dopamine, and maleate, and it forms thioesters with L-cysteine, coenzyme A, proteins, and other cellular thiols [PMID: 9755286]. In addition, GSH also binds endogenous metals, such as copper, selenium, chromium, and zinc, via nonenzymatic reactions. The first step is catalyzed by glutathione S-transferase, a family of enzymes found mainly in the cytosol. Once formed, the glutathione-S conjugates are metabolized by the same degradative enzymes that metabolize GSH (see gamma-glutamyl cycle). The GSH-toxin conjugate is transported out of the cell, where it is subsequently degraded by gamma-glutamyl hydrolase or gamma-glutamyl transpeptidase, and dipeptidases. The breakdown products of the GSH-toxin conjugates (glutamate and glycine) are reabsorbed and can be used for GSH synthesis. The L-cysteine-S-conjugate that is left is also transported back into the cell, where it can be metabolized in different ways. One route is the acetylation of the amino group of the cysteinyl residue by intracellular N-acetyltransferases to form the corresponding mercapturic acids (N-acetylcysteine S-conjugates). The addition of the N-acetylcysteine moiety generally increases the compound's polarity and water solubility, and converts neutral compounds to anions, facilitating their transport across cell membranes and their excretion from the organism [PMID: 4892500]. Mercapturic acids are released into the circulation or bile [PMID: 1939239]; some are eventually excreted in urine, and some may undergo further metabolism. A second route for L-cysteine-S-conjugates is the breakage of the carbon-sulfur bond, catalyzed by EC 4.4.1.13, cysteine-S-conjugate beta-lyase, resulting in the formation of thiols, pyruvate and ammonia [PMID: 4024656, PMID: 9045797, PMID: 15627473]. The thiols that are produced in this reaction are most likely oxidized to sulfonates or methylated to methylsulfinyl or methylsulfonyl derivatives [[https://www.ncbi.nlm.nih.gov/gene/14869](https://www.ncbi.nlm.nih.gov/gene/14869), [https://biocyc.org/MOUSE/NEW-IMAGE?object=PWY-4061](https://biocyc.org/MOUSE/NEW-IMAGE?object=PWY-4061)].
-   **Exercise-induced circadian regulation**: Time- and exercise-dependent gene regulation in human skeletal muscle, [http://genomebiology.com/2003/4/10/R61](http://genomebiology.com/2003/4/10/R61) Mouse genes regulated in the diurnal (inferred from human) and compared with mouse genes that display circadian regulation in mouse heart and liver (Panda 2002, Storch 2002), and SCN (Panda 2002). The 608 significantly regulated (P < 0.05) hSkM genes identified in the diurnal comparison (0800 h and 2000 h) were subjected to an additional statistical filter of absolute fold change > 20% (n = 239) and linked to mouse circadianly regulated orthologues. This pathway represents the resultant 44 putative hSkM circadianly regulated genes; L, promoter for the light-responsive element; E, E-box (Clock/Bmal1 promoter). Orthologue information is denoted to the left of the gene boxes: mHrts and mLvrs, mouse orthologue was circadianly regulated as described (Storch 2002) in mouse heart or liver, respectively; mLvrp and mSCNp, mouse orthologue was diurnally regulated as described (Panda 2002) in mouse liver or SCN, respectively. [[https://www.ncbi.nlm.nih.gov/gene/14869](https://www.ncbi.nlm.nih.gov/gene/14869), [https://www.wikipathways.org/index.php/Pathway:WP544](https://www.wikipathways.org/index.php/Pathway:WP544)].
-   **Oxidative stress and redox pathway**: This pathway represents biology relevant to glutathione, including biosynthesis, metabolism, redox cycle, uptake, glutathionylation and acivicin inhibition. Glutathione is an antioxidant that is synthesized in eukaryotes from L-cysteine, L-glutamic acid, and glycine in a two-step process involving gamma-glutamylcysteine synthetase and glutathione synthetase. Glutathione prevents cellular damage by acting as an electron donor to neutralize reactive oxygen species. Reactive glutathione is produced, which then reacts with another reactive glutathione molecule to produce glutathione disulfide, GSSG. [[https://www.ncbi.nlm.nih.gov/gene/14869](https://www.ncbi.nlm.nih.gov/gene/14869), [https://www.wikipathways.org/index.php/Pathway:WP4466](https://www.wikipathways.org/index.php/Pathway:WP4466)].

## GO terms:

**animal organ regeneration** [The regrowth of a lost or destroyed animal organ. GO:0031100]

**cellular oxidant detoxification** [Any process carried out at the cellular level that reduces or removes the toxicity superoxide radicals or hydrogen peroxide. GO:0098869]

**cellular response to cell-matrix adhesion** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of cell-matrix adhesion. GO:0071460]

**cellular response to epidermal growth factor stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an epidermal growth factor stimulus. GO:0071364]

**cellular response to glucocorticoid stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a glucocorticoid stimulus. Glucocorticoids are hormonal C21 corticosteroids synthesized from cholesterol with the ability to bind with the cortisol receptor and trigger similar effects. Glucocorticoids act primarily on carbohydrate and protein metabolism, and have anti-inflammatory effects. GO:0071385]

**cellular response to insulin stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an insulin stimulus. Insulin is a polypeptide hormone produced by the islets of Langerhans of the pancreas in mammals, and by the homologous organs of other organisms. GO:0032869]

**cellular response to lipopolysaccharide** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lipopolysaccharide stimulus; lipopolysaccharide is a major component of the cell wall of gram-negative bacteria. GO:0071222]

**common myeloid progenitor cell proliferation** [The multiplication or reproduction of common myeloid progenitor cells, resulting in the expansion of a cell population. A common myeloid progenitor cell is a progenitor cell committed to the myeloid lineage. GO:0035726]

**glutathione derivative biosynthetic process** [The chemical reactions and pathways resulting in the formation of glutathione derivative. GO:1901687]

**glutathione metabolic process** [The chemical reactions and pathways involving glutathione, the tripeptide glutamylcysteinylglycine, which acts as a coenzyme for some enzymes and as an antioxidant in the protection of sulfhydryl groups in enzymes and other proteins; it has a specific role in the reduction of hydrogen peroxide (H2O2) and oxidized ascorbate, and it participates in the gamma-glutamyl cycle. GO:0006749]

**hepoxilin biosynthetic process** [The chemical reactions and pathways resulting in the formation of hepoxilins, a class of bioactive icosanoids with roles in the regulation of cell physiology. GO:0051122]

**linoleic acid metabolic process** [The chemical reactions and pathways involving linoleic acid, an unsaturated omega-6 fatty acid that has the molecular formula C18H32O2. GO:0043651]

**negative regulation of ERK1 and ERK2 cascade** [Any process that stops, prevents, or reduces the frequency, rate or extent of signal transduction mediated by the ERK1 and ERK2 cascade. GO:0070373]

**negative regulation of biosynthetic process** [Any process that stops, prevents, or reduces the rate of the chemical reactions and pathways resulting in the formation of substances. GO:0009890]

**negative regulation of canonical NF-kappaB signal transduction** [Any process that stops, prevents, or reduces the frequency, rate or extent of a canonical NF-kappaB signaling cascade. GO:0043124]

**negative regulation of extrinsic apoptotic signaling pathway** [Any process that stops, prevents or reduces the frequency, rate or extent of extrinsic apoptotic signaling pathway. GO:2001237]

**negative regulation of fibroblast proliferation** [Any process that stops, prevents, or reduces the frequency, rate or extent of multiplication or reproduction of fibroblast cells. GO:0048147]

**negative regulation of interleukin-1 beta production** [Any process that stops, prevents, or reduces the frequency, rate, or extent of interleukin-1 beta production. GO:0032691]

**negative regulation of leukocyte proliferation** [Any process that stops, prevents, or reduces the frequency, rate or extent of leukocyte proliferation. GO:0070664]

**negative regulation of monocyte chemotactic protein-1 production** [Any process that stops, prevents, or reduces the frequency, rate, or extent of production of monocyte chemotactic protein-1. GO:0071638]

**negative regulation of nitric-oxide synthase biosynthetic process** [Any process that stops, prevents, or reduces the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of a nitric-oxide synthase enzyme. GO:0051771]

**negative regulation of protein kinase activity** [Any process that stops, prevents, or reduces the frequency, rate or extent of protein kinase activity. GO:0006469]

**negative regulation of smooth muscle cell chemotaxis** [Any process that stops, prevents, or reduces the frequency, rate, or extent of smooth muscle cell chemotaxis. GO:0071672]

**negative regulation of stress-activated MAPK cascade** [Any process that stops, prevents, or reduces the frequency, rate or extent of signal transduction mediated by the stress-activated MAPK cascade. GO:0032873]

**negative regulation of tumor necrosis factor production** [Any process that stops, prevents, or reduces the frequency, rate, or extent of tumor necrosis factor production.|Note that this term refers only to the specific, original 'tumor necrosis factor' protein (TNF) and not other members of the tumor necrosis factor superfamily (those with the gene symbol root 'TNFSF'). GO:0032720]

**negative regulation of vascular associated smooth muscle cell proliferation** [Any process that stops, prevents or reduces the frequency, rate or extent of vascular smooth muscle cell proliferation. GO:1904706]

**oligodendrocyte development** [The process aimed at the progression of an oligodendrocyte over time, from initial commitment of the cell to a specific fate, to the fully functional differentiated cell. An oligodendrocyte is a type of glial cell involved in myelinating the axons in the central nervous system. GO:0014003]

**positive regulation of superoxide anion generation** [Any process that activates or increases the frequency, rate or extent of enzymatic generation of superoxide by a cell. GO:0032930]

**prostaglandin metabolic process** [The chemical reactions and pathways involving prostaglandins, any of a group of biologically active metabolites which contain a cyclopentane ring due to the formation of a bond between two carbons of a fatty acid. They have a wide range of biological activities. GO:0006693]

**regulation of ERK1 and ERK2 cascade** [Any process that modulates the frequency, rate or extent of signal transduction mediated by the ERK1 and ERK2 cascade. GO:0070372]

**regulation of stress-activated MAPK cascade** [Any process that modulates the frequency, rate or extent of signal transduction mediated by the stress-activated MAPK cascade. GO:0032872]

**response to L-ascorbic acid** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an L-ascorbic acid (vitamin C) stimulus. GO:0033591]

**response to amino acid** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an amino acid stimulus. An amino acid is a carboxylic acids containing one or more amino groups. GO:0043200]

**response to estradiol** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of stimulus by estradiol, a C18 steroid hormone hydroxylated at C3 and C17 that acts as a potent estrogen. GO:0032355]

**response to ethanol** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an ethanol stimulus. GO:0045471]

**response to nutrient levels** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus reflecting the presence, absence, or concentration of nutrients. GO:0031667]

**response to reactive oxygen species** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a reactive oxygen species stimulus. Reactive oxygen species include singlet oxygen, superoxide, and oxygen free radicals. GO:0000302]

**response to toxic substance** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a toxic stimulus. GO:0009636]

**xenobiotic metabolic process** [The chemical reactions and pathways involving a xenobiotic compound, a compound foreign to the organism exposed to it. It may be synthesized by another organism (like ampicillin) or it can be a synthetic chemical. GO:0006805]

## MSigDB Signatures:

**WP_NUCLEAR_RECEPTORS_META_PATHWAY**: Nuclear receptors meta pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NUCLEAR_RECEPTORS_META_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NUCLEAR_RECEPTORS_META_PATHWAY.html)

**REACTOME_INNATE_IMMUNE_SYSTEM**: Innate Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html)

**KEGG_GLUTATHIONE_METABOLISM**: Glutathione metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_GLUTATHIONE_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_GLUTATHIONE_METABOLISM.html)

**REACTOME_CELLULAR_RESPONSES_TO_STIMULI**: Cellular responses to stimuli [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELLULAR_RESPONSES_TO_STIMULI.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELLULAR_RESPONSES_TO_STIMULI.html)

**KEGG_PATHWAYS_IN_CANCER**: Pathways in cancer [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_PATHWAYS_IN_CANCER.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_PATHWAYS_IN_CANCER.html)

**KEGG_PROSTATE_CANCER**: Prostate cancer [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_PROSTATE_CANCER.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_PROSTATE_CANCER.html)

**RIEGE_DELTANP63_DIRECT_TARGETS_UP**: Genes directly up-regulated by DeltaNp63, the p63 isoform that lacks the canonical transactivation domain and is predominantly expressed in stratifying epithelia, identified through a meta-analysis of both cell lines and primary cells. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RIEGE_DELTANP63_DIRECT_TARGETS_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RIEGE_DELTANP63_DIRECT_TARGETS_UP.html)

**REACTOME_CELLULAR_RESPONSE_TO_CHEMICAL_STRESS**: Cellular response to chemical stress [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELLULAR_RESPONSE_TO_CHEMICAL_STRESS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELLULAR_RESPONSE_TO_CHEMICAL_STRESS.html)

**KEGG_MEDICUS_ENV_FACTOR_TCDD_TO_AHR_SIGNALING_PATHWAY**: Pathway Definition from KEGG: TCDD -> (AHR+ARNT) => (CYP1A1,CYP1B1,GST) [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_ENV_FACTOR_TCDD_TO_AHR_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_ENV_FACTOR_TCDD_TO_AHR_SIGNALING_PATHWAY.html)

**REACTOME_BIOLOGICAL_OXIDATIONS**: Biological oxidations [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_BIOLOGICAL_OXIDATIONS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_BIOLOGICAL_OXIDATIONS.html)

**WP_METAPATHWAY_BIOTRANSFORMATION_PHASE_I_AND_II**: Metapathway biotransformation Phase I and II [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_METAPATHWAY_BIOTRANSFORMATION_PHASE_I_AND_II.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_METAPATHWAY_BIOTRANSFORMATION_PHASE_I_AND_II.html)

**KEGG_METABOLISM_OF_XENOBIOTICS_BY_CYTOCHROME_P450**: Metabolism of xenobiotics by cytochrome P450 [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_METABOLISM_OF_XENOBIOTICS_BY_CYTOCHROME_P450.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_METABOLISM_OF_XENOBIOTICS_BY_CYTOCHROME_P450.html)

**KEGG_MEDICUS_REFERENCE_KEAP1_NRF2_SIGNALING_PATHWAY**: Pathway Definition from KEGG: (O2-,HO2,H2O2,OH,ACRL,4HNE,NO) -| KEAP1 -| NRF2 => (HMOX1,NQO1,GST,TXNRD1) [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_KEAP1_NRF2_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_KEAP1_NRF2_SIGNALING_PATHWAY.html)

**REACTOME_GLUTATHIONE_CONJUGATION**: Glutathione conjugation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_GLUTATHIONE_CONJUGATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_GLUTATHIONE_CONJUGATION.html)

**REACTOME_DRUG_ADME**: Drug ADME [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DRUG_ADME.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DRUG_ADME.html)

**KEGG_MEDICUS_ENV_FACTOR_DCE_TO_DNA_ADDUCTS**: Pathway Definition from KEGG: DCE -- GST -> C20304 -> C14874 == DNA [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_ENV_FACTOR_DCE_TO_DNA_ADDUCTS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_ENV_FACTOR_DCE_TO_DNA_ADDUCTS.html)

**REACTOME_DETOXIFICATION_OF_REACTIVE_OXYGEN_SPECIES**: Detoxification of Reactive Oxygen Species [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DETOXIFICATION_OF_REACTIVE_OXYGEN_SPECIES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DETOXIFICATION_OF_REACTIVE_OXYGEN_SPECIES.html)

**REACTOME_PHASE_II_CONJUGATION_OF_COMPOUNDS**: Phase II - Conjugation of compounds [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PHASE_II_CONJUGATION_OF_COMPOUNDS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PHASE_II_CONJUGATION_OF_COMPOUNDS.html)
