
## **Pathways:**

**Glycoprotein hormones:** More complex protein hormones have carbohydrate side chains and are called glycoprotein hormones. Hormones in this class are Follicle-stimulating hormone (FSH; follitropin), Luteinizing hormone (LH), Thyroid-stimulating hormone (TSH; thyrotropin) and human chorionic gonadotropin (hCG). The alpha subunit of glycoprotein hormones is a 92 aa peptide and serves as the alpha subunit for FSH, LH, hCG and TSH (Fiddes JC and Goodman HM, 1981). The beta subunits for these hormones are unique and confer biological specificity to them. These two subunits combine via disulphide bonding to produce the mature glycoprotein hormone dimer. [[https://reactome.org/PathwayBrowser/#/R-HSA-209822](https://reactome.org/PathwayBrowser/#/R-HSA-209822)]

**Signaling by TGFB family members:** The human genome encodes 33 TGF-beta family members, including TGF-beta itself, as well as bone morphogenetic protein (BMP), activin, nodal and growth and differentiation factors (GDFs). This superfamily of ligands generally binds as dimers to hetero-tetrameric cell-surface receptor serine/threonine kinases to activate SMAD-dependent and SMAD-independent signaling (reviewed in Morikawa et al, 2016; Budi et al, 2017).

Signaling by the TGF-beta receptor complex is initiated by TGF-beta. TGF-beta (TGFB1), secreted as a homodimer, binds to TGF-beta receptor II (TGFBR2), inducing its dimerization and formation of a stable hetero-tetrameric complex with TGF-beta receptor I homodimer (TGFBR1). TGFBR2-mediated phosphorylation of TGFBR1 triggers internalization of the heterotetrameric TGF beta receptor complex (TGFBR) into clathrin coated endocytic vesicles and recruitment of cytosolic SMAD2 and SMAD3, which act as R-SMADs for TGF beta receptor complex. TGFBR1 phosphorylates SMAD2 and SMAD3, promoting their association with SMAD4 (known as Co-SMAD). In the nucleus, the SMAD2/3:SMAD4 heterotrimer binds target DNA elements and, in cooperation with other transcription factors, regulates expression of genes involved in cell differentiation. For a review of TGF-beta receptor signaling, please refer to Kang et al. 2009.

Signaling by BMP is triggered by bone morphogenetic proteins (BMPs). BMPs can bind type I receptors in the absence of type II receptors, but the presence of both types dramatically increases binding affinity. The type II receptor kinase transphosphorylates the type I receptor, leading to recruitment and phosphorylation of SMAD1, SMAD5 and SMAD8, which function as R-SMADs in BMP signalling pathways. Phosphorylated SMAD1, SMAD5 and SMAD8 form heterotrimeric complexes with SMAD4, the only Co-SMAD in mammals. The SMAD1/5/8:SMAD4 heterotrimer regulates transcription of genes involved in development of many tissues, including bone, cartilage, blood vessels, heart, kidney, neurons, liver and lung. For review of BMP signaling, please refer to Miyazono et al. 2010.

Signaling by activin is triggered when an activin dimer (activin A, activin AB or activin B) binds the type II receptor (ACVR2A, ACVR2B). This complex then interacts with the type I receptor (ACVR1B, ACVR1C) and phosphorylates it. The phosphorylated type I receptor phosphorylates SMAD2 and SMAD3. Dimers of phosphorylated SMAD2/3 bind SMAD4 and the resulting ternary complex enters the nucleus and activates target genes. For a review of activin signaling, please refer to Chen et al. 2006. [[https://reactome.org/PathwayBrowser/#/R-HSA-9006936&PATH=R-HSA-162582](https://reactome.org/PathwayBrowser/#/R-HSA-9006936&PATH=R-HSA-162582)]

**Antagonism of Activin by Follistatin:** Both Follistatin (FST) and Follistatin-like-3 (FSTL3) irreversibly bind Activin dimers and prevent Activin from interacting with its receptor (reviewed in Schneyer et al. 2004, Xia and Schneyer 2009). Though functionally similar in vitro, FST and FSTL3 do not function identically in vivo. Mice lacking FST die shortly after birth due to defects in muscle and bone (Matzuk et al. 1995); mice lacking FSTL3 are viable but have altered glucose metabolism (Mukherjee et al. 2007). [[https://reactome.org/PathwayBrowser/#/R-HSA-2473224](https://reactome.org/PathwayBrowser/#/R-HSA-2473224)]

## GO terms:

**GABAergic neuron differentiation** [The process in which a neuroblast acquires the specialized structural and functional features of a GABAergic neuron. GO:0097154]

**SMAD protein signal transduction** [An intracellular signal transduction pathway that starts with the activation of a SMAD protein, leading to the formation of a complex with co-SMADs, which translocates to the nucleus, where it regulates transcription of specific target genes.|Note that the upstream receptor and its ligand regulate the pathway (and are not part of the SMAD pathway), since it is an intracellular signaling pathway. GO:0060395]

**activin receptor signaling pathway** [The series of molecular signals initiated by an extracellular ligand binding to an activin receptor on the surface of a target cell, and ending with the regulation of a downstream cellular process, e.g. transcription. GO:0032924]

**autophagy** [The cellular catabolic process in which cells digest parts of their own cytoplasm; allows for both recycling of macromolecular constituents under conditions of cellular stress and remodeling the intracellular structure for cell differentiation. GO:0006914]

**cardiac fibroblast cell development** [The process whose specific outcome is the progression of a cardiac fibroblast over time, from its formation to the mature state. A cardiac fibroblast is a connective tissue cell of the heart which secretes an extracellular matrix rich in collagen and other macromolecules. GO:0060936]

**cellular response to angiotensin** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an angiotensin stimulus. Angiotensin is any of three physiologically active peptides (angiotensin II, III, or IV) processed from angiotensinogen. GO:1904385]

**cellular response to cholesterol** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cholesterol stimulus. GO:0071397]

**cellular response to follicle-stimulating hormone stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a follicle-stimulating hormone stimulus. GO:0071372]

**cellular response to hypoxia** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating lowered oxygen tension. Hypoxia, defined as a decline in O2 levels below normoxic levels of 20.8 - 20.95%, results in metabolic adaptation at both the cellular and organismal level.|Note that this term should not be confused with 'cellular response to anoxia ; GO:0071454'. Note that in laboratory studies, hypoxia is typically studied at O2 concentrations ranging from 0.1 - 5%. GO:0071456]

**cellular response to oxygen-glucose deprivation** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of the deprivation of oxygen and glucose. GO:0090650]

**cytokine-mediated signaling pathway** [The series of molecular signals initiated by the binding of a cytokine to a receptor on the surface of a cell, and ending with the regulation of a downstream cellular process, e.g. transcription. GO:0019221]

**endodermal cell differentiation** [The process in which a relatively unspecialized cell acquires the specialized features of an endoderm cell, a cell of the inner of the three germ layers of the embryo. GO:0035987]

**extrinsic apoptotic signaling pathway** [The series of molecular signals in which a signal is conveyed from the cell surface to trigger the apoptotic death of a cell. The pathway starts with either a ligand binding to a cell surface receptor, or a ligand being withdrawn from a cell surface receptor (e.g. in the case of signaling by dependence receptors), and ends when the execution phase of apoptosis is triggered.|Fas acts as a death receptor with a role in apoptosis, but can also act as a non-apoptotic signal transducer. GO:0097191]

**eyelid development in camera-type eye** [The progression of the eyelid in a camera-type eye from its formation to the mature state. The eyelid is a membranous cover that helps protect and lubricate the eye. GO:0061029]

**hair follicle development** [The process whose specific outcome is the progression of the hair follicle over time, from its formation to the mature structure. A hair follicle is a tube-like opening in the epidermis where the hair shaft develops and into which the sebaceous glands open. GO:0001942]

**hematopoietic progenitor cell differentiation** [The process in which precursor cell type acquires the specialized features of a hematopoietic progenitor cell, a class of cell types including myeloid progenitor cells and lymphoid progenitor cells. GO:0002244]

**hemoglobin biosynthetic process** [The chemical reactions and pathways resulting in the formation of hemoglobin, an oxygen carrying, conjugated protein containing four heme groups and globin. GO:0042541]

**male gonad development** [The process whose specific outcome is the progression of the male gonad over time, from its formation to the mature structure. GO:0008584]

**mesoderm formation** [The process that gives rise to the mesoderm. This process pertains to the initial formation of the structure from unspecified parts. GO:0001707]

**mesodermal cell differentiation** [The process in which a relatively unspecialized cell acquires the specialized features of a mesoderm cell. GO:0048333]

**negative regulation of G1/S transition of mitotic cell cycle** [Any signaling pathway that decreases or inhibits the activity of a cell cycle cyclin-dependent protein kinase to modulate the switch from G1 phase to S phase of the mitotic cell cycle. GO:2000134]

**negative regulation of cell growth** [Any process that stops, prevents, or reduces the frequency, rate, extent or direction of cell growth. GO:0030308]

**negative regulation of cell population proliferation** [Any process that stops, prevents or reduces the rate or extent of cell proliferation. GO:0008285]

**negative regulation of hair follicle development** [Any process that stops, prevents, or reduces the frequency, rate or extent of hair follicle development. GO:0051799]

**odontogenesis** [The process whose specific outcome is the progression of a tooth or teeth over time, from formation to the mature structure(s). A tooth is any hard bony, calcareous, or chitinous organ found in the mouth or pharynx of an animal and used in procuring or masticating food. GO:0042476]

**ovarian follicle development** [The process whose specific outcome is the progression of the ovarian follicle over time, from its formation to the mature structure. GO:0001541]

**positive regulation of DNA-templated transcription** [Any process that activates or increases the frequency, rate or extent of cellular DNA-templated transcription. GO:0045893]

**positive regulation of ERK1 and ERK2 cascade** [Any process that activates or increases the frequency, rate or extent of signal transduction mediated by the ERK1 and ERK2 cascade. GO:0070374]

**positive regulation of SMAD protein signal transduction** [Any process that increases the rate, frequency or extent of SMAD protein signal transduction. GO:0060391]

**positive regulation of collagen biosynthetic process** [Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of collagen, any of a group of fibrous proteins of very high tensile strength that form the main component of connective tissue in animals. GO:0032967]

**positive regulation of erythrocyte differentiation** [Any process that activates or increases the frequency, rate or extent of erythrocyte differentiation. GO:0045648]

**positive regulation of extrinsic apoptotic signaling pathway in absence of ligand** [Any process that activates or increases the frequency, rate or extent of extrinsic apoptotic signaling pathway in absence of ligand. GO:2001241]

**positive regulation of gene expression** [Any process that increases the frequency, rate or extent of gene expression. Gene expression is the process in which a gene's coding sequence is converted into a mature gene product (protein or RNA). GO:0010628]

**positive regulation of ovulation** [Any process that activates or increases the frequency, rate or extent of ovulation, the release of a mature ovum/oocyte from an ovary. GO:0060279]

**positive regulation of protein metabolic process** [Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways involving a protein. GO:0051247]

**positive regulation of protein phosphorylation** [Any process that activates or increases the frequency, rate or extent of addition of phosphate groups to amino acids within a protein. GO:0001934]

**positive regulation of transcription by RNA polymerase II** [Any process that activates or increases the frequency, rate or extent of transcription from an RNA polymerase II promoter. GO:0045944]

**positive regulation of transcription by RNA polymerase III** [Any process that activates or increases the frequency, rate or extent of transcription mediated by RNA polymerase III. GO:0045945]

**progesterone secretion** [The regulated release of progesterone, a steroid hormone, by the corpus luteum of the ovary and by the placenta. GO:0042701]

**regulation of follicle-stimulating hormone secretion** [Any process that modulates the frequency, rate or extent of the regulated release of follicle-stimulating hormone. GO:0046880]

**regulation of transcription by RNA polymerase II** [Any process that modulates the frequency, rate or extent of transcription mediated by RNA polymerase II. GO:0006357]

**response to aldosterone** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an aldosterone stimulus. GO:1904044]

**roof of mouth development** [The biological process whose specific outcome is the progression of the roof of the mouth from an initial condition to its mature state. This process begins with the formation of the structure and ends with the mature structure. The roof of the mouth is the partition that separates the nasal and oral cavities. GO:0060021]

**striatal medium spiny neuron differentiation** [The process in which a relatively unspecialized cell acquires specialized features of a medium spiny neuron residing in the striatum. GO:0021773]

**transcription by RNA polymerase II** [The synthesis of RNA from a DNA template by RNA polymerase II (RNAP II), originating at an RNA polymerase II promoter. Includes transcription of messenger RNA (mRNA) and certain small nuclear RNAs (snRNAs). GO:0006366]

## MSigDB Signatures:

**KEGG_MEDICUS_REFERENCE_ACTIVIN_SIGNALING_PATHWAY**: Pathway Definition from KEGG: INHBA -> ((ACVR2A,ACVR2B)+(ACVR1B,ACVR1C)) -> (SMAD2,SMAD3) == SMAD4 [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_ACTIVIN_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_ACTIVIN_SIGNALING_PATHWAY.html)

**NABA_MATRISOME**: Ensemble of genes encoding extracellular matrix and extracellular matrix-associated proteins [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME.html)

**KEGG_TGF_BETA_SIGNALING_PATHWAY**: TGF-beta signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_TGF_BETA_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_TGF_BETA_SIGNALING_PATHWAY.html)

**WP_TGF_BETA_RECEPTOR_SIGNALING**: TGF beta receptor signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TGF_BETA_RECEPTOR_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TGF_BETA_RECEPTOR_SIGNALING.html)

**NABA_MATRISOME_ASSOCIATED**: Ensemble of genes encoding ECM-associated proteins including ECM-affilaited proteins, ECM regulators and secreted factors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_ASSOCIATED.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_ASSOCIATED.html)

**REACTOME_SIGNALING_BY_TGFB_FAMILY_MEMBERS**: Signaling by TGFB family members [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_TGFB_FAMILY_MEMBERS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_TGFB_FAMILY_MEMBERS.html)

**REACTOME_SIGNALING_BY_BMP**: Signaling by BMP [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_BMP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_BMP.html)

**FOROUTAN_INTEGRATED_TGFB_EMT_UP**: Genes up-regulated in the epithelial-mesenchymal transition (EMT) upon transforming growth factor beta (TGFb) stimulation derived from multiple datasets by integrating them. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FOROUTAN_INTEGRATED_TGFB_EMT_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FOROUTAN_INTEGRATED_TGFB_EMT_UP.html)

**FOROUTAN_TGFB_EMT_UP**: Genes up-regulated in the epithelial-mesenchymal transition (EMT) upon transforming growth factor beta (TGFb) stimulation derived from multiple datasets by combining results from an integrative approach and a product of ranks meta-analysis approach. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FOROUTAN_TGFB_EMT_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FOROUTAN_TGFB_EMT_UP.html)

**FOROUTAN_PRODRANK_TGFB_EMT_UP**: Genes up-regulated in the epithelial-mesenchymal transition (EMT) upon transforming growth factor beta (TGFb) stimulation derived from multiple datasets using a product of ranks meta-analysis approach. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FOROUTAN_PRODRANK_TGFB_EMT_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FOROUTAN_PRODRANK_TGFB_EMT_UP.html)

**NABA_SECRETED_FACTORS**: Genes encoding secreted soluble factors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_SECRETED_FACTORS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_SECRETED_FACTORS.html)

**REACTOME_PEPTIDE_HORMONE_METABOLISM**: Peptide hormone metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PEPTIDE_HORMONE_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PEPTIDE_HORMONE_METABOLISM.html)

**WP_MESODERMAL_COMMITMENT_PATHWAY**: Mesodermal commitment pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_MESODERMAL_COMMITMENT_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_MESODERMAL_COMMITMENT_PATHWAY.html)
