
## **Pathways:**

**Activation of anterior HOX genes in hindbrain development during early embryogenesis:** In mammals, anterior Hox genes may be defined as paralog groups 1 to 4 (Natale et al. 2011), which are involved in development of the hindbrain through sequential expression in the rhombomeres, transient segments of the neural tube that form during development of the hindbrain (reviewed in Alexander et al. 2009, Soshnikova and Duboule 2009, Tumpel et al. 2009, Mallo et al. 2010, Andrey and Duboule 2014). Hox gene activation during mammalian development has been most thoroughly studied in mouse embryos and the results have been extended to human development by in vitro experiments with human embryonal carcinoma cells and human embryonic stem cells. Expression of a typical anterior Hox gene has an anterior boundary located at the junction between two rhombomeres and continues caudally to regulate segmentation and segmental fate in ectoderm, mesoderm, and endoderm. Anterior boundaries of expression of successive Hox paralog groups are generally separated from each other by 2 rhombomeres. For example, HOXB2 is expressed in rhombomere 3 (r3) and caudally while HOXB3 is expressed in r5 and caudally. Exceptions exist, however, as HOXA1, HOXA2, and HOXB1 do not follow the rule and HOXD1 and HOXC4 are not expressed in rhombomeres. Hox genes within a Hox cluster are expressed colinearly: the gene at the 3' end of the cluster is expressed earliest, and hence most anteriorly, then genes 5' are activated sequentially in the same order as they occur in the cluster [[https://reactome.org/PathwayBrowser/#/R-HSA-5617472](https://reactome.org/PathwayBrowser/#/R-HSA-5617472)].

**Toll Like Receptor TLR6:TLR2 Cascade:** TLR2 and TLR4 recognize different bacterial cell wall components. While TLR4 is trained onto Gram-negative lipopolysaccharide components, TLR2 - in combination with TLR6 - plays a major role in recognizing peptidoglycan wall products from Gram-positive bacteria, as well as Mycobacterial diacylated lipopeptides. In particular, TLR6 appears to participate in discriminating the subtle differences between dipalmitoyl and tripalmitoyl cysteinyl residues (Okusawa et al. 2004) [[https://reactome.org/PathwayBrowser/#/R-HSA-168188](https://reactome.org/PathwayBrowser/#/R-HSA-168188)].

**Toll Like Receptor TLR1:TLR2 Cascade:** TLR1 is expressed by monocytes. TLR1 and TLR2 cotranslationally form heterodimeric complexes on the cell surface and in the cytosol. The TLR2:TLR1 complex recognizes Neisserial PorB and Mycobacterial triacylated lipoproteins and peptides, amongst others, triggering up-regulation of nuclear factor-kappaB production and apoptotic cascades. Such cooperation between TLR1 and TLR2 on the cell surface of normal human peripheral blood mononuclear cells, for instance, leads to the activation of pro-inflammatory cytokine secretion (Sandor et al. 2003) [[https://reactome.org/PathwayBrowser/#/R-HSA-168179](https://reactome.org/PathwayBrowser/#/R-HSA-168179)].

**Activation of the AP-1 family of transcription factors:** Activator protein-1 (AP-1) is a collective term referring to a group of transcription factors that bind to promoters of target genes in a sequence-specific manner. AP-1 family consists of hetero- and homodimers of bZIP (basic region leucine zipper) proteins, mainly of Jun-Jun, Jun-Fos or Jun-ATF. AP-1 members are involved in the regulation of a number of cellular processes including cell growth, proliferation, survival, apoptosis, differentiation, cell migration. The ability of a single transcription factor to determine a cell fate critically depends on the relative abundance of AP-1 subunits, the composition of AP-1 dimers, the quality of stimulus, the cell type, the co-factor assembly [[https://reactome.org/PathwayBrowser/#/R-HSA-450341](https://reactome.org/PathwayBrowser/#/R-HSA-450341)].

**TRIF(TICAM1)-mediated TLR4 signaling:** TRIF (TICAM1) was shown to induce IRF3/7 and NF-kappa-B activation as well as apoptosis through distinct intracellular signaling pathways (Yamamoto M et al., 2003; Fitzgerald KA et al., 2003; Han KJ et al., 2004; Kaiser WJ & Offermann MK 2005) [[https://reactome.org/PathwayBrowser/#/R-HSA-937061](https://reactome.org/PathwayBrowser/#/R-HSA-937061)].

**FCERI mediated MAPK activation:** Formation of the LAT signaling complex leads to activation of MAPK and production of cytokines. The sequence of events that leads from LAT to cytokine production has not been as clearly defined as the sequence that leads to degranulation. However, the pathways that lead to cytokine production require the guanine-nucleotide-exchange factors SOS and VAV that regulate GDP-GTP exchange of RAS. After its activation, RAS positively regulates the RAF-dependent pathway that leads to phosphorylation and, in part, activation of the mitogen-activated protein kinases (MAPKs) extracellular-signal-regulated kinase 1 (ERK1) and ERK2 (Gilfillan & Tkaczyk 2006) [[https://reactome.org/PathwayBrowser/#/R-HSA-2871796](https://reactome.org/PathwayBrowser/#/R-HSA-2871796)].

**Interleukin-17 signaling:** Interleukin-17 (IL17) is a family of cytokines (Kawaguchi et al. 2004, Gu et al. 2013). IL17A, the founding member of the family is able to induce the production of other cytokines and chemokines, such as IL6, IL8, and granulocyte colony-stimulating factor (G-CSF) in a variety of cell types, including activated T-cells. It plays a pivotal role in host defenses in response to microbial infection and is involved in the pathogenesis of autoimmune diseases and allergic syndromes. IL17 activates several downstream signaling pathways including NFkB, MAPKs and C/EBPs, inducing the expression of antibacterial peptides, proinflammatory chemokines and cytokines and matrix metalloproteases (MMPs). IL17 can stabilize the mRNA of genes induced by TNF-alpha. IL17 signal transduction is mediated by the cytosolic adaptor molecule ACT1 (also known as CIKS) [[https://reactome.org/PathwayBrowser/#/R-HSA-448424](https://reactome.org/PathwayBrowser/#/R-HSA-448424)].

**MyD88 cascade initiated on plasma membrane:** Mammalian myeloid differentiation factor 88 (MyD88) is Toll/interleukin (IL)-1 (TIR)-domain containing adapter protein which plays crucial role in TLR signaling. All TLRs, with only one exception of TLR3, can initiate downstream signaling through MyD88. In the MyD88 - dependent pathway, once the adaptor is bound to TLR it leads to recruitment of IL1 receptor associated kinase family IRAK which is followed by activation of tumour necrosis factor receptor-associated factor 6 (TRAF6) . TRAF6 is an ubiquitin E3 ligase which in turn induces TGF-beta activating kinase 1 (TAK1) auto phosphorylation. Once activated TAK1 can ultimately mediate the induction of the transcription factor NF-kB or the mitogen-activated protein kinases (MAPK), such as JNK, p38 and ERK. This results in the translocation of the activated NF-kB and MAPKs to the nucleus and the initiation of appropriate gene transcription leading to the production of many proinflammatory cytokines and antimicrobial peptides [[https://reactome.org/PathwayBrowser/#/R-HSA-975871](https://reactome.org/PathwayBrowser/#/R-HSA-975871)].

**TRAF6 mediated induction of NFkB and MAP kinases upon TLR7/8 or 9 activation:** TRAF6 mediates NFkB activation via canonical phosphorylation of IKK complex by TAK1. TRAF6 and TAK1 also regulate MAPK cascades leading to the activation of AP-1 [[https://reactome.org/PathwayBrowser/#/R-HSA-975138](https://reactome.org/PathwayBrowser/#/R-HSA-975138)].

**MyD88:MAL(TIRAP) cascade initiated on plasma membrane:** The first known downstream component of TLR4 and TLR2 signaling is the adaptor MyD88. Another adapter MyD88-adaptor-like (Mal; also known as TIR-domain-containing adaptor protein or TIRAP) has also been described for TLR4 and TLR2 signaling. MyD88 comprises an N-terminal Death Domain (DD) and a C-terminal TIR, whereas Mal lacks the DD. The TIR homotypic interactions bring adapters into contact with the activated TLRs, whereas the DD modules recruit serine/threonine kinases such as interleukin-1-receptor-associated kinase (IRAK). Recruitment of these protein kinases is accompanied by phosphorylation, which in turn results in the interaction of IRAKs with TNF-receptor-associated factor 6 (TRAF6). The oligomerization of TRAF6 activates TAK1, a member of the MAP3-kinase family, and this leads to the activation of the IkB kinases. These kinases, in turn, phosphorylate IkB, leading to its proteolytic degradation and the translocation of NF-kB to the nucleus. Concomitantly, members of the activator protein-1 (AP-1) transcription factor family, Jun and Fos, are activated, and both AP-1 transcription factors and NF-kB are required for cytokine production, which in turn produces downstream inflammatory effects [[https://reactome.org/PathwayBrowser/#/R-HSA-166058](https://reactome.org/PathwayBrowser/#/R-HSA-166058)].

**MyD88-independent TLR4 cascade:** The MyD88-independent signaling pathway is shared by TLR3 and TLR4 cascades. TIR-domain-containing adapter-inducing interferon-beta (TRIF or TICAM1) is a key adapter molecule in transducing signals from TLR3 and TLR4 in a MyD88-independent manner (Yamamoto M et al. 2003a). TRIF is recruited to the ligand-stimulated TLR3 or 4 complex via its TIR domain. TLR3 directly binds TRIF (Oshiumi H et al 2003). In contrast, the TLR4-mediated signaling pathway requires two adapter molecules, TRAM (TRIF-related adapter molecule or TICAM2) and TRIF. TRAM(TICAM2) is thought to bridge the activated TLR4 complex and TRIF (Yamamoto M et al. 2003b, Tanimura N et al. 2008, Kagan JC et al. 2008) [[https://reactome.org/PathwayBrowser/#/R-HSA-166166](https://reactome.org/PathwayBrowser/#/R-HSA-166166)].

**Toll Like Receptor 10 (TLR10) Cascade:** Little is known about TLR10 ligands. It has been established that the receptor homodimerizes upon binding and signals in an MyD88-dependent manner (Hasan U et al 2005; Nyman T et al 2008). It may also heterodimerize with TLRs 1 and 2. It is expressed in a restricted fashion as a highly N-glycosylated protein detectable in B cells and dendritic cells [[https://reactome.org/PathwayBrowser/#/R-HSA-168142](https://reactome.org/PathwayBrowser/#/R-HSA-168142)].

**Toll Like Receptor 7/8 (TLR7/8) Cascade:** RNA can serve as a danger signal, both in its double-stranded form as well as single-stranded RNA (ssRNA). Toll like receptor 7 (TLR7) and TLR8 are endosomal receptors that sense ssRNA oligonucleotides containing guanosine (G)- and uridine (U)-rich sequences from RNA viruses (Jurk M et al. 2002; Heil F et al. 2004; Diebold SS et al. 2004; Li Y et al. 2013; reviewed in Lester SN & Li K 2014). TLR7 is primarily expressed in plasmacytoid dendritic cells (pDCs) and, to some extent, in B cells, monocytes and macrophages, whereas TLR8 is mostly expressed in monocytes, macrophages and myeloid DCs. Upon engagement of ssRNAs in endosomes, TLR7/8 initiate the myeloid differentiation factor 88 (MyD88)-dependent pathway, culminating in synthesis of type I and type III IFNs and proinflammatory mediators via activation of IFN regulatory factor 7 (IRF7) and NF-?B, respectively, depending on the cell type (reviewed in Lester SN & Li K 2014) [[https://reactome.org/PathwayBrowser/#/R-HSA-168181](https://reactome.org/PathwayBrowser/#/R-HSA-168181)].

**Estrogen-dependent gene expression:** Estrogens mediate their transcriptional effects through interaction with the estrogen receptors, ESR1 (also known as ER alpha) and ESR2 (ER beta). ESR1 and ESR2 share overlapping but distinct functions, with ESR1 playing the primary role in transcriptional activation in most cell types (Hah and Krauss, 2014; Haldosen et al, 2014. The receptors function as ligand-dependent dimers and can activate target genes either through direct binding to an estrogen responsive element (ERE) in the target gene promoter, or indirectly through interaction with another DNA-binding protein such as RUNX1, SP1, AP1 or NF-kappa beta (reviewed in Bai and Gust, 2009; Hah and Krause, 2014). Binding of estrogen receptors to the DNA promotes the assembly of higher order transcriptional complexes containing methyltransferases, histone acetyltransferases and other transcriptional activators, which promote transcription by establishing active chromatin marks and by recruiting general transcription factors and RNA polymerase II. ESR1- and estrogen-dependent recruitment of up to hundreds of coregulators has been demonstrated by varied co-immunoprecipitation and proteomic approaches (Kittler et al, 2013; Mohammed et al, 2013; Foulds et al, 2013; Mohammed et al, 2015; Liu et al, 2014; reviewed in Magnani and Lupien, 2014; Arnal, 2017). In some circumstances, ligand-bound receptors can also promote the assembly of a repression complex at a target gene, and in some cases, heterodimers of ESR1 and ESR2 serve as repressors of ESR1-mediated target gene activation (reviewed in Hah and Kraus, 2014; Arnal et al, 2017). Phosphorylation of the estrogen receptor also modulates its activity, and provides cross-talk between nuclear estrogen-dependent signaling and non-genomic estrogen signaling from the plasma membrane (reviewed in Anbalagan and Rowan, 2015; Haldosen et al, 2014; Schwartz et al, 2016) [[https://reactome.org/PathwayBrowser/#/R-HSA-9018519](https://reactome.org/PathwayBrowser/#/R-HSA-9018519)].

**MAPK6/MAPK4 signaling:** MAPK6 and MAPK4 (also known as ERK3 and ERK4) are vertebrate-specific atypical MAP kinases. Atypical MAPK are less well characterized than their conventional counterparts, and are generally classified as such based on their lack of activation by MAPKK family members. Unlike the conventional MAPK proteins, which contain a Thr-X-Tyr motif in the activation loop, MAPK6 and 4 have a single Ser-Glu-Gly phospho-acceptor motif (reviewed in Coulombe and Meloche, 2007; Cargnello et al, 2011). MAPK6 is also distinct in being an unstable kinase, whose turnover is mediated by ubiquitin-dependent degradation (Coulombe et al, 2003; Coulombe et al, 2004). The biological functions and pathways governing MAPK6 and 4 are not well established. MAPK6 and 4 are phosphorylated downstream of class I p21 activated kinases (PAKs) in a RAC- or CDC42-dependent manner (Deleris et al, 2008; Perander et al, 2008; Deleris et al, 2011; De La Mota-Peynado et al, 2011). One of the only well established substrates of MAPK6 and 4 is MAPKAPK5, which contributes to cell motility by promoting the HSBP1-dependent rearrangement of F-actin (Gerits et al, 2007; Kostenko et al, 2009a; reviewed in Kostenko et al, 2011b). The atypical MAPKs also contribute to cell motility and invasiveness through the NCOA3:ETV4-dependent regulation of MMP gene expression (Long et al, 2012; Yan et al, 2008; Qin et al, 2008). Both of these pathways may be misregulated in human cancers (reviewed in Myant and Sansom, 2011; Kostenko et al, 2012) [[https://reactome.org/PathwayBrowser/#/R-HSA-5687128](https://reactome.org/PathwayBrowser/#/R-HSA-5687128)].

**PIP3 activates AKT signaling:** Signaling by AKT is one of the key outcomes of receptor tyrosine kinase (RTK) activation. AKT is activated by the cellular second messenger PIP3, a phospholipid that is generated by PI3K. In ustimulated cells, PI3K class IA enzymes reside in the cytosol as inactive heterodimers composed of p85 regulatory subunit and p110 catalytic subunit. In this complex, p85 stabilizes p110 while inhibiting its catalytic activity. Upon binding of extracellular ligands to RTKs, receptors dimerize and undergo autophosphorylation. The regulatory subunit of PI3K, p85, is recruited to phosphorylated cytosolic RTK domains either directly or indirectly, through adaptor proteins, leading to a conformational change in the PI3K IA heterodimer that relieves inhibition of the p110 catalytic subunit. Activated PI3K IA phosphorylates PIP2, converting it to PIP3; this reaction is negatively regulated by PTEN phosphatase. PIP3 recruits AKT to the plasma membrane, allowing TORC2 to phosphorylate a conserved serine residue of AKT. Phosphorylation of this serine induces a conformation change in AKT, exposing a conserved threonine residue that is then phosphorylated by PDPK1 (PDK1). Phosphorylation of both the threonine and the serine residue is required to fully activate AKT. The active AKT then dissociates from PIP3 and phosphorylates a number of cytosolic and nuclear proteins that play important roles in cell survival and metabolism. For a recent review of AKT signaling, please refer to Manning and Cantley, 2007 [[https://reactome.org/PathwayBrowser/#/R-HSA-1257604](https://reactome.org/PathwayBrowser/#/R-HSA-1257604)].

**Pre-NOTCH Transcription and Translation:** In humans, the NOTCH protein family has four members: NOTCH1, NOTCH2, NOTCH3 and NOTCH4. NOTCH1 protein was identified first, as the product of a chromosome 9 gene translocated in T-cell acute lymphoblastic leukemia that was homologous to Drosophila Notch (Ellisen et al. 1991). At the same time, rat Notch1 was cloned (Weinmaster et al. 1991), followed by cloning of mouse Notch1, named Motch (Del Amo et al. 1992). NOTCH2 protein is the product of a gene on chromosome 1 (Larsson et al. 1994). NOTCH2 expression is differentially regulated during B-cell development (Bertrand et al. 2000). NOTCH2 mutations are a rare cause of Alagille syndrome (McDaniell et al. 2006). NOTCH3 is the product of a gene on chromosome 19. NOTCH3 mutations are the underlying cause of CADASIL, cerebral arteriopathy with subcortical infarcts and leukoencephalopathy (Joutel et al. 1996). NOTCH4, the last NOTCH protein discovered, is the product of a gene on chromosome 6 (Li et al. 1998) [[https://reactome.org/PathwayBrowser/#/R-HSA-1912408](https://reactome.org/PathwayBrowser/#/R-HSA-1912408)].

**Regulation of PTEN gene transcription:** Transcription of the PTEN gene is regulated at multiple levels. Epigenetic repression involves the recruitment of Mi-2/NuRD upon SALL4 binding to the PTEN promoter (Yang et al. 2008, Lu et al. 2009) or EVI1-mediated recruitment of the polycomb repressor complex (PRC) to the PTEN promoter (Song et al. 2009, Yoshimi et al. 2011). Transcriptional regulation is also elicited by negative regulators, including NR2E1:ATN1 (atrophin-1) complex, JUN (c-Jun), SNAIL and SLUG (Zhang et al. 2006, Vasudevan et al. 2007, Escriva et al. 2008, Uygur et al. 2015) and positive regulators such as TP53 (p53), MAF1, ATF2, EGR1 or PPARG (Stambolic et al. 2001, Virolle et al. 2001, Patel et al. 2001, Shen et al. 2006, Li et al. 2016) [[https://reactome.org/PathwayBrowser/#/R-HSA-8943724](https://reactome.org/PathwayBrowser/#/R-HSA-8943724)].

**Senescence-Associated Secretory Phenotype (SASP):** The culture medium of senescent cells in enriched in secreted proteins when compared with the culture medium of quiescent i.e. presenescent cells and these secreted proteins constitute the so-called senescence-associated secretory phenotype (SASP), also known as the senescence messaging secretome (SMS). SASP components include inflammatory and immune-modulatory cytokines (e.g. IL6 and IL8), growth factors (e.g. IGFBPs), shed cell surface molecules (e.g. TNF receptors) and survival factors. While the SASP exhibits a wide ranging profile, it is not significantly affected by the type of senescence trigger (oncogenic signalling, oxidative stress or DNA damage) or the cell type (epithelial vs. mesenchymal) (Coppe et al. 2008). However, as both oxidative stress and oncogenic signaling induce DNA damage, the persistent DNA damage may be a deciding SASP initiator (Rodier et al. 2009). SASP components function in an autocrine manner, reinforcing the senescent phenotype (Kuilman et al. 2008, Acosta et al. 2008), and in the paracrine manner, where they may promote epithelial-to-mesenchymal transition (EMT) and malignancy in the nearby premalignant or malignant cells (Coppe et al. 2008). Interleukin-1-alpha (IL1-alpha), a minor SASP component whose transcription is stimulated by the AP-1 (FOS:JUN) complex (Bailly et al. 1996), can cause paracrine senescence through IL1 and inflammasome signaling (Acosta et al. 2013) [[https://reactome.org/PathwayBrowser/#/R-HSA-2559582](https://reactome.org/PathwayBrowser/#/R-HSA-2559582)].

**Oxidative Stress Induced Senescence:** Oxidative stress, caused by increased concentration of reactive oxygen species (ROS) in the cell, can happen as a consequence of mitochondrial dysfunction induced by the oncogenic RAS (Moiseeva et al. 2009) or independent of oncogenic signaling. Prolonged exposure to interferon-beta (IFNB, IFN-beta) also results in ROS increase (Moiseeva et al. 2006). ROS oxidize thioredoxin (TXN), which causes TXN to dissociate from the N-terminus of MAP3K5 (ASK1), enabling MAP3K5 to become catalytically active (Saitoh et al. 1998). ROS also stimulate expression of Ste20 family kinases MINK1 (MINK) and TNIK through an unknown mechanism, and MINK1 and TNIK positively regulate MAP3K5 activation (Nicke et al. 2005) [[https://reactome.org/PathwayBrowser/#/R-HSA-2559580](https://reactome.org/PathwayBrowser/#/R-HSA-2559580)].

**TP53 Regulates Transcription of DNA Repair Genes:** Several DNA repair genes contain p53 response elements and their transcription is positively regulated by TP53 (p53). TP53-mediated regulation probably ensures increased protein level of DNA repair genes under genotoxic stress [[https://reactome.org/PathwayBrowser/#/R-HSA-6796648](https://reactome.org/PathwayBrowser/#/R-HSA-6796648)].

**Deregulated CDK5 triggers multiple neurodegenerative pathways in Alzheimer's disease models:** Post-mitotic neurons do not have an active cell cycle. However, deregulation of Cyclin Dependent Kinase-5 (CDK5) activity in these neurons can aberrantly activate various components of cell cycle leading to neuronal death (Chang et al. 2012). Random activation of cell cycle proteins has been shown to play a key role in the pathogenesis of several neurodegenerative disorders (Yang et al. 2003, Lopes et al. 2009). CDK5 is not activated by the canonical cyclins, but binds to its own specific partners, CDK5R1 and CDK5R2 (aka p35 and p39, respectively) (Tsai et al. 1994, Tang et al. 1995). Expression of p35 is nearly ubiquitous, whereas p39 is largely expressed in the central nervous system. A variety of neurotoxic insults such as beta-amyloid (A-beta), ischemia, excitotoxicity and oxidative stress disrupt the intracellular calcium homeostasis in neurons, thereby leading to the activation of calpain, which cleaves p35 into p25 and p10 (Lee et al. 2000). p25 has a six-fold longer half-life compared to p35 and lacks the membrane anchoring signal, which results in its constitutive activation and mislocalization of the CDK5:p25 complex to the cytoplasm and the nucleus. There, CDK5:p25 is able to access and phosphorylate a variety of atypical targets, triggering a cascade of neurotoxic pathways that culminate in neuronal death. One such neurotoxic pathway involves CDK5-mediated random activation of cell cycle proteins which culminate in neuronal death. Exposure of primary cortical neurons to oligomeric beta-amyloid (1-42) hyper-activates CDK5 due to p25 formation, which in turn phosphorylates CDC25A, CDC25B and CDC25C. CDK5 phosphorylates CDC25A at S40, S116 and S261; CDC25B at S50, T69, S160, S321 and S470; and CDC25C at T48, T67, S122, T130, S168 and S214. CDK5-mediated phosphorylation of CDC25A, CDC25B and CDC25C not only increases their phosphatase activities but also facilitates their release from 14-3-3 inhibitory binding. CDC25A, CDC25B and CDC25C in turn activate CDK1, CDK2 and CDK4 kinases causing neuronal death. Consistent with this mechanism, higher CDC25A, CDC25B and CDC25C activities were observed in human Alzheimer's disease (AD) clinical samples, as compared to age-matched controls. Inhibition of CDC25 isoforms confers neuroprotection to beta-amyloid toxicity, which underscores the contribution of this pathway to AD pathogenesis [[https://reactome.org/PathwayBrowser/#/R-HSA-8862803](https://reactome.org/PathwayBrowser/#/R-HSA-8862803)].

**WNT5:FZD7-mediated leishmania damping:** Wnt-5a (WNT5) is known for being a highly specific regulated gene in response to microbial infection (Blumenthal et al. 2006, Pereira et al. 2008 & Ljungberg et al. 2019) including leishmaniasis (Chakraborty et al. 2017), where it seems to be involve in mechanisms that dampen the parasite load within main host macrophages (Chakraborty et al. 2017). In addition, WNT5 is a highly responsive gene in human macrophages present in chronic diseases such as rheumatoid arthritis (Sen et al. 2000), cancer (Pukrop et al. 2006), atherosclerosis (Christman et al. 2008) and obesity (Ouchi et al. 2010 & Ljungberg et al. 2019) [[https://reactome.org/PathwayBrowser/#/R-HSA-9673324](https://reactome.org/PathwayBrowser/#/R-HSA-9673324)].

**Activation of anterior HOX genes in hindbrain development during early embryogenesis:** In mammals, anterior Hox genes may be defined as paralog groups 1 to 4 (Natale et al. 2011), which are involved in development of the hindbrain through sequential expression in the rhombomeres, transient segments of the neural tube that form during development of the hindbrain (reviewed in Alexander et al. 2009, Soshnikova and Duboule 2009, Tumpel et al. 2009, Mallo et al. 2010, Andrey and Duboule 2014). Hox gene activation during mammalian development has been most thoroughly studied in mouse embryos and the results have been extended to human development by in vitro experiments with human embryonal carcinoma cells and human embryonic stem cells [[https://reactome.org/PathwayBrowser/#/R-HSA-5617472](https://reactome.org/PathwayBrowser/#/R-HSA-5617472)].

## GO terms:

**DNA-templated transcription** [The synthesis of an RNA transcript from a DNA template. GO:0006351]

**SMAD protein signal transduction** [An intracellular signal transduction pathway that starts with the activation of a SMAD protein, leading to the formation of a complex with co-SMADs, which translocates to the nucleus, where it regulates transcription of specific target genes.|Note that the upstream receptor and its ligand regulate the pathway (and are not part of the SMAD pathway), since it is an intracellular signaling pathway. GO:0060395]

**angiogenesis** [Blood vessel formation when new vessels emerge from the proliferation of pre-existing blood vessels. GO:0001525]

**apoptotic process** [A programmed cell death process which begins when a cell receives an internal (e.g. DNA damage) or external signal (e.g. an extracellular death ligand), and proceeds through a series of biochemical events (signaling pathway phase) which trigger an execution phase. The execution phase is the last step of an apoptotic process, and is typically characterized by rounding-up of the cell, retraction of pseudopodes, reduction of cellular volume (pyknosis), chromatin condensation, nuclear fragmentation (karyorrhexis), plasma membrane blebbing and fragmentation of the cell into apoptotic bodies. When the execution phase is completed, the cell has died. GO:0006915]

**axon regeneration** [The regrowth of axons following their loss or damage. GO:0031103]

**cell population proliferation** [The multiplication or reproduction of cells, resulting in the expansion of a cell population.|This term was moved out from being a child of 'cellular process' because it is a cell population-level process, and cellular processes are restricted to those processes that involve individual cells. Also note that this term is intended to be used for the proliferation of cells within a multicellular organism, not for the expansion of a population of single-celled organisms. GO:0008283]

**cellular response to anisomycin** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an anisomycin stimulus. GO:0072740]

**cellular response to cadmium ion** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cadmium (Cd) ion stimulus. GO:0071276]

**cellular response to calcium ion** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a calcium ion stimulus. GO:0071277]

**cellular response to hypoxia** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating lowered oxygen tension. Hypoxia, defined as a decline in O2 levels below normoxic levels of 20.8 - 20.95%, results in metabolic adaptation at both the cellular and organismal level.|Note that this term should not be confused with 'cellular response to anoxia ; GO:0071454'. Note that in laboratory studies, hypoxia is typically studied at O2 concentrations ranging from 0.1 - 5%. GO:0071456]

**cellular response to lipopolysaccharide** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lipopolysaccharide stimulus; lipopolysaccharide is a major component of the cell wall of gram-negative bacteria. GO:0071222]

**cellular response to potassium ion starvation** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of deprivation of potassium ions. GO:0051365]

**cellular response to prolactin** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a prolactin stimulus. GO:1990646]

**cellular response to reactive oxygen species** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a reactive oxygen species stimulus. Reactive oxygen species include singlet oxygen, superoxide, and oxygen free radicals. GO:0034614]

**cellular response to zinc ion starvation** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of deprivation of zinc ions. GO:0034224]

**circadian rhythm** [Any biological process in an organism that recurs with a regularity of approximately 24 hours. GO:0007623]

**eyelid development in camera-type eye** [The progression of the eyelid in a camera-type eye from its formation to the mature state. The eyelid is a membranous cover that helps protect and lubricate the eye. GO:0061029]

**immune response** [Any immune system process that functions in the calibrated response of an organism to a potential internal or invasive threat. GO:0006955]

**leading edge cell differentiation** [The process in which relatively unspecialized cells acquire specialized structural and/or functional features of leading edge cells, cells at the front of a migrating epithelial sheet. GO:0035026]

**learning** [Any process in an organism in which a relatively long-lasting adaptive behavioral change occurs as the result of experience. GO:0007612]

**liver development** [The process whose specific outcome is the progression of the liver over time, from its formation to the mature structure. The liver is an exocrine gland which secretes bile and functions in metabolism of protein and carbohydrate and fat, synthesizes substances involved in the clotting of the blood, synthesizes vitamin A, detoxifies poisonous substances, stores glycogen, and breaks down worn-out erythrocytes. GO:0001889]

**membrane depolarization** [The process in which membrane potential decreases with respect to its steady-state potential, usually from negative potential to a more positive potential. For example, the initial depolarization during the rising phase of an action potential is in the direction from the negative steady-state resting potential towards the positive membrane potential that will be the peak of the action potential. GO:0051899]

**microglial cell activation** [The change in morphology and behavior of a microglial cell resulting from exposure to a cytokine, chemokine, cellular ligand, or soluble factor. GO:0001774]

**monocyte differentiation** [The process in which a relatively unspecialized myeloid precursor cell acquires the specialized features of a monocyte. GO:0030224]

**negative regulation of DNA-templated transcription** [Any process that stops, prevents, or reduces the frequency, rate or extent of cellular DNA-templated transcription. GO:0045892]

**negative regulation of apoptotic process** [Any process that stops, prevents, or reduces the frequency, rate or extent of cell death by apoptotic process.|This term should only be used when it is not possible to determine which phase or subtype of the apoptotic process is negatively regulated by a gene product. Whenever detailed information is available, the more granular children terms should be used. GO:0043066]

**negative regulation of cell population proliferation** [Any process that stops, prevents or reduces the rate or extent of cell proliferation. GO:0008285]

**negative regulation of neuron apoptotic process** [Any process that stops, prevents, or reduces the frequency, rate or extent of cell death by apoptotic process in neurons. GO:0043524]

**negative regulation of protein autophosphorylation** [Any process that stops, prevents or decreases the rate of the phosphorylation by a protein of one or more of its own residues. GO:0031953]

**negative regulation of transcription by RNA polymerase II** [Any process that stops, prevents, or reduces the frequency, rate or extent of transcription mediated by RNA polymerase II. GO:0000122]

**obsolete negative regulation of transcription from RNA polymerase II promoter in response to endoplasmic reticulum stress** [Any process that stops, prevents, or reduces the frequency, rate or extent of transcription from an RNA polymerase II promoter as a result of an endoplasmic reticulum stress. GO:1990441]

**outflow tract morphogenesis** [The process in which the anatomical structures of the outflow tract are generated and organized. The outflow tract is the portion of the heart through which blood flows into the arteries. GO:0003151]

**positive regulation of DNA replication** [Any process that activates or increases the frequency, rate or extent of DNA replication. GO:0045740]

**positive regulation of DNA-templated transcription** [Any process that activates or increases the frequency, rate or extent of cellular DNA-templated transcription. GO:0045893]

**positive regulation of DNA-templated transcription initiation** [Any process that activates or increases the frequency, rate or extent of DNA-templated transcription initiation. GO:2000144]

**positive regulation of ERK1 and ERK2 cascade** [Any process that activates or increases the frequency, rate or extent of signal transduction mediated by the ERK1 and ERK2 cascade. GO:0070374]

**positive regulation of apoptotic process** [Any process that activates or increases the frequency, rate or extent of cell death by apoptotic process.|This term should only be used when it is not possible to determine which phase or subtype of the apoptotic process is positively regulated by a gene product. Whenever detailed information is available, the more granular children terms should be used. GO:0043065]

**positive regulation of cell population proliferation** [Any process that activates or increases the rate or extent of cell proliferation. GO:0008284]

**positive regulation of endothelial cell proliferation** [Any process that activates or increases the rate or extent of endothelial cell proliferation. GO:0001938]

**positive regulation of epithelial cell migration** [Any process that activates or increases the frequency, rate or extent of epithelial cell migration. GO:0010634]

**positive regulation of fibroblast proliferation** [Any process that activates or increases the frequency, rate or extent of multiplication or reproduction of fibroblast cells. GO:0048146]

**positive regulation of miRNA transcription** [Any process that activates or increases the frequency, rate or extent of microRNA (miRNA) gene transcription. GO:1902895]

**positive regulation of monocyte differentiation** [Any process that activates or increases the frequency, rate or extent of monocyte differentiation. GO:0045657]

**positive regulation of neuron apoptotic process** [Any process that activates or increases the frequency, rate or extent of cell death of neurons by apoptotic process. GO:0043525]

**positive regulation of smooth muscle cell proliferation** [Any process that activates or increases the rate or extent of smooth muscle cell proliferation. GO:0048661]

**positive regulation of transcription by RNA polymerase II** [Any process that activates or increases the frequency, rate or extent of transcription from an RNA polymerase II promoter. GO:0045944]

**positive regulation of vascular associated smooth muscle cell proliferation** [Any process that activates or increases the frequency, rate or extent of vascular smooth muscle cell proliferation. GO:1904707]

**regulation of DNA-templated transcription** [Any process that modulates the frequency, rate or extent of cellular DNA-templated transcription. GO:0006355]

**regulation of cell cycle** [Any process that modulates the rate or extent of progression through the cell cycle. GO:0051726]

**regulation of cell population proliferation** [Any process that modulates the frequency, rate or extent of cell proliferation. GO:0042127]

**regulation of transcription by RNA polymerase II** [Any process that modulates the frequency, rate or extent of transcription mediated by RNA polymerase II. GO:0006357]

**release from viral latency** [The process by which a virus begins to replicate following a latency replication decision (switch). GO:0019046]

**release of cytochrome c from mitochondria** [The process that results in the movement of cytochrome c from the mitochondrial intermembrane space into the cytosol, which is part of the apoptotic signaling pathway and leads to caspase activation.|The release of cytochrome c from mitochondria is a central event in the signaling phase of the apoptotic process, and it is often used by researchers to monitor this type of cell death. Any event that induces apoptosis will at some point induce the release of cytochrome c from mitochondria. Therefore, this term should only be used to annotate gene products that are directly involved in this process. An example is Drp1 (DNM1L, UniProt symbol O00429) in PMID: 20850011. GO:0001836]

**response to cAMP** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cAMP (cyclic AMP, adenosine 3',5'-cyclophosphate) stimulus. GO:0051591]

**response to cytokine** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cytokine stimulus. GO:0034097]

**response to ethanol** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an ethanol stimulus. GO:0045471]

**response to hydrogen peroxide** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a hydrogen peroxide (H2O2) stimulus. GO:0042542]

**response to insulin** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an insulin stimulus. Insulin is a polypeptide hormone produced by the islets of Langerhans of the pancreas in mammals, and by the homologous organs of other organisms. GO:0032868]

**response to lipopolysaccharide** [Any process that results in a change in state or activity of an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lipopolysaccharide stimulus; lipopolysaccharide is a major component of the cell wall of gram-negative bacteria. GO:0032496]

**response to mechanical stimulus** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a mechanical stimulus. GO:0009612]

**response to muscle stretch** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a myofibril being extended beyond its slack length. GO:0035994]

**response to organic cyclic compound** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an organic cyclic compound stimulus. GO:0014070]

**response to organic substance** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an organic substance stimulus. GO:0010033]

**response to steroid hormone** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a steroid hormone stimulus. GO:0048545]

**response to xenobiotic stimulus** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a xenobiotic, a compound foreign to the organism exposed to it. It may be synthesized by another organism (like ampicillin) or it can be a synthetic chemical. GO:0009410]

**transcription by RNA polymerase II** [The synthesis of RNA from a DNA template by RNA polymerase II (RNAP II), originating at an RNA polymerase II promoter. Includes transcription of messenger RNA (mRNA) and certain small nuclear RNAs (snRNAs). GO:0006366]

**transforming growth factor beta receptor signaling pathway** [The series of molecular signals initiated by an extracellular ligand binding to a transforming growth factor beta receptor on the surface of a target cell, and ending with the regulation of a downstream cellular process, e.g. transcription. GO:0007179]

## MSigDB Signatures:

**BIOCARTA_KERATINOCYTE_PATHWAY**: Keratinocyte Differentiation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_KERATINOCYTE_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_KERATINOCYTE_PATHWAY.html)

**DAZARD_RESPONSE_TO_UV_NHEK_UP**: Genes up-regulated in NHEK cells (normal keratinocytes) by UV-B irradiation. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DAZARD_RESPONSE_TO_UV_NHEK_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DAZARD_RESPONSE_TO_UV_NHEK_UP.html)

**WP_HAIR_FOLLICLE_DEVELOPMENT_CYTODIFFERENTIATION_PART_3_OF_3**: Hair follicle development cytodifferentiation part 3 of 3 [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_HAIR_FOLLICLE_DEVELOPMENT_CYTODIFFERENTIATION_PART_3_OF_3.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_HAIR_FOLLICLE_DEVELOPMENT_CYTODIFFERENTIATION_PART_3_OF_3.html)

**CHASSOT_SKIN_WOUND**: List of the transcription factors up-regulated 1 hr after wounding HDF cells (dermal fibroblasts). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHASSOT_SKIN_WOUND.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHASSOT_SKIN_WOUND.html)

**HAMAI_APOPTOSIS_VIA_TRAIL_DN**: Genes down-regulated in T1 cells (primary melanoma, sensitive to TRAIL [GeneID=8743]) compared to G1 cells (metastatic melanoma, resistant to TRAIL). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HAMAI_APOPTOSIS_VIA_TRAIL_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HAMAI_APOPTOSIS_VIA_TRAIL_DN.html)

**REACTOME_CELLULAR_RESPONSES_TO_STIMULI**: Cellular responses to stimuli [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELLULAR_RESPONSES_TO_STIMULI.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELLULAR_RESPONSES_TO_STIMULI.html)

**REACTOME_INNATE_IMMUNE_SYSTEM**: Innate Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html)

**WP_WNT_SIGNALING**: Wnt signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_WNT_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_WNT_SIGNALING.html)

**WP_AGE_RAGE_PATHWAY**: AGE RAGE pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_AGE_RAGE_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_AGE_RAGE_PATHWAY.html)

**MARTENS_TRETINOIN_RESPONSE_DN**: Genes down-regulated in NB4 cells (acute promyelocytic leukemia, APL) in response to tretinoin [PubChem=444795]; based on Chip-seq data. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MARTENS_TRETINOIN_RESPONSE_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MARTENS_TRETINOIN_RESPONSE_DN.html)

**REACTOME_CELLULAR_SENESCENCE**: Cellular Senescence [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELLULAR_SENESCENCE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELLULAR_SENESCENCE.html)

**REACTOME_SENESCENCE_ASSOCIATED_SECRETORY_PHENOTYPE_SASP**: Senescence-Associated Secretory Phenotype (SASP) [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SENESCENCE_ASSOCIATED_SECRETORY_PHENOTYPE_SASP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SENESCENCE_ASSOCIATED_SECRETORY_PHENOTYPE_SASP.html)

**GENTILE_UV_RESPONSE_CLUSTER_D8**: Cluster d8: genes progressively down-regulated in WS1 cells (fibroblast) through 18 h after irradiation with high dose UV-C. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/GENTILE_UV_RESPONSE_CLUSTER_D8.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/GENTILE_UV_RESPONSE_CLUSTER_D8.html)

**KEGG_WNT_SIGNALING_PATHWAY**: Wnt signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_WNT_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_WNT_SIGNALING_PATHWAY.html)

**PETROVA_ENDOTHELIUM_LYMPHATIC_VS_BLOOD_DN**: Genes down-regulated in BEC (blood endothelial cells) compared to LEC (lymphatic endothelial cells). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PETROVA_ENDOTHELIUM_LYMPHATIC_VS_BLOOD_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PETROVA_ENDOTHELIUM_LYMPHATIC_VS_BLOOD_DN.html)

**KEGG_FOCAL_ADHESION**: Focal adhesion [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_FOCAL_ADHESION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_FOCAL_ADHESION.html)

**WP_FOCAL_ADHESION**: Focal adhesion [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FOCAL_ADHESION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FOCAL_ADHESION.html)

**REACTOME_INFECTIOUS_DISEASE**: Infectious disease [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INFECTIOUS_DISEASE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INFECTIOUS_DISEASE.html)

**WP_TH17_CELL_DIFFERENTIATION_PATHWAY**: Th17 cell differentiation pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TH17_CELL_DIFFERENTIATION_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TH17_CELL_DIFFERENTIATION_PATHWAY.html)

**WP_INSULIN_SIGNALING**: Insulin signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_INSULIN_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_INSULIN_SIGNALING.html)

**REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS**: Signaling by Nuclear Receptors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS.html)

**WP_TGF_BETA_RECEPTOR_SIGNALING**: TGF beta receptor signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TGF_BETA_RECEPTOR_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TGF_BETA_RECEPTOR_SIGNALING.html)

**KOKKINAKIS_METHIONINE_DEPRIVATION_48HR_UP**: Genes up-regulated in MEWO cells (melanoma) after 48h of methionine [PubChem=876] deprivation. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KOKKINAKIS_METHIONINE_DEPRIVATION_48HR_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KOKKINAKIS_METHIONINE_DEPRIVATION_48HR_UP.html)

**BIOCARTA_INTEGRIN_PATHWAY**: Integrin Signaling Pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_INTEGRIN_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_INTEGRIN_PATHWAY.html)

**PID_ERBB1_DOWNSTREAM_PATHWAY**: ErbB1 downstream signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_ERBB1_DOWNSTREAM_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_ERBB1_DOWNSTREAM_PATHWAY.html)

**KEGG_LEISHMANIA_INFECTION**: Leishmania infection [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_LEISHMANIA_INFECTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_LEISHMANIA_INFECTION.html)

**REACTOME_LEISHMANIA_INFECTION**: Leishmania infection [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_LEISHMANIA_INFECTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_LEISHMANIA_INFECTION.html)

**WP_NEURAL_CREST_CELL_MIGRATION_DURING_DEVELOPMENT**: Neural crest cell migration during development [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NEURAL_CREST_CELL_MIGRATION_DURING_DEVELOPMENT.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NEURAL_CREST_CELL_MIGRATION_DURING_DEVELOPMENT.html)

**KOKKINAKIS_METHIONINE_DEPRIVATION_96HR_UP**: Genes up-regulated in MEWO cells (melanoma) after 96 h of methionine [PubChem=876] deprivation. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KOKKINAKIS_METHIONINE_DEPRIVATION_96HR_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KOKKINAKIS_METHIONINE_DEPRIVATION_96HR_UP.html)

**KEGG_ERBB_SIGNALING_PATHWAY**: ErbB signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_ERBB_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_ERBB_SIGNALING_PATHWAY.html)

**WP_ERBB_SIGNALING_PATHWAY**: ErbB signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ERBB_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ERBB_SIGNALING_PATHWAY.html)

**BIOCARTA_STRESS_PATHWAY**: TNF/Stress Related Signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_STRESS_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_STRESS_PATHWAY.html)

**KEGG_PATHWAYS_IN_CANCER**: Pathways in cancer [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_PATHWAYS_IN_CANCER.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_PATHWAYS_IN_CANCER.html)

**WP_NETRIN_UNC5B_SIGNALING_PATHWAY**: Netrin UNC5B signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NETRIN_UNC5B_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NETRIN_UNC5B_SIGNALING_PATHWAY.html)

**WP_NUCLEAR_RECEPTORS_META_PATHWAY**: Nuclear receptors meta pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NUCLEAR_RECEPTORS_META_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NUCLEAR_RECEPTORS_META_PATHWAY.html)

**GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_TURQUOISE_UP**: Genes from the turquoise module which are up-regulated in HAEC cells (primary aortic endothelium) after exposure to the oxidized 1-palmitoyl-2-arachidonyl-sn-3-glycerophosphorylcholine (oxPAPC). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_TURQUOISE_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/GARGALOVIC_RESPONSE_TO_OXIDIZED_PHOSPHOLIPIDS_TURQUOISE_UP.html)

**WP_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY**: Toll like receptor signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY.html)

**WP_EGF_EGFR_SIGNALING_PATHWAY**: EGF EGFR signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_EGF_EGFR_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_EGF_EGFR_SIGNALING_PATHWAY.html)

**BOQUEST_STEM_CELL_CULTURED_VS_FRESH_UP**: Genes up-regulated in cultured stromal stem cells from adipose tissue, compared to the freshly isolated cells. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BOQUEST_STEM_CELL_CULTURED_VS_FRESH_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BOQUEST_STEM_CELL_CULTURED_VS_FRESH_UP.html)

**WP_ANDROGEN_RECEPTOR_SIGNALING_PATHWAY**: Androgen receptor signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ANDROGEN_RECEPTOR_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ANDROGEN_RECEPTOR_SIGNALING_PATHWAY.html)

**MARKS_ACETYLATED_NON_HISTONE_PROTEINS**: Non-histone proteins that are acetylated. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MARKS_ACETYLATED_NON_HISTONE_PROTEINS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MARKS_ACETYLATED_NON_HISTONE_PROTEINS.html)

**PID_CD40_PATHWAY**: CD40/CD40L signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_CD40_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_CD40_PATHWAY.html)

**REACTOME_DISEASES_OF_PROGRAMMED_CELL_DEATH**: Diseases of programmed cell death [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DISEASES_OF_PROGRAMMED_CELL_DEATH.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DISEASES_OF_PROGRAMMED_CELL_DEATH.html)

**WP_PHYSICO_CHEMICAL_FEATURES_AND_TOXICITY_ASSOCIATED_PATHWAYS**: Physico chemical features and toxicity associated pathways [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PHYSICO_CHEMICAL_FEATURES_AND_TOXICITY_ASSOCIATED_PATHWAYS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PHYSICO_CHEMICAL_FEATURES_AND_TOXICITY_ASSOCIATED_PATHWAYS.html)

**BIOCARTA_PDGF_PATHWAY**: PDGF Signaling Pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_PDGF_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_PDGF_PATHWAY.html)

**AMIT_SERUM_RESPONSE_20_MCF10A**: Genes whose expression peaked at 20 min after stimulation of MCF10A cells with serum. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_SERUM_RESPONSE_20_MCF10A.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_SERUM_RESPONSE_20_MCF10A.html)

**AMIT_SERUM_RESPONSE_40_MCF10A**: Genes whose expression peaked at 40 min after stimulation of MCF10A cells with serum. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_SERUM_RESPONSE_40_MCF10A.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_SERUM_RESPONSE_40_MCF10A.html)

**REACTOME_DEVELOPMENTAL_BIOLOGY**: Developmental Biology [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEVELOPMENTAL_BIOLOGY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEVELOPMENTAL_BIOLOGY.html)

**KEGG_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY**: Toll-like receptor signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY.html)

**PID_RAC1_PATHWAY**: RAC1 signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_RAC1_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_RAC1_PATHWAY.html)

**REACTOME_INTERLEUKIN_17_SIGNALING**: Interleukin-17 signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INTERLEUKIN_17_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INTERLEUKIN_17_SIGNALING.html)

**BIOCARTA_INSULIN_PATHWAY**: Insulin Signaling Pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_INSULIN_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_INSULIN_PATHWAY.html)

**WP_BMP_SIGNALING_IN_EYELID_DEVELOPMENT**: BMP signaling in eyelid development [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_BMP_SIGNALING_IN_EYELID_DEVELOPMENT.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_BMP_SIGNALING_IN_EYELID_DEVELOPMENT.html)

**REACTOME_OXIDATIVE_STRESS_INDUCED_SENESCENCE**: Oxidative Stress Induced Senescence [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_OXIDATIVE_STRESS_INDUCED_SENESCENCE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_OXIDATIVE_STRESS_INDUCED_SENESCENCE.html)

**WP_T_CELL_RECEPTOR_SIGNALING_PATHWAY**: T cell receptor signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_T_CELL_RECEPTOR_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_T_CELL_RECEPTOR_SIGNALING_PATHWAY.html)

**KEGG_T_CELL_RECEPTOR_SIGNALING_PATHWAY**: T cell receptor signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_T_CELL_RECEPTOR_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_T_CELL_RECEPTOR_SIGNALING_PATHWAY.html)

**BIOCARTA_TCR_PATHWAY**: T Cell Receptor Signaling Pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_TCR_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_TCR_PATHWAY.html)

**PID_PDGFRA_PATHWAY**: PDGFR-alpha signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_PDGFRA_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_PDGFRA_PATHWAY.html)

**WP_ESTROGEN_RECEPTOR_PATHWAY**: Estrogen receptor pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ESTROGEN_RECEPTOR_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ESTROGEN_RECEPTOR_PATHWAY.html)

**PID_P38_ALPHA_BETA_DOWNSTREAM_PATHWAY**: Signaling mediated by p38-alpha and p38-beta [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_P38_ALPHA_BETA_DOWNSTREAM_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_P38_ALPHA_BETA_DOWNSTREAM_PATHWAY.html)

**WP_APOPTOSIS**: Apoptosis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_APOPTOSIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_APOPTOSIS.html)

**WEIGEL_OXIDATIVE_STRESS_BY_HNE_AND_H2O2**: Oxidative stress genes down-regulated in ARPE-19 cells (retinal pigmented epithelium) in response to HNE and H2O2 [PubChem=5283344;784]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WEIGEL_OXIDATIVE_STRESS_BY_HNE_AND_H2O2.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WEIGEL_OXIDATIVE_STRESS_BY_HNE_AND_H2O2.html)

**WP_MAPK_CASCADE**: MAPK cascade [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_MAPK_CASCADE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_MAPK_CASCADE.html)

**REACTOME_SIGNALING_BY_NOTCH**: Signaling by NOTCH [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NOTCH.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NOTCH.html)

**WP_COPPER_HOMEOSTASIS**: Copper homeostasis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_COPPER_HOMEOSTASIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_COPPER_HOMEOSTASIS.html)

**PID_ILK_PATHWAY**: Integrin-linked kinase signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_ILK_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_ILK_PATHWAY.html)

**WP_TGF_BETA_SIGNALING_PATHWAY**: TGF beta signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TGF_BETA_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TGF_BETA_SIGNALING_PATHWAY.html)

**BIOCARTA_FAS_PATHWAY**: FAS signaling pathway ( CD95 ) [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_FAS_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_FAS_PATHWAY.html)

**BIOCARTA_TOLL_PATHWAY**: Toll-Like Receptor Pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_TOLL_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_TOLL_PATHWAY.html)

**WP_NEUROINFLAMMATION**: Neuroinflammation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NEUROINFLAMMATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NEUROINFLAMMATION.html)

**PID_FAK_PATHWAY**: Signaling events mediated by focal adhesion kinase [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_FAK_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_FAK_PATHWAY.html)

**BIOCARTA_EGF_PATHWAY**: EGF Signaling Pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_EGF_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_EGF_PATHWAY.html)

**WP_CELL_MIGRATION_AND_INVASION_THROUGH_P75NTR**: Cell migration and invasion through p75NTR [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_CELL_MIGRATION_AND_INVASION_THROUGH_P75NTR.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_CELL_MIGRATION_AND_INVASION_THROUGH_P75NTR.html)

**WP_TNF_ALPHA_SIGNALING_PATHWAY**: TNF alpha signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TNF_ALPHA_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TNF_ALPHA_SIGNALING_PATHWAY.html)

**WP_TROP2_REGULATORY_SIGNALING**: TROP2 regulatory signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TROP2_REGULATORY_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TROP2_REGULATORY_SIGNALING.html)

**REACTOME_PTEN_REGULATION**: PTEN Regulation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PTEN_REGULATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PTEN_REGULATION.html)

**PID_PDGFRB_PATHWAY**: PDGFR-beta signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_PDGFRB_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_PDGFRB_PATHWAY.html)

**PID_ERBB2_ERBB3_PATHWAY**: ErbB2/ErbB3 signaling events [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_ERBB2_ERBB3_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_ERBB2_ERBB3_PATHWAY.html)

**BIOCARTA_IL2_PATHWAY**: IL 2 signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_IL2_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_IL2_PATHWAY.html)

**REACTOME_TOLL_LIKE_RECEPTOR_TLR1_TLR2_CASCADE**: Toll Like Receptor TLR1:TLR2 Cascade [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TOLL_LIKE_RECEPTOR_TLR1_TLR2_CASCADE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TOLL_LIKE_RECEPTOR_TLR1_TLR2_CASCADE.html)

**WP_PDGFR_BETA_PATHWAY**: PDGFR beta pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PDGFR_BETA_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PDGFR_BETA_PATHWAY.html)

**WP_BREAST_CANCER_PATHWAY**: Breast cancer pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_BREAST_CANCER_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_BREAST_CANCER_PATHWAY.html)

**WP_RANKL_RANK_SIGNALING_PATHWAY**: RANKL RANK signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_RANKL_RANK_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_RANKL_RANK_SIGNALING_PATHWAY.html)

**WP_ESTROGEN_SIGNALING_PATHWAY**: Estrogen signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ESTROGEN_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ESTROGEN_SIGNALING_PATHWAY.html)

**REACTOME_SIGNALING_BY_INTERLEUKINS**: Signaling by Interleukins [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_INTERLEUKINS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_INTERLEUKINS.html)

**DACOSTA_UV_RESPONSE_VIA_ERCC3_COMMON_DN**: Common down-regulated transcripts in fibroblasts expressing either XP/CS or TDD mutant forms of ERCC3 [GeneID=2071], after UVC irradiation. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DACOSTA_UV_RESPONSE_VIA_ERCC3_COMMON_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DACOSTA_UV_RESPONSE_VIA_ERCC3_COMMON_DN.html)

**REACTOME_MAPK6_MAPK4_SIGNALING**: MAPK6/MAPK4 signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_MAPK6_MAPK4_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_MAPK6_MAPK4_SIGNALING.html)

**BIOCARTA_ETS_PATHWAY**: METS affect on Macrophage Differentiation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_ETS_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_ETS_PATHWAY.html)

**KEGG_MAPK_SIGNALING_PATHWAY**: MAPK signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MAPK_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MAPK_SIGNALING_PATHWAY.html)

**WP_MAPK_SIGNALING_PATHWAY**: MAPK signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_MAPK_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_MAPK_SIGNALING_PATHWAY.html)

**PID_SMAD2_3NUCLEAR_PATHWAY**: Regulation of nuclear SMAD2/3 signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_SMAD2_3NUCLEAR_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_SMAD2_3NUCLEAR_PATHWAY.html)

**REACTOME_TOLL_LIKE_RECEPTOR_9_TLR9_CASCADE**: Toll Like Receptor 9 (TLR9) Cascade [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TOLL_LIKE_RECEPTOR_9_TLR9_CASCADE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TOLL_LIKE_RECEPTOR_9_TLR9_CASCADE.html)

**WP_IL_1_SIGNALING_PATHWAY**: IL 1 signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_IL_1_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_IL_1_SIGNALING_PATHWAY.html)

**WP_IL_5_SIGNALING_PATHWAY**: IL 5 signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_IL_5_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_IL_5_SIGNALING_PATHWAY.html)

**WP_VEGFA_VEGFR2_SIGNALING**: VEGFA VEGFR2 signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_VEGFA_VEGFR2_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_VEGFA_VEGFR2_SIGNALING.html)

**REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM**: Cytokine Signaling in Immune system [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM.html)

**WP_NEURAL_CREST_CELL_MIGRATION_IN_CANCER**: Neural crest cell migration in cancer [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NEURAL_CREST_CELL_MIGRATION_IN_CANCER.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NEURAL_CREST_CELL_MIGRATION_IN_CANCER.html)

**DACOSTA_UV_RESPONSE_VIA_ERCC3_DN**: Genes down-regulated in fibroblasts expressing mutant forms of ERCC3 [GeneID=2071] after UV irradiation. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DACOSTA_UV_RESPONSE_VIA_ERCC3_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DACOSTA_UV_RESPONSE_VIA_ERCC3_DN.html)

**PID_IL1_PATHWAY**: IL1-mediated signaling events [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_IL1_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_IL1_PATHWAY.html)

**WP_IL_3_SIGNALING_PATHWAY**: IL 3 signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_IL_3_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_IL_3_SIGNALING_PATHWAY.html)

The list of signatures has been truncated to include only signatures with the highest tissue association scores.
