
## Pathways:

**Neutrophil degranulation:** Neutrophils are the most abundant leukocytes (white blood cells), indispensable in defending the body against invading microorganisms. In response to infection, neutrophils leave the circulation and migrate towards the inflammatory focus. They contain several subsets of granules that are mobilized to fuse with the cell membrane or phagosomal membrane, resulting in the exocytosis or exposure of membrane proteins. Traditionally, neutrophil granule constituents are described as antimicrobial or proteolytic, but granules also introduce membrane proteins to the cell surface, changing how the neutrophil responds to its environment (Borregaard et al. 2007). Primed neutrophils actively secrete cytokines and other inflammatory mediators and can present antigens via MHC II, stimulating T-cells [[https://reactome.org/PathwayBrowser/#/R-HSA-6798695](https://reactome.org/PathwayBrowser/#/R-HSA-6798695)].

**Antimicrobial peptides:** Antimicrobial peptides (AMPs) are small molecular weight proteins with broad spectrum of antimicrobial activity against bacteria, viruses, and fungi (Zasloff M 2002; Radek K & Gallo R 2007). The majority of known AMPs are cationic peptides with common structural characteristics where domains of hydrophobic and cationic amino acids are spatially arranged into an amphipathic design, which facilitates their interaction with bacterial membranes (Shai Y 2002; Yeaman MR & Yount NY 2003; Brown KL & Hancock RE 2006; Dennison SR et al. 2005; Zelezetsky I & Tossi A 2006). It is generally accepted that the electrostatic interaction facilitates the initial binding of the positively charged peptides to the negatively charged bacterial membrane. Moreover, the structural amphiphilicity of AMPs is thought to promote their integration into lipid bilayers of pathogenic cells, leading to membrane disintegration and finally to the microbial cell death. In addition to cationic AMPs a few anionic antimicrobial peptides have been found in humans, however their mechanism of action remains to be clarified (Lai Y et al. 2007; Harris F et al. 2009; Paulmann M et al. 2012). Besides the direct neutralizing effects on bacteria AMPs may modulate cells of the adaptive immunity (neutrophils, T-cells, macrophages) to control inflammation and/or to increase bacterial clearance [[https://reactome.org/PathwayBrowser/#/R-HSA-6803157](https://reactome.org/PathwayBrowser/#/R-HSA-6803157)].

**Interleukin-4 and Interleukin-13 signaling:** Interleukin-4 (IL4) is a principal regulatory cytokine during the immune response, crucially important in allergy and asthma (Nelms et al. 1999). When resting T cells are antigen-activated and expand in response to Interleukin-2 (IL2), they can differentiate as Type 1 (Th1) or Type 2 (Th2) T helper cells. The outcome is influenced by IL4. Th2 cells secrete IL4, which both stimulates Th2 in an autocrine fashion and acts as a potent B cell growth factor to promote humoral immunity [[https://reactome.org/PathwayBrowser/#/R-HSA-6785807](https://reactome.org/PathwayBrowser/#/R-HSA-6785807)].

**Metal sequestration by antimicrobial proteins:** Metals are necessary for all forms of life including microorganisms, evidenced by the fact that metal cations are constituents of approximately 40% of all proteins crystallized to date (Waldron KJ et al. 2009; Foster AW et al. 2014; Guengerich FP 2014, 2015). The ability of microorganisms to maintain the intracellular metal quota is essential and allows microorganisms to adapt to a variety of environments. Accordingly, the ability of the host to control metal quota at inflammation sites can influence host-pathogen interactions. The host may restrict microbial growth either by excluding essential metals from the microbes, by delivery of excess metals to cause toxicity, or by complexing metals in microorganisms (Becker KW & Skaar EP 2014) [[https://reactome.org/PathwayBrowser/#/R-HSA-6799990](https://reactome.org/PathwayBrowser/#/R-HSA-6799990)].

**Iron uptake and transport:** The transport of iron between cells is mediated by transferrin. However, iron can also enter and leave cells not only by itself, but also in the form of heme and siderophores. When entering the cell via the main path (by transferrin endocytosis), its goal is not the (still elusive) chelated iron pool in the cytosol nor the lysosomes but the mitochondria, where heme is synthesized and iron-sulfur clusters are assembled [[https://reactome.org/PathwayBrowser/#/R-HSA-917937](https://reactome.org/PathwayBrowser/#/R-HSA-917937)].

## GO terms:

**acute-phase response** [An acute inflammatory response that involves non-antibody proteins whose concentrations in the plasma increase in response to infection or injury of homeothermic animals. GO:0006953]

**cellular response to X-ray** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of X-ray radiation. An X-ray is a form of electromagnetic radiation with a wavelength in the range of 10 nanometers to 100 picometers (corresponding to frequencies in the range 30 PHz to 3 EHz). GO:0071481]

**cellular response to amyloid-beta** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a amyloid-beta stimulus. GO:1904646]

**cellular response to hydrogen peroxide** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a hydrogen peroxide (H2O2) stimulus. GO:0070301]

**cellular response to hypoxia** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating lowered oxygen tension. Hypoxia, defined as a decline in O2 levels below normoxic levels of 20.8 - 20.95%, results in metabolic adaptation at both the cellular and organismal level.|Note that this term should not be confused with 'cellular response to anoxia ; GO:0071454'. Note that in laboratory studies, hypoxia is typically studied at O2 concentrations ranging from 0.1 - 5%. GO:0071456]

**cellular response to increased oxygen levels** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus reflecting an increase in the level of oxygen.|This term should be used when an increase in oxygen levels is not considered a stress response. For a hyperoxic stress response, consider instead 'cellular response to hyperoxia ; GO:0071455'. GO:0036295]

**cellular response to interleukin-1** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interleukin-1 stimulus. GO:0071347]

**cellular response to interleukin-6** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interleukin-6 stimulus. GO:0071354]

**cellular response to lipopolysaccharide** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lipopolysaccharide stimulus; lipopolysaccharide is a major component of the cell wall of gram-negative bacteria. GO:0071222]

**cellular response to nerve growth factor stimulus** [A process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a nerve growth factor stimulus. GO:1990090]

**cellular response to nutrient levels** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus reflecting the presence, absence, or concentration of nutrients. GO:0031669]

**cellular response to tumor necrosis factor** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a tumor necrosis factor stimulus. GO:0071356]

**defense response to bacterium** [Reactions triggered in response to the presence of a bacterium that act to protect the cell or organism. GO:0042742]

**extrinsic apoptotic signaling pathway in absence of ligand** [The series of molecular signals in which a signal is conveyed from the cell surface to trigger the apoptotic death of a cell. The pathway starts with withdrawal of a ligand from a cell surface receptor, and ends when the execution phase of apoptosis is triggered.|For dependence receptors, absence of a ligand or withdrawal of a ligand from a receptor acts as a signal. An example of 'extrinsic apoptotic signaling pathway in absence of ligand' is withdrawal of a growth factor such as NGF, even if traditionally apoptosis induced via growth factor withdrawal has been classified as an instance of intrinsic apoptosis. See an example in PMID: 19767770. Ligands whose withdrawal or absence induce apoptosis should be annotated to GO:2001239 'regulation of extrinsic apoptotic signaling pathway in absence of ligand', rather than to the pathway term itself. Examples of gene products that may be annotated to GO:0097192 'extrinsic apoptotic signaling pathway in absence of ligand' include dependence receptors such as DCC or UNC5B, which relay lethal signals in the absence of their ligand (netrin-1). In the case of DCC and UNC5B, the signaling proceeds through the assembly of a DRAL- and TUCAN- (or NLRP1-) containing caspase-9-activating complex or by the dephosphorylation-mediated activation of death-associated protein kinase 1 (DAPK1) by UNC5B-bound protein phosphatase 2A (PP2A), respectively. DAPK1 can mediate the direct activation of executioner caspases or favor MOMP (reviewed in PMID: 21760595). Also see PMID: 21172653 (annotations to UNC5B and PR65beta, UniProt symbols O08722, PPP2R1B and P30154). GO:0097192]

**innate immune response** [Innate immune responses are defense responses mediated by germline encoded components that directly recognize components of potential pathogens. GO:0045087]

**long-term memory** [The memory process that deals with the storage, retrieval and modification of information a long time (typically weeks, months or years) after receiving that information. This type of memory is typically dependent on gene transcription regulated by second messenger activation. GO:0007616]

**negative regulation of hippocampal neuron apoptotic process** [Any process that stops, prevents, or reduces the frequency, rate or extent of cell death by apoptotic process in hippocampal neurons. GO:0110091]

**positive regulation of apoptotic process** [Any process that activates or increases the frequency, rate or extent of cell death by apoptotic process.|This term should only be used when it is not possible to determine which phase or subtype of the apoptotic process is positively regulated by a gene product. Whenever detailed information is available, the more granular children terms should be used. GO:0043065]

**positive regulation of cell projection organization** [Any process that activates or increases the frequency, rate or extent of the process involved in the formation, arrangement of constituent parts, or disassembly of cell projections. GO:0031346]

**positive regulation of cold-induced thermogenesis** [Any process that activates or increases the frequency, rate or extent of cold-induced thermogenesis. GO:0120162]

**positive regulation of endothelial cell migration** [Any process that increases the rate, frequency, or extent of the orderly movement of an endothelial cell into the extracellular matrix to form an endothelium. GO:0010595]

**positive regulation of endothelial tube morphogenesis** [Any process that activates or increases the frequency, rate or extent of endothelial tube morphogenesis. GO:1905956]

**positive regulation of gene expression** [Any process that increases the frequency, rate or extent of gene expression. Gene expression is the process in which a gene's coding sequence is converted into a mature gene product (protein or RNA). GO:0010628]

**positive regulation of hippocampal neuron apoptotic process** [Any process that activates or increases the frequency, rate or extent of cell death by apoptotic process in hippocampal neurons. GO:0110090]

**positive regulation of iron ion import across plasma membrane** [Any process that activates or increases the frequency, rate or extent of iron ions import across plasma membrane. GO:1904440]

**positive regulation of neuron apoptotic process** [Any process that activates or increases the frequency, rate or extent of cell death of neurons by apoptotic process. GO:0043525]

**positive regulation of reactive oxygen species biosynthetic process** [Any process that activates or increases the frequency, rate or extent of reactive oxygen species biosynthetic process. GO:1903428]

**positive regulation of reactive oxygen species metabolic process** [Any process that activates or increases the frequency, rate or extent of reactive oxygen species metabolic process. GO:2000379]

**response to bacterium** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a bacterium. GO:0009617]

**response to blue light** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a blue light stimulus. Blue light is electromagnetic radiation with a wavelength of between 440 and 500nm. GO:0009637]

**response to fructose** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a fructose stimulus. GO:0009750]

**response to herbicide** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a herbicide stimulus. Herbicides are chemicals used to kill or control the growth of plants. GO:0009635]

**response to iron(II) ion** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an iron(II) ion stimulus. GO:0010040]

**response to kainic acid** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a kainic acid stimulus. GO:1904373]

**response to lipopolysaccharide** [Any process that results in a change in state or activity of an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lipopolysaccharide stimulus; lipopolysaccharide is a major component of the cell wall of gram-negative bacteria. GO:0032496]

**response to mycotoxin** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a mycotoxin stimulus. A mycotoxin is a toxic chemical substance produced by fungi. GO:0010046]

**response to nutrient levels** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus reflecting the presence, absence, or concentration of nutrients. GO:0031667]

**response to oxidative stress** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of oxidative stress, a state often resulting from exposure to high levels of reactive oxygen species, e.g. superoxide anions, hydrogen peroxide (H2O2), and hydroxyl radicals. GO:0006979]

**response to toxic substance** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a toxic stimulus. GO:0009636]

**response to virus** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a virus. GO:0009615]

**response to xenobiotic stimulus** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a xenobiotic, a compound foreign to the organim exposed to it. It may be synthesized by another organism (like ampicilin) or it can be a synthetic chemical. GO:0009410]

**short-term memory** [The memory process that deals with the storage, retrieval and modification of information received a short time (up to about 30 minutes) ago. This type of memory is typically dependent on direct, transient effects of second messenger activation. GO:0007614]

**siderophore transport** [The directed movement of siderophores, low molecular weight Fe(III)-chelating substances, into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. GO:0015891]

## MSigDB Signatures:

**FLECHNER_BIOPSY_KIDNEY_TRANSPLANT_REJECTED_VS_OK_UP**: Genes up-regulated in kidney biopsies from patients with acute transplant rejection compared to the biopsies from patients with well functioning kidneys more than 1-year post transplant. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FLECHNER_BIOPSY_KIDNEY_TRANSPLANT_REJECTED_VS_OK_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FLECHNER_BIOPSY_KIDNEY_TRANSPLANT_REJECTED_VS_OK_UP.html)

**REACTOME_INNATE_IMMUNE_SYSTEM**: Innate Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html)

**WP_CILIARY_LANDSCAPE**: Ciliary landscape [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_CILIARY_LANDSCAPE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_CILIARY_LANDSCAPE.html)

**REACTOME_NEUTROPHIL_DEGRANULATION**: Neutrophil degranulation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NEUTROPHIL_DEGRANULATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NEUTROPHIL_DEGRANULATION.html)

**REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM**: Cytokine Signaling in Immune system [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM.html)

**REACTOME_SIGNALING_BY_INTERLEUKINS**: Signaling by Interleukins [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_INTERLEUKINS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_INTERLEUKINS.html)

**REACTOME_IRON_UPTAKE_AND_TRANSPORT**: Iron uptake and transport [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_IRON_UPTAKE_AND_TRANSPORT.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_IRON_UPTAKE_AND_TRANSPORT.html)

**REACTOME_TRANSPORT_OF_SMALL_MOLECULES**: Transport of small molecules [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRANSPORT_OF_SMALL_MOLECULES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRANSPORT_OF_SMALL_MOLECULES.html)
