
## **Pathways:**

**Immunoregulatory interactions between a Lymphoid and a non-Lymphoid cell:** A number of receptors and cell adhesion molecules play a key role in modifying the response of cells of lymphoid origin (such as B-, T- and NK cells) to self and tumor antigens, as well as to pathogenic organisms.

Molecules such as KIRs and LILRs form part of a crucial surveillance system that looks out for any derangement, usually caused by cancer or viral infection, in MHC Class I presentation. Somatic cells are also able to report internal functional impairment by displaying surface stress markers such as MICA. The presence of these molecules on somatic cells is picked up by C-lectin NK immune receptors.

Lymphoid cells are able to regulate their location and movement in accordance to their state of activation, and home in on tissues expressing the appropriate complementary ligands. For example, lymphoid cells may fine tune the presence and concentration of adhesion molecules belonging to the IgSF, Selectin and Integrin class that interact with a number of vascular markers of inflammation.

Furthermore, there are a number of avenues through which lymphoid cells may interact with antigen. This may be presented directly to a specific T-cell receptor in the context of an MHC molecule. Antigen-antibody complexes may anchor to the cell via a small number of lymphoid-specific Fc receptors that may, in turn, influence cell function further. Activated complement factor C3d binds to both antigen and to cell surface receptor CD21. In such cases, the far-reaching influence of CD19 on B-lymphocyte function is tempered by its interaction with CD21.[[https://reactome.org/PathwayBrowser/#/R-HSA-198933](https://reactome.org/PathwayBrowser/#/R-HSA-198933)]

**Regulation of NF-kappa B signaling:** Nuclear factor kappa B (NF-kappa-B) is activated by a diverse range of stimuli including cytokines, ligands of pattern-recognition receptors (PRRs) such as Toll-like receptors (TLRs) in myeloid cells, antigen-activated TCR in T-cells and by DNA damage (reviewed in Yu H et al. 2020; Zhang T et al. 2021). NF-kappa-B regulates the transcription of genes that are involved in immune and inflammatory responses, cell cycle, cell proliferation and apoptosis (Bhatt D & Ghosh S 2014; Liu T et al. 2017; Yu H et al. 2020). In unstimulated cells, NF-kappa-B is sequestered in the cytosol through interactions with a class of inhibitor proteins, called NF-kappa-B inhibitors (IkBs, such as NFKBIA or NFKBIB) (Jacobs MD & Harrison SC 1998). IkBs mask the nuclear localization signal (NLS) of NF-kappa-B preventing its nuclear translocation (Cervantes CF et al. 2011). A key event in NF-kappa-B activation involves phosphorylation of IkBs by the IkappaB kinase (IKK) complex which consists of CHUK, IKBKB and IKBKG subunits (Israel A 2010). The activated NF-kappa-B signaling is tightly controlled at multiple levels (Dorrington MG & Fraser IDC 2019; Prescott JA et al. 2021). Dysregulated NF-kappa-B activity can cause tissue damage associated with inflammatory diseases and is also linked to tumorigenesis (Aggarwal BB & Sung B 2011; Liu T et al.2017; Barnabei L et al. 2021). The regulation of NF-kappa-B is cell-type-, context- , and stimulus-dependent and is crucial for orchestrating specific cellular responses (Mussbacher M et al. 2019). [PMID: 35957669, PMID: 30333625, PMID: 31138763], [[https://reactome.org/PathwayBrowser/#/R-HSA-9758274&PATH=R-HSA-9020702](https://reactome.org/PathwayBrowser/#/R-HSA-9758274&PATH=R-HSA-9020702)].

## GO terms:

**Fc receptor mediated inhibitory signaling pathway** [The series of molecular signals generated as a consequence of the binding of the Fc portion of an immunoglobulin by an Fc receptor capable of inhibiting an immune effector process contributing to an immune response. The Fc portion of an immunoglobulin is its C-terminal constant region. GO:0002774]

**cytokine-mediated signaling pathway** [The series of molecular signals initiated by the binding of a cytokine to a receptor on the surface of a cell, and ending with the regulation of a downstream cellular process, e.g. transcription. GO:0019221]

**interleukin-10-mediated signaling pathway** [The series of molecular signals initiated by interleukin-10 binding to its receptor on the surface of a target cell, and ending with the regulation of a downstream cellular process, e.g. transcription. GO:0140105]

**mast cell activation** [The change in morphology and behavior of a mast cell resulting from exposure to a cytokine, chemokine, soluble factor, or to (at least in mammals) an antigen which the mast cell has specifically bound via IgE bound to Fc-epsilonRI receptors. GO:0045576]

**negative regulation of IP-10 production** [Any process that stops, prevents, or reduces the frequency, rate, or extent of production of IP-10. GO:0071659]

**negative regulation of MAPK cascade** [Any process that stops, prevents, or reduces the frequency, rate or extent of signal transduction mediated by the MAPKKK cascade. GO:0043409]

**negative regulation of T cell costimulation** [Any process that stops, prevents or reduces the frequency, rate or extent of T cell costimulation. GO:2000524]

**negative regulation of T cell cytokine production** [Any process that stops, prevents, or reduces the frequency, rate, or extent of T cell cytokine production. GO:0002725]

**negative regulation of T cell proliferation** [Any process that stops, prevents or reduces the rate or extent of T cell proliferation. GO:0042130]

**negative regulation of T cell receptor signaling pathway** [Any process that stops, prevents, or reduces the frequency, rate or extent of signaling pathways initiated by the cross-linking of an antigen receptor on a T cell. GO:0050860]

**negative regulation of activated T cell proliferation** [Any process that stops, prevents or reduces the rate or extent of activated T cell proliferation. GO:0046007]

**negative regulation of canonical NF-kappaB signal transduction** [Any process that stops, prevents, or reduces the frequency, rate or extent of a canonical NF-kappaB signaling cascade. GO:0043124]

**negative regulation of chemokine production** [Any process that stops, prevents, or reduces the frequency, rate, or extent of chemokine production. GO:0032682]

**negative regulation of cytokine production involved in inflammatory response** [Any process that stops, prevents or reduces the frequency, rate or extent of cytokine production involved in inflammatory response. GO:1900016]

**negative regulation of cytotoxic T cell differentiation** [Any process that stops, prevents, or reduces the frequency, rate or extent of cytotoxic T cell differentiation.|Note that immunologists typically use the word 'development' to refer to cells of B or T cell lineages undergoing the process that GO describes as 'cell differentiation'. GO:0045584]

**negative regulation of interleukin-1 beta production** [Any process that stops, prevents, or reduces the frequency, rate, or extent of interleukin-1 beta production. GO:0032691]

**negative regulation of interleukin-10 production** [Any process that stops, prevents, or reduces the frequency, rate, or extent of interleukin-10 production. GO:0032693]

**negative regulation of interleukin-2 production** [Any process that stops, prevents, or reduces the frequency, rate, or extent of interleukin-2 production. GO:0032703]

**negative regulation of interleukin-5 production** [Any process that stops, prevents, or reduces the frequency, rate, or extent of interleukin-5 production. GO:0032714]

**negative regulation of interleukin-6 production** [Any process that stops, prevents, or reduces the frequency, rate, or extent of interleukin-6 production. GO:0032715]

**negative regulation of miRNA transcription** [Any process that stops, prevents or reduces the frequency, rate or extent of microRNA (miRNA) gene transcription. GO:1902894]

**negative regulation of monocyte activation** [Any process that stops, prevents or reduces the frequency, rate or extent of monocyte activation. GO:0150102]

**negative regulation of osteoclast differentiation** [Any process that stops, prevents, or reduces the frequency, rate or extent of osteoclast differentiation. GO:0045671]

**negative regulation of protein localization to nucleus** [Any process that stops, prevents or reduces the frequency, rate or extent of protein localization to nucleus. GO:1900181]

**negative regulation of tumor necrosis factor production** [Any process that stops, prevents, or reduces the frequency, rate, or extent of tumor necrosis factor production.|Note that this term refers only to the specific, original 'tumor necrosis factor' protein (TNF) and not other members of the tumor necrosis factor superfamily (those with the gene symbol root 'TNFSF'). GO:0032720]

**negative regulation of type II interferon production** [Any process that stops, prevents, or reduces the frequency, rate, or extent of interferon-gamma production. Interferon-gamma is also known as type II interferon. GO:0032689]

**positive regulation of CD8-positive, alpha-beta T cell differentiation** [Any process that activates or increases the frequency, rate or extent of CD8-positive, alpha-beta T cell differentiation.|Note that immunologists typically use the word 'development' to refer to cells of B or T cell lineages undergoing the process that GO describes as 'cell differentiation'. GO:0043378]

**positive regulation of T cell anergy** [Any process that activates or increases the frequency, rate, or extent of T cell anergy. GO:0002669]

**positive regulation of regulatory T cell differentiation** [Any process that activates or increases the frequency, rate or extent of differentiation of regulatory T cells.|Note that immunologists typically use the word 'development' to refer to cells of B or T cell lineages undergoing the process that GO describes as 'cell differentiation'. GO:0045591]

**receptor internalization** [A receptor-mediated endocytosis process that results in the movement of receptors from the plasma membrane to the inside of the cell. The process begins when cell surface receptors are monoubiquitinated following ligand-induced activation. Receptors are subsequently taken up into endocytic vesicles from where they are either targeted to the lysosome or vacuole for degradation or recycled back to the plasma membrane. GO:0031623]

**tolerance induction** [A process that directly activates any of the steps required for tolerance, a physiologic state in which the immune system does not react destructively against the components of an organism that harbors it or against antigens that are introduced to it. GO:0002507]

## MSigDB Signatures:

**REACTOME_ADAPTIVE_IMMUNE_SYSTEM**: Adaptive Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ADAPTIVE_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ADAPTIVE_IMMUNE_SYSTEM.html)
