
## **Pathways:**

**Copper homeostasis:** Copper is a redox-active transition metal and an essential trace element for life. It is a catalytic cofactor for numerous enzymes involved in critical biological processes (eg. detoxyfication by oxygen free radicals, angiogenesis, pigmentation, peptide hormone production, etc.). However, "free" copper is harmful for cells because can generate ROS that leads to cellular damage. Thus, all organisms and cells maintain a tight control of its uptake, trafficking, and export. This process is rather intricate and requires an interplay between numerous biomolecules (proteins, enzymes, metabolites) that act as copper ions importers (CTR1, CTR2, DMT1, Prp, APP), chaperones (CCS, ATOX1, COX17, COMMD1) and exporters (ATP7A, ATP7B). Copper ions and Cu-independent stimuli (hormone, oxygen, phosphorylation and ubiquination) seem to affect localization and expression of Cu-transporters and chaperones. Potential target of copper ions seems to be crucial signaling pathways, such as PI3K/Akt, in which copper induces insulin-like effects. Copper dyshomeostasis could be implicated in cancer and a number of neurodegenerative diseases, including Alzheimer's disease, Parkinson's disease, prion disease and ALS [[https://www.wikipathways.org/pathways/WP3286.html](https://www.wikipathways.org/pathways/WP3286.html)]

**Zinc homeostasis:** Zinc is a transition metal and catalytic cofactor involved in many biological processes such as proliferation, development and differentiation, regulation of DNA synthesis, genomic stability, cell activation, RNA transcription, immune function. Zinc homeostasis in cells is ensured by various protein families including zinc transporters, zinc-binding proteins (Metallothioneins, MTs), transcription factors (MTF1-2). ZnT (1-10) transporters are responsible of zinc efflux and are assigned to the SLC30A family while ZIP (1-14) transporters are responsible for the influx of zinc into the cytoplasm and are assigned to the SLC39A family. Zn2+ enters into the cell by the ZIP transporters, and once inside the cell is available to bind metalloproteins (MT) which deliver to ZnT, or the zinc can bind to directly ZnTs and then deliver in the organelles / vesicles or lead outside the cell. Elevated zinc levels have been reported in different tumour tissue, such as breast and lung cancer. [[https://www.wikipathways.org/pathways/WP3529.html](https://www.wikipathways.org/pathways/WP3529.html)]

**Cellular responses to stimuli:** Individual cells detect and respond to diverse external molecular and physical signals. Appropriate responses to these signals are essential for normal development, maintenance of homeostasis in mature tissues, and effective defensive responses to potentially noxious agents (Kultz 2005). It is convenient, if somewhat arbitrary, to distinguish responses to signals involved in development and homeostasis from ones involved in stress responses, and that classification is followed here, with macroautophagy and responses to metal ions classified as responses to normal external stimuli, while responses to hypoxia, reactive oxygen species, and heat, and the process of cellular senescence are classified as stress responses. [[https://reactome.org/PathwayBrowser/#/R-HSA-8953897](https://reactome.org/PathwayBrowser/#/R-HSA-8953897)]

**Metallothioneins bind metals:** Metallothioneins are highly conserved, cysteine-rich proteins that bind metals via thiolate bonds (recent general reviews in Capdevila et al. 2012, Blindauer et al. 2014, reviews of mammalian metallothioneins in Miles et al. 2000, Maret 2011, Vasak and Meloni 2011, Thirumoorthy et al. 2001, Babula et al. 2012). Mammals contain 4 general metallothionein isoforms (MT1,2,3,4). The MT1 isoform has radiated in primates to 8 or 9 functional proteins (depending on classification of MT1L). Each mammalian metallothionein binds a total of 7 divalent metal ions in two clusters, the alpha and beta clusters. Though the functions of metallothioneins have not been fully elucidated, they appear to participate in detoxifying heavy metals (reviewed in Sharma et al. 2013), storing and transporting zinc, and redox biochemistry. Metallothioneins interact with many other cellular proteins, with most interactions involving proteins of the central nervous system (reviewed in Atrian and Capdevila 2013). [[https://reactome.org/PathwayBrowser/#/R-HSA-5661231](https://reactome.org/PathwayBrowser/#/R-HSA-5661231)]

**Response to metal ions**: Though metals such as zinc, copper, and iron are required as cofactors for cellular enzymes they can also catalyze damaging metal substitution or unspecific redox reactions if they are not sequestered. The transcription factor MTF1 directs the major cellular response to zinc, cadmium, and copper. MTF1 activates gene expression to up-regulate genes encoding proteins, such as metallothioneins and glutamate-cysteine ligase (GCLC), involved in sequestering metals. MTF1 represses gene expression to down-regulate genes encoding transporters that import the metals into the cell (reviewed in Laity and Andrews 2007, Jackson et al. 2008, Gunther et al. 2012, Dong et al. 2015). During activation MTF1 in the cytosol binds zinc ions and is translocated into the nucleus, where it binds metal response elements in the promoters of target genes. Activation of MTF1 by cadmium and copper appears to be indirect as these metals displace zinc from metallothioneins and the displaced zinc then binds MTF1. Metallothioneins bind metals and participate in detoxifying heavy metals, storing and transporting zinc, and redox biochemistry. [[https://reactome.org/PathwayBrowser/#/R-HSA-5660526&PATH=R-HSA-8953897](https://reactome.org/PathwayBrowser/#/R-HSA-5660526&PATH=R-HSA-8953897)]

**Platinum Pathway, Pharmacokinetics/Pharmacodynamics**: Platinum (Pt)-containing drugs are currently used in the clinic for treating cancer. The major Pt-containing drugs are cisplatin, carboplatin, and oxaliplatin. Platinum-based drugs are now the largest class of drugs used to treat cancer. They destroy cancerous cells by interfering with the DNA, via inter- and intrastrand crosslinks, and DNA-protein crosslinks, thereby preventing cell division and growth. Although platinum-based drugs are the most widely used in cancer treatment, many tumors are completely resistant to these drugs and no clinical response is attained. The difference in clinical response is thought to be due, in part, to the pharmacokinetics of these drugs. The influx of platinum drugs into the cell is regulated by SLC31A1 (CTR1) and the efflux by ABCC2 (MRP2), ATP7A, and ATP7B. ATP7A is involved in the Cu transport from cytoplasm into trans-Golgi network where it serves to export Cu from the cell via the vesicular secretory pathway. ATP7B is also an exporter of copper and is localized to the trans-Golgi network. When the copper content of the cell increases, ATP7A moves from trans-Golgi network to the plasma membrane and ATP7B relocates to intracellular vesicular compartments, presumably involved in the export pathway. Once platinum is inside the cell, the primary anti-tumor mechanism is the formation of Pt-DNA adducts which lead to cell-cycle arrest and apoptosis. HMGB1 is important in the cell recognition of these Pt-DNA adducts, and therefore signals cellular response to these adducts. Genes involved in mismatch repair, such as MSH6 and MLH1, decrease the cell-sensitivity to these drugs. In addition, nucleotide excision repair is mediated by XRCC1, ERCC1, ERCC2, and XPA, and known variants in these genes affect patient's response to Pt-based drugs [PMID: 16931584, PMID: 16880786]. These genes act by detecting single strand breaks and removing proteins from the DNA helix, which then becomes more accessible to repair enzymes. POLH and POLB variants have been shown to provide tolerance to platinum-based drugs, and therefore represent an important determinant of the cellular response to platinum drugs. In addition, there are several genes, such as MPO, SOD1, GSTM1, NQO1, GSTP1, and MT, that are responsible for lowering the intracellular concentration of platinum drugs and therefore play a key role in cellular resistance to these drugs. [[https://www.pharmgkb.org/pathway/PA150642262](https://www.pharmgkb.org/pathway/PA150642262)]

## GO terms:

**cellular response to cadmium ion** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cadmium (Cd) ion stimulus. GO:0071276]

**cellular response to copper ion** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a copper ion stimulus. GO:0071280]

**cellular response to zinc ion** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a zinc ion stimulus. GO:0071294]

**detoxification of copper ion** [Any process that reduces or removes the toxicity of copper ion. These include transport of copper away from sensitive areas and to compartments or complexes whose purpose is sequestration of copper ion. GO:0010273]

**intracellular zinc ion homeostasis** [A homeostatic process involved in the maintenance of a steady state level of zinc ions within a cell. GO:0006882]

**negative regulation of growth** [Any process that stops, prevents or reduces the rate or extent of growth, the increase in size or mass of all or part of an organism. GO:0045926]

**response to cadmium ion** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cadmium (Cd) ion stimulus. GO:0046686]

**response to zinc ion** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a zinc ion stimulus. GO:0010043]

## MSigDB Signatures:

**REACTOME_CELLULAR_RESPONSES_TO_STIMULI**: Cellular responses to stimuli [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELLULAR_RESPONSES_TO_STIMULI.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELLULAR_RESPONSES_TO_STIMULI.html)

**REACTOME_METALLOTHIONEINS_BIND_METALS**: Metallothioneins bind metals [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_METALLOTHIONEINS_BIND_METALS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_METALLOTHIONEINS_BIND_METALS.html)

**WP_ZINC_HOMEOSTASIS**: Zinc homeostasis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ZINC_HOMEOSTASIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ZINC_HOMEOSTASIS.html)

**MA_RAT_AGING_UP**: Genes up-regulated across multiple cell types from nine tissues during rat aging. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MA_RAT_AGING_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MA_RAT_AGING_UP.html)

**WP_COPPER_HOMEOSTASIS**: Copper homeostasis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_COPPER_HOMEOSTASIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_COPPER_HOMEOSTASIS.html)

**REACTOME_RESPONSE_TO_METAL_IONS**: Response to metal ions [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RESPONSE_TO_METAL_IONS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RESPONSE_TO_METAL_IONS.html)
