
## **Pathways:**

-   **Cellular responses to stimuli:** Individual cells detect and respond to diverse external molecular and physical signals. Appropriate responses to these signals are essential for normal development, maintenance of homeostasis in mature tissues, and effective defensive responses to potentially noxious agents (Kultz 2005). It is convenient, if somewhat arbitrary, to distinguish responses to signals involved in development and homeostasis from ones involved in stress responses, and that classification is followed here, with macroautophagy and responses to metal ions classified as responses to normal external stimuli, while responses to hypoxia, reactive oxygen species, and heat, and the process of cellular senescence are classified as stress responses. [[https://reactome.org/PathwayBrowser/#/R-HSA-8953897](https://reactome.org/PathwayBrowser/#/R-HSA-8953897)].
-   **Cytokine Signaling in Immune system:** Cytokines are small proteins that regulate and mediate immunity, inflammation, and hematopoiesis. They are secreted in response to immune stimuli, and usually act briefly, locally, at very low concentrations. Cytokines bind to specific membrane receptors, which then signal the cell via second messengers, to regulate cellular activity. [[https://reactome.org/PathwayBrowser/#/R-HSA-1280215](https://reactome.org/PathwayBrowser/#/R-HSA-1280215)].
-   **Interferon gamma signaling:** Interferon-gamma (IFN-gamma) belongs to the type II interferon family and is secreted by activated immune cells-primarily T and NK cells, but also B-cells and APC. INFG exerts its effect on cells by interacting with the specific IFN-gamma receptor (IFNGR). IFNGR consists of two chains, namely IFNGR1 (also known as the IFNGR alpha chain) and IFNGR2 (also known as the IFNGR beta chain). IFNGR1 is the ligand binding receptor and is required but not sufficient for signal transduction, whereas IFNGR2 do not bind IFNG independently but mainly plays a role in IFNG signaling and is generally the limiting factor in IFNG responsiveness. Both IFNGR chains lack intrinsic kinase/phosphatase activity and thus rely on other signaling proteins like Janus-activated kinase 1 (JAK1), JAK2 and Signal transducer and activator of transcription 1 (STAT-1) for signal transduction. IFNGR complex in its resting state is a preformed tetramer and upon IFNG association undergoes a conformational change. This conformational change induces the phosphorylation and activation of JAK1, JAK2, and STAT1 which in turn induces genes containing the gamma-interferon activation sequence (GAS) in the promoter. [[https://reactome.org/PathwayBrowser/#/R-HSA-877300](https://reactome.org/PathwayBrowser/#/R-HSA-877300)].
-   **Interferon Signaling:** Interferons (IFNs) are cytokines that play a central role in initiating immune responses, especially antiviral and antitumor effects. There are three types of IFNs:Type I (IFN-alpha, -beta and others, such as omega, epsilon, and kappa), Type II (IFN-gamma) and Type III (IFN-lambda). In this module we are mainly focusing on type I IFNs alpha and beta and type II IFN-gamma. Both type I and type II IFNs exert their actions through cognate receptor complexes, IFNAR and IFNGR respectively, present on cell surface membranes. Type I IFNs are broadly expressed heterodimeric receptors composed of the IFNAR1 and IFNAR2 subunits, while the type II IFN receptor consists of IFNGR1 and IFNGR2. Type III interferon lambda has three members: lambda1 (IL-29), lambda2 (IL-28A), and lambda3 (IL-28B) respectively. IFN-lambda signaling is initiated through unique heterodimeric receptor composed of IFN-LR1/IF-28Ralpha and IL10R2 chains. Type I IFNs typically recruit JAK1 and TYK2 proteins to transduce their signals to STAT1 and 2; in combination with IRF9 (IFN-regulatory factor 9), these proteins form the heterotrimeric complex ISGF3. In nucleus ISGF3 binds to IFN-stimulated response elements (ISRE) to promote gene induction. Type II IFNs in turn rely upon the activation of JAKs 1 and 2 and STAT1. Once activated, STAT1 dimerizes to form the transcriptional regulator GAF (IFNG activated factor) and this binds to the IFNG activated sequence (GAS) elements and initiate the transcription of IFNG-responsive genes. Like type I IFNs, IFN-lambda recruits TYK2 and JAK1 kinases and then promote the phosphorylation of STAT1/2, and induce the ISRE3 complex formation. [[https://reactome.org/PathwayBrowser/#/R-HSA-913531&PATH=R-HSA-168256,R-HSA-1280215](https://reactome.org/PathwayBrowser/#/R-HSA-913531&PATH=R-HSA-168256,R-HSA-1280215)].
-   **Metallothioneins bind metals:** Metallothioneins are highly conserved, cysteine-rich proteins that bind metals via thiolate bonds (recent general reviews in Capdevila et al. 2012, Blindauer et al. 2014, reviews of mammalian metallothioneins in Miles et al. 2000, Maret 2011, Vasak and Meloni 2011, Thirumoorthy et al. 2001, Babula et al. 2012). Mammals contain 4 general metallothionein isoforms (MT1,2,3,4). The MT1 isoform has radiated in primates to 8 or 9 functional proteins (depending on classification of MT1L). Each mammalian metallothionein binds a total of 7 divalent metal ions in two clusters, the alpha and beta clusters. Though the functions of metallothioneins have not been fully elucidated, they appear to participate in detoxifying heavy metals (reviewed in Sharma et al. 2013), storing and transporting zinc, and redox biochemistry. Metallothioneins interact with many other cellular proteins, with most interactions involving proteins of the central nervous system (reviewed in Atrian and Capdevila 2013). [[https://reactome.org/PathwayBrowser/#/R-HSA-5661231](https://reactome.org/PathwayBrowser/#/R-HSA-5661231)].
-   **Response to metal ions:** Though metals such as zinc, copper, and iron are required as cofactors for cellular enzymes they can also catalyze damaging metal substitution or unspecific redox reactions if they are not sequestered. The transcription factor MTF1 directs the major cellular response to zinc, cadmium, and copper. MTF1 activates gene expression to up-regulate genes encoding proteins, such as metallothioneins and glutamate-cysteine ligase (GCLC), involved in sequestering metals. MTF1 represses gene expression to down-regulate genes encoding transporters that import the metals into the cell (reviewed in Laity and Andrews 2007, Jackson et al. 2008, Guenther et al. 2012, Dong et al. 2015). During activation MTF1 in the cytosol binds zinc ions and is translocated into the nucleus, where it binds metal response elements in the promoters of target genes. Activation of MTF1 by cadmium and copper appears to be indirect as these metals displace zinc from metallothioneins and the displaced zinc then binds MTF1. Metallothioneins bind metals and participate in detoxifying heavy metals, storing and transporting zinc, and redox biochemistry. [[https://reactome.org/PathwayBrowser/#/R-HSA-5660526](https://reactome.org/PathwayBrowser/#/R-HSA-5660526)].

## GO terms:

**astrocyte activation** [A change in morphology and behavior of an astrocyte resulting from exposure to a cytokine, chemokine, cellular ligand, or soluble factor. GO:0048143]

**cellular response to cadmium ion** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cadmium (Cd) ion stimulus. GO:0071276]

**cellular response to copper ion** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a copper ion stimulus. GO:0071280]

**cellular response to erythropoietin** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an erythropoietin stimulus. GO:0036018]

**cellular response to interleukin-3** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interleukin-3 stimulus. GO:0036016]

**cellular response to zinc ion** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a zinc ion stimulus. GO:0071294]

**detoxification of copper ion** [Any process that reduces or removes the toxicity of copper ion. These include transport of copper away from sensitive areas and to compartments or complexes whose purpose is sequestration of copper ion. GO:0010273]

**intracellular zinc ion homeostasis** [A homeostatic process involved in the maintenance of a steady state level of zinc ions within a cell. GO:0006882]

**negative regulation of growth** [Any process that stops, prevents or reduces the rate or extent of growth, the increase in size or mass of all or part of an organism. GO:0045926]

**nitric oxide mediated signal transduction** [Any intracellular signal transduction in which the signal is passed on within the cell via nitric oxide (NO). Includes synthesis of nitric oxide, receptors/sensors for nitric oxide (such as soluble guanylyl cyclase/sGC) and downstream effectors that further transmit the signal within the cell. Nitric oxide transmits its downstream effects through either cyclic GMP (cGMP)-dependent or independent mechanisms. GO:0007263]

**response to bacterium** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a bacterium. GO:0009617]

## MSigDB Signatures:

**REACTOME_CELLULAR_RESPONSES_TO_STIMULI**: Cellular responses to stimuli [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELLULAR_RESPONSES_TO_STIMULI.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELLULAR_RESPONSES_TO_STIMULI.html)

**WP_LUNG_FIBROSIS**: Lung fibrosis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_LUNG_FIBROSIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_LUNG_FIBROSIS.html)

**REACTOME_METALLOTHIONEINS_BIND_METALS**: Metallothioneins bind metals [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_METALLOTHIONEINS_BIND_METALS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_METALLOTHIONEINS_BIND_METALS.html)

**WP_ZINC_HOMEOSTASIS**: Zinc homeostasis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ZINC_HOMEOSTASIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ZINC_HOMEOSTASIS.html)

**MA_RAT_AGING_UP**: Genes up-regulated across multiple cell types from nine tissues during rat aging. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MA_RAT_AGING_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MA_RAT_AGING_UP.html)

**REACTOME_INTERFERON_SIGNALING**: Interferon Signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INTERFERON_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INTERFERON_SIGNALING.html)

**WP_COPPER_HOMEOSTASIS**: Copper homeostasis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_COPPER_HOMEOSTASIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_COPPER_HOMEOSTASIS.html)

**REACTOME_RESPONSE_TO_METAL_IONS**: Response to metal ions [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RESPONSE_TO_METAL_IONS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RESPONSE_TO_METAL_IONS.html)

**REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM**: Cytokine Signaling in Immune system [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM.html)

**REACTOME_INTERFERON_GAMMA_SIGNALING**: Interferon gamma signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INTERFERON_GAMMA_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INTERFERON_GAMMA_SIGNALING.html)
