
## Pathways:

-   **Cell surface interactions at the vascular wall:** Leukocyte extravasation is a rigorously controlled process that guides white cell movement from the vascular lumen to sites of tissue inflammation. The powerful adhesive interactions that are required for leukocytes to withstand local flow at the vessel wall is a multistep process mediated by different adhesion molecules. Platelets adhered to injured vessel walls form strong adhesive substrates for leukocytes. For instance, the initial tethering and rolling of leukocytes over the site of injury are mediated by reversible binding of selectins to their cognate cell-surface glycoconjugates [[https://reactome.org/PathwayBrowser/#/R-HSA-202733](https://reactome.org/PathwayBrowser/#/R-HSA-202733)].
-   **Neutrophil degranulation:** Neutrophils are the most abundant leukocytes (white blood cells), indispensable in defending the body against invading microorganisms. In response to infection, neutrophils leave the circulation and migrate towards the inflammatory focus. They contain several subsets of granules that are mobilized to fuse with the cell membrane or phagosomal membrane, resulting in the exocytosis or exposure of membrane proteins. Traditionally, neutrophil granule constituents are described as antimicrobial or proteolytic, but granules also introduce membrane proteins to the cell surface, changing how the neutrophil responds to its environment (Borregaard et al. 2007). Primed neutrophils actively secrete cytokines and other inflammatory mediators and can present antigens via MHC II, stimulating T-cells (Wright et al. 2010) [[https://reactome.org/PathwayBrowser/#/R-HSA-6798695](https://reactome.org/PathwayBrowser/#/R-HSA-6798695)].
-   **PPAR signaling pathway:** Peroxisome proliferator-activated receptors (PPARs) are nuclear hormone receptors that are activated by fatty acids and their derivatives. PPAR has three subtypes (PPARalpha, beta/delta, and gamma) showing different expression patterns in vertebrates. Each of them is encoded in a separate gene and binds fatty acids and eicosanoids. PPARalpha plays a role in the clearance of circulating or cellular lipids via the regulation of gene expression involved in lipid metabolism in liver and skeletal muscle. PPARbeta/delta is involved in lipid oxidation and cell proliferation. PPARgamma promotes adipocyte differentiation to enhance blood glucose uptake [[https://www.wikipathways.org/pathways/WP3942.html](https://www.wikipathways.org/pathways/WP3942.html)].

## GO terms:

**immune system process** [Any process involved in the development or functioning of the immune system, an organismal system for calibrated responses to potential internal or invasive threats.|Note that this term is a direct child of 'biological_process ; GO:0008150' because some immune system processes are types of cellular process (GO:0009987), whereas others are types of multicellular organism process (GO:0032501). GO:0002376]

**inflammatory response** [The immediate defensive reaction (by vertebrate tissue) to infection or injury caused by chemical or physical agents. The process is characterized by local vasodilation, extravasation of plasma into intercellular spaces and accumulation of white blood cells and macrophages. GO:0006954]

**leukocyte cell-cell adhesion** [The attachment of a leukocyte to another cell via adhesion molecules. GO:0007159]

**lipoprotein metabolic process** [The chemical reactions and pathways involving any conjugated, water-soluble protein in which the covalently attached nonprotein group consists of a lipid or lipids. GO:0042157]

**negative regulation of gene expression** [Any process that decreases the frequency, rate or extent of gene expression. Gene expression is the process in which a gene's coding sequence is converted into a mature gene product (protein or RNA).|This term covers any process that negatively regulates the rate of production of a mature gene product, and so includes processes that negatively regulate that rate by reducing the level, stability or availability of intermediates in the process of gene expression. For example, it covers any process that reduces the level, stability or availability of mRNA or circRNA for translation and thereby reduces the rate of production of the encoded protein via translation. GO:0010629]

**positive regulation of cellular process** [Any process that activates or increases the frequency, rate or extent of a cellular process, any of those that are carried out at the cellular level, but are not necessarily restricted to a single cell. For example, cell communication occurs among more than one cell, but occurs at the cellular level. GO:0048522]

**positive regulation of superoxide anion generation** [Any process that activates or increases the frequency, rate or extent of enzymatic generation of superoxide by a cell. GO:0032930]

**response to hydrogen peroxide** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a hydrogen peroxide (H2O2) stimulus. GO:0042542]

**vasoconstriction** [A decrease in the diameter of blood vessels, especially arteries, due to constriction of smooth muscle cells that line the vessels, and usually causing an increase in blood pressure. GO:0042310]

**vesicle-mediated transport** [A cellular transport process in which transported substances are moved in membrane-bounded vesicles; transported substances are enclosed in the vesicle lumen or located in the vesicle membrane. The process begins with a step that directs a substance to the forming vesicle, and includes vesicle budding and coating. Vesicles are then targeted to, and fuse with, an acceptor membrane. GO:0016192]

## MSigDB Signatures:

**REACTOME_HEMOSTASIS**: Hemostasis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HEMOSTASIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HEMOSTASIS.html)

**REACTOME_INNATE_IMMUNE_SYSTEM**: Innate Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html)

**REACTOME_NEUTROPHIL_DEGRANULATION**: Neutrophil degranulation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NEUTROPHIL_DEGRANULATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NEUTROPHIL_DEGRANULATION.html)

**REACTOME_CELL_SURFACE_INTERACTIONS_AT_THE_VASCULAR_WALL**: Cell surface interactions at the vascular wall [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELL_SURFACE_INTERACTIONS_AT_THE_VASCULAR_WALL.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELL_SURFACE_INTERACTIONS_AT_THE_VASCULAR_WALL.html)

**KEGG_PPAR_SIGNALING_PATHWAY**: PPAR signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_PPAR_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_PPAR_SIGNALING_PATHWAY.html)

**WP_PPAR_SIGNALING_PATHWAY**: PPAR signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PPAR_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PPAR_SIGNALING_PATHWAY.html)

**CHICAS_RB1_TARGETS_CONFLUENT**: Genes up-regulated in confluent IMR90 cells (fibroblast) after knockdown of RB1 [GeneID=5925] by RNAi. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHICAS_RB1_TARGETS_CONFLUENT.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHICAS_RB1_TARGETS_CONFLUENT.html)
