
## **Pathways:**

**Pyruvate metabolism and Citric Acid (TCA) cycle:** Pyruvate metabolism and the citric acid (TCA) cycle together link the processes of energy metabolism in a human cell with one another and with key biosynthetic reactions. Pyruvate, derived from the reversible oxidation of lactate or transamination of alanine, can be converted to acetyl CoA. Other sources of acetyl CoA include breakdown of free fatty acids and ketone bodies in the fasting state. Acetyl CoA can enter the citric acid cycle, a major source of reducing equivalents used to synthesize ATP, or enter biosynthetic pathways.

In addition to its role in energy generation, the citric acid cycle is a source of carbon skeletons for amino acid metabolism and other biosynthetic processes. One such process included here is the interconversion of 2-hydroxyglutarate, probably derived from porphyrin and amino acid metabolism, and 2-oxoglutarate (alpha-ketoglutarate), a citric acid cycle intermediate [[https://reactome.org/PathwayBrowser/#/R-HSA-1428517&SEL=R-HSA-71406&PATH=R-HSA-1430728](https://reactome.org/PathwayBrowser/#/R-HSA-1428517&SEL=R-HSA-71406&PATH=R-HSA-1430728)].

**Regulation of pyruvate dehydrogenase (PDH) complex:** The mitochondrial pyruvate dehydrogenase (PDH) complex catalyzes the oxidative decarboxylation of pyruvate, linking glycolysis to the tricarboxylic acid cycle and fatty acid synthesis. PDH inactivation is crucial for glucose conservation when glucose is scarce, while adequate PDH activity is required to allow both ATP and fatty acid production from glucose. The mechanisms that control human PDH activity include its phosphorylation (inactivation) by pyruvate dehydrogenase kinases (PDK 1-4) and its dephosphorylation (activation, reactivation) by pyruvate dehydrogenase phosphate phosphatases (PDP 1 and 2). Isoform-specific differences in kinetic parameters, regulation, and phosphorylation site specificity of the PDKs introduce variations in the regulation of PDC activity in differing endocrine and metabolic states (Sugden and Holness 2003) [[https://reactome.org/PathwayBrowser/#/R-HSA-204174](https://reactome.org/PathwayBrowser/#/R-HSA-204174)].

**Signaling by Retinoic Acid:** Vitamin A (retinol) can be metabolised into active retinoid metabolites that function either as a chromophore in vision or in regulating gene expression transcriptionally and post-transcriptionally. Genes regulated by retinoids are essential for reproduction, embryonic development, growth, and multiple processes in the adult, including energy balance, neurogenesis, and the immune response. The retinoid used as a cofactor in the visual cycle is 11-cis-retinal (11cRAL). The non-visual cycle effects of retinol are mediated by retinoic acid (RA), generated by two-step conversion from retinol (Napoli 2012). All-trans-retinoic acid (atRA) is the major activated metabolite of retinol. An isomer, 9-cis-retinoic acid (9cRA) has biological activity, but has not been detected in vivo, except in the pancreas. An alternative route involves BCO1 cleavage of carotenoids into retinal, which is then reduced into retinol in the intestine (Harrison 2012). The two isomers of RA serve as ligands for retinoic acid receptors (RAR) that regulate gene expression. (Das et al. 2014). RA is catabolised to oxidised metabolites such as 4-hydroxy-, 18-hydroxy- or 4-oxo-RA by CYP family enzymes, these metabolites then becoming substrates for Phase II conjugation enzymes (Ross & Zolfaghari 2011) [[https://reactome.org/PathwayBrowser/#/R-HSA-5362517&PATH=R-HSA-162582,R-HSA-9006931](https://reactome.org/PathwayBrowser/#/R-HSA-5362517&PATH=R-HSA-162582,R-HSA-9006931)].

**The citric acid (TCA) cycle and respiratory electron transport:** The metabolism of pyruvate provides one source of acetyl-CoA which enters the citric acid (TCA, tricarboxylic acid) cycle to generate energy and the reducing equivalent NADH. These reducing equivalents are re-oxidized back to NAD+ in the electron transport chain (ETC), coupling this process with the export of protons across the inner mitochondrial membrane. The chemiosmotic gradient created is used to drive ATP synthesis.[[https://reactome.org/PathwayBrowser/#/R-HSA-1428517](https://reactome.org/PathwayBrowser/#/R-HSA-1428517)]

## GO terms:

**acetyl-CoA biosynthetic process from pyruvate** [The chemical reactions and pathways resulting in the formation of acetyl-CoA from pyruvate. GO:0006086]

**cellular response to fatty acid** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a fatty acid stimulus. GO:0071398]

**cellular response to starvation** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of deprivation of nourishment. GO:0009267]

**glucose homeostasis** [Any process involved in the maintenance of an internal steady state of glucose within an organism or cell. GO:0042593]

**glucose metabolic process** [The chemical reactions and pathways involving glucose, the aldohexose gluco-hexose. D-glucose is dextrorotatory and is sometimes known as dextrose; it is an important source of energy for living organisms and is found free as well as combined in homo- and hetero-oligosaccharides and polysaccharides. GO:0006006]

**insulin receptor signaling pathway** [The series of molecular signals generated as a consequence of the insulin receptor binding to insulin. GO:0008286]

**negative regulation of anoikis** [Any process that stops, prevents or reduces the frequency, rate or extent of anoikis. GO:2000811]

**phosphorylation** [The process of introducing a phosphate group into a molecule, usually with the formation of a phosphoric ester, a phosphoric anhydride or a phosphoric amide. GO:0016310]

**protein phosphorylation** [The process of introducing a phosphate group on to a protein. GO:0006468]

**reactive oxygen species metabolic process** [The chemical reactions and pathways involving a reactive oxygen species, any molecules or ions formed by the incomplete one-electron reduction of oxygen. They contribute to the microbicidal activity of phagocytes, regulation of signal transduction and gene expression, and the oxidative damage to biopolymers. GO:0072593]

**regulation of acetyl-CoA biosynthetic process from pyruvate** [Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of acetyl-CoA from pyruvate. GO:0010510]

**regulation of bone resorption** [Any process that modulates the frequency, rate or extent of bone tissue loss (resorption). GO:0045124]

**regulation of cellular ketone metabolic process** [Any process that modulates the chemical reactions and pathways involving any of a class of organic compounds that contain the carbonyl group, CO, and in which the carbonyl group is bonded only to carbon atoms. The general formula for a ketone is RCOR, where R and R are alkyl or aryl groups. GO:0010565]

**regulation of fatty acid biosynthetic process** [Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of fatty acids, any of the aliphatic monocarboxylic acids that can be liberated by hydrolysis from naturally occurring fats and oils. GO:0042304]

**regulation of fatty acid oxidation** [Any process that modulates the frequency, rate or extent of fatty acid oxidation. GO:0046320]

**regulation of glucose metabolic process** [Any process that modulates the rate, frequency or extent of glucose metabolism. Glucose metabolic processes are the chemical reactions and pathways involving glucose, the aldohexose gluco-hexose. GO:0010906]

**regulation of pH** [Any process involved in the maintenance of an internal equilibrium of hydrogen ions, thereby modulating the internal pH, within an organism or cell. GO:0006885]

**response to starvation** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a starvation stimulus, deprivation of nourishment. GO:0042594]

## MSigDB Signatures:

**WP_NUCLEAR_RECEPTORS_META_PATHWAY**: Nuclear receptors meta pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NUCLEAR_RECEPTORS_META_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NUCLEAR_RECEPTORS_META_PATHWAY.html)

**WP_AMINO_ACID_METABOLISM**: Amino acid metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_AMINO_ACID_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_AMINO_ACID_METABOLISM.html)

**REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS**: Signaling by Nuclear Receptors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS.html)

**WP_ESTROGEN_RECEPTOR_PATHWAY**: Estrogen receptor pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ESTROGEN_RECEPTOR_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ESTROGEN_RECEPTOR_PATHWAY.html)

**REACTOME_SIGNALING_BY_RETINOIC_ACID**: Signaling by Retinoic Acid [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_RETINOIC_ACID.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_RETINOIC_ACID.html)

**REACTOME_PYRUVATE_METABOLISM**: Pyruvate metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PYRUVATE_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PYRUVATE_METABOLISM.html)

**REACTOME_PYRUVATE_METABOLISM_AND_CITRIC_ACID_TCA_CYCLE**: Pyruvate metabolism and Citric Acid (TCA) cycle [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PYRUVATE_METABOLISM_AND_CITRIC_ACID_TCA_CYCLE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PYRUVATE_METABOLISM_AND_CITRIC_ACID_TCA_CYCLE.html)

**REACTOME_THE_CITRIC_ACID_TCA_CYCLE_AND_RESPIRATORY_ELECTRON_TRANSPORT**: The citric acid (TCA) cycle and respiratory electron transport [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_THE_CITRIC_ACID_TCA_CYCLE_AND_RESPIRATORY_ELECTRON_TRANSPORT.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_THE_CITRIC_ACID_TCA_CYCLE_AND_RESPIRATORY_ELECTRON_TRANSPORT.html)
