
## **Pathways:**

-   **Glycolysis**: The reactions of glycolysis (e.g., van Wijk and van Solinge 2005) convert glucose 6-phosphate to pyruvate. The entire process is cytosolic. Glucose 6-phosphate is reversibly isomerized to form fructose 6-phosphate. Phosphofructokinase 1 catalyzes the physiologically irreversible phosphorylation of fructose 6-phosphate to form fructose 1,6-bisphosphate. In six reversible reactions, fructose 1,6-bisphosphate is converted to two molecules of phosphoenolpyruvate and two molecules of NAD+ are reduced to NADH + H+. Each molecule of phosphoenolpyruvate reacts with ADP to form ATP and pyruvate in a physiologically irreversible reaction. Under aerobic conditions the NADH +H+ can be reoxidized to NAD+ via electron transport to yield additional ATP, while under anaerobic conditions or in cells lacking mitochondria NAD+ can be regenerated via the reduction of pyruvate to lactate. [[https://reactome.org/PathwayBrowser/#/R-HSA-70171](https://reactome.org/PathwayBrowser/#/R-HSA-70171)].
-   **ChREBP activates metabolic gene expression**: ChREBP (Carbohydrate Response Element Binding Protein) is a large multidomain protein containing a nuclear localization signal near its amino terminus, polyproline domains, a basic helix-loop-helix-leucine zipper domain, and a leucine-zipper-like domain (Uyeda et al., 2002). Its dephosphorylation in response to molecular signals associated with the well-fed state allows it to enter the nucleus, interact with MLX protein, and bind to ChRE DNA sequence motifs near Acetyl-CoA carboxylase, Fatty acid synthase, and Pyruvate kinase (L isoform) genes (Ishi et al.2004). This sequence of events is outlined schematically in the picture below (adapted from Kawaguchi et al. (2001) - copyright (2001) National Academy of Sciences, U.S.A.) [[https://reactome.org/PathwayBrowser/#/R-HSA-163765](https://reactome.org/PathwayBrowser/#/R-HSA-163765)].
-   **Regulation of gene expression in beta cells**: Two transcription factors, PDX1 and HNF1A, play key roles in maintaining the gene expression pattern characteristic of mature beta cells in the endocrine pancreas. Targets of these regulatory molecules include genes encoding insulin, the GLUT2 glucose transporter, the liver- (and pancreas) specific form of pyruvate kinase and other transcription factors including HNF4A, HNF4G, and FOXA3. PDX1 expression in turn is controlled by the activities of MAFA, FOXA2, and PAX6, and negatively regulated via AKT (Chakrabarti and Mirmira 2003; Servitja and Ferrer 2004) [[https://reactome.org/PathwayBrowser/#/R-HSA-210745](https://reactome.org/PathwayBrowser/#/R-HSA-210745)].
-   **SARS-CoV-1-host interactions**: Coronaviruses are a group of enveloped viruses with single-stranded, positive-sense RNA genomes. Each of the steps of viral replication - attachment and entry, translation of viral replicase, genome transcription and replication, translation of structural proteins, and virion assembly and release - involves host factors. These interactions can cause alterations in cellular structure and physiology, and activate host stress responses, autophagy, cell death, and processes of innate immunity (Fung TS & Liu DX 2019). This Reactome module describes molecular mechanisms by which severe acute respiratory syndrome coronavirus type 1 (SARS-CoV-1) modulates host cell death pathways, innate immune responses, translation, intracellular signaling and regulatory pathways, and PDZ-mediated cell-cell junctions [[https://reactome.org/PathwayBrowser/#/R-HSA-9692914](https://reactome.org/PathwayBrowser/#/R-HSA-9692914)].

## GO terms:

**cellular response to epinephrine stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an epinephrine stimulus. Epinephrine is a catecholamine that has the formula C9H13NO3; it is secreted by the adrenal medulla to act as a hormone, and released by certain neurons to act as a neurotransmitter active in the central nervous system.|Note that epinephrine and norepinephrine are ligands for the same receptors, and there are multiple adrenergic receptors. GO:0071872]

**cellular response to insulin stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an insulin stimulus. Insulin is a polypeptide hormone produced by the islets of Langerhans of the pancreas in mammals, and by the homologous organs of other organisms. GO:0032869]

**glycolytic process** [The chemical reactions and pathways resulting in the breakdown of a carbohydrate into pyruvate, with the concomitant production of a small amount of ATP and the reduction of NAD(P) to NAD(P)H. Glycolysis begins with the metabolism of a carbohydrate to generate products that can enter the pathway and ends with the production of pyruvate. Pyruvate may be converted to acetyl-coenzyme A, ethanol, lactate, or other small molecules. GO:0006096]

**phosphorylation** [The process of introducing a phosphate group into a molecule, usually with the formation of a phosphoric ester, a phosphoric anhydride or a phosphoric amide. GO:0016310]

**pyruvate biosynthetic process** [The chemical reactions and pathways resulting in the formation of pyruvate, 2-oxopropanoate. GO:0042866]

**response to ATP** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an ATP (adenosine 5'-triphosphate) stimulus. GO:0033198]

**response to cAMP** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cAMP (cyclic AMP, adenosine 3',5'-cyclophosphate) stimulus. GO:0051591]

**response to glucose** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a glucose stimulus. GO:0009749]

**response to hypoxia** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating lowered oxygen tension. Hypoxia, defined as a decline in O2 levels below normoxic levels of 20.8 - 20.95%, results in metabolic adaptation at both the cellular and organismal level.|Note that this term should not be confused with 'response to anoxia ; GO:0034059'. Note that in laboratory studies, hypoxia is typically studied at O2 concentrations ranging from 0.1 - 5%. GO:0001666]

**response to metal ion** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a metal ion stimulus. GO:0010038]

**response to nutrient** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a nutrient stimulus. GO:0007584]

**response to other organism** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from another living organism. GO:0051707]

## MSigDB Signatures:

**WP_NONALCOHOLIC_FATTY_LIVER_DISEASE**: Nonalcoholic fatty liver disease [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NONALCOHOLIC_FATTY_LIVER_DISEASE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NONALCOHOLIC_FATTY_LIVER_DISEASE.html)

**KEGG_GLYCOLYSIS_GLUCONEOGENESIS**: Glycolysis / Gluconeogenesis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_GLYCOLYSIS_GLUCONEOGENESIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_GLYCOLYSIS_GLUCONEOGENESIS.html)

**REACTOME_GLUCOSE_METABOLISM**: Glucose metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_GLUCOSE_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_GLUCOSE_METABOLISM.html)

**REACTOME_INFECTIOUS_DISEASE**: Infectious disease [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INFECTIOUS_DISEASE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INFECTIOUS_DISEASE.html)

**REACTOME_GLYCOLYSIS**: Glycolysis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_GLYCOLYSIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_GLYCOLYSIS.html)

**KEGG_PYRUVATE_METABOLISM**: Pyruvate metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_PYRUVATE_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_PYRUVATE_METABOLISM.html)

**KEGG_MEDICUS_REFERENCE_GLYCOLYSIS**: Pathway Definition from KEGG: Glc-6P -- GPI >> PFK >> ALDO >> GAPDH >> PGK1/2 >> (PGAM,BPGM) >> ENO1/2/3/4 >> (PKLR,PKM) >> (LDH,LDHAL6) -> Lactate [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_GLYCOLYSIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_GLYCOLYSIS.html)

**WP_GLYCOLYSIS_AND_GLUCONEOGENESIS**: Glycolysis and gluconeogenesis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_GLYCOLYSIS_AND_GLUCONEOGENESIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_GLYCOLYSIS_AND_GLUCONEOGENESIS.html)

**REACTOME_METABOLISM_OF_CARBOHYDRATES**: Metabolism of carbohydrates [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_METABOLISM_OF_CARBOHYDRATES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_METABOLISM_OF_CARBOHYDRATES.html)

**REACTOME_INTEGRATION_OF_ENERGY_METABOLISM**: Integration of energy metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INTEGRATION_OF_ENERGY_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INTEGRATION_OF_ENERGY_METABOLISM.html)

**KEGG_PURINE_METABOLISM**: Purine metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_PURINE_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_PURINE_METABOLISM.html)

**REACTOME_VIRAL_INFECTION_PATHWAYS**: Viral Infection Pathways [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_VIRAL_INFECTION_PATHWAYS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_VIRAL_INFECTION_PATHWAYS.html)

**KEGG_INSULIN_SIGNALING_PATHWAY**: Insulin signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_INSULIN_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_INSULIN_SIGNALING_PATHWAY.html)

**REACTOME_CHREBP_ACTIVATES_METABOLIC_GENE_EXPRESSION**: ChREBP activates metabolic gene expression [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CHREBP_ACTIVATES_METABOLIC_GENE_EXPRESSION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CHREBP_ACTIVATES_METABOLIC_GENE_EXPRESSION.html)

**KEGG_TYPE_II_DIABETES_MELLITUS**: Type II diabetes mellitus [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_TYPE_II_DIABETES_MELLITUS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_TYPE_II_DIABETES_MELLITUS.html)

**WP_METABOLIC_EPILEPTIC_DISORDERS**: Metabolic Epileptic Disorders [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_METABOLIC_EPILEPTIC_DISORDERS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_METABOLIC_EPILEPTIC_DISORDERS.html)

**REACTOME_SARS_COV_1_INFECTION**: SARS-CoV-1 Infection [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_1_INFECTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_1_INFECTION.html)

**REACTOME_SARS_COV_INFECTIONS**: SARS-CoV Infections [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_INFECTIONS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_INFECTIONS.html)

**REACTOME_DEVELOPMENTAL_BIOLOGY**: Developmental Biology [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEVELOPMENTAL_BIOLOGY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEVELOPMENTAL_BIOLOGY.html)

**WP_CLEAR_CELL_RENAL_CELL_CARCINOMA_PATHWAYS**: Clear cell renal cell carcinoma pathways [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_CLEAR_CELL_RENAL_CELL_CARCINOMA_PATHWAYS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_CLEAR_CELL_RENAL_CELL_CARCINOMA_PATHWAYS.html)

**KEGG_MATURITY_ONSET_DIABETES_OF_THE_YOUNG**: Maturity onset diabetes of the young [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MATURITY_ONSET_DIABETES_OF_THE_YOUNG.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MATURITY_ONSET_DIABETES_OF_THE_YOUNG.html)
