
## **Pathways:**

**Amplification and expansion of oncogenic pathways as metastatic traits:** The majority of cancer cells released from tumors die off, so cancer biologists are trying to figure out exactly what gives certain cells the ability to colonize other distant organs. Specific genes and mediators of metastasis have been identified, but it remains mostly unknown how cancer cells acquire these traits. Metastatic traits acquired by a quantitative gain in pathway output: These pathways demonstrate metastatic traits acquired by a quantitative gain in pathway output. The PI3K-Akt signaling pathway, which is augmented by VCAM-1 and SRC, leads to increased cell survival, a significant metastatic trait. Similarly, TCF augments the output of the NOTCH and, along with periostin, Wnt signaling pathways. As the signaling of these pathways increases, the metastatic and oncogenic potential of the cell also increase. Metastatic traits acquired by a qualitative expansion of pathway output: This pathway demonstrates metastatic traits acquired by a qualitative expansion of pathway output. Loss of the von Hippel-Lindau tumor suppressor (VHL) in renal cell carcinoma leads to increased activation of hypoxia-inducible transcription factors (HIFs). Histone H3K27 and CYTIP give the VHL-HIF pathway access to new target genes. Each of these new target genes, in this case CXCR4, VEGFA, and CYTIP, lead to an increase in a metastatic trait. Here, the level of metastatic fitness is not linearly proportional to pathway activity; rather, the pathway activates an additional set of factors that affect metastatic fitness. [[https://www.wikipathways.org/pathways/WP3678.html](https://www.wikipathways.org/pathways/WP3678.html)].

**Hypothesized pathways in pathogenesis of cardiovascular disease:** The pathways hypothesized to be involved in cardiovascular diseases begin with LTBPs and Fibrillins activating a TGFBR complex. The complex can begin the canonical TGFB pathway involving SMAD proteins that target gene expression for proteins involved in endocardial and epicardial EMT, neural crest migration, ECM remodeling, cell differentiation, development and maintenance of cardiovascular structure and function. The non-canonical TGFB pathway involves the calcium-calneurin signaling pathway that also affects the previously mentioned functions. the TGFBR complex also activates SHCA and Tak1 which promote the function of a complex (ERK1/2, JNK1, and p38) to regulate the previously mentioned cell functions and influence the development of cardiovascular diseases. These diseases are additionally influenced by a signalling pathway involving the activation of TGFB ligands, receptors, activators, and effectors by ANG2/AT1/2R complex. This pathway is based on figure 1 from Doetschman et al. [[https://www.wikipathways.org/pathways/WP3668.html](https://www.wikipathways.org/pathways/WP3668.html)].

## GO terms:

**bone regeneration** [The regrowth of bone following its loss or destruction. GO:1990523]

**cell adhesion** [The attachment of a cell, either to another cell or to an underlying substrate such as the extracellular matrix, via cell adhesion molecules. GO:0007155]

**cellular response to fibroblast growth factor stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an fibroblast growth factor stimulus. GO:0044344]

**cellular response to transforming growth factor beta stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a transforming growth factor beta stimulus. GO:0071560]

**cellular response to tumor necrosis factor** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a tumor necrosis factor stimulus. GO:0071356]

**cellular response to vitamin K** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a vitamin K stimulus. GO:0071307]

**extracellular matrix organization** [A process that is carried out at the cellular level which results in the assembly, arrangement of constituent parts, or disassembly of an extracellular matrix. GO:0030198]

**negative regulation of cell-matrix adhesion** [Any process that stops, prevents, or reduces the rate or extent of cell adhesion to the extracellular matrix. GO:0001953]

**negative regulation of substrate adhesion-dependent cell spreading** [Any process that stops, prevents or reduces the frequency, rate or extent of substrate adhesion-dependent cell spreading. GO:1900025]

**neuron projection extension** [Long distance growth of a single neuron projection involved in cellular development. A neuron projection is a prolongation or process extending from a nerve cell, e.g. an axon or dendrite. GO:1990138]

**positive regulation of chemokine (C-X-C motif) ligand 2 production** [Any process that activates or increases the frequency, rate or extent of chemokine (C-X-C motif) ligand 2 production. GO:2000343]

**positive regulation of smooth muscle cell migration** [Any process that activates, maintains or increases the frequency, rate or extent of smooth muscle cell migration. GO:0014911]

**regulation of Notch signaling pathway** [Any process that modulates the frequency, rate or extent of the Notch signaling pathway. GO:0008593]

**regulation of systemic arterial blood pressure** [The process that modulates the force with which blood travels through the systemic arterial circulatory system. The process is controlled by a balance of processes that increase pressure and decrease pressure. GO:0003073]

**response to estradiol** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of stimulus by estradiol, a C18 steroid hormone hydroxylated at C3 and C17 that acts as a potent estrogen. GO:0032355]

**response to hypoxia** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating lowered oxygen tension. Hypoxia, defined as a decline in O2 levels below normoxic levels of 20.8 - 20.95%, results in metabolic adaptation at both the cellular and organismal level.|Note that this term should not be confused with 'response to anoxia ; GO:0034059'. Note that in laboratory studies, hypoxia is typically studied at O2 concentrations ranging from 0.1 - 5%. GO:0001666]

**response to mechanical stimulus** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a mechanical stimulus. GO:0009612]

**response to muscle activity** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a muscle activity stimulus. GO:0014850]

**tissue development** [The process whose specific outcome is the progression of a tissue over time, from its formation to the mature structure. GO:0009888]

## MSigDB Signatures:

**WP_HYPOTHESIZED_PATHWAYS_IN_PATHOGENESIS_OF_CARDIOVASCULAR_DISEASE**: Hypothesized pathways in pathogenesis of cardiovascular disease [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_HYPOTHESIZED_PATHWAYS_IN_PATHOGENESIS_OF_CARDIOVASCULAR_DISEASE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_HYPOTHESIZED_PATHWAYS_IN_PATHOGENESIS_OF_CARDIOVASCULAR_DISEASE.html)
