
## **Pathways:**

-   **Arachidonic acid metabolism:** Eicosanoids, oxygenated, 20-carbon fatty acids, are autocrine and paracrine signaling molecules that modulate physiological processes including pain, fever, inflammation, blood clot formation, smooth muscle contraction and relaxation, and the release of gastric acid. Eicosanoids are synthesized in humans primarily from arachidonic acid (all-cis 5,8,11,14-eicosatetraenoic acid) that is released from membrane phospholipids. Once released, arachidonic acid is acted on by prostaglandin G/H synthases (PTGS, also known as cyclooxygenases (COX)) to form prostaglandins and thromboxanes, by arachidonate lipoxygenases (ALOX) to form leukotrienes, epoxygenases (cytochrome P450s and epoxide hydrolase) to form epoxides such as 15-eicosatetraenoic acids, and omega-hydrolases (cytochrome P450s) to form hydroxyeicosatetraenoic acids (Buczynski et al. 2009, Vance & Vance 2008). Levels of free arachidonic acid in the cell are normally very low so the rate of synthesis of eicosanoids is determined primarily by the activity of phospholipase A2, which mediates phospholipid cleavage to generate free arachidonic acid. The enzymes involved in arachidonic acid metabolism are typically constitutively expressed so the subset of these enzymes expressed by a cell determines the range of eicosanoids it can synthesize. Eicosanoids are unstable, undergoing conversion to inactive forms with half-times under physiological conditions of seconds or minutes. Many of these reactions appear to be spontaneous [[https://reactome.org/PathwayBrowser/#/R-HSA-2142753&PATH=R-HSA-1430728,R-HSA-556833,R-HSA-8978868](https://reactome.org/PathwayBrowser/#/R-HSA-2142753&PATH=R-HSA-1430728,R-HSA-556833,R-HSA-8978868)].
-   **COX reactions:** Arachidonic acid (AA) is a 20-carbon unsaturated fatty acid which is present in the lipid bilayer of all mammalian cells. AA is released from the membrane by phospholipases, thus making it available for conversion to bioactive lipids. The cyclooxygenase pathway is one of three pathways (the others being lipoxygenase and P450 monooxygenase pathways) that perform this conversion. The enzyme that acts in the cyclooxygenase pathway is called cyclooxygenase (COX) or prostaglandin H synthase (PGHS). PGHS exhibits a dual catalytic activity, a cyclooxygenase and a peroxidase. The cyclooxygenase catalyzes the initial conversion of AA to an intermediate, prostaglandin G2 (PGG2) whilst the peroxidase converts PGG2 to prostaglandin H2 (PGH2) via a two-electron reduction. PGH2 is the intermediate for products that play critical roles in immune function regulation, kidney development and mucosal integrity of the GI tract. PGHS exists in two isoforms, 1 and 2 and both forms can perform the above reactions. Form 1 is constitutively expressed in most tissues and is involved in performing normal physiological functions. Form 2, in contrast, is inducible and is involved in critical steps of rheumatic disease, inflammation and tumorigenesis. [[https://reactome.org/PathwayBrowser/#/R-HSA-140180](https://reactome.org/PathwayBrowser/#/R-HSA-140180)].
-   **Fatty acid metabolism:** The synthesis and breakdown of fatty acids are a central part of human energy metabolism, and the eicosanoid class of fatty acid derivatives regulate diverse processes in the body (Vance & Vance 2008 - URL). Processes annotated in this module include the synthesis of fatty acids from acetyl-CoA, mitochondrial and peroxisomal breakdown of fatty acids, and the metabolism of eicosanoids and related molecules. [[https://reactome.org/PathwayBrowser/#/R-HSA-8978868&PATH=R-HSA-1430728,R-HSA-556833](https://reactome.org/PathwayBrowser/#/R-HSA-8978868&PATH=R-HSA-1430728,R-HSA-556833)].
-   **Phase I - Functionalization of compounds:** Phase 1 of metabolism is concerned with functionalization, that is the introduction or exposure of functional groups on the chemical structure of a compound. This provides a 'handle' for phase 2 conjugating species with which to react with. Many xenobiotics are lipophilic and almost chemically inert (e.g., PAHs) so would not necessarily undergo a phase 2 reaction. Making them more chemically reactive would facilitate their excretion but also increases their chance of reacting with cellular macromolecules (e.g., proteins, DNA). There is a fine balance between producing a more reactive metabolite and conjugation reactions. There are two groups of enzymes in phase 1 - oxidoreductases and hydrolases. Oxidoreductases introduce an oxygen atom into or remove electrons from their substrates. The major oxidoreductase enzyme system is called the P450 monooxygenases. Other systems include flavin-containing monooxygenases (FMO), cyclooxygenases (COX) and monoamine oxidases (MAO). Hydrolases hydrolyze esters, amides, epoxides and glucuronides. [[https://reactome.org/PathwayBrowser/#/R-HSA-211945](https://reactome.org/PathwayBrowser/#/R-HSA-211945)].
-   **Synthesis of Prostaglandins (PG) and Thromboxanes (TX):** The bioactive prostaglandin (PG) signaling molecules, including PGA2, PGE2, PGF2a, and PGI2 (prostacyclin) are synthesized from arachidonic acid and its products by various prostaglandin synthase type enzymes. Prostaglandin H2 (PGH2) is the starting point for the synthesis of Thromboxanes (TXs) (Buczynski et al. 2009, Vance & Vance 2008). PGs and TXs are collectively known as the prostanoids. Two enzymes, PTGS1 and 2 (COX1 and 2) both catalyze the two-step conversion of arachidonic acid to PGH2. PTGS1 is constitutively expressed in many cell types while PTGS2 is induced in response to stress and mediates the syntheses of prostaglandins associated with pain, fever, and inflammation. Aspirin irreversibly inactivates both enzymes (though it acts more efficiently on PTGS1), explaining both its anti-inflammatory effects and side effects like perturbed gastric acid secretion. Drugs like celecoxib, by specifically inhibiting PTGS2, have a strong anti-inflammatory effect with fewer side effects. These PTGS2-specific drugs, however, probably because of their effects on the balance of prostaglandin synthesis in platelets and endothelial cells, can also promote blood clot formation (Buczynski et al. 2009; Stables & Gilroy 2011). [[https://reactome.org/PathwayBrowser/#/R-HSA-2162123](https://reactome.org/PathwayBrowser/#/R-HSA-2162123)].

## GO terms:

**cellular oxidant detoxification** [Any process carried out at the cellular level that reduces or removes the toxicity superoxide radicals or hydrogen peroxide. GO:0098869]

**cyclooxygenase pathway** [The chemical reactions and pathways by which prostaglandins are formed from arachidonic acid, and in which prostaglandin-endoperoxide synthase (cyclooxygenase) catalyzes the committed step in the conversion of arachidonic acid to the prostaglandin-endoperoxides PGG2 and PGH2. GO:0019371]

**learning** [Any process in an organism in which a relatively long-lasting adaptive behavioral change occurs as the result of experience. GO:0007612]

**maintenance of blood-brain barrier** [Maintaining the structure and function of the blood-brain barrier, thus ensuring specific regulated transport of substances (e.g. macromolecules, small molecules, ions) into the brain, and out of the brain into the blood circulation.|Homeostasis and maintenance processes are regulatory processes, therefore, regulation child terms, such as: regulation of maintenance of blood-brain barrier, should not exist for these terms.  
Instead, for capturing regulation at the blood-brain barrier, consider using the part_of child term: regulation of blood-brain barrier permeability. GO:0035633]

**memory** [The activities involved in the mental information processing system that receives (registers), modifies, stores, and retrieves informational stimuli. The main stages involved in the formation and retrieval of memory are encoding (processing of received information by acquisition), storage (building a permanent record of received information as a result of consolidation) and retrieval (calling back the stored information and use it in a suitable way to execute a given task). GO:0007613]

**negative regulation of epinephrine secretion** [Any process that stops, prevents, or reduces the frequency, rate or extent of the regulated release of epinephrine. GO:0032811]

**negative regulation of norepinephrine secretion** [Any process that decreases the frequency, rate or extent of the regulated release of norepinephrine. GO:0010700]

**positive regulation of smooth muscle contraction** [Any process that activates or increases the frequency, rate or extent of smooth muscle contraction. GO:0045987]

**positive regulation of vasoconstriction** [Any process that activates or increases the frequency, rate or extent of vasoconstriction. GO:0045907]

**prostaglandin biosynthetic process** [The chemical reactions and pathways resulting in the formation of prostaglandins, any of a group of biologically active metabolites which contain a cyclopentane ring. GO:0001516]

**prostaglandin metabolic process** [The chemical reactions and pathways involving prostaglandins, any of a group of biologically active metabolites which contain a cyclopentane ring due to the formation of a bond between two carbons of a fatty acid. They have a wide range of biological activities. GO:0006693]

**regulation of blood pressure** [Any process that modulates the force with which blood travels through the circulatory system. The process is controlled by a balance of processes that increase pressure and decrease pressure. GO:0008217]

**regulation of cell population proliferation** [Any process that modulates the frequency, rate or extent of cell proliferation. GO:0042127]

**response to corticosterone** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a corticosterone stimulus. Corticosterone is a 21 carbon steroid hormone of the corticosteroid type, produced in the cortex of the adrenal glands. In many species, corticosterone is the principal glucocorticoid, involved in regulation of fuel metabolism, immune reactions, and stress responses. GO:0051412]

**response to fatty acid** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a fatty acid stimulus. GO:0070542]

**response to organonitrogen compound** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an organonitrogen stimulus. An organonitrogen compound is formally a compound containing at least one carbon-nitrogen bond. GO:0010243]

**response to oxidative stress** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of oxidative stress, a state often resulting from exposure to high levels of reactive oxygen species, e.g. superoxide anions, hydrogen peroxide (H2O2), and hydroxyl radicals. GO:0006979]

## MSigDB Signatures:

**WP_EICOSANOID_METABOLISM_VIA_CYCLOOXYGENASES_COX**: Eicosanoid metabolism via cyclooxygenases COX [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_EICOSANOID_METABOLISM_VIA_CYCLOOXYGENASES_COX.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_EICOSANOID_METABOLISM_VIA_CYCLOOXYGENASES_COX.html)

**REACTOME_BIOLOGICAL_OXIDATIONS**: Biological oxidations [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_BIOLOGICAL_OXIDATIONS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_BIOLOGICAL_OXIDATIONS.html)

**REACTOME_FATTY_ACID_METABOLISM**: Fatty acid metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_FATTY_ACID_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_FATTY_ACID_METABOLISM.html)

**WP_PROSTAGLANDIN_SYNTHESIS_AND_REGULATION**: Prostaglandin synthesis and regulation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PROSTAGLANDIN_SYNTHESIS_AND_REGULATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PROSTAGLANDIN_SYNTHESIS_AND_REGULATION.html)

**BIOCARTA_ACETAMINOPHEN_PATHWAY**: Mechanism of Acetaminophen Activity and Toxicity [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_ACETAMINOPHEN_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_ACETAMINOPHEN_PATHWAY.html)

**KEGG_ARACHIDONIC_ACID_METABOLISM**: Arachidonic acid metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_ARACHIDONIC_ACID_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_ARACHIDONIC_ACID_METABOLISM.html)

**REACTOME_ARACHIDONIC_ACID_METABOLISM**: Arachidonic acid metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ARACHIDONIC_ACID_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ARACHIDONIC_ACID_METABOLISM.html)

**REACTOME_SYNTHESIS_OF_PROSTAGLANDINS_PG_AND_THROMBOXANES_TX**: Synthesis of Prostaglandins (PG) and Thromboxanes (TX) [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SYNTHESIS_OF_PROSTAGLANDINS_PG_AND_THROMBOXANES_TX.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SYNTHESIS_OF_PROSTAGLANDINS_PG_AND_THROMBOXANES_TX.html)

**WP_EICOSANOID_SYNTHESIS**: Eicosanoid synthesis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_EICOSANOID_SYNTHESIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_EICOSANOID_SYNTHESIS.html)
