
## **Pathways:**

**Adherens junctions interactions:** The adherens junctions (AJ) are multiprotein complexes that promote homotypic cell adhesion in nearly all types of tissue by linking membrane and cytoskeletal components at discrete contact regions (reviewed in Hartsock & Nelson 2008; Gumbiner 2005; Ebnet, 2008). The molecular constituents of adherens junctions form adhesive units which are organized into higher order junctional adhesions that create a zipper-like seal between adjacent cells. Junctional adhesions function in epithelial cell polarization and in the coupling of cytoskeletons in adjacent cells that allow coordinated movements. During embryonic development, AJs function in specifying adhesion between cells and contribute in the sorting of different cell types. AJs also regulate cell polarity and shape, promote cell-cell communication and help mediate contact inhibition of cell growth. This module covers transdimerization events involving AJ transmembrane proteins (cadherins and nectins) (Gumbiner 2005; Ebnet 2008; Hartsock & Nelson 2008).[[https://reactome.org/PathwayBrowser/#/R-HSA-418990](https://reactome.org/PathwayBrowser/#/R-HSA-418990)].

**Immunoregulatory interactions between a Lymphoid and a non-Lymphoid cell:** A number of receptors and cell adhesion molecules play a key role in modifying the response of cells of lymphoid origin (such as B-, T- and NK cells) to self and tumor antigens, as well as to pathogenic organisms.

Molecules such as KIRs and LILRs form part of a crucial surveillance system that looks out for any derangement, usually caused by cancer or viral infection, in MHC Class I presentation. Somatic cells are also able to report internal functional impairment by displaying surface stress markers such as MICA. The presence of these molecules on somatic cells is picked up by C-lectin NK immune receptors.

Lymphoid cells are able to regulate their location and movement in accordance to their state of activation, and home in on tissues expressing the appropriate complementary ligands. For example, lymphoid cells may fine tune the presence and concentration of adhesion molecules belonging to the IgSF, Selectin and Integrin class that interact with a number of vascular markers of inflammation.

Furthermore, there are a number of avenues through which lymphoid cells may interact with antigen. This may be presented directly to a specific T-cell receptor in the context of an MHC molecule. Antigen-antibody complexes may anchor to the cell via a small number of lymphoid-specific Fc receptors that may, in turn, influence cell function further. Activated complement factor C3d binds to both antigen and to cell surface receptor CD21. In such cases, the far-reaching influence of CD19 on B-lymphocyte function is tempered by its interaction with CD21 [[https://reactome.org/PathwayBrowser/#/R-HSA-198933](https://reactome.org/PathwayBrowser/#/R-HSA-198933)].

**Nectin/Necl trans heterodimerization:** Nectins and Nectin-like molecules (Necls) also undergo trans-heterophilic interactions to interact with other nectin or Necl family members. Besides these trans interactions among nectins and nectin-like family members, trans-homophilic interactions have also been described between nectins or Necls with other immunoglobulin-superfamily members like CD96, CD226 and CRTAM (Sakisaka et al., 2007; Takai et al., 2008). It should be noted that some of these interactions might not exist in epithelial cell-cell contacts but may occur in other cell-cell adhesion systems.[[https://reactome.org/PathwayBrowser/#/R-HSA-420597](https://reactome.org/PathwayBrowser/#/R-HSA-420597)].

## GO terms:

**cell migration** [The controlled self-propelled movement of a cell from one site to a destination guided by molecular cues. GO:0016477]

**cell-cell adhesion** [The attachment of one cell to another cell via adhesion molecules. GO:0098609]

**heterophilic cell-cell adhesion via plasma membrane cell adhesion molecules** [The attachment of an adhesion molecule in one cell to a nonidentical adhesion molecule in an adjacent cell. GO:0007157]

**homophilic cell adhesion via plasma membrane adhesion molecules** [The attachment of a plasma membrane adhesion molecule in one cell to an identical molecule in an adjacent cell. GO:0007156]

**positive regulation of natural killer cell mediated cytotoxicity** [Any process that activates or increases the frequency, rate or extent of natural killer cell mediated cytotoxicity. GO:0045954]

**positive regulation of natural killer cell mediated cytotoxicity directed against tumor cell target** [Any process that activates or increases the frequency, rate, or extent of natural killer cell mediated cytotoxicity directed against tumor cell target. GO:0002860]

**susceptibility to T cell mediated cytotoxicity** [The process of causing a cell to become susceptible to T cell mediated cytotoxicity. GO:0060370]

**susceptibility to natural killer cell mediated cytotoxicity** [The process of causing a cell to become susceptible to natural killer cell mediated cytotoxicity.|Note that this term is intended for cell-surface molecules on a target cell which interact with activating receptors on a natural killer cell to promote natural killer cell mediated cytotoxicity. GO:0042271]

**viral entry into host cell** [The process that occurs after viral attachment by which a virus, or viral nucleic acid, breaches the plasma membrane or cell envelope and enters the host cell. The process ends when the viral nucleic acid is released into the host cell cytoplasm.|Viral attachment to the host cell is not part of viral entry in GO because virus attachment does not always lead to viral entry: attachment can also result in the virion being carried by the host cell to another location. GO:0046718]

## MSigDB Signatures:

**ACEVEDO_LIVER_TUMOR_VS_NORMAL_ADJACENT_TISSUE_DN**: Genes down-regulated in liver tumor compared to the normal adjacent tissue. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ACEVEDO_LIVER_TUMOR_VS_NORMAL_ADJACENT_TISSUE_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ACEVEDO_LIVER_TUMOR_VS_NORMAL_ADJACENT_TISSUE_DN.html)

**STONER_ESOPHAGEAL_CARCINOGENESIS_UP**: Genes up-regulated in esophagus by the carcinogen NMBA [PubChem=13643] and brought back to normal by a diet with PEITC [PubChem=16741] or black raspberries. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/STONER_ESOPHAGEAL_CARCINOGENESIS_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/STONER_ESOPHAGEAL_CARCINOGENESIS_UP.html)

**REACTOME_ADAPTIVE_IMMUNE_SYSTEM**: Adaptive Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ADAPTIVE_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ADAPTIVE_IMMUNE_SYSTEM.html)

**AMIT_SERUM_RESPONSE_480_MCF10A**: Genes whose expression peaked at 480 min after stimulation of MCF10A cells with serum. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_SERUM_RESPONSE_480_MCF10A.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_SERUM_RESPONSE_480_MCF10A.html)

**AMIT_SERUM_RESPONSE_40_MCF10A**: Genes whose expression peaked at 40 min after stimulation of MCF10A cells with serum. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_SERUM_RESPONSE_40_MCF10A.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_SERUM_RESPONSE_40_MCF10A.html)

**PID_NECTIN_PATHWAY**: Nectin adhesion pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_NECTIN_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_NECTIN_PATHWAY.html)

**PUJANA_BRCA1_PCC_NETWORK**: Genes constituting the BRCA1-PCC network of transcripts whose expression positively correlated (Pearson correlation coefficient, PCC >= 0.4) with that of BRCA1 [GeneID=672] across a compendium of normal tissues. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PUJANA_BRCA1_PCC_NETWORK.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PUJANA_BRCA1_PCC_NETWORK.html)

**REACTOME_NECTIN_NECL_TRANS_HETERODIMERIZATION**: Nectin/Necl trans heterodimerization [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NECTIN_NECL_TRANS_HETERODIMERIZATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NECTIN_NECL_TRANS_HETERODIMERIZATION.html)

**REACTOME_CELL_CELL_COMMUNICATION**: Cell-Cell communication [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELL_CELL_COMMUNICATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELL_CELL_COMMUNICATION.html)

**AMIT_EGF_RESPONSE_480_HELA**: Genes whose expression peaked at 480 min after stimulation of HeLa cells with EGF [GeneID=1950]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_EGF_RESPONSE_480_HELA.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_EGF_RESPONSE_480_HELA.html)

**REACTOME_CELL_JUNCTION_ORGANIZATION**: Cell junction organization [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELL_JUNCTION_ORGANIZATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELL_JUNCTION_ORGANIZATION.html)

**RUTELLA_RESPONSE_TO_HGF_VS_CSF2RB_AND_IL4_DN**: Genes down-regulated in peripheral blood mononucleocytes by HGF [GeneID=3082] compared to those regulated by CSF2RB (GM-CSF) and IL4 [GeneID=1437;3565]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_VS_CSF2RB_AND_IL4_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_VS_CSF2RB_AND_IL4_DN.html)

**REACTOME_ADHERENS_JUNCTIONS_INTERACTIONS**: Adherens junctions interactions [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ADHERENS_JUNCTIONS_INTERACTIONS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ADHERENS_JUNCTIONS_INTERACTIONS.html)

**RIGGI_EWING_SARCOMA_PROGENITOR_UP**: Genes up-regulated in mesenchymal stem cells (MSC) engineered to express EWS-FLI1 [GeneID=2130;2321] fusion protein. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RIGGI_EWING_SARCOMA_PROGENITOR_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RIGGI_EWING_SARCOMA_PROGENITOR_UP.html)

**REACTOME_CELL_CELL_JUNCTION_ORGANIZATION**: Cell-cell junction organization [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELL_CELL_JUNCTION_ORGANIZATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELL_CELL_JUNCTION_ORGANIZATION.html)

**ZWANG_CLASS_1_TRANSIENTLY_INDUCED_BY_EGF**: Class I of genes transiently induced by EGF [GeneID =1950] in 184A1 cells (mammary epithelium). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZWANG_CLASS_1_TRANSIENTLY_INDUCED_BY_EGF.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZWANG_CLASS_1_TRANSIENTLY_INDUCED_BY_EGF.html)

**RUTELLA_RESPONSE_TO_HGF_UP**: Genes up-regulated in peripheral blood monocytes by HGF [GeneID=3082]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_UP.html)

**KEGG_CELL_ADHESION_MOLECULES_CAMS**: Cell adhesion molecules (CAMs) [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_CELL_ADHESION_MOLECULES_CAMS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_CELL_ADHESION_MOLECULES_CAMS.html)
