
## **Pathways:**

**Antimicrobial peptides:** Antimicrobial peptides (AMPs) are small molecular weight proteins with broad spectrum of antimicrobial activity against bacteria, viruses, and fungi (Zasloff M 2002; Radek K & Gallo R 2007). The majority of known AMPs are cationic peptides with common structural characteristics where domains of hydrophobic and cationic amino acids are spatially arranged into an amphipathic design, which facilitates their interaction with bacterial membranes (Shai Y 2002; Yeaman MR & Yount NY 2003; Brown KL & Hancock RE 2006; Dennison SR et al. 2005; Zelezetsky I & Tossi A 2006). It is generally excepted that the electrostatic interaction facilitates the initial binding of the positively charged peptides to the negatively charged bacterial membrane. Moreover, the structural amphiphilicity of AMPs is thought to promote their integration into lipid bilayers of pathogenic cells, leading to membrane disintegration and finally to the microbial cell death. In addition to cationic AMPs a few anionic antimicrobial peptides have been found in humans, however their mechanism of action remains to be clarified (Lai Y et al. 2007; Harris F et al. 2009; Paulmann M et al. 2012). Besides the direct neutralizing effects on bacteria AMPs may modulate cells of the adaptive immunity (neutrophils, T-cells, macrophages) to control inflammation and/or to increase bacterial clearance. AMPs have also been referred to as cationic host defense peptides, anionic antimicrobial peptides/proteins, cationic amphipathic peptides, cationic AMPs, host defense peptides and alpha-helical antimicrobial peptides (Brown KL & Hancock RE 2006; Harris F et al. 2009; Groenink J et al. 1999; Bradshaw J 2003; Riedl S et al. 2011; Huang Y et al. 2010).

The Reactome module describes the interaction events of various types of human AMPs, such as cathelicidin, histatins and neutrophil serine proteases, with conserved patterns of microbial membranes at the host-pathogen interface. The module includes also proteolytic processing events for dermcidin (DCD) and cathelicidin (CAMP) that become functional upon cleavage. In addition, the module highlights an AMP-associated ability of the host to control metal quota at inflammation sites to influence host-pathogen interactions. [[https://reactome.org/PathwayBrowser/#/R-HSA-6803157](https://reactome.org/PathwayBrowser/#/R-HSA-6803157)]

**STAT3 activation:** Activation of TRKA by NGF triggers STAT3 phosphorylation at Ser-727, and enhances the DNA binding and transcriptional activities of STAT3. Ser-727 phosphorylation of STAT3 begins within 5 min, and the levels of Ser(P) STAT3 remain elevated up to 30 min of NGF stimulation. Ser(P) STAT3 was localized to the cytoplasm, nuclei, and growth cones of neurites. Although the mechanisms by which STAT3 is activated by neurotrophins remaines unknown, phosphorylation of STAT3 at serine 727 might function as a convergent point for several signaling pathways triggered by Trk activation. Inhibition of STAT3 expression was found to attenuate NGF-induced transcription of immediate early genes, to suppress NGF-induced cyclin D1 expression, and to decrease BDNF-promoted neurite outgrowth in hippocampal neurons. The IL-37b:IL18R1:SIGIRR complex can facilitate the activation phosphorylation of STAT3 (Nold-Petry C A et al., 2015). [PMID: 28780076] [[https://reactome.org/PathwayBrowser/#/R-HSA-187037&SEL=R-HSA-198732&PATH=R-HSA-162582,R-HSA-9006934,R-HSA-166520](https://reactome.org/PathwayBrowser/#/R-HSA-187037&SEL=R-HSA-198732&PATH=R-HSA-162582,R-HSA-9006934,R-HSA-166520)].

**Signalling to RAS:** Signalling through Shc adaptor proteins appears to be identical for both NGF and EGF. It leads to a fast, but transient, MAPK/ERK activation, which is insufficient to explain the prolonged activation of MAPK found in NGF-treated cells [PMID: 34099862], [[https://reactome.org/PathwayBrowser/#/R-HSA-167044](https://reactome.org/PathwayBrowser/#/R-HSA-167044)].

## GO terms:

**acute-phase response** [An acute inflammatory response that involves non-antibody proteins whose concentrations in the plasma increase in response to infection or injury of homeothermic animals. GO:0006953]

**antimicrobial humoral immune response mediated by antimicrobial peptide** [An immune response against microbes mediated by anti-microbial peptides in body fluid. GO:0061844]

**cellular response to L-arginine** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a L-arginine stimulus. GO:1903577]

**cellular response to tumor necrosis factor** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a tumor necrosis factor stimulus. GO:0071356]

**cellular response to xenobiotic stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a xenobiotic, a compound foreign to the organism exposed to it. It may be synthesized by another organism (like ampicillin) or it can be a synthetic chemical. GO:0071466]

**defense response to Gram-negative bacterium** [Reactions triggered in response to the presence of a Gram-negative bacterium that act to protect the cell or organism. GO:0050829]

**defense response to Gram-positive bacterium** [Reactions triggered in response to the presence of a Gram-positive bacterium that act to protect the cell or organism. GO:0050830]

**estrous cycle** [A type of ovulation cycle, which occurs in most mammalian therian females, where the endometrium is resorbed if pregnancy does not occur. GO:0044849]

**female pregnancy** [The set of physiological processes that allow an embryo or foetus to develop within the body of a female animal. It covers the time from fertilization of a female ovum by a male spermatozoon until birth. GO:0007565]

**midgut development** [The process whose specific outcome is the progression of the midgut over time, from its formation to the mature structure. The midgut is the middle part of the alimentary canal from the stomach, or entrance of the bile duct, to, or including, the large intestine. GO:0007494]

**negative regulation of apoptotic process** [Any process that stops, prevents, or reduces the frequency, rate or extent of cell death by apoptotic process.|This term should only be used when it is not possible to determine which phase or subtype of the apoptotic process is negatively regulated by a gene product. Whenever detailed information is available, the more granular children terms should be used. GO:0043066]

**negative regulation of cellular process** [Any process that stops, prevents, or reduces the frequency, rate or extent of a cellular process, any of those that are carried out at the cellular level, but are not necessarily restricted to a single cell. For example, cell communication occurs among more than one cell, but occurs at the cellular level. GO:0048523]

**negative regulation of cellular response to oxidative stress** [Any process that stops, prevents or reduces the frequency, rate or extent of cellular response to oxidative stress. GO:1900408]

**negative regulation of inflammatory response to wounding** [Any process that stops, prevents, or reduces the frequency, rate or extent of the inflammatory response to wounding. GO:0106015]

**negative regulation of keratinocyte differentiation** [Any process that stops, prevents, or reduces the frequency, rate or extent of keratinocyte differentiation. GO:0045617]

**positive regulation of cell population proliferation** [Any process that activates or increases the rate or extent of cell proliferation. GO:0008284]

**positive regulation of protein phosphorylation** [Any process that activates or increases the frequency, rate or extent of addition of phosphate groups to amino acids within a protein. GO:0001934]

**response to bacterium** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a bacterium. GO:0009617]

**response to estradiol** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of stimulus by estradiol, a C18 steroid hormone hydroxylated at C3 and C17 that acts as a potent estrogen. GO:0032355]

**response to nutrient levels** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus reflecting the presence, absence, or concentration of nutrients. GO:0031667]

**response to peptide hormone** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a peptide hormone stimulus. A peptide hormone is any of a class of peptides that are secreted into the blood stream and have endocrine functions in living animals. GO:0043434]

**response to starvation** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a starvation stimulus, deprivation of nourishment. GO:0042594]

**response to wounding** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating damage to the organism. GO:0009611]

**signal transduction** [The cellular process in which a signal is conveyed to trigger a change in the activity or state of a cell. Signal transduction begins with reception of a signal (e.g. a ligand binding to a receptor or receptor activation by a stimulus such as light), or for signal transduction in the absence of ligand, signal-withdrawal or the activity of a constitutively active receptor. Signal transduction ends with regulation of a downstream cellular process, e.g. regulation of transcription or regulation of a metabolic process. Signal transduction covers signaling from receptors located on the surface of the cell and signaling via molecules located within the cell. For signaling between cells, signal transduction is restricted to events at and within the receiving cell.|Note that signal transduction is defined broadly to include a ligand interacting with a receptor, downstream signaling steps and a response being triggered. A change in form of the signal in every step is not necessary. Note that in many cases the end of this process is regulation of the initiation of transcription. Note that specific transcription factors may be annotated to this term, but core/general transcription machinery such as RNA polymerase should not. GO:0007165]

## MSigDB Signatures:

**REACTOME_INNATE_IMMUNE_SYSTEM**: Innate Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html)

**DESERT_PERIVENOUS_HEPATOCELLULAR_CARCINOMA_SUBCLASS_UP**: Genes up-regulated in the perivenous-type subclass of hepatocellular carcinomas. Sets created as part of a metaanalysis of nine public transcriptomic datasets merged into a metadataset including 1133 human hepatocellular carcinomas obtained after curative resection. For platform descriptions of each one of the 9 datasets, see Figure 1B in Desert et al., Hepatology (2017), 66: 1502-1518. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DESERT_PERIVENOUS_HEPATOCELLULAR_CARCINOMA_SUBCLASS_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DESERT_PERIVENOUS_HEPATOCELLULAR_CARCINOMA_SUBCLASS_UP.html)
