
## **Pathways:**

**Estrogen-dependent gene expression:** Estrogens mediate their transcriptional effects through interaction with the estrogen receptors, ESR1 (also known as ER alpha) and ESR2 (ER beta). ESR1 and ESR2 share overlapping but distinct functions, with ESR1 playing the primary role in transcriptional activation in most cell types (Hah and Krauss, 2014; Haldosen et al, 2014. The receptors function as ligand-dependent dimers and can activate target genes either through direct binding to an estrogen responsive element (ERE) in the target gene promoter, or indirectly through interaction with another DNA-binding protein such as RUNX1, SP1, AP1 or NF-kappa beta (reviewed in Bai and Gust, 2009; Hah and Krause, 2014). Binding of estrogen receptors to the DNA promotes the assembly of higher order transcriptional complexes containing methyltransferases, histone acetyltransferases and other transcriptional activators, which promote transcription by establishing active chromatin marks and by recruiting general transcription factors and RNA polymerase II. ESR1- and estrogen-dependent recruitment of up to hundreds of coregulators has been demonstrated by varied co-immunoprecipitation and proteomic approaches (Kittler et al, 2013; Mohammed et al, 2013; Foulds et al, 2013; Mohammed et al, 2015; Liu et al, 2014; reviewed in Magnani and Lupien, 2014; Arnal, 2017). In some circumstances, ligand-bound receptors can also promote the assembly of a repression complex at a target gene, and in some cases, heterodimers of ESR1 and ESR2 serve as repressors of ESR1-mediated target gene activation (reviewed in Hah and Kraus, 2014; Arnal et al, 2017). Phosphorylation of the estrogen receptor also modulates its activity, and provides cross-talk between nuclear estrogen-dependent signaling and non-genomic estrogen signaling from the plasma membrane (reviewed in Anbalagan and Rowan, 2015; Halodsen et al, 2014; Schwartz et al, 2016)

A number of recent genome wide studies highlight the breadth of the transcriptional response to estrogen. The number of predicted estrogen-dependent target genes ranges from a couple of hundred (based on microarray studies) to upwards of 10000, based on ChIP-chip or ChIP-seq (Cheung and Kraus, 2010; Kinnis and Kraus, 2008; Lin et al, 2004; Welboren et al, 2009; Ikeda et al, 2015; Lin et al, 2007; Carroll et al, 2006). Many of these predicted sites may not represent transcriptionally productive binding events, however. A study examining ESR1 binding by ChIP-seq in 20 primary breast cancers identified a core of 484 ESR-binding events that were conserved in at least 75% of ER+ tumors, which may represent a more realistic estimate (Ross-Innes et al, 2012). These studies also highlight the long-range effect of estrogen receptor-binding, with distal enhancer or promoter elements regulating the expression of many target genes, often through looping or other higher order chromatin structures (Kittler et al, 2013; reviewed in Dietz and Carroll, 2008; Liu and Cheung, 2014; Magnani and Lupien, 2014). Transcription from a number of estrogen-responsive target genes also appears to be primed by the binding of pioneering transcription factors such as FOXA1, GATA3, PBX1 among others. These factors bind to heterochromatin by virtue of their winged helix domains and promote chromatin opening, allowing subsequent recruitment of other transcription factors (reviewed in Zaret and Carroll, 2011; Fiorito et al, 2013; Arnal et al, 2017; Magnani et al, 2011)[[https://reactome.org/PathwayBrowser/#/R-HSA-9018519](https://reactome.org/PathwayBrowser/#/R-HSA-9018519)].

**Regulation of RUNX1 Expression and Activity:** At the level of transcription, expression of the RUNX1 transcription factor is regulated by two alternative promoters: a distal promoter, P1, and a proximal promoter, P2. P1 is more than 7 kb upstream of P2 (Ghozi et al. 1996). In mice, the Runx1 gene is preferentially transcribed from the proximal P2 promoter during generation of hematopoietic cells from hemogenic endothelium. In fully committed hematopoietic progenitors, the Runx1 gene is preferentially transcribed from the distal P1 promoter (Sroczynska et al. 2009, Bee et al. 2010). In human T cells, RUNX1 is preferentially transcribed from P1 throughout development, while developing natural killer cells transcribe RUNX1 predominantly from P2. Developing B cells transcribe low levels of RUNX1 from both promoters (Telfer and Rothenberg 2001).

RUNX1 mRNAs transcribed from alternative promoters differ in their 5'UTRs and splicing isoforms of RUNX1 have also been described. The function of alternative splice isoforms and alternative 5'UTRs has not been fully elucidated (Challen and Goodell 2010, Komeno et al. 2014).

During zebrafish hematopoiesis, RUNX1 expression increases in response to NOTCH signaling, but direct transcriptional regulation of RUNX1 by NOTCH has not been demonstrated (Burns et al. 2005). RUNX1 transcription also increases in response to WNT signaling. BothTCF7 and TCF4 bind the RUNX1 promoter (Wu et al. 2012, Hoverter et al. 2012), and RUNX1 transcription driven by the TCF binding element (TBE) in response to WNT3A treatment is inhibited by the dominant-negative mutant of TCF4 (Medina et al. 2016). In developing mouse ovary, Runx1 expression is positively regulated by Wnt4 signaling (Naillat et al. 2015). Studies in mouse hematopoietic stem and progenitor cells imply that RUNX1 may be a direct transcriptional target of HOXB4 (Oshima et al. 2011).

Conserved cis-regulatory elements were recently identified in intron 5 of RUNX1. The RUNX1 breakpoints observed in acute myeloid leukemia (AML) with translocation (8;21), which result in expression of a fusion RUNX1-ETO protein, cluster in intron 5, in proximity to these not yet fully characterized cis regulatory elements (Rebolledo-Jaramillo et al. 2014).

At the level of translation, RUNX1 expression is regulated by various microRNAs which bind to the 3'UTR of RUNX1 mRNA and inhibit its translation through endonucleolytic and/or nonendonucleolytic mechanisms. MicroRNAs that target RUNX1 include miR-378 (Browne et al. 2016), miR-302b (Ge et al. 2014), miR-18a (Miao et al. 2015), miR-675 (Zhuang et al. 2014), miR-27a (Ben-Ami et al. 2009), miR-17, miR-20a, miR106 (Fontana et al. 2007) and miR-215 (Li et al. 2016).

At the posttranslational level, RUNX1 activity is regulated by postranslational modifications and binding to co-factors. SRC family kinases phosphorylate RUNX1 on multiple tyrosine residues in the negative regulatory domain, involved in autoinhibition of RUNX1. RUNX1 tyrosine phosphorylation correlates with reduced binding of RUNX1 to GATA1 and increased binding of RUNX1 to the SWI/SNF complex, leading to inhibition of RUNX1-mediated differentiation of T-cells and megakaryocytes. SHP2 (PTPN11) tyrosine phosphatase binds to RUNX1 and dephosphorylates it (Huang et al. 2012).

Formation of the complex with CBFB is necessary for the transcriptional activity of RUNX1 (Wang et al. 1996). Binding of CCND3 and probably other two cyclin D family members, CCND1 and CCND2, to RUNX1 inhibits its association with CBFB (Peterson et al. 2005), while binding to CDK6 interferes with binding of RUNX1 to DNA without affecting formation of the RUNX1:CBFB complex. Binding of RUNX1 to PML plays a role in subnuclear targeting of RUNX1 (Nguyen et al. 2005).

RUNX1 activity and protein levels vary during the cell cycle. RUNX1 protein levels increase from G1 to S and from S to G2 phases, with no increase in RUNX1 mRNA levels. CDK1-mediated phosphorylation of RUNX1 at the G2/M transition is implicated in reduction of RUNX1 transactivation potency and may promote RUNX1 protein degradation by the anaphase promoting complex (reviewed by Friedman 2009).[[https://reactome.org/PathwayBrowser/#/R-HSA-8934593](https://reactome.org/PathwayBrowser/#/R-HSA-8934593)].

**RUNX1 and FOXP3 control the development of regulatory T lymphocytes (Tregs):** The complex of CBFB and RUNX1 (AML1) controls transcription of the FOXP3 gene. FOXP3 is a transcription factor that acts as a key regulator of development and function of regulatory T lymphocytes (Tregs). Tregs are CD25+CD4+ T lymphocytes involved in suppression of aberrant immune responses seen in autoimmune diseases and allergies. FOXP3 can bind to RUNX1 and control transcriptional activity of the RUNX1:CBFB complex. RUNX1 stimulates transcription of IL2 and IFNG1 (IFN-gamma), and the expression of these two genes is repressed upon binding of FOXP3 to RUNX1. The complex of FOXP3 and RUNX1, on the other hand, stimulates transcription of cell surface markers of Tregs, such as CD25, CTLA-4 and GITR. In the absence of FOXP3, RUNX1 represses transcription of these genes (Shevach 2000, Maloy and Powrie 2001, Sakaguchi 2004, Ono et al. 2007, Kitoh et al. 2009).

The RUNX1:CBFB complex directly stimulates transcription of the CR1 gene, encoding Complement receptor type 1 (CD35) (Kim et al. 1999, Rho et al. 2002). Expression of CR1 on the surface of activated T cells contributes to generation of Tregs (Torok et al. 2015).[[https://reactome.org/PathwayBrowser/#/R-HSA-8877330](https://reactome.org/PathwayBrowser/#/R-HSA-8877330)].

**RUNX1 interacts with co-factors whose precise effect on RUNX1 targets is not known:** The transcriptional activity of the RUNX1:CBFB complex is regulated by interaction with co-factors and posttranslational modifications of RUNX1. Protein serine/threonine kinase HIPK2 can phosphorylate RUNX1 and affect transcriptional activity of the RUNX1:CBFB complex during hematopoiesis. Some CBFB mutations found in leukemia interfere with HIPK2-mediated phosphorylation of RUNX1. HIPK2 can simultaneously phosphorylate RUNX1 and EP300 (p300) bound to the RUNX1:CBFB1 complex (Aikawa et al. 2006, Wee et al. 2008).

The RUNX1:CBFB complex can associate with the polycomb repressor complex 1 (PRC1). PRC1 complexes are found at many RUNX1 target promoters and can act either as co-activators or co-repressors in the transactivation of RUNX1 targets (Yu et al. 2011).

RUNX1 recruits the SWI/SNF chromatin remodeling complex to many RUNX1 target promoters by directly interacting with several SWI/SNF subunits (Bakshi et al. 2010).

Other co-factors of the RUNX1:CBFB complex are annotated in the context of transcriptional regulation of specific genes.[[https://reactome.org/PathwayBrowser/#/R-HSA-8878171&SEL=R-HSA-8939243&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436](https://reactome.org/PathwayBrowser/#/R-HSA-8878171&SEL=R-HSA-8939243&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436)].

**RUNX1 regulates estrogen receptor mediated transcription:** The RUNX1:CBFB complex can associate with the activated estrogen receptor alpha (ESR1) through direct interaction between RUNX1 and ESR1. The RUNX1:CBFB complex is thus involved in transcriptional regulation of estrogen responsive genes, including GPAM, KCTD6 and AXIN1 (Stender et al. 2010). High GPAM expression correlates with better overall survival in breast cancer (Brockmoller et al. 2012).[[https://reactome.org/PathwayBrowser/#/R-HSA-8878171&SEL=R-HSA-8931987&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436](https://reactome.org/PathwayBrowser/#/R-HSA-8878171&SEL=R-HSA-8931987&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436)].

**RUNX1 regulates expression of components of tight junctions:** The RUNX1 transcription factor, which functions as part of the RUNX1:CBFB complex, was shown to directly transcriptionally regulate expression of several genes that encode components of tight junctions. Namely, RUNX1 binds to promoters of TJP1 (encoding ZO-1), OCLDN (encoding Occludin) and CLDN5 (encoding Claudin-5) and stimulates their transcription. Downregulation of RUNX1 by microRNA miR-18a negatively regulates expression of these three tight junction genes, which may affect the permeability of blood-tumor barrier in glioma (Miao et al. 2015). [[https://reactome.org/PathwayBrowser/#/R-HSA-8878171&SEL=R-HSA-8935964&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436](https://reactome.org/PathwayBrowser/#/R-HSA-8878171&SEL=R-HSA-8935964&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436)].

**RUNX1 regulates genes involved in megakaryocyte differentiation and platelet function:** In human hematopoietic progenitors, RUNX1 and its partner CBFB are up-regulated at the onset of megakaryocytic differentiation and down-regulated at the onset of erythroid differentiation. The complex of RUNX1 and CBFB cooperates with the transcription factor GATA1 in the transactivation of megakaryocyte-specific genes. In addition, RUNX1 and GATA1 physically interact (Elagib et al. 2003), and this interaction involves the zinc finger domain of GATA1 (Xu et al. 2006). Other components of the RUNX1:CBFB activating complex at megakaryocytic promoters are GATA1 heterodimerization partner, ZFPM1 (FOG1), histone acetyltransferases EP300 (p300) and KAT2B (PCAF), the WDR5-containing histone methyltransferase MLL complex and the arginine methyltransferase PRMT1 (Herglotz et al. 2013). In the absence of PRMT1, the transcriptional repressor complex can form at megakaryocytic promoters, as RUNX1 that is not arginine methylated can bind to SIN3A/SIN3B co-repressors (Zhao et al. 2008). Besides SIN3A/SIN3B, the RUNX1:CBFB repressor complex at megakaryocytic promoters also includes histone deacetylase HDAC1 and histone arginine methyltransferase PRMT6 (Herglotz et al. 2013).

Megakaryocytic promoters regulated by the described RUNX1:CBFB activating and repressing complexes include ITGA2B, GP1BA, THBS1 and MIR27A (Herglotz et al. 2013). ITGA2B is only expressed in maturing megakaryocytes and platelets and is involved in platelet aggregation (Block and Poncz 1995). GP1BA is expressed at the cell surface membrane of maturing megakaryocytes and platelets and participates in formation of platelet plugs (Cauwenberghs et al. 2000, Jilma-Stohlawetz et al. 2003, Debili et al. 1990). THBS1 homotrimers contribute to stabilization of the platelet aggregate (Bonnefoy and Hoylaerts 2008). MIR27A is a negative regulator of RUNX1 mRNA translation and may be involved in erythroid/megakaryocytic lineage determination (Ben-Ami et al. 2009).

The RUNX1:CBFB complex stimulates transcription of the PF4 gene, encoding a component of platelet alpha granules (Aneja et al. 2011), the NR4A3 gene, associated with the familial platelet disorder (FPD) (Bluteau et al. 2011), the PRKCQ gene, associated with inherited thrombocytopenia (Jalagadugula et al. 2011), the MYL9 gene, involved in thrombopoiesis (Jalagadugula et al. 2010), and the NFE2 gene, a regulator of erythroid and megakaryocytic maturation and differentiation (Wang et al. 2010).[[https://reactome.org/PathwayBrowser/#/R-HSA-8936459&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436,R-HSA-8878171](https://reactome.org/PathwayBrowser/#/R-HSA-8936459&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436,R-HSA-8878171)].

**RUNX1 regulates transcription of genes involved in BCR signaling:** The RUNX1:CBFB complex, in association with transcription co-factors ELF1 (MEF), ELF2 (NERF2) or PAX5 (BSAP) stimulates transcription of the BLK gene, encoding a B-cell specific tyrosine kinase involved in B cell receptor (BCR) signaling, B cell development and differentiation (Libermann et al. 1999, Cho et al. 2004).[[https://reactome.org/PathwayBrowser/#/R-HSA-8878171&SEL=R-HSA-8939245&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436](https://reactome.org/PathwayBrowser/#/R-HSA-8878171&SEL=R-HSA-8939245&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436)].

**RUNX1 regulates transcription of genes involved in differentiation of HSCs:** The RUNX1:CBFB complex regulates transcription of the SPI1 (PU.1) gene, involved in differentiation of hematopoietic stem cells (HSCs). RUNX1 recruits histone methyltransferase KMT2A (MLL) to the SPI1 gene locus, leading to generation of the activating H3K4Me3 mark on nucleosomes associated with the SPI1 promoter and the upstream regulatory element (Huang et al. 2011). SPI1 transactivation represses self-renewal and proliferation of HSCs (Fukuchi et al. 2008) and is needed for commitment of HSCs to specific hematopoietic lineages (Imperato et al. 2015). As a component of the TAL1 transcription factor complex, involved in acute T cell lymphoblastic leukemia (T-ALL), RUNX1 can promote growth and inhibit apoptosis of hematopoietic stem cells by stimulating transcription of the MYB gene and possibly the TRIB2 gene (Sanda et al. 2012, Mansour et al. 2014). [[https://reactome.org/PathwayBrowser/#/R-HSA-8878171&SEL=R-HSA-8939236&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436](https://reactome.org/PathwayBrowser/#/R-HSA-8878171&SEL=R-HSA-8939236&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436)].

**RUNX1 regulates transcription of genes involved in differentiation of keratinocytes:** The RUNX1:CBFB complex directly inhibits transcription of the SERPINB13 gene (Nomura et al. 2005), a gene involved in keratinocyte differentiation that is frequently down-regulated in head and neck cancers (Boyapati et al. 2011). RUNX1 also inhibits transcription of STAT3 inhibitors SOCS3 and SOCS4, resulting in elevated STAT3 activity. RUNX1-mediated increase in STAT3 activity, first discovered in keratinocytes, is thought to be involved in the maintenance of epithelial stem cells and contributes to development of epithelial cancers, including squamous cell carcinoma (SCC) of the skin (Scheitz et al. 2012) [[https://reactome.org/PathwayBrowser/#/R-HSA-8878171&SEL=R-HSA-8939242&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436](https://reactome.org/PathwayBrowser/#/R-HSA-8878171&SEL=R-HSA-8939242&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436)].

**RUNX1 regulates transcription of genes involved in differentiation of myeloid cells:** The RUNX1:CBFB complex regulates expression of genes involved in differentiation of myeloid progenitors which can commit to hematopoietic lineages that lead to generation of platelets, erythrocytes, leukocytes or monocytes. The RUNX1:CBFB complex recruits histone acetyltransferase CREBBP (CBP) to the promoter of the CSF2 gene, encoding Granulocyte-macrophage colony stimulating factor (GM-CSF), thus inducing GM-CSF expression (Oakford et al. 2010). GM-CSF induces growth, differentiation and survival of macrophages, granulocytes, erythrocytes and megakaryocytes from myeloid progenitors (Barreda et al. 2004).

The RUNX1:CBFB complex directly stimulates transcription of the LGALS3 gene, encoding galectin-3 (Zhang et al. 2009). Galectin-3 is expressed in myeloid progenitors and its levels increase during the maturation process (Le Marer 2000).

The PRKCB gene, encoding protein kinase C-beta, which regulates apoptosis of myeloid cells, is directly transactivated by the RUNX1:CBFB complex (Hu et al. 2004)[[https://reactome.org/PathwayBrowser/#/R-HSA-8878171&SEL=R-HSA-8939246&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436](https://reactome.org/PathwayBrowser/#/R-HSA-8878171&SEL=R-HSA-8939246&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436)].

**RUNX1 regulates transcription of genes involved in interleukin signaling:** The RUNX1:CBFB complex regulates transcription of at least a couple of genes involved in interleukin signaling. The LIFR gene, a direct transcriptional target of the RUNX1:CBFB complex (Qadi et al. 2016), encodes the receptor for the leukemia inhibitory factor (LIF), a member of the interleukin-6 family. LIFR is implicated in hematopoiesis, embryo implantation, placental formation and nervous system development (Nicola et al. 2015). In association with its co-activator ELF1, the RUNX1:CBFB complex stimulates transcription of the IL3 gene, encoding interleukin-3 (Mao et al. 1999)[[https://reactome.org/PathwayBrowser/#/R-HSA-8878171&SEL=R-HSA-8939247&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436](https://reactome.org/PathwayBrowser/#/R-HSA-8878171&SEL=R-HSA-8939247&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436)].

**RUNX1 regulates transcription of genes involved in WNT signaling:** The RUNX1:CBFB complex directly regulates transcription of at least two components of WNT signaling. In association with its co-factor FOXP3, the RUNX1:CBFB complex stimulates transcription of the RSPO3 gene, encoding a WNT ligand that is implicated as a breast cancer oncogene (Recouvreux et al. 2016). In association with the activated estrogen receptor alpha (ESR1), the RUNX1:CBFB complex stimulates the expression of AXIN1, which functions as a regulator of WNT signaling (Stender et al. 2010) [[https://reactome.org/PathwayBrowser/#/R-HSA-8878171&SEL=R-HSA-8939256&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436](https://reactome.org/PathwayBrowser/#/R-HSA-8878171&SEL=R-HSA-8939256&PATH=R-HSA-74160,R-HSA-73857,R-HSA-212436)].

**RUNX2 regulates genes involved in differentiation of myeloid cells:** Both RUNX2 and RUNX1 can stimulate transcription of the LGALS3 gene, encoding Galectin-3 (Vladimirova et al. 2008, Zhang et al. 2009). Galectin 3 is expressed in myeloid progenitors and its levels increase during the maturation process (Le Marer 2000). Galectin 3 is highly expressed in pituitary tumors and glioma (Vladimirova et al. 2008, Zhang et al. 2009) [[https://reactome.org/PathwayBrowser/#/R-HSA-8941333](https://reactome.org/PathwayBrowser/#/R-HSA-8941333)].

**RUNX3 regulates p14-ARF:** The transcription factor RUNX3 is a RUNX family member. All RUNX family members, RUNX1, RUNX2 and RUNX3, possess a highly conserved Runt domain, involved in DNA binding. For a more detailed description of the structure of RUNX proteins, please refer to the pathway 'Transcriptional regulation by RUNX1'. Similar to RUNX1 and RUNX2, RUNX3 forms a transcriptionally active heterodimer with CBFB (CBF-beta). Studies in mice have shown that RUNX3 plays a role in neurogenesis and development of T lymphocytes. RUNX3 is implicated as a tumor suppressor gene in various human malignancies.

During nervous system formation, the Cbfb:Runx3 complex is involved in development of mouse proprioceptive dorsal root ganglion neurons by regulating expression of Ntrk3 (Neurotrophic tyrosine kinase receptor type 3) and possibly other genes (Inoue et al. 2002, Kramer et al. 2006, Nakamura et al. 2008, Dykes et al. 2011, Ogihara et al. 2016). It is not yet known whether RUNX3 is involved in human neuronal development and neuronal disorders.

RUNX3 plays a major role in immune response. RUNX3 regulates development of T lymphocytes. In mouse hematopoietic stem cells, expression of Runx3 is regulated by the transcription factor TAL1 (Landry et al. 2008). RUNX3 promotes the CD8+ lineage fate in developing thymocytes. In the CD4+ thymocyte lineage in mice, the transcription factor ThPOK induces transcription of SOCS family members, which repress Runx3 expression (Luckey et al. 2014). RUNX3, along with RUNX1 and ETS1, is implicated in regulation of transcription of the CD6 gene, encoding a lymphocyte surface receptor expressed on developing and mature T cells (Arman et al. 2009). RUNX3 and ThPOK regulate intestinal CD4+ T cell immunity in a TGF-beta and retinoic acid-dependent manner, which is important for cellular defense against intestinal pathogens (Reis et al. 2013). Besides T lymphocytes, RUNX3 is a key transcription factor in the commitment of innate lymphoid cells ILC1 and ILC3 (Ebihara et al. 2015). RUNX3 regulates expression of CD11A and CD49D integrin genes, involved in immune and inflammatory responses (Dominguez-Soto et al. 2005). RUNX3 is involved in mouse TGF-beta-mediated dendritic cell function and its deficiency is linked to airway inflammation (Fainaru et al. 2004).

In addition to its developmental role, RUNX3 is implicated as a tumor suppressor. The loss of RUNX3 expression and function was first causally linked to the genesis and progression of human gastric cancer (Li et al. 2002). Expression of RUNX3 increases in human pancreatic islet of Langerhans cells but not in pancreatic adenocarcinoma cells in response to differentiation stimulus (serum withdrawal) (Levkovitz et al. 2010). Hypermethylation of the RUNX3 gene is associated with an increased risk for progression of Barrett's esophagus to esophageal adenocarcinoma (Schulmann et al. 2005). Hypermethylation-mediated silencing of the RUNX3 gene expression is also frequent in granulosa cell tumors (Dhillon et al. 2004) and has also been reported in colon cancer (Weisenberger et al. 2006), breast cancer (Lau et al. 2006, Huang et al. 2012), bladder cancer (Wolff et al. 2008) and gastric cancer (Li et al. 2002). In colorectal cancer, RUNX3 is one of the five markers in a gene panel used to classify CpG island methylator phenotype (CIMP+) (Weisenberger et al. 2006).

RUNX3 and CBFB are frequently downregulated in gastric cancer. RUNX3 cooperates with TGF-beta to maintain homeostasis in the stomach and is involved in TGF-beta-induced cell cycle arrest of stomach epithelial cells. Runx3 knockout mice exhibit decreased sensitivity to TGF-beta and develop gastric epithelial hyperplasia (Li et al. 2002, Chi et al. 2005). RUNX3-mediated inhibition of binding of TEADs:YAP1 complexes to target promoters is also implicated in gastric cancer suppression (Qiao et al. 2016).

RUNX3 is a negative regulator of NOTCH signaling and RUNX3-mediated inhibition of NOTCH activity may play a tumor suppressor role in hepatocellular carcinoma (Gao et al. 2010, Nishina et al. 2011). In addition to RUNX3 silencing through promoter hypermethylation in breast cancer (Lau et al. 2006), Runx3+/- mice are predisposed to breast cancer development. RUNX3 downregulates estrogen receptor alpha (ESR1) protein levels in a proteasome-dependent manner (Huang et al. 2012).

Besides its tumor suppressor role, mainly manifested through its negative effect on cell proliferation, RUNX3 can promote cancer cell invasion by stimulating expression of genes involved in metastasis, such as osteopontin (SPP1) (Whittle et al. 2015) [[https://reactome.org/PathwayBrowser/#/R-HSA-8878159](https://reactome.org/PathwayBrowser/#/R-HSA-8878159)].

**Organic cation transport:** The organic cation transporters comprise three SLC22 members, OCT1-3. They can transport a wide range of organic cations including weak bases. All transport by OCTs is electrogenic, sodium-independent and bidirectional. Two further organic cation transporters mediate transport of ergothioneine and carnitine (Koepsell H and Endou H, 2004).[[https://reactome.org/PathwayBrowser/#/R-HSA-425366&SEL=R-HSA-549127&PATH=R-HSA-382551,R-HSA-425407](https://reactome.org/PathwayBrowser/#/R-HSA-425366&SEL=R-HSA-549127&PATH=R-HSA-382551,R-HSA-425407)].

**SARS-CoV-1 activates/modulates innate immune responses:** Coronaviruses (CoVs) are positive-sense RNA viruses that replicate in the interior of double membrane vesicles (DMV) in the cytoplasm of infected cells (Stertz S et al. 2007; Knoops K et al. 2008). The viral replication and transcription are facilitated by virus-encoded non-structural proteins (SARS-CoV-1 nsp1-nsp16) that assemble to form a DMV-bound replication-transcription complex (RTC). The replication strategy of CoVs can generate both single-stranded RNA (ssRNA) and double-stranded RNA (dsRNA) species, that may act as pathogen-associated molecular patterns (PAMPs) recognized by pattern recognition receptor (PRR) such as toll-like receptor 7 (TLR7) and TLR8, antiviral innate immune response receptor RIG-I (also known as DEAD box protein 58, DDX58) and interferon-induced helicase C domain-containing protein 1 (IFIH1, also known as MDA5) (Cervantes-Barragan L et al. 2007; Chen Y et al. 2009, 2011; Daffis S et al. 2010; Li Y et al. 2013). The activated PRRs trigger signaling pathways to produce type I and type III interferons IFNs and proinflammatory mediators that perform antiviral functions. This Reactome module describes the mechanisms underlying PRR-mediated sensing of the severe acute respiratory syndrome coronavirus type 1 (SARS-CoV-1) infection. First, endosomal recognition of viral ssRNA occurs by means of TLR7 and TLR8 which detect GU-rich ssRNA sequences. Specifically, GU-rich ssRNA oligonucleotides derived from SARS-CoV-1 stimulated mononuclear phagocytes to release considerable levels of pro-inflammatory cytokines TNF-a, IL-6 and IL-12 via TLR7 and TLR8 (Li Y et al. 2013). Second, SARS-CoV-1 dsRNA replication intermediates can be recognized by cytoplasmic receptors DDX58 and IFIH1 which bind to mitochondrial antiviral-signaling protein (MAVS, IPS-1) to induce the IFN-mediated antiviral response. In addition, the module shows an antiviral function of interferon-induced protein with tetratricopeptide repeats 1 (IFIT1) that directly binds and sequesters viral single-stranded uncapped 5'-ppp RNA and cap-0 RNA (Daffis S et al. 2010). This module also describes several strategies developed by SARS-CoV-1 to evade or alter host immunity, including escaping innate immune sensors, inhibiting IFN production and signaling, and evading antiviral function of IFN stimulated gene (ISG) products. For example, viral dsRNA replication intermediates derived from SARS-CoV-1 were shown to associate with RTC bound to double membrane vesicles, which protected viral RNA from sensing by DDX58 or IFIH1 (Stertz S et al. 2007; Knoops K et al. 2008). Further, SARS-CoV-1 encodes nsp14 and nsp16 which possess guanine-N7-methyltransferase activity and 2'-O-methyl-transferase activity respectively (Chen Y et al. 2009, 2011). SARS-CoV-1 nsp14 generates 5' cap-0 viral RNA (m7GpppN, guanine N7-methylated) and nsp16 further methylates cap-0 viral RNA. These viral RNA modifications mimic the 5'-cap structure of host mRNAs allowing the virus to efficiently evade recognition by cytosolic DDX58 and IFIH1 (Chen Y et al. 2009, 2011; Daffis S et al. 2010). The nsp16-mediated ribose 2'-O-methylation of viral RNA also blocks the antiviral function of IFIT1 complexes (Menachery VD et al. 2014). Further, the uridylate-specific endoribonuclease (EndoU) activity of viral nsp15 degrades viral RNA to hide it from innate immune sensors (Bhardwaj K et al. 2006; Ricagno S et al. 2006). Moreover, SARS-CoV-1 encodes several proteins that directly bind to host targets associated with SARS-CoV-1 infection and cytokine production (Frieman M et al. 2009; Hu Y et al. 2017; Kopecky-Bromberg SA et al. 2007; Lindner H et al. 2005; Siu KL et al. 2009). This Reactome module describes several such binding events and their consequences. For example, as a de-ubiquitinating enzyme, viral nsp3 binds to and removes polyubiquitin chains of signaling proteins such as TRAF3, TRAF6, STING, IkBA, and IRF3 thereby modulating the formation of signaling complexes and the activation of IRF3/7 and NFkappaB (Sun L et al. 2012; Chen X et al. 2014; Li SW et al. 2016). This inhibits IFN production downstream of TLR7/8, DDX58, IFIH1, MAVS and STING signaling pathways. Binding of SARS-CoV-1 nucleocapsid (N) protein to E3 ubiquitin ligase TRIM25 inhibits TRIM25-mediated DDX58 ubiquitination and DDX58-mediated signaling pathway (Hu Y et al. 2017). Next, SARS-CoV-1 membrane (M) protein targets IBK1/IKBKE and TRAF3 to prevent the formation of the TRAF3:TANK:TBK1/IKBKE complex and thereby inhibits TBK1/IKBKE-dependent activation of IRF3/IRF7 transcription factors downstream of DDX58, IFIH1 and adaptor MAVS (Siu KL et al. 2009; 2014). The ion channel activities of open reading frame 3a (orf3a or 3a) and E contribute to activation of the NLRP3 inflammasome leading to highly inflammatory pyroptotic cell death (Nieto-Torres JL et al. 2015; Chen IY et al. 2019; Yue Y et al. 2018). Viral 3a promoted the NLRP3-mediated formation of PYCARD (ASC) speck by interaction with both TRAF3 and PYCARD (ASC) (Siu KL et al. 2019). Binding of 3a to caspase-1 (CASP1) enhanced CASP1-mediated cleavage of interleukin 1 beta (IL-1beta) downstream of the NLRP3 inflammasome pathway (Yue Y et al. 2018). Like 3a, SARS-CoV-1 8b was found to bind to NLRP3 activating the NLRP3 inflammasome and triggering IL-1beta release (Shi CS et al. 2019). 8b was also shown to bind IRF3, inhibiting subsequent IRF3 dimerization (Wong et al. 2018). At the plasma membrane, binding of SARS-CoV-1 7a to host BST2 disrupts the antiviral tethering function of BST2 which restricts the release of diverse mammalian enveloped viruses (Taylor JK et al. 2015). SARS-CoV-1 9b (orf9b) inhibits the MAVS-mediated production of type I IFNs by targeting TOMM70 on the mitochondria (Jiang HW et al. 2020). SARS-CoV-1 6 (orf6) inhibits the IFN signaling pathway by tethering karyopherins KPNA2 and KPNB1 to the endoplasmic reticulum (ER)/Golgi intermediate compartment (ERGIC) and thus blocking the KPNA1:KPNB1-dependent nuclear import of STAT1 (Frieman M et al. 2007). Binding of SARS-CoV-1 nsp1 to peptidyl-prolyl isomerases (PPIases) and calcipressin-3 (RCAN3) significantly activates the cyclophilin A/NFAT pathway, ultimately enhancing the induction of the IL-2 promoter (Pfefferle et al, 2011; Law et al, 2007). At last, SARS-CoV-1 3b, after translocating to the nucleus, binds to transcription factor RUNX1 and increases its promoting activity (Varshney et al, 2012)[[https://reactome.org/PathwayBrowser/#/R-HSA-9692914&SEL=R-HSA-9692916&PATH=R-HSA-1643685,R-HSA-5663205,R-HSA-9824446,R-HSA-9679506,R-HSA-9678108](https://reactome.org/PathwayBrowser/#/R-HSA-9692914&SEL=R-HSA-9692916&PATH=R-HSA-1643685,R-HSA-5663205,R-HSA-9824446,R-HSA-9679506,R-HSA-9678108)].

**Pre-NOTCH Transcription and Translation:** In humans, the NOTCH protein family has four members: NOTCH1, NOTCH2, NOTCH3 and NOTCH4. NOTCH1 protein was identified first, as the product of a chromosome 9 gene translocated in T-cell acute lymphoblastic leukemia that was homologous to Drosophila Notch (Ellisen et al. 1991). At the same time, rat Notch1 was cloned (Weinmaster et al. 1991), followed by cloning of mouse Notch1, named Motch (Del Amo et al. 1992). NOTCH2 protein is the product of a gene on chromosome 1 (Larsson et al. 1994). NOTCH2 expression is differentially regulated during B-cell development (Bertrand et al. 2000). NOTCH2 mutations are a rare cause of Alagille syndrome (McDaniell et al. 2006). NOTCH3 is the product of a gene on chromosome 19. NOTCH3 mutations are the underlying cause of CADASIL, cerebral arteriopathy with subcortical infarcts and leukoencephalopathy (Joutel et al. 1996). NOTCH4, the last NOTCH protein discovered, is the product of a gene on chromosome 6 (Li et al. 1998).

MicroRNAs play an important negative role in translation and/or stability of NOTCH mRNAs. MicroRNAs miR-34 (miR-34A, miR-34B and miR-34C), whose transcription is directly induced by the tumor suppressor protein p53 (Chang et al. 2007, Raver-Shapira et al. 2007, He et al. 2007, Corney et al. 2007) bind and negatively regulate translation of NOTCH1 mRNA (Li et al. 2009, Pang et al. 2010, Ji et al. 2009) and NOTCH2 mRNA (Li et al. 2009). NOTCH1 mRNA translation is also negatively regulated by microRNAs miR-200B and miR-200C (Kong et al. 2010), as well as miR-449A, miR-449B and miR-449C (Marcet et al. 2011). Translation of NOTCH3 mRNA is negatively regulated by microRNAs miR-150 (Ghisi et al. 2011) and miR-206 (Song et al. 2009). Translation of NOTCH4 mRNA is negatively regulated by microRNAs miR-181C (Hashimoto et al. 2010) and miR-302A (Costa et al. 2009).

Nascent NOTCH peptides are co-translationally targeted to the endoplasmic reticulum for further processing, followed by modification in the Golgi apparatus, before trafficking to the plasma membrane. Endoplasmic reticulum calcium ATPases, positively regulate NOTCH trafficking, possibly by contributing to accurate folding of NOTCH precursors (Periz et al. 1999)[[https://reactome.org/PathwayBrowser/#/R-HSA-1912408](https://reactome.org/PathwayBrowser/#/R-HSA-1912408)].

**Transcriptional regulation of granulopoiesis:** Neutrophilic granulocytes (hereafter called granulocytes) are distinguished by multilobulated nuclei and presence of cytoplasmic granules containing antipathogenic proteins (reviewed in Cowland and Borregaard 2016, Yin and Heit 2018). Granulocytes comprise eosinophils, basophils, mast cells, and neutrophils, all of which are ultimately derived from hemopoietic stem cells (HSCs), a self-renewing population of stem cells located in the bone marrow. A portion of HSCs exit self-renewing proliferation and differentiate to form multipotent progenitors (MPPs). MPPs then differentiate to form common myeloid progenitors (CMPs) as well as the erythrocyte lineage. CMPs further differentiate into granulocyte-monocyte progenitors (GMPs) which can then differentiate into monocytes or any of the types of granulocytes (reviewed in Fiedler and Brunner 2012). granulocytes are the most abundant leukocytes in peripheral blood.

For early granulopoiesis the CEBPA, SPI1 (PU.1), RAR, CBF, and MYB transcription factors are essential. CEBPE, SPI1, SP1, CDP, and HOXA10 transcription factors initiate terminal neutrophil differentiation.

Initially, RUNX1 activates SPI1 (PU.1), which is believed to be the key transcription factor driving the formation of MPPs and CMPs (reviewed in Friedman 2007, Fiedler and Brunner 2012). SPI1, in turn, activates expression of CEBPA, an indispensable transcription factor for granulopoiesis especially important in the transition from CMP to GMP (inferred from mouse homologs in Wilson et al. 2010, Guo et al. 2012, Guo et al. 2014, Cooper et al. 2015). CEBPA, in turn, activates the expression of several transcription factors and receptors characteristic of granulocytes, including CEBPA (autoregulation), CEBPE (Loke et al. 2018, and inferred from mouse homologs in Wang and Friedman 2002, Friedman et al. 2003), GFI1 (inferred from mouse homologs in Lidonnici et al. 2010), KLF5 (Federzoni et al. 2014), IL6R (inferred from mouse homologs in Zhang et al. 1998), and CSF3R (Smith et al. 1996). Importantly, CEBPA dimers repress transcription of MYC (c-Myc) (Johansen et al. 2001, and inferred from mouse homologs in Slomiany et al. 2000, Porse et al. 2001). CEBPA binds CDK2 and CDK4 (Wang et al. 2001) which inhibits their kinase activity by disrupting their association with cyclins thereby limiting proliferation and favoring differentiation of granulocyte progenitors during regular ("steady-state") granulopoiesis (reviewed in Friedman 2015). The transcription factor GFI1 regulates G-CSF signaling and neutrophil development through the Ras activator RasGRP1 (de la Luz Sierra et al. 2010).

Inhibitors of DNA binding (ID) proteins ID1 and ID2 regulate granulopoiesis and eosinophil production such that ID1 induces neutrophil development and inhibits eosinophil differentiation, whereas ID2 induces both eosinophil and neutrophil development (Buitenhuis et al. 2005, Skokowa et al. 2009).

Major infection activates emergency granulopoiesis (reviewed in Manz and Boettcher 2014, Hirai et al. 2015), the production of large numbers of granulocytes in a relatively short period of time. Emergency granulopoiesis is activated by cytokines, CSF2 (GM-CSF) and especially CSF3 (G-CSF, reviewed in Panopoulos and Watowich 2008, Liongue et al. 2009) which bind receptors, CSF2R and CSF3R, respectively, resulting in expression of CEBPB, which interferes with repression of MYC by CEBPA (inferred from mouse homologs in Zhang et al. 2010) and represses MYC less than CEBPA does (Hirai et al. 2006), leading to proliferation of granulocyte progenitors prior to final differentiation.Both, emergency and steady-state granulopoiesis are regulated by direct interaction of CEBPA (steady-state) or CEBPB (emergency) proteins with NAD+-dependent protein deacetylases, SIRT1 and SIRT2 (Skokowa et al. 2009). G-CSF induces the NAD+-generating enzyme, Nicotinamide phosphoribosyltransferase (NAMPT, or PBEF), that in turn activates sirtuins (Skokowa et al. 2009).

GADD45A and GADD45B proteins are essential for stress-induced granulopoiesis and granulocyte chemotaxis by activation of p38 kinase (Gupta et al. 2006, Salerno et al. 2012). SHP2 is required for induction of CEBPA expression and granulopoiesis in response to CSF3 (G-CSF) or other cytokines independent of SHP2-mediated ERK activation (Zhang et al. 2011).

Transcription of neutrophil granule proteins (e.g. ELANE, MPO, AZU1, DEFA4), that play an essential role in bacterial killing are regulated by CEBPE and SPI1 (PU.1) transcription factors (Gombart et al. 2003, Nakajima et al. 2006). RUNX1 and LEF1 also regulate ELANE (ELA2) mRNA expression by binding to its promoter (Li et al. 2003)[[https://reactome.org/PathwayBrowser/#/R-HSA-9616222](https://reactome.org/PathwayBrowser/#/R-HSA-9616222)].

## GO terms:

**behavioral response to pain** [Any process that results in a change in the behavior of an organism as a result of a pain stimulus. Pain stimuli cause activation of nociceptors, peripheral receptors for pain, include receptors which are sensitive to painful mechanical stimuli, extreme heat or cold, and chemical stimuli. GO:0048266]

**cellular response to transforming growth factor beta stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a transforming growth factor beta stimulus. GO:0071560]

**central nervous system development** [The process whose specific outcome is the progression of the central nervous system over time, from its formation to the mature structure. The central nervous system is the core nervous system that serves an integrating and coordinating function. In vertebrates it consists of the brain and spinal cord. In those invertebrates with a central nervous system it typically consists of a brain, cerebral ganglia and a nerve cord. GO:0007417]

**chondrocyte differentiation** [The process in which a chondroblast acquires specialized structural and/or functional features of a chondrocyte. A chondrocyte is a polymorphic cell that forms cartilage. GO:0002062]

**definitive hemopoiesis** [A second wave of blood cell production that, in vertebrates, generates long-term hemopoietic stem cells that continously provide erythroid, myeloid and lymphoid lineages throughout adulthood. GO:0060216]

**embryonic hemopoiesis** [The stages of blood cell formation that take place within the embryo. GO:0035162]

**hair follicle morphogenesis** [The process in which the anatomical structures of the hair follicle are generated and organized. GO:0031069]

**hemopoiesis** [The process whose specific outcome is the progression of the myeloid and lymphoid derived organ/tissue systems of the blood and other parts of the body over time, from formation to the mature structure. The site of hemopoiesis is variable during development, but occurs primarily in bone marrow or kidney in many adult vertebrates. GO:0030097]

**in utero embryonic development** [The process whose specific outcome is the progression of the embryo in the uterus over time, from formation of the zygote in the oviduct, to birth. An example of this process is found in Mus musculus. GO:0001701]

**liver development** [The process whose specific outcome is the progression of the liver over time, from its formation to the mature structure. The liver is an exocrine gland which secretes bile and functions in metabolism of protein and carbohydrate and fat, synthesizes substances involved in the clotting of the blood, synthesizes vitamin A, detoxifies poisonous substances, stores glycogen, and breaks down worn-out erythrocytes. GO:0001889]

**myeloid cell differentiation** [The process in which a relatively unspecialized myeloid precursor cell acquires the specialized features of any cell of the myeloid leukocyte, megakaryocyte, thrombocyte, or erythrocyte lineages. GO:0030099]

**myeloid leukocyte differentiation** [The process in which a relatively unspecialized myeloid precursor cell acquires the specialized features of any cell of the myeloid leukocyte lineage. GO:0002573]

**myeloid progenitor cell differentiation** [The process in which a precursor cell type acquires the specialized features of a myeloid progenitor cell. Myeloid progenitor cells include progenitor cells for any of the myeloid lineages. GO:0002318]

**negative regulation of CD4-positive, alpha-beta T cell differentiation** [Any process that stops, prevents, or reduces the frequency, rate, or extent of CD4-positive, alpha-beta T cell differentiation.|Note that immunologists typically use the word 'development' to refer to cells of B or T cell lineages undergoing the process that GO describes as 'cell differentiation'. GO:0043371]

**negative regulation of DNA-templated transcription** [Any process that stops, prevents, or reduces the frequency, rate or extent of cellular DNA-templated transcription. GO:0045892]

**negative regulation of cell population proliferation** [Any process that stops, prevents or reduces the rate or extent of cell proliferation. GO:0008285]

**negative regulation of granulocyte differentiation** [Any process that stops, prevents, or reduces the frequency, rate or extent of granulocyte differentiation. GO:0030853]

**negative regulation of transcription by RNA polymerase II** [Any process that stops, prevents, or reduces the frequency, rate or extent of transcription mediated by RNA polymerase II. GO:0000122]

**neuron development** [The process whose specific outcome is the progression of a neuron over time, from initial commitment of the cell to a specific fate, to the fully functional differentiated cell. GO:0048666]

**neuron differentiation** [The process in which a relatively unspecialized cell acquires specialized features of a neuron. GO:0030182]

**neuron fate commitment** [The process in which the developmental fate of a cell becomes restricted such that it will develop into a neuron. GO:0048663]

**ossification** [The formation of bone or of a bony substance, or the conversion of fibrous tissue or of cartilage into bone or a bony substance.|Note that this term does not have a 'developmental process' parent because ossification isn't necessarily developmental, can also occur as part of bone remodeling. Instead use 'ossification involved in bone maturation ; GO:0043931'. GO:0001503]

**positive regulation of CD8-positive, alpha-beta T cell differentiation** [Any process that activates or increases the frequency, rate or extent of CD8-positive, alpha-beta T cell differentiation.|Note that immunologists typically use the word 'development' to refer to cells of B or T cell lineages undergoing the process that GO describes as 'cell differentiation'. GO:0043378]

**positive regulation of DNA-templated transcription** [Any process that activates or increases the frequency, rate or extent of cellular DNA-templated transcription. GO:0045893]

**positive regulation of angiogenesis** [Any process that activates or increases angiogenesis. GO:0045766]

**positive regulation of cell maturation** [Any process that activates or increases the frequency, rate or extent of cell maturation. GO:1903431]

**positive regulation of developmental process** [Any process that activates or increases the rate or extent of development, the biological process whose specific outcome is the progression of an organism over time from an initial condition (e.g. a zygote, or a young adult) to a later condition (e.g. a multicellular animal or an aged adult). GO:0051094]

**positive regulation of granulocyte differentiation** [Any process that activates or increases the frequency, rate or extent of granulocyte differentiation. GO:0030854]

**positive regulation of interleukin-2 production** [Any process that activates or increases the frequency, rate, or extent of interleukin-2 production. GO:0032743]

**positive regulation of multicellular organismal process** [Any process that activates or increases the frequency, rate or extent of an organismal process, any of the processes pertinent to the function of an organism above the cellular level; includes the integrated processes of tissues and organs. GO:0051240]

**positive regulation of progesterone secretion** [Any process that activates or increases the frequency, rate or extent of progesterone secretion. GO:2000872]

**positive regulation of transcription by RNA polymerase II** [Any process that activates or increases the frequency, rate or extent of transcription from an RNA polymerase II promoter. GO:0045944]

**positive regulation of type II interferon production** [Any process that activates or increases the frequency, rate, or extent of interferon-gamma production. Interferon-gamma is also known as type II interferon. GO:0032729]

**regulation of DNA-templated transcription** [Any process that modulates the frequency, rate or extent of cellular DNA-templated transcription. GO:0006355]

**regulation of T cell anergy** [Any process that modulates the frequency, rate, or extent of T cell anergy. GO:0002667]

**regulation of cell differentiation** [Any process that modulates the frequency, rate or extent of cell differentiation, the process in which relatively unspecialized cells acquire specialized structural and functional features. GO:0045595]

**regulation of hair follicle cell proliferation** [Any process that modulates the frequency, rate or extent of hair follicle cell proliferation. GO:0071336]

**regulation of signal transduction** [Any process that modulates the frequency, rate or extent of signal transduction. GO:0009966]

**regulation of transcription by RNA polymerase II** [Any process that modulates the frequency, rate or extent of transcription mediated by RNA polymerase II. GO:0006357]

**response to denervation involved in regulation of muscle adaptation** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a denervation stimulus. This process occurs as part of the regulation of muscle adaptation. GO:0014894]

**response to retinoic acid** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a retinoic acid stimulus. GO:0032526]

**skeletal system development** [The process whose specific outcome is the progression of the skeleton over time, from its formation to the mature structure. The skeleton is the bony framework of the body in vertebrates (endoskeleton) or the hard outer envelope of insects (exoskeleton or dermoskeleton). GO:0001501]

## MSigDB Signatures:

**ACEVEDO_LIVER_CANCER_WITH_H3K27ME3_DN**: Genes whose promoters display lower levels of histone H3 trimethylation mark at K27 (H3K27me3) in hepatocellular carcinoma (HCC) compared to normal liver. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ACEVEDO_LIVER_CANCER_WITH_H3K27ME3_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ACEVEDO_LIVER_CANCER_WITH_H3K27ME3_DN.html)

**MEBARKI_HCC_PROGENITOR_FZD8CRD_UP**: Transcriptome of human HepaRG hepatocellular carcinoma liver progenitors in responses to a WNT3A-enriched microenvironment and dissection of pathways dependent on beta-catenin and/or blocked by the SFRP-like Wnt inhibitor FZD8_CRD. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MEBARKI_HCC_PROGENITOR_FZD8CRD_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MEBARKI_HCC_PROGENITOR_FZD8CRD_UP.html)

**REACTOME_TRANSPORT_OF_BILE_SALTS_AND_ORGANIC_ACIDS_METAL_IONS_AND_AMINE_COMPOUNDS**: Transport of bile salts and organic acids, metal ions and amine compounds [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRANSPORT_OF_BILE_SALTS_AND_ORGANIC_ACIDS_METAL_IONS_AND_AMINE_COMPOUNDS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRANSPORT_OF_BILE_SALTS_AND_ORGANIC_ACIDS_METAL_IONS_AND_AMINE_COMPOUNDS.html)

**REACTOME_INFECTIOUS_DISEASE**: Infectious disease [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INFECTIOUS_DISEASE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INFECTIOUS_DISEASE.html)

**KEGG_PATHWAYS_IN_CANCER**: Pathways in cancer [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_PATHWAYS_IN_CANCER.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_PATHWAYS_IN_CANCER.html)

**PUJANA_ATM_PCC_NETWORK**: Genes constituting the ATM-PCC network of transcripts whose expression positively correlated (Pearson correlation coefficient, PCC >= 0.4) with that of ATM [GeneID=472] across a compendium of normal tissues. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PUJANA_ATM_PCC_NETWORK.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PUJANA_ATM_PCC_NETWORK.html)

**REACTOME_VIRAL_INFECTION_PATHWAYS**: Viral Infection Pathways [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_VIRAL_INFECTION_PATHWAYS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_VIRAL_INFECTION_PATHWAYS.html)

**KEGG_MEDICUS_VARIANT_TEL_AML1_FUSION_TO_TRANSCRIPTIONAL_REPRESSION**: Pathway Definition from KEGG: TEL-AML1 == (HDAC+SIN3A+NCOR1) =| (IL3,CSF2,MPO,DEFA3,ELANE,GZMB) [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_VARIANT_TEL_AML1_FUSION_TO_TRANSCRIPTIONAL_REPRESSION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_VARIANT_TEL_AML1_FUSION_TO_TRANSCRIPTIONAL_REPRESSION.html)

**REACTOME_ORGANIC_CATION_TRANSPORT**: Organic cation transport [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ORGANIC_CATION_TRANSPORT.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ORGANIC_CATION_TRANSPORT.html)

**REACTOME_RNA_POLYMERASE_II_TRANSCRIPTION**: RNA Polymerase II Transcription [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RNA_POLYMERASE_II_TRANSCRIPTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RNA_POLYMERASE_II_TRANSCRIPTION.html)

**REACTOME_SARS_COV_1_INFECTION**: SARS-CoV-1 Infection [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_1_INFECTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_1_INFECTION.html)

**KEGG_ACUTE_MYELOID_LEUKEMIA**: Acute myeloid leukemia [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_ACUTE_MYELOID_LEUKEMIA.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_ACUTE_MYELOID_LEUKEMIA.html)

**REACTOME_TRANSPORT_OF_SMALL_MOLECULES**: Transport of small molecules [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRANSPORT_OF_SMALL_MOLECULES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRANSPORT_OF_SMALL_MOLECULES.html)

**PUJANA_BRCA2_PCC_NETWORK**: Genes constituting the BRCA2-PCC network of transcripts whose expression positively correlated (Pearson correlation coefficient, PCC >= 0.4) with that of BRCA2 [GeneID=675] across a compendium of normal tissues. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PUJANA_BRCA2_PCC_NETWORK.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PUJANA_BRCA2_PCC_NETWORK.html)

**REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS**: Signaling by Nuclear Receptors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS.html)

**PUJANA_BRCA1_PCC_NETWORK**: Genes constituting the BRCA1-PCC network of transcripts whose expression positively correlated (Pearson correlation coefficient, PCC >= 0.4) with that of BRCA1 [GeneID=672] across a compendium of normal tissues. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PUJANA_BRCA1_PCC_NETWORK.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PUJANA_BRCA1_PCC_NETWORK.html)

**BROWNE_HCMV_INFECTION_4HR_DN**: Genes down-regulated in primary fibroblast cell culture point after infection with HCMV (AD169 strain) at 4 h time point that were not down-regulated at the previous time point, 2 h. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_4HR_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_4HR_DN.html)

**WP_TH17_CELL_DIFFERENTIATION_PATHWAY**: Th17 cell differentiation pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TH17_CELL_DIFFERENTIATION_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TH17_CELL_DIFFERENTIATION_PATHWAY.html)

**BENPORATH_CYCLING_GENES**: Genes showing cell-cycle stage-specific expression [PMID: 12058064]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BENPORATH_CYCLING_GENES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BENPORATH_CYCLING_GENES.html)

**REACTOME_SARS_COV_INFECTIONS**: SARS-CoV Infections [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_INFECTIONS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_INFECTIONS.html)

**REACTOME_ESTROGEN_DEPENDENT_GENE_EXPRESSION**: Estrogen-dependent gene expression [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ESTROGEN_DEPENDENT_GENE_EXPRESSION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ESTROGEN_DEPENDENT_GENE_EXPRESSION.html)

**REACTOME_ESR_MEDIATED_SIGNALING**: ESR-mediated signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ESR_MEDIATED_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ESR_MEDIATED_SIGNALING.html)

**BROWNE_HCMV_INFECTION_10HR_DN**: Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 10 h time point that were not down-regulated at the previous time point, 8 h. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_10HR_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_10HR_DN.html)

**REACTOME_SLC_MEDIATED_TRANSMEMBRANE_TRANSPORT**: SLC-mediated transmembrane transport [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SLC_MEDIATED_TRANSMEMBRANE_TRANSPORT.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SLC_MEDIATED_TRANSMEMBRANE_TRANSPORT.html)

**WHITFIELD_CELL_CYCLE_G1_S**: Genes periodically expressed in synchronized HeLa cells (cervical carcinoma), with peak during the G1/S phase of cell cycle. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WHITFIELD_CELL_CYCLE_G1_S.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WHITFIELD_CELL_CYCLE_G1_S.html)

**KEGG_CHRONIC_MYELOID_LEUKEMIA**: Chronic myeloid leukemia [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_CHRONIC_MYELOID_LEUKEMIA.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_CHRONIC_MYELOID_LEUKEMIA.html)

**BROWNE_HCMV_INFECTION_12HR_DN**: Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 12 h time point that were not down-regulated at the previous time point, 10 h. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_12HR_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_12HR_DN.html)

**BROWNE_HCMV_INFECTION_16HR_DN**: Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 16 h time point that were not down-regulated at the previous time point, 14 h. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_16HR_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_16HR_DN.html)

**REACTOME_DEVELOPMENTAL_BIOLOGY**: Developmental Biology [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEVELOPMENTAL_BIOLOGY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEVELOPMENTAL_BIOLOGY.html)

**KRIEG_HYPOXIA_NOT_VIA_KDM3A**: Genes induced under hypoxia independently of KDM3A [GeneID=55818] in RCC4 cells (renal carcinoma) expressing VHL [GeneID=7428]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KRIEG_HYPOXIA_NOT_VIA_KDM3A.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KRIEG_HYPOXIA_NOT_VIA_KDM3A.html)

**VALK_AML_CLUSTER_15**: Top 40 genes from cluster 15 of acute myeloid leukemia (AML) expression profile; 88% of the samples are FAB M1 or M2 subtype, 63% have mutations in CEBPA [GeneID=1050]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/VALK_AML_CLUSTER_15.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/VALK_AML_CLUSTER_15.html)

**DODD_NASOPHARYNGEAL_CARCINOMA_UP**: Genes up-regulated in nasopharyngeal carcinoma (NPC) compared to the normal tissue. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DODD_NASOPHARYNGEAL_CARCINOMA_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DODD_NASOPHARYNGEAL_CARCINOMA_UP.html)

**DUAN_PRDM5_TARGETS**: Direct targets of PRDM5 [GeneID=11107]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DUAN_PRDM5_TARGETS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DUAN_PRDM5_TARGETS.html)

**FISCHER_DREAM_TARGETS**: Target genes of the DREAM complex. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FISCHER_DREAM_TARGETS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FISCHER_DREAM_TARGETS.html)

**RUTELLA_RESPONSE_TO_HGF_VS_CSF2RB_AND_IL4_DN**: Genes down-regulated in peripheral blood mononucleocytes by HGF [GeneID=3082] compared to those regulated by CSF2RB (GM-CSF) and IL4 [GeneID=1437;3565]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_VS_CSF2RB_AND_IL4_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_VS_CSF2RB_AND_IL4_DN.html)

**WEST_ADRENOCORTICAL_TUMOR_DN**: Down-regulated genes in pediatric adrenocortical tumors (ACT) compared to the normal tissue. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WEST_ADRENOCORTICAL_TUMOR_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WEST_ADRENOCORTICAL_TUMOR_DN.html)

**MA_RAT_AGING_UP**: Genes up-regulated across multiple cell types from nine tissues during rat aging. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MA_RAT_AGING_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MA_RAT_AGING_UP.html)

**REACTOME_PRE_NOTCH_EXPRESSION_AND_PROCESSING**: Pre-NOTCH Expression and Processing [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PRE_NOTCH_EXPRESSION_AND_PROCESSING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PRE_NOTCH_EXPRESSION_AND_PROCESSING.html)

**REACTOME_ORGANIC_CATION_ANION_ZWITTERION_TRANSPORT**: Organic cation/anion/zwitterion transport [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ORGANIC_CATION_ANION_ZWITTERION_TRANSPORT.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ORGANIC_CATION_ANION_ZWITTERION_TRANSPORT.html)

**REACTOME_SIGNALING_BY_NOTCH**: Signaling by NOTCH [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NOTCH.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NOTCH.html)

**VECCHI_GASTRIC_CANCER_EARLY_UP**: Up-regulated genes distinguishing between early gastric cancer (EGC) and normal tissue samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/VECCHI_GASTRIC_CANCER_EARLY_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/VECCHI_GASTRIC_CANCER_EARLY_UP.html)

**RUTELLA_RESPONSE_TO_HGF_UP**: Genes up-regulated in peripheral blood monocytes by HGF [GeneID=3082]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_UP.html)

**ZWANG_CLASS_3_TRANSIENTLY_INDUCED_BY_EGF**: Class III of genes transiently induced by EGF [GeneID =1950] in 184A1 cells (mammary epithelium). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZWANG_CLASS_3_TRANSIENTLY_INDUCED_BY_EGF.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZWANG_CLASS_3_TRANSIENTLY_INDUCED_BY_EGF.html)

**KOINUMA_TARGETS_OF_SMAD2_OR_SMAD3**: Genes with promoters occupied by SMAD2 or SMAD3 [GeneID=4087, 4088] in HaCaT cells (keratinocyte) according to a ChIP-chip analysis. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KOINUMA_TARGETS_OF_SMAD2_OR_SMAD3.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KOINUMA_TARGETS_OF_SMAD2_OR_SMAD3.html)

**OSWALD_HEMATOPOIETIC_STEM_CELL_IN_COLLAGEN_GEL_UP**: Genes up-regulated in hematopoietic stem cells (HSC, CD34+ [GeneID=947]) cultured in a three-dimensional collagen gel compared to the cells grown in suspension. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/OSWALD_HEMATOPOIETIC_STEM_CELL_IN_COLLAGEN_GEL_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/OSWALD_HEMATOPOIETIC_STEM_CELL_IN_COLLAGEN_GEL_UP.html)

**PID_SMAD2_3NUCLEAR_PATHWAY**: Regulation of nuclear SMAD2/3 signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_SMAD2_3NUCLEAR_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_SMAD2_3NUCLEAR_PATHWAY.html)
