
## **Pathways:**

**Dissolution of Fibrin Clot:** The crosslinked fibrin multimers in a clot are broken down to soluble polypeptides by plasmin, a serine protease. Plasmin can be generated from its inactive precursor plasminogen and recruited to the site of a fibrin clot in two ways, by interaction with tissue plasminogen activator at the surface of a fibrin clot, and by interaction with urokinase plasminogen activator at a cell surface. The first mechanism appears to be the major one responsible for the dissolution of clots within blood vessels. The second, although capable of mediating clot dissolution, may normally play a major role in tissue remodeling, cell migration, and inflammation (Chapman 1997; Lijnen 2001).

Clot dissolution is regulated in two ways. First, efficient plasmin activation and fibrinolysis occur only in complexes formed at the clot surface or on a cell membrane - proteins free in the blood are inefficient catalysts and are rapidly inactivated. Second, both plasminogen activators and plasmin itself are inactivated by specific serpins, proteins that bind to serine proteases to form stable, enzymatically inactive complexes (Kohler and Grant 2000).

These events are outlined in the drawing: black arrows connect the substrates (inputs) and products (outputs) of individual reactions, and blue lines connect output activated enzymes to the other reactions that they catalyze [[https://reactome.org/PathwayBrowser/#/R-HSA-75205](https://reactome.org/PathwayBrowser/#/R-HSA-75205)].

## GO terms:

**mRNA transcription by RNA polymerase II** [The cellular synthesis of messenger RNA (mRNA) from a DNA template by RNA polymerase II, originating at an RNA polymerase II promoter. GO:0042789]

**membrane raft assembly** [The aggregation, arrangement and bonding together of a set of components to form a membrane raft, a small (10-200 nm), heterogeneous, highly dynamic, sterol- and sphingolipid-enriched membrane domains that compartmentalizes cellular processes. GO:0001765]

**positive regulation of focal adhesion assembly** [Any process that activates or increases the frequency, rate or extent of focal adhesion assembly, the establishment and maturation of focal adhesions. GO:0051894]

**positive regulation of plasminogen activation** [Any process that increases the rate, frequency or extent of plasminogen activation. Plasminogen activation is the process in which plasminogen is processed to plasmin. GO:0010756]

**positive regulation of stress fiber assembly** [Any process that activates or increases the frequency, rate or extent of the assembly of a stress fiber, a bundle of microfilaments and other proteins found in fibroblasts. GO:0051496]

**positive regulation of substrate adhesion-dependent cell spreading** [Any process that activates or increases the frequency, rate or extent of substrate adhesion-dependent cell spreading. GO:1900026]

**positive regulation of transcription by RNA polymerase II** [Any process that activates or increases the frequency, rate or extent of transcription from an RNA polymerase II promoter. GO:0045944]

**protein localization to plasma membrane** [A process in which a protein is transported to, or maintained in, a specific location in the plasma membrane. GO:0072659]

**regulation of cell differentiation** [Any process that modulates the frequency, rate or extent of cell differentiation, the process in which relatively unspecialized cells acquire specialized structural and functional features. GO:0045595]

**regulation of cell growth** [Any process that modulates the frequency, rate, extent or direction of cell growth. GO:0001558]

**regulation of neurogenesis** [Any process that modulates the frequency, rate or extent of neurogenesis, the generation of cells in the nervous system. GO:0050767]

**response to xenobiotic stimulus** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a xenobiotic, a compound foreign to the organim exposed to it. It may be synthesized by another organism (like ampicilin) or it can be a synthetic chemical. GO:0009410]

**vesicle budding from membrane** [The evagination of a membrane, resulting in formation of a vesicle. GO:0006900]

## MSigDB Signatures:

**ACEVEDO_LIVER_TUMOR_VS_NORMAL_ADJACENT_TISSUE_UP**: Genes up-regulated in liver tumor compared to the normal adjacent tissue. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ACEVEDO_LIVER_TUMOR_VS_NORMAL_ADJACENT_TISSUE_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ACEVEDO_LIVER_TUMOR_VS_NORMAL_ADJACENT_TISSUE_UP.html)

**WIELAND_UP_BY_HBV_INFECTION**: Genes induced in the liver during hepatitis B (HBV) viral clearance in chimpanzees. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WIELAND_UP_BY_HBV_INFECTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WIELAND_UP_BY_HBV_INFECTION.html)

**ACEVEDO_LIVER_CANCER_UP**: Genes up-regulated in hepatocellular carcinoma (HCC) compared to normal liver samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ACEVEDO_LIVER_CANCER_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ACEVEDO_LIVER_CANCER_UP.html)

**PATIL_LIVER_CANCER**: Genes up-regulated in hepatocellular carcinoma (HCC) compared to normal liver samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PATIL_LIVER_CANCER.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PATIL_LIVER_CANCER.html)

**REACTOME_HEMOSTASIS**: Hemostasis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HEMOSTASIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HEMOSTASIS.html)

**HSIAO_HOUSEKEEPING_GENES**: Housekeeping genes identified as expressed across 19 normal tissues. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HSIAO_HOUSEKEEPING_GENES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HSIAO_HOUSEKEEPING_GENES.html)

**HOSHIDA_LIVER_CANCER_SUBCLASS_S1**: Genes from 'subtype S1' signature of hepatocellular carcinoma (HCC): aberrant activation of the WNT signaling pathway. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HOSHIDA_LIVER_CANCER_SUBCLASS_S1.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HOSHIDA_LIVER_CANCER_SUBCLASS_S1.html)

**CHIANG_LIVER_CANCER_SUBCLASS_UNANNOTATED_DN**: Marker genes down-regulated in the 'unannotated' subclass of hepatocellular carcinoma (HCC) samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHIANG_LIVER_CANCER_SUBCLASS_UNANNOTATED_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHIANG_LIVER_CANCER_SUBCLASS_UNANNOTATED_DN.html)

**WP_PROSTAGLANDIN_SYNTHESIS_AND_REGULATION**: Prostaglandin synthesis and regulation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PROSTAGLANDIN_SYNTHESIS_AND_REGULATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PROSTAGLANDIN_SYNTHESIS_AND_REGULATION.html)

**KEGG_MEDICUS_PATHOGEN_SALMONELLA_SOPB_TO_ANXA2_S100A10_REGULATED_ACTIN_CYTOSKELETON**: Pathway Definition from KEGG: (SopB,SopE) -> (ANXA2+S100A10) == AHNAK == (ACTB,ACTG1) [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_PATHOGEN_SALMONELLA_SOPB_TO_ANXA2_S100A10_REGULATED_ACTIN_CYTOSKELETON.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_PATHOGEN_SALMONELLA_SOPB_TO_ANXA2_S100A10_REGULATED_ACTIN_CYTOSKELETON.html)

**REACTOME_DISSOLUTION_OF_FIBRIN_CLOT**: Dissolution of Fibrin Clot [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DISSOLUTION_OF_FIBRIN_CLOT.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DISSOLUTION_OF_FIBRIN_CLOT.html)

**BROWNE_HCMV_INFECTION_24HR_DN**: Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 24 h time point that were not down-regulated at the previous time point, 20 h. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_24HR_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_24HR_DN.html)

**NABA_SECRETED_FACTORS**: Genes encoding secreted soluble factors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_SECRETED_FACTORS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_SECRETED_FACTORS.html)

**LEE_NEURAL_CREST_STEM_CELL_UP**: Genes up-regulated in the neural crest stem cells (NCS), defined as p75+/HNK1+ [GeneID=4804;27087]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LEE_NEURAL_CREST_STEM_CELL_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LEE_NEURAL_CREST_STEM_CELL_UP.html)

**NABA_MATRISOME_ASSOCIATED**: Ensemble of genes encoding ECM-associated proteins including ECM-affilaited proteins, ECM regulators and secreted factors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_ASSOCIATED.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_ASSOCIATED.html)

**NABA_MATRISOME_HIGHLY_METASTATIC_BREAST_CANCER**: Matrisome proteins exclusively detected in highly metastatic breast cancer human-to-mouse xenografts (MDA-MB-231_LM2) in comparison to poorly metastatic breast cancer human-to-mouse xenografts (MDA-MB-231). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_HIGHLY_METASTATIC_BREAST_CANCER.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_HIGHLY_METASTATIC_BREAST_CANCER.html)

**SA_FAS_SIGNALING**: The TNF-type receptor Fas induces apoptosis on ligand binding. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/SA_FAS_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/SA_FAS_SIGNALING.html)

**AKL_HTLV1_INFECTION_UP**: Genes up-regulated in WE17/10 cells (CD4+ [GeneID=920] T lymphocytes) infected by HTLV1 (and thus displaying low CD7 [GeneID=924]) compared to the uninfected (i.e., CD7+) cells. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AKL_HTLV1_INFECTION_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AKL_HTLV1_INFECTION_UP.html)

**PURBEY_TARGETS_OF_CTBP1_NOT_SATB1_DN**: Genes down-regulated in HEK-293 cells (fibroblast) upon knockdown of CTBP1 but not of SATB1 [GeneID=1487, 6304] by RNAi. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PURBEY_TARGETS_OF_CTBP1_NOT_SATB1_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PURBEY_TARGETS_OF_CTBP1_NOT_SATB1_DN.html)

**LI_WILMS_TUMOR_VS_FETAL_KIDNEY_1_UP**: Genes up-regulated in Wilm's tumor samples compared to fetal kidney. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LI_WILMS_TUMOR_VS_FETAL_KIDNEY_1_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LI_WILMS_TUMOR_VS_FETAL_KIDNEY_1_UP.html)

**LOPEZ_MBD_TARGETS**: Genes up-regulated in HeLa cells (cervical cancer) after simultaneus knockdown of all three MBD (methyl-CpG binding domain) proteins MeCP2, MBD1 and MBD2 [GeneID=4204;4152;8932] by RNAi. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LOPEZ_MBD_TARGETS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LOPEZ_MBD_TARGETS.html)

**VECCHI_GASTRIC_CANCER_EARLY_UP**: Up-regulated genes distinguishing between early gastric cancer (EGC) and normal tissue samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/VECCHI_GASTRIC_CANCER_EARLY_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/VECCHI_GASTRIC_CANCER_EARLY_UP.html)

**CHICAS_RB1_TARGETS_CONFLUENT**: Genes up-regulated in confluent IMR90 cells (fibroblast) after knockdown of RB1 [GeneID=5925] by RNAi. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHICAS_RB1_TARGETS_CONFLUENT.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHICAS_RB1_TARGETS_CONFLUENT.html)

**KOINUMA_TARGETS_OF_SMAD2_OR_SMAD3**: Genes with promoters occupied by SMAD2 or SMAD3 [GeneID=4087, 4088] in HaCaT cells (keratinocyte) according to a ChIP-chip analysis. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KOINUMA_TARGETS_OF_SMAD2_OR_SMAD3.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KOINUMA_TARGETS_OF_SMAD2_OR_SMAD3.html)
