
## **Pathways:**

**Vitamin D receptor pathway:** The vitamin D receptor (VDR, a.k.a. NR1I1) is a nuclear receptor that responds to binding of vitamin D and subsequently forms a dimer with RXR to induce transcription of its target genes. It mainly regulates genes cytochrome P450 genes involved in xenobiotic biotransformation [[https://www.wikipathways.org/pathways/WP2877.html](https://www.wikipathways.org/pathways/WP2877.html)].

**Wnt/beta-Catenin Signaling**: The conserved Wnt/beta-Catenin pathway regulates stem cell pluripotency and cell fate decisions during development. This developmental cascade integrates signals from other pathways, including retinoic acid, FGF, TGF-beta, and BMP, within different cell types and tissues. The Wnt ligand is a secreted glycoprotein that binds to Frizzled receptors, leading to the formation of a larger cell surface complex with LRP5/6. Frizzleds are ubiquitinated by ZNRF3 and RNF43, whose activity is inhibited by R-spondin binding to LGR5/6. In this manner R-spondins increase sensitivity of cells to the Wnt ligand. Activation of the Wnt receptor complex triggers displacement of the multifunctional kinase GSK-3beta from a regulatory APC/Axin/GSK-3beta-complex. In the absence of Wnt-signal (Off-state), beta-catenin, an integral E-cadherin cell-cell adhesion adaptor protein and transcriptional co-regulator, is targeted by coordinated phosphorylation by CK1 and the APC/Axin/GSK-3beta-complex leading to its ubiquitination and proteasomal degradation through the beta-TrCP/Skp pathway. In the presence of Wnt ligand (On-state), the co-receptor LRP5/6 is brought in complex with Wnt-bound Frizzled. This leads to activation of Dishevelled (Dvl) by sequential phosphorylation, poly-ubiquitination, and polymerization, which displaces GSK-3beta from APC/Axin through an unclear mechanism that may involve substrate trapping and/ or endosome sequestration. Stablized beta-catenin is translocated to the nucleus via Rac1 and other factors, where it binds to LEF/TCF transcription factors, displacing co-repressors and recruiting additional co-activators to Wnt target genes. Additionally, beta-catenin cooperates with several other transcription factors to regulate specific targets. Importantly, researchers have found beta-catenin point mutations in human tumors that prevent GSK-3beta phosphorylation and thus lead to its aberrant accumulation. E-cadherin, APC, R-spondin and Axin mutations have also been documented in tumor samples, underscoring the deregulation of this pathway in cancer. Wnt signaling has also been shown to promote nuclear accumulation of other transcriptional regulator implicated in cancer, such as TAZ and Snail1. Furthermore, GSK-3beta is involved in glycogen metabolism and other signaling pathways, which has made its inhibition relevant to diabetes and neurodegenerative disorders [[https://www.cellsignal.com/pathways/wnt-beta-catenin-signaling-pathway](https://www.cellsignal.com/pathways/wnt-beta-catenin-signaling-pathway), PMID: 21795396, PMID: 17101323].

**Regulation of NF-kappa B signaling:** Nuclear factor kappa B (NF-kappa-B) is activated by a diverse range of stimuli including cytokines, ligands of pattern-recognition receptors (PRRs) such as Toll-like receptors (TLRs) in myeloid cells, antigen-activated TCR in T-cells and by DNA damage (reviewed in Yu H et al. 2020; Zhang T et al. 2021). NF-kappa-B regulates the transcription of genes that are involved in immune and inflammatory responses, cell cycle, cell proliferation and apoptosis (Bhatt D & Ghosh S 2014; Liu T et al. 2017; Yu H et al. 2020). In unstimulated cells, NF-kappaB is sequestered in the cytosol through interactions with a class of inhibitor proteins, called NF-kappaB inhibitors (IkBs, such as NFKBIA or NFKBIB) (Jacobs MD & Harrison SC 1998). IkBs mask the nuclear localization signal (NLS) of NF-kappaB preventing its nuclear translocation (Cervantes CF et al. 2011). A key event in NF-kappaB activation involves phosphorylation of IkBs by the IkB kinase (IKK) complex which consists of CHUK, IKBKB and IKBKG subunits (Israel A 2010). The activated NF-kappaB signaling is tightly controlled at multiple levels (Dorrington MG & Fraser IDC 2019; Prescott JA et al. 2021). Dysregulated NF-kappaB activity can cause tissue damage associated with inflammatory diseases and is also linked to tumorigenesis (Aggarwal BB & Sung B 2011; Liu T et al.2017; Barnabei L et al. 2021). The regulation of NF-kappaB is cell-type-, context- , and stimulus-dependent and is crucial for orchestrating specific cellular responses (Mussbacher M et al. 2019).This Reactome module describes several molecular mechanisms that regulate TLR-mediated NF-kappaB signaling at the level of the IKK signaling complex [[https://reactome.org/content/detail/R-HSA-9758274](https://reactome.org/content/detail/R-HSA-9758274), PMID: 20507646].

## GO terms:

**positive chemotaxis** [The directed movement of a motile cell or organism towards a higher concentration of a chemical. GO:0050918]

**positive regulation of canonical NF-kappaB signal transduction** [Any process that activates or increases the frequency, rate or extent of a canonical NF-kappaB signaling cascade. GO:0043123]

## MSigDB Signatures:

**HEBERT_MATRISOME_TNBC_BONE_BRAIN_LIVER_LUNG_METASTASTASES**: Matrisome proteins found in significantly higher abundance in TNBC brain, bone, liver and lung metastatases compared to normal samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HEBERT_MATRISOME_TNBC_BONE_BRAIN_LIVER_LUNG_METASTASTASES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HEBERT_MATRISOME_TNBC_BONE_BRAIN_LIVER_LUNG_METASTASTASES.html)

**HEBERT_MATRISOME_TNBC_BONE_BRAIN_LUNG_LIVER_METASTASTASES_TUMOR_CELL_DERIVED**: Tumor cell-derived matrisome proteins found in significantly higher abundance in TNBC brain, bone, liver and lung metastatases compared to normal samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HEBERT_MATRISOME_TNBC_BONE_BRAIN_LUNG_LIVER_METASTASTASES_TUMOR_CELL_DERIVED.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HEBERT_MATRISOME_TNBC_BONE_BRAIN_LUNG_LIVER_METASTASTASES_TUMOR_CELL_DERIVED.html)

**WOOD_EBV_EBNA1_TARGETS_UP**: Genes up-regulated in the Ad/AH cells (adenocarcinoma) engineered to stably express the Epstein-Barr virus (EBV) gene EBNA1. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WOOD_EBV_EBNA1_TARGETS_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WOOD_EBV_EBNA1_TARGETS_UP.html)

**WP_VITAMIN_D_RECEPTOR_PATHWAY**: Vitamin D receptor pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_VITAMIN_D_RECEPTOR_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_VITAMIN_D_RECEPTOR_PATHWAY.html)

**ROY_WOUND_BLOOD_VESSEL_UP**: Genes up-regulated in blood vessel cells from wound site. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ROY_WOUND_BLOOD_VESSEL_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ROY_WOUND_BLOOD_VESSEL_UP.html)

**NAKAYAMA_SOFT_TISSUE_TUMORS_PCA1_UP**: Top 100 probe sets contrubuting to the positive side of the 1st principal component; predominantly associated with spindle cell and pleomorphic sarcoma samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NAKAYAMA_SOFT_TISSUE_TUMORS_PCA1_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NAKAYAMA_SOFT_TISSUE_TUMORS_PCA1_UP.html)

**BROWNE_HCMV_INFECTION_24HR_DN**: Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 24 h time point that were not down-regulated at the previous time point, 20 h. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_24HR_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_24HR_DN.html)

**DAIRKEE_CANCER_PRONE_RESPONSE_BPA_E2**: 'Cancer prone response profile' (CPRP): genes common to estradiol and bisphenol A [PubChem=5757;6623] response of epithelial cell cultures from patients at high risk of breast cancer. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DAIRKEE_CANCER_PRONE_RESPONSE_BPA_E2.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DAIRKEE_CANCER_PRONE_RESPONSE_BPA_E2.html)

**NABA_SECRETED_FACTORS**: Genes encoding secreted soluble factors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_SECRETED_FACTORS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_SECRETED_FACTORS.html)

**NABA_MATRISOME_ASSOCIATED**: Ensemble of genes encoding ECM-associated proteins including ECM-affilaited proteins, ECM regulators and secreted factors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_ASSOCIATED.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_ASSOCIATED.html)

**FARMER_BREAST_CANCER_APOCRINE_VS_BASAL**: Genes which best discriminate between two groups of breast cancer according the status of ESR1 and AR [GeneID=2099;367]: apocrine (ESR1- AR+) vs basal (ESR1- AR-). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FARMER_BREAST_CANCER_APOCRINE_VS_BASAL.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FARMER_BREAST_CANCER_APOCRINE_VS_BASAL.html)

**WP_HAIR_FOLLICLE_DEVELOPMENT_CYTODIFFERENTIATION_PART_3_OF_3**: Hair follicle development cytodifferentiation part 3 of 3 [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_HAIR_FOLLICLE_DEVELOPMENT_CYTODIFFERENTIATION_PART_3_OF_3.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_HAIR_FOLLICLE_DEVELOPMENT_CYTODIFFERENTIATION_PART_3_OF_3.html)

**FLECHNER_BIOPSY_KIDNEY_TRANSPLANT_REJECTED_VS_OK_UP**: Genes up-regulated in kidney biopsies from patients with acute transplant rejection compared to the biopsies from patients with well functioning kidneys more than 1-year post transplant. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FLECHNER_BIOPSY_KIDNEY_TRANSPLANT_REJECTED_VS_OK_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FLECHNER_BIOPSY_KIDNEY_TRANSPLANT_REJECTED_VS_OK_UP.html)

**DEMAGALHAES_AGING_UP**: Genes consistently overexpressed with age, based on meta-analysis of microarray data. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DEMAGALHAES_AGING_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DEMAGALHAES_AGING_UP.html)

**GRABARCZYK_BCL11B_TARGETS_UP**: Genes up-regulated in Jurkat cells (transformed T lymphocytes) after knockdown of BCL11B [GeneID=64919] by RNAi. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/GRABARCZYK_BCL11B_TARGETS_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/GRABARCZYK_BCL11B_TARGETS_UP.html)

**BASSO_B_LYMPHOCYTE_NETWORK**: Genes which comprise the top 1% of highly interconnected genes (major hubs) that account for most of gene interactions in the reconstructed regulatory networks from expression profiles in B lymphocytes. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BASSO_B_LYMPHOCYTE_NETWORK.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BASSO_B_LYMPHOCYTE_NETWORK.html)

**MA_RAT_AGING_UP**: Genes up-regulated across multiple cell types from nine tissues during rat aging. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MA_RAT_AGING_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MA_RAT_AGING_UP.html)

**CONCANNON_APOPTOSIS_BY_EPOXOMICIN_DN**: Genes down-regulated in SH-SY5Y cells (neuroblastoma) after treatment with epoxomicin [PubChem=3035402], a protease inhibitor causing apoptosis. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CONCANNON_APOPTOSIS_BY_EPOXOMICIN_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CONCANNON_APOPTOSIS_BY_EPOXOMICIN_DN.html)

**JINESH_BLEBBISHIELD_TRANSFORMED_STEM_CELL_SPHERES_DN**: Genes Down-regulated in transformed spheres compared to blebbishields from RT4 cells [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JINESH_BLEBBISHIELD_TRANSFORMED_STEM_CELL_SPHERES_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JINESH_BLEBBISHIELD_TRANSFORMED_STEM_CELL_SPHERES_DN.html)

**CHICAS_RB1_TARGETS_CONFLUENT**: Genes up-regulated in confluent IMR90 cells (fibroblast) after knockdown of RB1 [GeneID=5925] by RNAi. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHICAS_RB1_TARGETS_CONFLUENT.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHICAS_RB1_TARGETS_CONFLUENT.html)

**JINESH_BLEBBISHIELD_VS_LIVE_CONTROL_UP**: Genes up-regulated in blebbishields compared to control RT4 live cells [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JINESH_BLEBBISHIELD_VS_LIVE_CONTROL_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JINESH_BLEBBISHIELD_VS_LIVE_CONTROL_UP.html)

**LINDGREN_BLADDER_CANCER_CLUSTER_1_DN**: Down-regulated genes whose expression profile is specific to Custer I of urothelial cell carcinoma (UCC) tumors. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LINDGREN_BLADDER_CANCER_CLUSTER_1_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LINDGREN_BLADDER_CANCER_CLUSTER_1_DN.html)

**BOQUEST_STEM_CELL_UP**: Genes up-regulated in freshly isolated CD31- [GeneID=5175] (stromal stem cells from adipose tissue) versus the CD31+ (non-stem) counterparts. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BOQUEST_STEM_CELL_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BOQUEST_STEM_CELL_UP.html)

**ELVIDGE_HYPOXIA_BY_DMOG_UP**: Genes up-regulated in MCF7 cells (breast cancer) treated with hypoxia mimetic DMOG [PubChem=3080614]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ELVIDGE_HYPOXIA_BY_DMOG_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ELVIDGE_HYPOXIA_BY_DMOG_UP.html)
