
## **Pathways:**

-   **Neutrophil degranulation**: Neutrophils are the most abundant leukocytes (white blood cells), indispensable in defending the body against invading microorganisms. In response to infection, neutrophils leave the circulation and migrate towards the inflammatory focus. They contain several subsets of granules that are mobilized to fuse with the cell membrane or phagosomal membrane, resulting in the exocytosis or exposure of membrane proteins. Traditionally, neutrophil granule constituents are described as antimicrobial or proteolytic, but granules also introduce membrane proteins to the cell surface, changing how the neutrophil responds to its environment (Borregaard et al. 2007). Primed neutrophils actively secrete cytokines and other inflammatory mediators and can present antigens via MHC II, stimulating T-cells (Wright et al. 2010). Granules form during neutrophil differentiation. Granule subtypes can be distinguished by their content but overlap in structure and composition. The differences are believed to be a consequence of changing protein expression and differential timing of granule formation during the terminal processes of neutrophil differentiation, rather than sorting (Le Cabec et al. 1996). The classical granule subsets are Azurophil or primary granules (AG), secondary granules (SG) and gelatinase granules (GG). Neutrophils also contain exocytosable storage cell organelles, storage vesicles (SV), formed by endocytosis they contain many cell-surface markers and extracellular, plasma proteins (Borregaard et al. 1992). Ficolin-1-rich granules (FG) are like GGs highly exocytosable but gelatinase-poor (Rorvig et al. 2009) [[https://reactome.org/PathwayBrowser/#/R-HSA-6798695](https://reactome.org/PathwayBrowser/#/R-HSA-6798695)].
-   **Platelet degranulation**: Platelets function as exocytotic cells, secreting a plethora of effector molecules at sites of vascular injury. Platelets contain a number of distinguishable storage granules including alpha granules, dense granules and lysosomes. On activation platelets release a variety of proteins, largely from storage granules but also as the result of apparent cell lysis. These act in an autocrine or paracrine fashion to modulate cell signaling. Alpha granules contain mainly polypeptides such as fibrinogen, von Willebrand factor, growth factors and protease inhibitors that that supplement thrombin generation at the site of injury. Dense granules contain small molecules, particularly adenosine diphosphate (ADP), adenosine triphosphate (ATP), serotonin and calcium, all recruit platelets to the site of injury. The molecular mechanism which facilitates granule release involves soluble NSF attachment protein receptors (SNAREs), which assemble into complexes to form a universal membrane fusion apparatus. Although all cells use SNAREs for membrane fusion, different cells possess different SNARE isoforms. Platelets and chromaffin cells use many of the same chaperone proteins to regulate SNARE-mediated secretion (Fitch-Tewfik & Flaumenhaft 2013) [[https://reactome.org/PathwayBrowser/#/R-HSA-114608](https://reactome.org/PathwayBrowser/#/R-HSA-114608)].

## GO terms:

**cellular response to cAMP** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cAMP (cyclic AMP, adenosine 3',5'-cyclophosphate) stimulus. GO:0071320]

**cellular response to glucocorticoid stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a glucocorticoid stimulus. Glucocorticoids are hormonal C21 corticosteroids synthesized from cholesterol with the ability to bind with the cortisol receptor and trigger similar effects. Glucocorticoids act primarily on carbohydrate and protein metabolism, and have anti-inflammatory effects. GO:0071385]

**cellular response to interleukin-1** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interleukin-1 stimulus. GO:0071347]

**cellular response to interleukin-6** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interleukin-6 stimulus. GO:0071354]

**cellular response to type II interferon** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interferon-gamma stimulus. Interferon gamma is the only member of the type II interferon found so far. GO:0071346]

**response to bacterium** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a bacterium. GO:0009617]

**response to cytokine** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cytokine stimulus. GO:0034097]

**response to lipopolysaccharide** [Any process that results in a change in state or activity of an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lipopolysaccharide stimulus; lipopolysaccharide is a major component of the cell wall of gram-negative bacteria. GO:0032496]

**response to peptide hormone** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a peptide hormone stimulus. A peptide hormone is any of a class of peptides that are secreted into the blood stream and have endocrine functions in living animals. GO:0043434]

**response to vitamin B6** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a vitamin B6 stimulus. Vitamin B6 encompasses pyridoxal, pyridoxamine and pyridoxine and the active form, pyridoxal phosphate. GO:0034516]

## MSigDB Signatures:

**BLALOCK_ALZHEIMERS_DISEASE_UP**: Genes up-regulated in brain from patients with Alzheimer's disease. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BLALOCK_ALZHEIMERS_DISEASE_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BLALOCK_ALZHEIMERS_DISEASE_UP.html)

**HSIAO_HOUSEKEEPING_GENES**: Housekeeping genes identified as expressed across 19 normal tissues. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HSIAO_HOUSEKEEPING_GENES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HSIAO_HOUSEKEEPING_GENES.html)

**REACTOME_INNATE_IMMUNE_SYSTEM**: Innate Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html)

**COLIN_PILOCYTIC_ASTROCYTOMA_VS_GLIOBLASTOMA_UP**: Genes up-regulated in pilocytic astrocytoma compared to glioblastoma samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/COLIN_PILOCYTIC_ASTROCYTOMA_VS_GLIOBLASTOMA_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/COLIN_PILOCYTIC_ASTROCYTOMA_VS_GLIOBLASTOMA_UP.html)

**HSIAO_LIVER_SPECIFIC_GENES**: Liver selective genes [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HSIAO_LIVER_SPECIFIC_GENES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HSIAO_LIVER_SPECIFIC_GENES.html)

**REACTOME_NEUTROPHIL_DEGRANULATION**: Neutrophil degranulation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NEUTROPHIL_DEGRANULATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NEUTROPHIL_DEGRANULATION.html)

**WP_VITAMIN_B12_METABOLISM**: Vitamin B12 metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_VITAMIN_B12_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_VITAMIN_B12_METABOLISM.html)

**REACTOME_HEMOSTASIS**: Hemostasis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HEMOSTASIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HEMOSTASIS.html)

**WP_SELENIUM_MICRONUTRIENT_NETWORK**: Selenium micronutrient network [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_SELENIUM_MICRONUTRIENT_NETWORK.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_SELENIUM_MICRONUTRIENT_NETWORK.html)

**PECE_MAMMARY_STEM_CELL_UP**: The '3/3 signature': genes consistently up-regulated in all three pools of normal mammary stem cells (defined by their ability to retain the dye PKH26). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PECE_MAMMARY_STEM_CELL_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PECE_MAMMARY_STEM_CELL_UP.html)

**MA_RAT_AGING_UP**: Genes up-regulated across multiple cell types from nine tissues during rat aging. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MA_RAT_AGING_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MA_RAT_AGING_UP.html)

**PEDERSEN_METASTASIS_BY_ERBB2_ISOFORM_6**: Genes regulated in MCF7 cells (breast cancer) by expression of the full-length form of ERBB2 [GeneID=2064] at 60 h time point. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PEDERSEN_METASTASIS_BY_ERBB2_ISOFORM_6.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PEDERSEN_METASTASIS_BY_ERBB2_ISOFORM_6.html)

**SENGUPTA_NASOPHARYNGEAL_CARCINOMA_WITH_LMP1_DN**: Genes down-regulated in nasopharyngeal carcinoma (NPC) positive for LMP1 [GeneID=9260], a latent gene of Epstein-Barr virus (EBV). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/SENGUPTA_NASOPHARYNGEAL_CARCINOMA_WITH_LMP1_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/SENGUPTA_NASOPHARYNGEAL_CARCINOMA_WITH_LMP1_DN.html)

**NABA_MATRISOME_HGSOC_OMENTAL_METASTASIS**: Matrisome proteins detected in significantly different abundance in omentum metastases from high grade serous ovarian cancer (HGSOC) compared to normal omentum. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_HGSOC_OMENTAL_METASTASIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_HGSOC_OMENTAL_METASTASIS.html)

**KAAB_FAILED_HEART_VENTRICLE_DN**: Genes down-regulated in the ventricles of failing hearts (DCM and ICM) compared to the healthy controls. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KAAB_FAILED_HEART_VENTRICLE_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KAAB_FAILED_HEART_VENTRICLE_DN.html)

**MCCABE_BOUND_BY_HOXC6**: Genes whose promoters where bound by HOXC6 [GeneID=3223] in LNCaP cells (prostate cancer), according to a ChIP-chip analysis. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MCCABE_BOUND_BY_HOXC6.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MCCABE_BOUND_BY_HOXC6.html)

**NABA_MATRISOME**: Ensemble of genes encoding extracellular matrix and extracellular matrix-associated proteins [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME.html)

**SCHOEN_NFKB_SIGNALING**: Genes down-regulated in A375 cells (melanoma) treated with KINK-1, a small molecule inhibitor of NFKB. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/SCHOEN_NFKB_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/SCHOEN_NFKB_SIGNALING.html)
