
## **Pathways:**

**BMAL1:CLOCK,NPAS2 activates circadian gene expression:** As inferred from mouse, BMAL1:CLOCK (ARNTL:CLOCK) and BMAL1:NPAS2 (ARNTL:NPAS2) heterodimers bind to sequence elements (E boxes) in the promoters of target genes and enhance transcription (Gekakis et al. 1998, reviewed in Munoz and Baler 2003)[[https://reactome.org/PathwayBrowser/#/R-HSA-1368108&PATH=R-HSA-400253](https://reactome.org/PathwayBrowser/#/R-HSA-1368108&PATH=R-HSA-400253)].

**Dissolution of Fibrin Clot:** The crosslinked fibrin multimers in a clot are broken down to soluble polypeptides by plasmin, a serine protease. Plasmin can be generated from its inactive precursor plasminogen and recruited to the site of a fibrin clot in two ways, by interaction with tissue plasminogen activator at the surface of a fibrin clot, and by interaction with urokinase plasminogen activator at a cell surface. The first mechanism appears to be the major one responsible for the dissolution of clots within blood vessels. The second, although capable of mediating clot dissolution, may normally play a major role in tissue remodeling, cell migration, and inflammation (Chapman 1997; Lijnen 2001).

Clot dissolution is regulated in two ways. First, efficient plasmin activation and fibrinolysis occur only in complexes formed at the clot surface or on a cell membrane - proteins free in the blood are inefficient catalysts and are rapidly inactivated. Second, both plasminogen activators and plasmin itself are inactivated by specific serpins, proteins that bind to serine proteases to form stable, enzymatically inactive complexes (Kohler and Grant 2000). These events are outlined in the drawing: black arrows connect the substrates (inputs) and products (outputs) of individual reactions, and blue lines connect output activated enzymes to the other reactions that they catalyze [[https://reactome.org/PathwayBrowser/#/R-HSA-75205](https://reactome.org/PathwayBrowser/#/R-HSA-75205)].

**ECM proteoglycans:** Proteoglycans are major components of the extracellular matrix. In cartilage the matrix constitutes more than 90% of tissue dry weight. Proteoglycans are proteins substituted with glycosaminoglycans (GAGs), linear polysaccharides consisting of a repeating disaccharide, generally of an acetylated amino sugar alternating with a uronic acid. Most proteoglycans are located in the extracellular space. Proteoglycans are highly diverse, both in terms of the core proteins and the subtypes of GAG chains, namely chondroitin sulfate (CS), keratan sulfate (KS), dermatan sulfate (DS) and heparan sulfate (HS). Hyaluronan is a non-sulfated GAG whose molecular weight runs into millions of Dalton; in articular cartilage, a single hyaluronan molecule can hold upto 100 aggrecan molecules and these aggregates are stabilized by a link protein[[https://reactome.org/PathwayBrowser/#/R-HSA-3000178](https://reactome.org/PathwayBrowser/#/R-HSA-3000178)].

**Generic Transcription Pathway:** Detailed studies of gene transcription regulation in a wide variety of eukaryotic systems has revealed the general principles and mechanisms by which cell- or tissue-specific regulation of differential gene transcription is mediated (reviewed in Naar, 2001. Kadonaga, 2004, Maston, 2006, Barolo, 2002; Roeder, 2005, Rosenfeld, 2006). Of the three major classes of DNA polymerase involved in eukaryotic gene transcription, Polymerase II generally regulates protein-encoding genes. Figure 1 shows a diagram of the various components involved in cell-specific regulation of Pol-II gene transcription.

Core Promoter: Pol II-regulated genes typically have a Core Promoter where Pol II and a variety of general factors bind to specific DNA motifs: i: the TATA box (TATA DNA sequence), which is bound by the "TATA-binding protein" (TBP). ii: the Initiator motif (INR), where Pol II and certain other core factors bind, is present in many Pol II-regulated genes. iii: the Downstream Promoter Element (DPE), which is present in a subset of Pol II genes, and where additional core factors bind. The core promoter binding factors are generally ubiquitously expressed, although there are exceptions to this.

Proximal Promoter: immediately upstream (5') of the core promoter, Pol II target genes often have a Proximal Promoter region that spans up to 500 base pairs (b.p.), or even to 1000 b.p.. This region contains a number of functional DNA binding sites for a specific set of transcription activator (TA) and transcription repressor (TR) proteins. These TA and TR factors are generally cell- or tissue-specific in expression, rather than ubiquitous, so that the presence of their cognate binding sites in the proximal promoter region programs cell- or tissue-specific expression of the target gene, perhaps in conjunction with TA and TR complexes bound in distal enhancer regions.

Distal Enhancer(s): many or most Pol II regulated genes in higher eukaryotes have one or more distal Enhancer regions which are essential for proper regulation of the gene, often in a cell or tissue-specific pattern. Like the proximal promoter region, each of the distal enhancer regions typically contain a cluster of binding sites for specific TA and/or TR DNA-binding factors, rather than just a single site.

Enhancers generally have three defining characteristics: i: They can be located very long distances from the promoter of the target gene they regulate, sometimes as far as 100 Kb, or more. ii: They can be either upstream (5') or downstream (3') of the target gene, including within introns of that gene. iii: They can function in either orientation in the DNA.

Combinatorial mechanisms of transcription regulation: The specific combination of TA and TR binding sites within the proximal promoter and/or distal enhancer(s) provides a "combinatorial transcription code" that mediates cell- or tissue-specific expression of the associated target gene. Each promoter or enhancer region mediates expression in a specific subset of the overall expression pattern. In at least some cases, each enhancer region functions completely independently of the others, so that the overall expression pattern is a linear combination of the expression patterns of each of the enhancer modules.

Co-Activator and Co-Repressor Complexes: DNA-bound TA and TR proteins typically recruit the assembly of specific Co-Activator (Co-A) and Co-Repressor (Co-R) Complexes, respectively, which are essential for regulating target gene transcription. Both Co-A's and Co-R's are multi-protein complexes that contain several specific protein components.

Co-Activator complexes generally contain at lease one component protein that has Histone Acetyl Transferase (HAT) enzymatic activity. This functions to acetylate Histones and/or other chromatin-associated factors, which typically increases that transcription activation of the target gene. By contrast, Co-Repressor complexes generally contain at lease one component protein that has Histone De-Acetylase (HDAC) enzymatic activity. This functions to de-acetylate Histones and/or other chromatin-associated factors. This typically increases the transcription repression of the target gene.

Adaptor (Mediator) complexes: In addition to the co-activator complexes that assemble on particular cell-specific TA factors, - there are at least two additional transcriptional co-activator complexes common to most cells. One of these is the Mediator complex, which functions as an "adaptor" complex that bridges between the tissue-specific co-activator complexes assembled in the proximal promoter (or distal enhancers). The human Mediator complex has been shown to contain at least 19 protein distinct components. Different combinations of these co-activator proteins are also found to be components of specific transcription Co-Activator complexes, such as the DRIP, TRAP and ARC complexes described below.

TBP/TAF complex: Another large Co-A complex is the "TBP-associated factors" (TAFs) that assemble on TBP (TATA-Binding Protein), which is bound to the TATA box present in many promoters. There are at least 23 human TAF proteins that have been identified. Many of these are ubiquitously expressed, but TAFs can also be expressed in a cell or tissue-specific pattern.

Specific Coactivator Complexes for DNA-binding Transcription Factors: A number of specific co-activator complexes for DNA-binding transcription factors have been identified, including DRIP, TRAP, and ARC (reviewed in Bourbon, 2004, Blazek, 2005, Conaway, 2005, and Malik, 2005). The DRIP co-activator complex was originally identified and named as a specific complex associated with the Vitamin D Receptor member of the nuclear receptor family of transcription factors (Rachez, 1998). Similarly, the TRAP co-activator complex was originally identified as a complex that associates with the thyroid receptor (Yuan, 1998). It was later determined that all of the components of the DRIP complex are also present in the TRAP complex, and the ARC complex (discussed further below). For example, the DRIP205 and TRAP220 proteins were show to be identical, as were specific pairs of the other components of these complexes (Rachez, 1999).

In addition, these various transcription co-activator proteins identified in mammalian cells were found to be the orthologues or homologues of the Mediator ("adaptor") complex proteins (reviewed in Bourbon, 2004). The Mediator proteins were originally identified in yeast by Kornberg and colleagues, as complexes associated with DNA polymerase (Kelleher, 1990). In higher organisms, Adapter complexes bridge between the basal transcription factors (including Pol II) and tissue-specific transcription factors (TFs) bound to sites within upstream Proximal Promoter regions or distal Enhancer regions (Figure 1). However, many of the Mediator homologues can also be found in complexes associated with specific transcription factors in higher organisms. A unified nomenclature system for these adapter / co-activator proteins now labels them Mediator 1 through Mediator 31 (Bourbon, 2004). For example, the DRIP205 / TRAP220 proteins are now identified as Mediator 1 (Rachez, 1999), based on homology with yeast Mediator 1 [[https://reactome.org/PathwayBrowser/#/R-HSA-212436&PATH=R-HSA-74160,R-HSA-73857](https://reactome.org/PathwayBrowser/#/R-HSA-212436&PATH=R-HSA-74160,R-HSA-73857)].

**Platelet degranulation:** Platelets function as exocytotic cells, secreting a plethora of effector molecules at sites of vascular injury. Platelets contain a number of distinguishable storage granules including alpha granules, dense granules and lysosomes. On activation platelets release a variety of proteins, largely from storage granules but also as the result of apparent cell lysis. These act in an autocrine or paracrine fashion to modulate cell signaling.

Alpha granules contain mainly polypeptides such as fibrinogen, von Willebrand factor, growth factors and protease inhibitors that that supplement thrombin generation at the site of injury. Dense granules contain small molecules, particularly adenosine diphosphate (ADP), adenosine triphosphate (ATP), serotonin and calcium, all recruit platelets to the site of injury. The molecular mechanism which facilitates granule release involves soluble NSF attachment protein receptors (SNAREs), which assemble into complexes to form a universal membrane fusion apparatus. Although all cells use SNAREs for membrane fusion, different cells possess different SNARE isoforms. Platelets and chromaffin cells use many of the same chaperone proteins to regulate SNARE-mediated secretion (Fitch-Tewfik & Flaumenhaft 2013) [[https://reactome.org/PathwayBrowser/#/R-HSA-114608](https://reactome.org/PathwayBrowser/#/R-HSA-114608)].

**SMAD2/SMAD3:SMAD4 heterotrimer regulates transcription:** After phosphorylated SMAD2 and/or SMAD3 form a heterotrimer with SMAD4, SMAD2/3:SMAD4 complex translocates to the nucleus (Xu et al. 2000, Kurisaki et al. 2001, Xiao et al. 2003). In the nucleus, linker regions of SMAD2 and SMAD3 within SMAD2/3:SMAD4 complex can be phosphorylated by CDK8 associated with cyclin C (CDK8:CCNC) or CDK9 associated with cyclin T (CDK9:CCNT). CDK8/CDK9-mediated phosphorylation of SMAD2/3 enhances transcriptional activity of SMAD2/3:SMAD4 complex, but also primes it for ubiquitination and consequent degradation (Alarcon et al. 2009).

The transfer of SMAD2/3:SMAD4 complex to the nucleus can be assisted by other proteins, such as WWTR1. In human embryonic cells, WWTR1 (TAZ) binds SMAD2/3:SMAD4 heterotrimer and mediates TGF-beta-dependent nuclear accumulation of SMAD2/3:SMAD4. The complex of WWTR1 and SMAD2/3:SMAD4 binds promoters of SMAD7 and SERPINE1 (PAI-1 i.e. plasminogen activator inhibitor 1) genes and stimulates their transcription (Varelas et al. 2008). Stimulation of SMAD7 transcription by SMAD2/3:SMAD4 represents a negative feedback loop in TGF-beta receptor signaling. SMAD7 can be downregulated by RNF111 ubiquitin ligase (Arkadia), which binds and ubiquitinates SMAD7, targeting it for degradation (Koinuma et al. 2003).

SMAD2/3:SMAD4 heterotrimer also binds the complex of RBL1 (p107), E2F4/5 and TFDP1/2 (DP1/2). The resulting complex binds MYC promoter and inhibits MYC transcription. Inhibition of MYC transcription contributes to anti-proliferative effect of TGF-beta (Chen et al. 2002). SMAD2/3:SMAD4 heterotrimer also associates with transcription factor SP1. SMAD2/3:SMAD4:SP1 complex stimulates transcription of a CDK inhibitor CDKN2B (p15-INK4B), also contributing to the anti-proliferative effect of TGF-beta (Feng et al. 2000).

MEN1 (menin), a transcription factor tumor suppressor mutated in a familial cancer syndrome multiple endocrine neoplasia type 1, forms a complex with SMAD2/3:SMAD4 heterotrimer, but transcriptional targets of SMAD2/3:SMAD4:MEN1 have not been elucidated (Kaji et al. 2001, Sowa et al. 2004, Canaff et al. 2012).

JUNB is also an established transcriptional target of SMAD2/3:SMAD4 complex (Wong et al. 1999) [[https://reactome.org/PathwayBrowser/#/R-HSA-2173793&SEL=R-HSA-2173796&PATH=R-HSA-162582,R-HSA-9006936,R-HSA-170834](https://reactome.org/PathwayBrowser/#/R-HSA-2173793&SEL=R-HSA-2173796&PATH=R-HSA-162582,R-HSA-9006936,R-HSA-170834)].

## GO terms:

**angiogenesis** [Blood vessel formation when new vessels emerge from the proliferation of pre-existing blood vessels. GO:0001525]

**cellular response to ATP** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an ATP (adenosine 5'-triphosphate) stimulus. GO:0071318]

**cellular response to aldosterone** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an aldosterone stimulus. GO:1904045]

**cellular response to angiotensin** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an angiotensin stimulus. Angiotensin is any of three physiologically active peptides (angiotensin II, III, or IV) processed from angiotensinogen. GO:1904385]

**cellular response to cAMP** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cAMP (cyclic AMP, adenosine 3',5'-cyclophosphate) stimulus. GO:0071320]

**cellular response to cGMP** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cGMP (cyclic GMP, guanosine 3',5'-cyclophosphate) stimulus. GO:0071321]

**cellular response to cycloheximide** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cycloheximide stimulus. Cycloheximide (actidione) is an antibiotic produced by some Streptomyces species which interferes with protein synthesis in eukaryotes. GO:0071409]

**cellular response to dexamethasone stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a dexamethasone stimulus. GO:0071549]

**cellular response to fibroblast growth factor stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an fibroblast growth factor stimulus. GO:0044344]

**cellular response to follicle-stimulating hormone stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a follicle-stimulating hormone stimulus. GO:0071372]

**cellular response to glucagon stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a glucagon stimulus. GO:0071377]

**cellular response to glucose stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a glucose stimulus. GO:0071333]

**cellular response to gravity** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a gravitational stimulus. GO:0071258]

**cellular response to growth factor stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a growth factor stimulus. GO:0071363]

**cellular response to hydrogen peroxide** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a hydrogen peroxide (H2O2) stimulus. GO:0070301]

**cellular response to hypoxia** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating lowered oxygen tension. Hypoxia, defined as a decline in O2 levels below normoxic levels of 20.8 - 20.95%, results in metabolic adaptation at both the cellular and organismal level.|Note that this term should not be confused with 'cellular response to anoxia ; GO:0071454'. Note that in laboratory studies, hypoxia is typically studied at O2 concentrations ranging from 0.1 - 5%. GO:0071456]

**cellular response to insulin stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an insulin stimulus. Insulin is a polypeptide hormone produced by the islets of Langerhans of the pancreas in mammals, and by the homologous organs of other organisms. GO:0032869]

**cellular response to interleukin-1** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an interleukin-1 stimulus. GO:0071347]

**cellular response to leukemia inhibitory factor** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a leukemia inhibitory factor stimulus. GO:1990830]

**cellular response to lipopolysaccharide** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lipopolysaccharide stimulus; lipopolysaccharide is a major component of the cell wall of gram-negative bacteria. GO:0071222]

**cellular response to low-density lipoprotein particle stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a low-density lipoprotein particle stimulus. GO:0071404]

**cellular response to mechanical stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a mechanical stimulus. GO:0071260]

**cellular response to metal ion** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a metal ion stimulus. GO:0071248]

**cellular response to nerve growth factor stimulus** [A process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a nerve growth factor stimulus. GO:1990090]

**cellular response to nicotine** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a nicotine stimulus. GO:0071316]

**cellular response to organic cyclic compound** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an organic cyclic compound stimulus. GO:0071407]

**cellular response to platelet-derived growth factor stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a platelet-derived growth factor stimulus. GO:0036120]

**cellular response to potassium ion** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a potassium ion stimulus. GO:0035865]

**cellular response to resveratrol** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a resveratrol stimulus. GO:1904639]

**cellular response to transforming growth factor beta stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a transforming growth factor beta stimulus. GO:0071560]

**cellular response to xenobiotic stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a xenobiotic, a compound foreign to the organism exposed to it. It may be synthesized by another organism (like ampicilin) or it can be a synthetic chemical. GO:0071466]

**decidualization** [The cellular and vascular changes occurring in the endometrium of the pregnant uterus just after the onset of blastocyst implantation. This process involves the proliferation and differentiation of the fibroblast-like endometrial stromal cells into large, polyploid decidual cells that eventually form the maternal component of the placenta. GO:0046697]

**defense response to Gram-negative bacterium** [Reactions triggered in response to the presence of a Gram-negative bacterium that act to protect the cell or organism. GO:0050829]

**dentinogenesis** [The process whose specific outcome is the formation of dentin, the mineralized tissue that constitutes the major bulk of teeth. Dentin may be one of three types: primary dentin, secondary dentin, and tertiary dentin. GO:0097187]

**female gonad development** [The process whose specific outcome is the progression of the female gonad over time, from its formation to the mature structure. GO:0008585]

**mast cell activation** [The change in morphology and behavior of a mast cell resulting from exposure to a cytokine, chemokine, soluble factor, or to (at least in mammals) an antigen which the mast cell has specifically bound via IgE bound to Fc-epsilonRI receptors. GO:0045576]

**negative regulation of cell adhesion mediated by integrin** [Any process that stops, prevents, or reduces the frequency, rate, or extent of cell adhesion mediated by integrin. GO:0033629]

**negative regulation of cell migration** [Any process that stops, prevents, or reduces the frequency, rate or extent of cell migration. GO:0030336]

**negative regulation of endopeptidase activity** [Any process that decreases the frequency, rate or extent of endopeptidase activity, the endohydrolysis of peptide bonds within proteins. GO:0010951]

**negative regulation of endothelial cell apoptotic process** [Any process that stops, prevents or reduces the frequency, rate or extent of endothelial cell apoptotic process. GO:2000352]

**negative regulation of extrinsic apoptotic signaling pathway via death domain receptors** [Any process that stops, prevents or reduces the frequency, rate or extent of extrinsic apoptotic signaling pathway via death domain receptors. GO:1902042]

**negative regulation of fibrinolysis** [Any process that stops, prevents, or reduces the frequency, rate or extent of fibrinolysis, an ongoing process that solubilizes fibrin, resulting in the removal of small blood clots. GO:0051918]

**negative regulation of gene expression** [Any process that decreases the frequency, rate or extent of gene expression. Gene expression is the process in which a gene's coding sequence is converted into a mature gene product (protein or RNA).|This term covers any process that negatively regulates the rate of production of a mature gene product, and so includes processes that negatively regulate that rate by reducing the level, stability or availability of intermediates in the process of gene expression. For example, it covers any process that reduces the level, stability or availability of mRNA or circRNA for translation and thereby reduces the rate of production of the encoded protein via translation. GO:0010629]

**negative regulation of plasminogen activation** [Any process that decreases the rate, frequency or extent of plasminogen activation. Plasminogen activation is the process in which plasminogen is processed to plasmin. GO:0010757]

**negative regulation of smooth muscle cell migration** [Any process that stops, prevents, or reduces the frequency, rate or extent of smooth muscle cell migration. GO:0014912]

**negative regulation of smooth muscle cell-matrix adhesion** [Any process that stops, prevents, or reduces the frequency, rate or extent of smooth muscle cell-matrix adhesion. GO:2000098]

**negative regulation of vascular wound healing** [Any process that decreases the rate, frequency, or extent of blood vessel formation when new vessels emerge from the proliferation of pre-existing blood vessels and contribute to the series of events that restore integrity to damaged vasculature. GO:0061044]

**placenta development** [The process whose specific outcome is the progression of the placenta over time, from its formation to the mature structure. The placenta is an organ of metabolic interchange between fetus and mother, partly of embryonic origin and partly of maternal origin. GO:0001890]

**positive regulation of angiogenesis** [Any process that activates or increases angiogenesis. GO:0045766]

**positive regulation of blood coagulation** [Any process that activates or increases the frequency, rate or extent of blood coagulation. GO:0030194]

**positive regulation of calcium ion import** [Any process that increases the rate, frequency, or extent of the directed movement of calcium ions into a cell or organelle. GO:0090280]

**positive regulation of coagulation** [Any process that activates or increases the frequency, rate or extent of coagulation. GO:0050820]

**positive regulation of collagen biosynthetic process** [Any process that activates or increases the frequency, rate or extent of the chemical reactions and pathways resulting in the formation of collagen, any of a group of fibrous proteins of very high tensile strength that form the main component of connective tissue in animals. GO:0032967]

**positive regulation of epithelium regeneration** [Any process that activates or increases the frequency, rate or extent of epithelium regeneration. GO:1905043]

**positive regulation of fibroblast proliferation** [Any process that activates or increases the frequency, rate or extent of multiplication or reproduction of fibroblast cells. GO:0048146]

**positive regulation of gene expression** [Any process that increases the frequency, rate or extent of gene expression. Gene expression is the process in which a gene's coding sequence is converted into a mature gene product (protein or RNA). GO:0010628]

**positive regulation of inflammatory response** [Any process that activates or increases the frequency, rate or extent of the inflammatory response. GO:0050729]

**positive regulation of interleukin-8 production** [Any process that activates or increases the frequency, rate, or extent of interleukin-8 production. GO:0032757]

**positive regulation of keratinocyte migration** [Any process that activates or increases the frequency, rate or extent of keratinocyte migration. GO:0051549]

**positive regulation of leukotriene production involved in inflammatory response** [Any process that increases the rate, frequency or extent of the synthesis or release of any leukotriene following a stimulus as part of an inflammatory response. GO:0035491]

**positive regulation of monocyte chemotaxis** [Any process that increases the frequency, rate, or extent of monocyte chemotaxis. GO:0090026]

**positive regulation of odontoblast differentiation** [Any process that activates or increases the frequency, rate or extent of odontoblast differentiation. GO:1901331]

**positive regulation of receptor-mediated endocytosis** [Any process that activates or increases the frequency, rate or extent of receptor mediated endocytosis, the uptake of external materials by cells, utilizing receptors to ensure specificity of transport. GO:0048260]

**regulation of angiogenesis** [Any process that modulates the frequency, rate or extent of angiogenesis. GO:0045765]

**regulation of cell population proliferation** [Any process that modulates the frequency, rate or extent of cell proliferation. GO:0042127]

**replicative senescence** [A cell aging process associated with the dismantling of a cell as a response to telomere shortening and/or cellular aging. GO:0090399]

**response to cytokine** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cytokine stimulus. GO:0034097]

**response to epidermal growth factor** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an epidermal growth factor stimulus. GO:0070849]

**response to estrogen** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of stimulus by an estrogen, C18 steroid hormones that can stimulate the development of female sexual characteristics. GO:0043627]

**response to hyperoxia** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating increased oxygen tension. GO:0055093]

**response to laminar fluid shear stress** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a laminar fluid shear stress stimulus. Laminar fluid flow is the force acting on an object in a system where the fluid is moving across a solid surface in parallel layers. As an example, laminar shear stress can be seen where blood flows against the luminal side of blood vessel walls. GO:0034616]

**response to lipopolysaccharide** [Any process that results in a change in state or activity of an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lipopolysaccharide stimulus; lipopolysaccharide is a major component of the cell wall of gram-negative bacteria. GO:0032496]

**response to nutrient levels** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus reflecting the presence, absence, or concentration of nutrients. GO:0031667]

**response to reactive oxygen species** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a reactive oxygen species stimulus. Reactive oxygen species include singlet oxygen, superoxide, and oxygen free radicals. GO:0000302]

**response to starvation** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a starvation stimulus, deprivation of nourishment. GO:0042594]

**response to transforming growth factor beta** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a transforming growth factor beta stimulus. GO:0071559]

**tissue regeneration** [The regrowth of lost or destroyed tissues. GO:0042246]

## MSigDB Signatures:

**HSIAO_LIVER_SPECIFIC_GENES**: Liver selective genes [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HSIAO_LIVER_SPECIFIC_GENES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HSIAO_LIVER_SPECIFIC_GENES.html)

**CAIRO_HEPATOBLASTOMA_DN**: Genes down-regulated in hepatoblastoma samples compared to normal liver tissue. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CAIRO_HEPATOBLASTOMA_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CAIRO_HEPATOBLASTOMA_DN.html)

**MEBARKI_HCC_PROGENITOR_WNT_UP**: Transcriptome of human HepaRG hepatocellular carcinoma liver progenitors in responses to a WNT3A-enriched microenvironment and dissection of pathways dependent on _-catenin and/or blocked by the SFRP-like Wnt inhibitor FZD8_CRD. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MEBARKI_HCC_PROGENITOR_WNT_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MEBARKI_HCC_PROGENITOR_WNT_UP.html)

**MEBARKI_HCC_PROGENITOR_WNT_UP_BLOCKED_BY_FZD8CRD**: Transcriptome of human HepaRG hepatocellular carcinoma liver progenitors in responses to a WNT3A-enriched microenvironment and dissection of pathways dependent on _-catenin and/or blocked by the SFRP-like Wnt inhibitor FZD8_CRD. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MEBARKI_HCC_PROGENITOR_WNT_UP_BLOCKED_BY_FZD8CRD.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MEBARKI_HCC_PROGENITOR_WNT_UP_BLOCKED_BY_FZD8CRD.html)

**MEBARKI_HCC_PROGENITOR_WNT_UP_CTNNB1_DEPENDENT**: Transcriptome of human HepaRG hepatocellular carcinoma liver progenitors in responses to a WNT3A-enriched microenvironment and dissection of pathways dependent on _-catenin and/or blocked by the SFRP-like Wnt inhibitor FZD8_CRD. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MEBARKI_HCC_PROGENITOR_WNT_UP_CTNNB1_DEPENDENT.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MEBARKI_HCC_PROGENITOR_WNT_UP_CTNNB1_DEPENDENT.html)

**MEBARKI_HCC_PROGENITOR_WNT_UP_CTNNB1_DEPENDENT_BLOCKED_BY_FZD8CRD**: Transcriptome of human HepaRG hepatocellular carcinoma liver progenitors in responses to a WNT3A-enriched microenvironment and dissection of pathways dependent on _-catenin and/or blocked by the SFRP-like Wnt inhibitor FZD8_CRD. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MEBARKI_HCC_PROGENITOR_WNT_UP_CTNNB1_DEPENDENT_BLOCKED_BY_FZD8CRD.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MEBARKI_HCC_PROGENITOR_WNT_UP_CTNNB1_DEPENDENT_BLOCKED_BY_FZD8CRD.html)

**COULOUARN_TEMPORAL_TGFB1_SIGNATURE_UP**: 'Late-TGFB1 signature': genes overexpressed in primary hepatocytes at a late phase of TGFB1 [GeneID=7040] treatment; is associated with a more invasive phenotype. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/COULOUARN_TEMPORAL_TGFB1_SIGNATURE_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/COULOUARN_TEMPORAL_TGFB1_SIGNATURE_UP.html)

**REACTOME_HEMOSTASIS**: Hemostasis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HEMOSTASIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HEMOSTASIS.html)

**WP_VITAMIN_B12_METABOLISM**: Vitamin B12 metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_VITAMIN_B12_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_VITAMIN_B12_METABOLISM.html)

**ACEVEDO_LIVER_CANCER_DN**: Genes down-regulated in hepatocellular carcinoma (HCC) compared to normal liver samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ACEVEDO_LIVER_CANCER_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ACEVEDO_LIVER_CANCER_DN.html)

**REACTOME_INFECTIOUS_DISEASE**: Infectious disease [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INFECTIOUS_DISEASE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INFECTIOUS_DISEASE.html)

**CHIANG_LIVER_CANCER_SUBCLASS_CTNNB1_DN**: Top 200 marker genes down-regulated in the 'CTNNB1' subclass of hepatocellular carcinoma (HCC); characterized by activated CTNNB1 [GeneID=1499]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHIANG_LIVER_CANCER_SUBCLASS_CTNNB1_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHIANG_LIVER_CANCER_SUBCLASS_CTNNB1_DN.html)

**BIOCARTA_FIBRINOLYSIS_PATHWAY**: Fibrinolysis Pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_FIBRINOLYSIS_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_FIBRINOLYSIS_PATHWAY.html)

**WP_BLOOD_CLOTTING_CASCADE**: Blood clotting cascade [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_BLOOD_CLOTTING_CASCADE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_BLOOD_CLOTTING_CASCADE.html)

**REACTOME_VIRAL_INFECTION_PATHWAYS**: Viral Infection Pathways [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_VIRAL_INFECTION_PATHWAYS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_VIRAL_INFECTION_PATHWAYS.html)

**KEGG_MEDICUS_REFERENCE_REGULATION_OF_FIBRINOLYTIC_SYSTEM_PAI**: Pathway Definition from KEGG: PAI -| (PLAU,PLAT) [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_REGULATION_OF_FIBRINOLYTIC_SYSTEM_PAI.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_REGULATION_OF_FIBRINOLYTIC_SYSTEM_PAI.html)

**SEAVEY_EPITHELIOID_HEMANGIOENDOTHELIOMA**: Genes overexpressed in Epithelioid Hemangioendothelioma versus Angiosarcoma, Kaposi Sarcoma, Hemangioblastoma, and Liver [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/SEAVEY_EPITHELIOID_HEMANGIOENDOTHELIOMA.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/SEAVEY_EPITHELIOID_HEMANGIOENDOTHELIOMA.html)

**WP_ADIPOGENESIS**: Adipogenesis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ADIPOGENESIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ADIPOGENESIS.html)

**REACTOME_RNA_POLYMERASE_II_TRANSCRIPTION**: RNA Polymerase II Transcription [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RNA_POLYMERASE_II_TRANSCRIPTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RNA_POLYMERASE_II_TRANSCRIPTION.html)

**REACTOME_SARS_COV_1_INFECTION**: SARS-CoV-1 Infection [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_1_INFECTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_1_INFECTION.html)

**AMIT_SERUM_RESPONSE_240_MCF10A**: Genes whose expression peaked at 240 min after stimulation of MCF10A cells with serum. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_SERUM_RESPONSE_240_MCF10A.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_SERUM_RESPONSE_240_MCF10A.html)

**WP_FOLATE_METABOLISM**: Folate metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FOLATE_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FOLATE_METABOLISM.html)

**NAKAMURA_ADIPOGENESIS_EARLY_DN**: Genes down-regulated in mesenchymal stem cells during early phase of adipogenesis, defined as days 1 to 5 of culturing with adipogenic hormones. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NAKAMURA_ADIPOGENESIS_EARLY_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NAKAMURA_ADIPOGENESIS_EARLY_DN.html)

**NAKAMURA_ADIPOGENESIS_LATE_DN**: Genes down-regulated in mesenchymal stem cells during late phase of adipogenesis, defined as days 7 to 14 of culturing with adipogenic hormones. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NAKAMURA_ADIPOGENESIS_LATE_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NAKAMURA_ADIPOGENESIS_LATE_DN.html)

**WINTER_HYPOXIA_METAGENE**: Genes regulated by hypoxia, based on literature searches. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WINTER_HYPOXIA_METAGENE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WINTER_HYPOXIA_METAGENE.html)

**PETROVA_ENDOTHELIUM_LYMPHATIC_VS_BLOOD_DN**: Genes down-regulated in BEC (blood endothelial cells) compared to LEC (lymphatic endothelial cells). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PETROVA_ENDOTHELIUM_LYMPHATIC_VS_BLOOD_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PETROVA_ENDOTHELIUM_LYMPHATIC_VS_BLOOD_DN.html)

**PID_UPA_UPAR_PATHWAY**: Urokinase-type plasminogen activator (uPA) and uPAR-mediated signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_UPA_UPAR_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_UPA_UPAR_PATHWAY.html)

**KRIEG_HYPOXIA_VIA_KDM3A**: Genes dependent on KDM3A [GeneID=55818] for hypoxic induction in RCC4 cells (renal carcinoma) expressing VHL [GeneID=7428]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KRIEG_HYPOXIA_VIA_KDM3A.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KRIEG_HYPOXIA_VIA_KDM3A.html)

**ZHANG_ANTIVIRAL_RESPONSE_TO_RIBAVIRIN_DN**: Genes up-regulated in A549 cells (lung carcinoma) upon infection with RSV (respiratory syncytial virus) and down-regulated by further treatment with ribavirin [PubChem=5064]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZHANG_ANTIVIRAL_RESPONSE_TO_RIBAVIRIN_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZHANG_ANTIVIRAL_RESPONSE_TO_RIBAVIRIN_DN.html)

**REACTOME_DISSOLUTION_OF_FIBRIN_CLOT**: Dissolution of Fibrin Clot [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DISSOLUTION_OF_FIBRIN_CLOT.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DISSOLUTION_OF_FIBRIN_CLOT.html)

**BROWNE_HCMV_INFECTION_2HR_DN**: Genes down-regulated in primary fibroblast cell culture point after infection with HCMV (AD169 strain) at 2 h time point that were not down-regulated at the previous time point, 1 h. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_2HR_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_2HR_DN.html)

**REACTOME_EXTRACELLULAR_MATRIX_ORGANIZATION**: Extracellular matrix organization [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_EXTRACELLULAR_MATRIX_ORGANIZATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_EXTRACELLULAR_MATRIX_ORGANIZATION.html)

**WP_COMPLEMENT_AND_COAGULATION_CASCADES**: Complement and coagulation cascades [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_COMPLEMENT_AND_COAGULATION_CASCADES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_COMPLEMENT_AND_COAGULATION_CASCADES.html)

**KEGG_COMPLEMENT_AND_COAGULATION_CASCADES**: Complement and coagulation cascades [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_COMPLEMENT_AND_COAGULATION_CASCADES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_COMPLEMENT_AND_COAGULATION_CASCADES.html)

**NAKAYAMA_SOFT_TISSUE_TUMORS_PCA1_UP**: Top 100 probe sets contrubuting to the positive side of the 1st principal component; predominantly associated with spindle cell and pleomorphic sarcoma samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NAKAYAMA_SOFT_TISSUE_TUMORS_PCA1_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NAKAYAMA_SOFT_TISSUE_TUMORS_PCA1_UP.html)

**REACTOME_SARS_COV_INFECTIONS**: SARS-CoV Infections [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_INFECTIONS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_INFECTIONS.html)

**BIOCARTA_PLATELETAPP_PATHWAY**: Platelet Amyloid Precursor Protein Pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_PLATELETAPP_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BIOCARTA_PLATELETAPP_PATHWAY.html)

**BROWNE_HCMV_INFECTION_14HR_DN**: Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 14 h time point that were not down-regulated at the previous time point, 12 h. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_14HR_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_14HR_DN.html)

**BROWNE_HCMV_INFECTION_12HR_DN**: Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 12 h time point that were not down-regulated at the previous time point, 10 h. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_12HR_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_12HR_DN.html)

**PID_HIF1_TFPATHWAY**: HIF-1-alpha transcription factor network [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_HIF1_TFPATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_HIF1_TFPATHWAY.html)

**JIANG_HYPOXIA_NORMAL**: Genes up-regulated in RPTEC cells (normal kidney) by hypoxia. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JIANG_HYPOXIA_NORMAL.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JIANG_HYPOXIA_NORMAL.html)

**WANG_ESOPHAGUS_CANCER_VS_NORMAL_UP**: Up-regulated genes specific to esophageal adenocarcinoma (EAC) relative to normal tissue. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WANG_ESOPHAGUS_CANCER_VS_NORMAL_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WANG_ESOPHAGUS_CANCER_VS_NORMAL_UP.html)

**MANALO_HYPOXIA_UP**: Genes up-regulated in response to both hypoxia and overexpression of an active form of HIF1A [GeneID=3091]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MANALO_HYPOXIA_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MANALO_HYPOXIA_UP.html)

**SUNG_METASTASIS_STROMA_DN**: Genes down-regulated in metastatic vs non-metastatic stromal cells originated from either bone or prostate tissues. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/SUNG_METASTASIS_STROMA_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/SUNG_METASTASIS_STROMA_DN.html)

**KAN_RESPONSE_TO_ARSENIC_TRIOXIDE**: Genes changed in U373-MG cells (malignant glioma) upon treatment with arsenic trioxide [PubChem=14888], a chemical that can cause autophagic cell death. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KAN_RESPONSE_TO_ARSENIC_TRIOXIDE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KAN_RESPONSE_TO_ARSENIC_TRIOXIDE.html)

**DANG_REGULATED_BY_MYC_UP**: Genes up-regulated by MYC [GeneID=4609], according to the MYC Target Gene Database. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DANG_REGULATED_BY_MYC_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DANG_REGULATED_BY_MYC_UP.html)

**PID_HIF2PATHWAY**: HIF-2-alpha transcription factor network [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_HIF2PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_HIF2PATHWAY.html)

**WP_CKAP4_SIGNALING_PATHWAY_MAP**: CKAP4 signaling pathway map [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_CKAP4_SIGNALING_PATHWAY_MAP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_CKAP4_SIGNALING_PATHWAY_MAP.html)

**MAINA_HYPOXIA_VHL_TARGETS_UP**: Genes up-regulated by hypoxia in RCC4 cells (renal cell carcinoma) engineered to stably express VHL [GeneID=7428] off a plasmid vector. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MAINA_HYPOXIA_VHL_TARGETS_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MAINA_HYPOXIA_VHL_TARGETS_UP.html)

**AMIT_EGF_RESPONSE_480_HELA**: Genes whose expression peaked at 480 min after stimulation of HeLa cells with EGF [GeneID=1950]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_EGF_RESPONSE_480_HELA.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_EGF_RESPONSE_480_HELA.html)

**SANA_TNF_SIGNALING_UP**: Genes up-regulated in five primary endothelial cell types (lung, aortic, iliac, dermal, and colon) by TNF [GeneID=7124]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/SANA_TNF_SIGNALING_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/SANA_TNF_SIGNALING_UP.html)

**WP_SELENIUM_MICRONUTRIENT_NETWORK**: Selenium micronutrient network [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_SELENIUM_MICRONUTRIENT_NETWORK.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_SELENIUM_MICRONUTRIENT_NETWORK.html)

**REACTOME_ECM_PROTEOGLYCANS**: ECM proteoglycans [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ECM_PROTEOGLYCANS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ECM_PROTEOGLYCANS.html)

**NABA_MATRISOME_ASSOCIATED**: Ensemble of genes encoding ECM-associated proteins including ECM-affilaited proteins, ECM regulators and secreted factors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_ASSOCIATED.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_ASSOCIATED.html)

**SEMENZA_HIF1_TARGETS**: Genes that are transcriptionally regulated by HIF1A [GeneID=3091]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/SEMENZA_HIF1_TARGETS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/SEMENZA_HIF1_TARGETS.html)

**FALVELLA_SMOKERS_WITH_LUNG_CANCER**: Genes that distinguish normal from cancer (lung adenocarcinoma) samples and smokers from non-smoking subjects. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FALVELLA_SMOKERS_WITH_LUNG_CANCER.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FALVELLA_SMOKERS_WITH_LUNG_CANCER.html)

**AMIT_EGF_RESPONSE_60_HELA**: Genes whose expression peaked at 60 min after stimulation of HeLa cells with EGF [GeneID=1950]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_EGF_RESPONSE_60_HELA.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/AMIT_EGF_RESPONSE_60_HELA.html)

**ZWANG_EGF_INTERVAL_DN**: Genes repressed in the time interval between two pulses of EGF [GeneID =1950] in 184A1 cells (mammary epithelium). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZWANG_EGF_INTERVAL_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZWANG_EGF_INTERVAL_DN.html)

**RUTELLA_RESPONSE_TO_HGF_VS_CSF2RB_AND_IL4_UP**: Genes up-regulated in peripheral blood mononucleocytes by HGF [GeneID=3082] compared to those regulated by CSF2RB (GM-CSF) and IL4 [GeneID=1437;3565]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_VS_CSF2RB_AND_IL4_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_VS_CSF2RB_AND_IL4_UP.html)

**REACTOME_CIRCADIAN_CLOCK**: Circadian Clock [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CIRCADIAN_CLOCK.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CIRCADIAN_CLOCK.html)

**FISCHER_DIRECT_P53_TARGETS_META_ANALYSIS**: Genes directly bound and regulated by TP53[GeneID=7157]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FISCHER_DIRECT_P53_TARGETS_META_ANALYSIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FISCHER_DIRECT_P53_TARGETS_META_ANALYSIS.html)

**REACTOME_PLATELET_ACTIVATION_SIGNALING_AND_AGGREGATION**: Platelet activation, signaling and aggregation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PLATELET_ACTIVATION_SIGNALING_AND_AGGREGATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_PLATELET_ACTIVATION_SIGNALING_AND_AGGREGATION.html)

**VERRECCHIA_RESPONSE_TO_TGFB1_C1**: Cluster 1: ECM related genes up-regulated in dermal fibroblasts within 30 min after TGFB1 [GeneID=7040] addition, and which kept increasing with time. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/VERRECCHIA_RESPONSE_TO_TGFB1_C1.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/VERRECCHIA_RESPONSE_TO_TGFB1_C1.html)

**JINESH_BLEBBISHIELD_TRANSFORMED_STEM_CELL_SPHERES_UP**: Genes up-regulated in transformed spheres compared to blebbishields from RT4 cells [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JINESH_BLEBBISHIELD_TRANSFORMED_STEM_CELL_SPHERES_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JINESH_BLEBBISHIELD_TRANSFORMED_STEM_CELL_SPHERES_UP.html)

**DORSEY_GAB2_TARGETS**: Genes up-regulated by expression of GAB2 [GeneID=9846] in K562 cells (chronic myeloid leukemia (CML) cell line with p210 BCR-ABL [GeneID=613;25]). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DORSEY_GAB2_TARGETS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DORSEY_GAB2_TARGETS.html)

**FERNANDEZ_BOUND_BY_MYC**: Genes identified by ChIP within the high-affinity group of MYC [GeneID=4609] targets. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FERNANDEZ_BOUND_BY_MYC.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FERNANDEZ_BOUND_BY_MYC.html)

**FLORIO_NEOCORTEX_BASAL_RADIAL_GLIA_DN**: Genes down-regulated in basal radial glia (bRG) relative to apical radial glia (aRG), and up-regulated in both aRG and bRG relative to neurons. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FLORIO_NEOCORTEX_BASAL_RADIAL_GLIA_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FLORIO_NEOCORTEX_BASAL_RADIAL_GLIA_DN.html)

**PETROVA_PROX1_TARGETS_DN**: Genes specific to BEC (blood endothelium cells) repressed in BEC by expression of PROX1 [GeneID=5629] off adenovirus vector. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PETROVA_PROX1_TARGETS_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PETROVA_PROX1_TARGETS_DN.html)

**CONCANNON_APOPTOSIS_BY_EPOXOMICIN_UP**: Genes up-regulated in SH-SY5Y cells (neuroblastoma) after treatment with epoxomicin [PubChem=3035402], a protease inhibitor causing apoptosis. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CONCANNON_APOPTOSIS_BY_EPOXOMICIN_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CONCANNON_APOPTOSIS_BY_EPOXOMICIN_UP.html)

**DANG_REGULATED_BY_MYC_DN**: Genes down-regulated by MYC [GeneID=4609], according to the MYC Target Gene Database. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DANG_REGULATED_BY_MYC_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DANG_REGULATED_BY_MYC_DN.html)

**DANG_BOUND_BY_MYC**: Genes whose promoters are bound by MYC [GeneID=4609], according to MYC Target Gene Database. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DANG_BOUND_BY_MYC.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DANG_BOUND_BY_MYC.html)

**LEONARD_HYPOXIA**: Genes up-regulated in HK-2 cells kidney tubular epithelium) under hypoxia and down-regulated on re-oxygenation. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LEONARD_HYPOXIA.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LEONARD_HYPOXIA.html)

**MA_RAT_AGING_UP**: Genes up-regulated across multiple cell types from nine tissues during rat aging. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MA_RAT_AGING_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MA_RAT_AGING_UP.html)

**FRIDMAN_SENESCENCE_UP**: Genes up-regulated in senescent cells. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FRIDMAN_SENESCENCE_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FRIDMAN_SENESCENCE_UP.html)

**WP_HYPOTHESIZED_PATHWAYS_IN_PATHOGENESIS_OF_CARDIOVASCULAR_DISEASE**: Hypothesized pathways in pathogenesis of cardiovascular disease [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_HYPOTHESIZED_PATHWAYS_IN_PATHOGENESIS_OF_CARDIOVASCULAR_DISEASE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_HYPOTHESIZED_PATHWAYS_IN_PATHOGENESIS_OF_CARDIOVASCULAR_DISEASE.html)

**BOQUEST_STEM_CELL_CULTURED_VS_FRESH_UP**: Genes up-regulated in cultured stromal stem cells from adipose tissue, compared to the freshly isolated cells. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BOQUEST_STEM_CELL_CULTURED_VS_FRESH_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BOQUEST_STEM_CELL_CULTURED_VS_FRESH_UP.html)

**DODD_NASOPHARYNGEAL_CARCINOMA_DN**: Genes down-regulated in nasopharyngeal carcinoma (NPC) compared to the normal tissue. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DODD_NASOPHARYNGEAL_CARCINOMA_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DODD_NASOPHARYNGEAL_CARCINOMA_DN.html)

**WP_TGF_BETA_RECEPTOR_SIGNALING**: TGF beta receptor signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TGF_BETA_RECEPTOR_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TGF_BETA_RECEPTOR_SIGNALING.html)

**LOPEZ_MBD_TARGETS**: Genes up-regulated in HeLa cells (cervical cancer) after simultaneus knockdown of all three MBD (methyl-CpG binding domain) proteins MeCP2, MBD1 and MBD2 [GeneID=4204;4152;8932] by RNAi. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LOPEZ_MBD_TARGETS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LOPEZ_MBD_TARGETS.html)

**DANG_MYC_TARGETS_DN**: Genes down-regulated by MYC [GeneID=4609] and whose promoters are bound by MYC, according to MYC Target Gene Database. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DANG_MYC_TARGETS_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DANG_MYC_TARGETS_DN.html)

**DASU_IL6_SIGNALING_DN**: Genes down-regulated in normal fibroblasts in response to IL6 [GeneID=3569]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DASU_IL6_SIGNALING_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DASU_IL6_SIGNALING_DN.html)

**CHICAS_RB1_TARGETS_CONFLUENT**: Genes up-regulated in confluent IMR90 cells (fibroblast) after knockdown of RB1 [GeneID=5925] by RNAi. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHICAS_RB1_TARGETS_CONFLUENT.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHICAS_RB1_TARGETS_CONFLUENT.html)

**REACTOME_SIGNALING_BY_TGF_BETA_RECEPTOR_COMPLEX**: Signaling by TGF-beta Receptor Complex [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_TGF_BETA_RECEPTOR_COMPLEX.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_TGF_BETA_RECEPTOR_COMPLEX.html)

**HINATA_NFKB_TARGETS_FIBROBLAST_UP**: Genes up-regulated in primary fibroblast cells by expression of p50 (NFKB1) and p65 (RELA) [GeneID=4790;5970] components of NFKB. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HINATA_NFKB_TARGETS_FIBROBLAST_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HINATA_NFKB_TARGETS_FIBROBLAST_UP.html)

**PID_E2F_PATHWAY**: E2F transcription factor network [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_E2F_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_E2F_PATHWAY.html)

**RUTELLA_RESPONSE_TO_HGF_UP**: Genes up-regulated in peripheral blood monocytes by HGF [GeneID=3082]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_UP.html)

**REACTOME_SIGNALING_BY_TGFB_FAMILY_MEMBERS**: Signaling by TGFB family members [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_TGFB_FAMILY_MEMBERS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_TGFB_FAMILY_MEMBERS.html)

**WP_P53_TRANSCRIPTIONAL_GENE_NETWORK**: p53 transcriptional gene network [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_P53_TRANSCRIPTIONAL_GENE_NETWORK.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_P53_TRANSCRIPTIONAL_GENE_NETWORK.html)

**ZWANG_CLASS_3_TRANSIENTLY_INDUCED_BY_EGF**: Class III of genes transiently induced by EGF [GeneID =1950] in 184A1 cells (mammary epithelium). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZWANG_CLASS_3_TRANSIENTLY_INDUCED_BY_EGF.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZWANG_CLASS_3_TRANSIENTLY_INDUCED_BY_EGF.html)

**KOINUMA_TARGETS_OF_SMAD2_OR_SMAD3**: Genes with promoters occupied by SMAD2 or SMAD3 [GeneID=4087, 4088] in HaCaT cells (keratinocyte) according to a ChIP-chip analysis. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KOINUMA_TARGETS_OF_SMAD2_OR_SMAD3.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KOINUMA_TARGETS_OF_SMAD2_OR_SMAD3.html)

**PROVENZANI_METASTASIS_DN**: Genes down-regulated in polysomal and total RNA samples from SW480 cells (primary colorectal carcinoma, CRC) compared to the SW620 cells (lymph node metastasis from the same individual). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PROVENZANI_METASTASIS_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PROVENZANI_METASTASIS_DN.html)

**WP_RAS_AND_BRADYKININ_PATHWAYS_IN_COVID_19**: RAS and bradykinin pathways in COVID 19 [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_RAS_AND_BRADYKININ_PATHWAYS_IN_COVID_19.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_RAS_AND_BRADYKININ_PATHWAYS_IN_COVID_19.html)

**HINATA_NFKB_TARGETS_KERATINOCYTE_UP**: Genes up-regulated in primary keratinocytes by expression of p50 (NFKB1) and p65 (RELA) [GeneID=4790;5970] components of NFKB. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HINATA_NFKB_TARGETS_KERATINOCYTE_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HINATA_NFKB_TARGETS_KERATINOCYTE_UP.html)

**WP_PRIMARY_OVARIAN_INSUFFICIENCY**: Primary ovarian insufficiency [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PRIMARY_OVARIAN_INSUFFICIENCY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PRIMARY_OVARIAN_INSUFFICIENCY.html)

**WP_GASTRIN_SIGNALING_PATHWAY**: Gastrin signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_GASTRIN_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_GASTRIN_SIGNALING_PATHWAY.html)

**KIM_WT1_TARGETS_UP**: Genes up-regulated in UB27 cells (osteosarcoma) at any time point after inducing the expression of a mutant form of WT1 [GeneID=7490]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KIM_WT1_TARGETS_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KIM_WT1_TARGETS_UP.html)

**BENPORATH_MYC_TARGETS_WITH_EBOX**: Set 'Myc targets1': targets of c-Myc [GeneID=4609] identified by ChIP on chip in cultured cell lines, focusing on E-box-containing genes; high affinity bound subset [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BENPORATH_MYC_TARGETS_WITH_EBOX.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BENPORATH_MYC_TARGETS_WITH_EBOX.html)

**ELVIDGE_HYPOXIA_BY_DMOG_UP**: Genes up-regulated in MCF7 cells (breast cancer) treated with hypoxia mimetic DMOG [PubChem=3080614]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ELVIDGE_HYPOXIA_BY_DMOG_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ELVIDGE_HYPOXIA_BY_DMOG_UP.html)

**PID_SMAD2_3NUCLEAR_PATHWAY**: Regulation of nuclear SMAD2/3 signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_SMAD2_3NUCLEAR_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_SMAD2_3NUCLEAR_PATHWAY.html)

**WP_DISTURBED_PATHWAYS_IN_DUCHENNE_MUSCULAR_DYSTROPHY**: Disturbed pathways in Duchenne Muscular Dystrophy [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_DISTURBED_PATHWAYS_IN_DUCHENNE_MUSCULAR_DYSTROPHY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_DISTURBED_PATHWAYS_IN_DUCHENNE_MUSCULAR_DYSTROPHY.html)
