
## **Pathways:**

**Neutrophil degranulation**: Neutrophils are the most abundant leukocytes (white blood cells), indispensable in defending the body against invading microorganisms. In response to infection, neutrophils leave the circulation and migrate towards the inflammatory focus. They contain several subsets of granules that are mobilized to fuse with the cell membrane or phagosomal membrane, resulting in the exocytosis or exposure of membrane proteins. Traditionally, neutrophil granule constituents are described as antimicrobial or proteolytic, but granules also introduce membrane proteins to the cell surface, changing how the neutrophil responds to its environment (Borregaard et al. 2007). Primed neutrophils actively secrete cytokines and other inflammatory mediators and can present antigens via MHC II, stimulating T-cells (Wright et al. 2010). Granules form during neutrophil differentiation. Granule subtypes can be distinguished by their content but overlap in structure and composition. The differences are believed to be a consequence of changing protein expression and differential timing of granule formation during the terminal processes of neutrophil differentiation, rather than sorting (Le Cabec et al. 1996). The classical granule subsets are Azurophil or primary granules (AG), secondary granules (SG) and gelatinase granules (GG). Neutrophils also contain exocytosable storage cell organelles, storage vesicles (SV), formed by endocytosis they contain many cell-surface markers and extracellular, plasma proteins (Borregaard et al. 1992). Ficolin-1-rich granules (FG) are like GGs highly exocytosable but gelatinase-poor (Rorvig et al. 2009). [[https://reactome.org/PathwayBrowser/#/R-HSA-6798695](https://reactome.org/PathwayBrowser/#/R-HSA-6798695)]

## GO terms:

**antibacterial humoral response** [An immune response against bacteria mediated through a body fluid. Examples of this process are the antibacterial humoral responses in Mus musculus and Drosophila melanogaster. GO:0019731]

**immune response** [Any immune system process that functions in the calibrated response of an organism to a potential internal or invasive threat. GO:0006955]

**innate immune response** [Innate immune responses are defense responses mediated by germline encoded components that directly recognize components of potential pathogens. GO:0045087]

**negative regulation of viral genome replication** [Any process that stops, prevents, or reduces the frequency, rate or extent of viral genome replication. GO:0045071]

**response to lipopolysaccharide** [Any process that results in a change in state or activity of an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lipopolysaccharide stimulus; lipopolysaccharide is a major component of the cell wall of gram-negative bacteria. GO:0032496]

## MSigDB Signatures:

**NABA_MATRISOME**: Ensemble of genes encoding extracellular matrix and extracellular matrix-associated proteins [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME.html)

**NABA_MATRISOME_ASSOCIATED**: Ensemble of genes encoding ECM-associated proteins including ECM-affilaited proteins, ECM regulators and secreted factors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_ASSOCIATED.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_ASSOCIATED.html)

**CHIANG_LIVER_CANCER_SUBCLASS_CTNNB1_DN**: Top 200 marker genes down-regulated in the 'CTNNB1' subclass of hepatocellular carcinoma (HCC); characterized by activated CTNNB1 [GeneID=1499]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHIANG_LIVER_CANCER_SUBCLASS_CTNNB1_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CHIANG_LIVER_CANCER_SUBCLASS_CTNNB1_DN.html)

**REACTOME_INNATE_IMMUNE_SYSTEM**: Innate Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html)

**FOROUTAN_INTEGRATED_TGFB_EMT_DN**: Genes down-regulated in the epithelial-mesenchymal transition (EMT) upon transforming growth factor beta (TGFb) stimulation derived from multiple datasets by integrating them. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FOROUTAN_INTEGRATED_TGFB_EMT_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FOROUTAN_INTEGRATED_TGFB_EMT_DN.html)

**NABA_ECM_REGULATORS**: Genes encoding enzymes and their regulators involved in the remodeling of the extracellular matrix [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_ECM_REGULATORS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_ECM_REGULATORS.html)

**FARMER_BREAST_CANCER_APOCRINE_VS_LUMINAL**: Genes which best discriminate between two groups of breast cancer according to the status of ESR1 and AR [GeneID=2099;367]: apocrine (ESR1- AR+) and luminal (ESR1+ AR+). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FARMER_BREAST_CANCER_APOCRINE_VS_LUMINAL.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FARMER_BREAST_CANCER_APOCRINE_VS_LUMINAL.html)

**FOROUTAN_TGFB_EMT_DN**: Genes down-regulated in the epithelial-mesenchymal transition (EMT) upon transforming growth factor beta (TGFb) stimulation derived from multiple datasets by combining results from an integrative approach and a product of ranks meta-analysis approach. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FOROUTAN_TGFB_EMT_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FOROUTAN_TGFB_EMT_DN.html)

**ACEVEDO_NORMAL_TISSUE_ADJACENT_TO_LIVER_TUMOR_UP**: Genes up-regulated in normal tissue adjacent to liver tumor, compared to the normal liver samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ACEVEDO_NORMAL_TISSUE_ADJACENT_TO_LIVER_TUMOR_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ACEVEDO_NORMAL_TISSUE_ADJACENT_TO_LIVER_TUMOR_UP.html)

**NUYTTEN_NIPP1_TARGETS_DN**: Genes down-regulated in PC3 cells (prostate cancer) after knockdown of NIPP1 [GeneID=5511] by RNAi. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NUYTTEN_NIPP1_TARGETS_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NUYTTEN_NIPP1_TARGETS_DN.html)

**JAEGER_METASTASIS_DN**: Genes down-regulated in metastases from malignant melanoma compared to the primary tumors. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JAEGER_METASTASIS_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JAEGER_METASTASIS_DN.html)

**NAKAMURA_TUMOR_ZONE_PERIPHERAL_VS_CENTRAL_DN**: Down-regulated genes in peripheral zone of human pancreatic cancer growing in the pancreas of nude mice compared to that of the tumor from the central zone. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NAKAMURA_TUMOR_ZONE_PERIPHERAL_VS_CENTRAL_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NAKAMURA_TUMOR_ZONE_PERIPHERAL_VS_CENTRAL_DN.html)

**WU_CELL_MIGRATION**: Genes associated with migration rate of 40 human bladder cancer cells. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WU_CELL_MIGRATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WU_CELL_MIGRATION.html)

**VECCHI_GASTRIC_CANCER_ADVANCED_VS_EARLY_DN**: Down-regulated genes distinguishing between two subtypes of gastric cancer: advanced (AGC) and early (EGC). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/VECCHI_GASTRIC_CANCER_ADVANCED_VS_EARLY_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/VECCHI_GASTRIC_CANCER_ADVANCED_VS_EARLY_DN.html)

**REACTOME_NEUTROPHIL_DEGRANULATION**: Neutrophil degranulation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NEUTROPHIL_DEGRANULATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NEUTROPHIL_DEGRANULATION.html)

**DODD_NASOPHARYNGEAL_CARCINOMA_UP**: Genes up-regulated in nasopharyngeal carcinoma (NPC) compared to the normal tissue. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DODD_NASOPHARYNGEAL_CARCINOMA_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DODD_NASOPHARYNGEAL_CARCINOMA_UP.html)

**ZWANG_CLASS_1_TRANSIENTLY_INDUCED_BY_EGF**: Class I of genes transiently induced by EGF [GeneID =1950] in 184A1 cells (mammary epithelium). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZWANG_CLASS_1_TRANSIENTLY_INDUCED_BY_EGF.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZWANG_CLASS_1_TRANSIENTLY_INDUCED_BY_EGF.html)

**ZWANG_EGF_INTERVAL_DN**: Genes repressed in the time interval between two pulses of EGF [GeneID =1950] in 184A1 cells (mammary epithelium). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZWANG_EGF_INTERVAL_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZWANG_EGF_INTERVAL_DN.html)

**NABA_MATRISOME_HGSOC_OMENTAL_METASTASIS**: Matrisome proteins detected in significantly different abundance in omentum metastases from high grade serous ovarian cancer (HGSOC) compared to normal omentum. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_HGSOC_OMENTAL_METASTASIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_HGSOC_OMENTAL_METASTASIS.html)
