
## **Pathways:**

**Degradation of the extracellular matrix:** Matrix metalloproteinases (MMPs), previously referred to as matrixins because of their role in degradation of the extracellular matrix (ECM), are zinc and calcium dependent proteases belonging to the metzincin family. They contain a characteristic zinc-binding motif HEXXHXXGXXH (Stocker & Bode 1995) and a conserved Methionine which forms a Met-turn. Humans have 24 MMP genes giving rise to 23 MMP proteins, as MMP23 is encoded by two identical genes. All MMPs contain an N-terminal secretory signal peptide and a prodomain with a conserved PRCGXPD motif that in the inactive enzyme is localized with the catalytic site, the cysteine acting as a fourth unpaired ligand for the catalytic zinc atom. Activation involves delocalization of the domain containing this cysteine by a conformational change or proteolytic cleavage, a mechanism referred to as the cysteine-switch (Van Wart & Birkedal-Hansen 1990). Most MMPs are secreted but the membrane type MT-MMPs are membrane anchored and some MMPs may act on intracellular proteins. Various domains determine substrate specificity, cell localization and activation (Hadler-Olsen et al. 2011). MMPs are regulated by transcription, cellular location (most are not activated until secreted), activating proteinases that can be other MMPs, and by metalloproteinase inhibitors such as the tissue inhibitors of metalloproteinases (TIMPs). MMPs are best known for their role in the degradation and removal of ECM molecules. In addition, cleavage of the ECM and other cell surface molecules can release ECM-bound growth factors, and a number of non-ECM proteins are substrates of MMPs (Nagase et al. 2006). MMPs can be divided into subgroups based on domain structure and substrate specificity but it is clear that these are somewhat artificial, many MMPs belong to more than one functional group (Vise & Nagase 2003, Somerville et al. 2003) [[https://reactome.org/PathwayBrowser/#/R-HSA-1474228](https://reactome.org/PathwayBrowser/#/R-HSA-1474228)].

**Integrin cell surface interactions:** The extracellular matrix (ECM) is a network of macro-molecules that underlies all epithelia and endothelia and that surrounds all connective tissue cells. This matrix provides the mechanical strength and also influences the behavior and differentiation state of cells in contact with it. The ECM are diverse in composition, but they generally comprise a mixture of fibrillar proteins, polysaccharides synthesized, secreted and organized by neighboring cells. Collagens, fibronectin, and laminins are the principal components involved in cell matrix interactions; other components, such as vitronectin, thrombospondin, and osteopontin, although less abundant, are also important adhesive molecules.

Integrins are the receptors that mediate cell adhesion to ECM. Integrins consists of one alpha and one beta subunit forming a noncovalently bound heterodimer. 18 alpha and 8 beta subunits have been identified in humans that combine to form 24 different receptors.

The integrin dimers can be broadly divided into three families consisting of the beta1, beta2/beta7, and beta3/alphaV integrins. beta1 associates with 12 alpha-subunits and can be further divided into RGD-, collagen-, or laminin binding and the related alpha4/alpha9 integrins that recognise both matrix and vascular ligands. beta2/beta7 integrins are restricted to leukocytes and mediate cell-cell rather than cell-matrix interactions, although some recognize fibrinogen. The beta3/alphaV family members are all RGD receptors and comprise aIIbb3, an important receptor on platelets, and the remaining b-subunits, which all associate with alphaV. It is the collagen receptors and leukocyte-specific integrins that contain alpha A-domains [[https://reactome.org/PathwayBrowser/#/R-HSA-216083](https://reactome.org/PathwayBrowser/#/R-HSA-216083)].

**Post-translational protein phosphorylation:** Secretory pathway kinases phosphorylate a diverse array of substrates involved in many physiological processes [[https://reactome.org/PathwayBrowser/#/R-HSA-8957275](https://reactome.org/PathwayBrowser/#/R-HSA-8957275)].

**Regulation of Insulin-like Growth Factor (IGF) transport and uptake by Insulin-like Growth Factor Binding Proteins (IGFBPs):** The family of Insulin like Growth Factor Binding Proteins (IGFBPs) share 50% amino acid identity with conserved N terminal and C terminal regions responsible for binding Insulin like Growth Factors I and II (IGF I and IGF II). Most circulating IGFs are in complexes with IGFBPs, which are believed to increase the residence of IGFs in the body, modulate availability of IGFs to target receptors for IGFs, reduce insulin like effects of IGFs, and act as signaling molecules independently of IGFs. About 75% of circulating IGFs are in 1500 220 KDa complexes with IGFBP3 and ALS. Such complexes are too large to pass the endothelial barrier. The remaining 20 25% of IGFs are bound to other IGFBPs in 40 50 KDa complexes. IGFs are released from IGF:IGFBP complexes by proteolysis of the IGFBP. IGFs become active after release, however IGFs may also have activity when still bound to some IGFBPs. IGFBP1 is enriched in amniotic fluid and is produced in the liver under control of insulin (insulin suppresses production). IGFBP1 binding stimulates IGF function. It is unknown which if any protease degrades IGFBP1. IGFBP2 is enriched in cerebrospinal fluid; its binding inhibits IGF function. IGFBP2 is not significantly degraded in circulation. IGFBP3, which binds most IGF in the body is enriched in follicular fluid and found in many other tissues. IGFBP 3 may be cleaved by plasmin, thrombin, Prostate specific Antigen (PSA, KLK3), Matrix Metalloprotease-1 (MMP1), and Matrix Metalloprotease-2 (MMP2). IGFBP3 also binds extracellular matrix and binding lowers its affinity for IGFs. IGFBP3 binding stimulates the effects of IGFs. IGFBP4 acts to inhibit IGF function and is cleaved by Pregnancy associated Plasma Protein A (PAPPA) to release IGF. IGFBP5 is enriched in bone matrix; its binding stimulates IGF function. IGFBP5 is cleaved by Pregnancy Associated Plasma Protein A2 (PAPPA2), ADAM9, complement C1s from smooth muscle, and thrombin. Only the cleavage site for PAPPA2 is known. IGFBP6 is enriched in cerebrospinal fluid. It is unknown which if any protease degrades IGFBP6 [[https://reactome.org/PathwayBrowser/#/R-HSA-381426](https://reactome.org/PathwayBrowser/#/R-HSA-381426)].

**RUNX3 Regulates Immune Response and Cell Migration:** RUNX3-mediated transcription regulates development of immune system cells. RUNX3 is necessary for the development of innate lymphoid cells (ILCs) of ILC1 and ILC3 lineages, which reside in the mucosa and are involved in response to external pathogens. RUNX3 exerts its role in the development of ILC1 and ILC3 lineages by stimulating expression of the RORC (RORgamma) gene, encoding nuclear retinoid-related orphan receptor-gamma (Ebihara et al. 2015).

RUNX3 regulates transcription of integrin genes ITGAL (CD11a) and ITGA4 (CD49d), involved in transendothelial migration of leukocytes during immune and inflammatory responses as well as co-stimulation of T cells (Domniguez-Soto et al. 2005). The RUNX3 splicing isoform p33 lacks the Runt domain and is unable to transactivate integrin genes. The p33 isoform is induced during maturation of monocyte-derived dendritic cells (MDDC), leading to reduced expression of genes involved in inflammatory responses, such as IL8 (interleukin-8) (Puig-Kroger et al. 2010).

RUNX3 positively regulates transcription of the SPP1 (osteopontin) gene, which contributes to invasiveness of pancreatic cancer cells (Whittle et al. 2015) [[https://reactome.org/PathwayBrowser/#/R-HSA-8949275](https://reactome.org/PathwayBrowser/#/R-HSA-8949275)].

**Signaling by PDGF:** Platelet-derived Growth Factor (PDGF) is a potent stimulator of growth and motility of connective tissue cells such as fibroblasts and smooth muscle cells as well as other cells such as capillary endothelial cells and neurons. The PDGF family of growth factors is composed of four different polypeptide chains encoded by four different genes. The classical PDGF chains, PDGF-A and PDGF-B, and more recently discovered PDGF-C and PDGF-D. The four PDGF chains assemble into disulphide-bonded dimers via homo- or heterodimerization, and five different dimeric isoforms have been described so far; PDGF-AA, PDGF-AB, PDGF-BB, PDGF-CC and PDGF-DD. It is notable that no heterodimers involving PDGF-C and PDGF-D chains have been described. PDGF exerts its effects by binding to, and activating, two protein tyrosine kinase (PTK) receptors, alpha and beta. These receptors dimerize and undergo autophosphorylation. The phosphorylation sites then attract downstream effectors to transduct the signal into the cell. [[https://reactome.org/PathwayBrowser/#/R-HSA-186797](https://reactome.org/PathwayBrowser/#/R-HSA-186797)].

**Mesenchymal Stem Cell Differentiation Pathways & Lineage-specific Markers**: Mesenchymal stem cells (MSCs) are defined as multipotent, self-renewing progenitors that can be differentiated into adipocytes, chondrocytes, and osteocytes. Originally identified in mouse bone marrow, MSCs have now been discovered in a variety of species and isolated from numerous tissues including adipose, placental, dental pulp, and umbilical cord. Despite the classical trilineage differentiation that functionally identifies MSCs, these cells have also been shown to differentiate into non-traditional lineages to produce cardiomyocytes, endothelial cells, hepatocytes, and neural cells. To date, the biological properties of MSC identification, differentiation, and function have yet to be confirmed in vivo, raising caution for the extrapolation of in vitro generated data. The mechanisms controlling MSC self-renewal and differentiation are thought to be influenced by a diverse set of growth factors, receptors, intracellular signaling molecules, and transcription factors. The factors depicted below are known to influence MSC multipotency, proliferation, and lineage commitment. MSCs and their differentiated progeny can be identified by the expression of a unique combination of cell surface markers and transcription factors. Unique identifiers for each cell can be viewed by clicking on that cell-type within the lineage pathway. [[https://www.rndsystems.com/pathways/mesenchymal-stem-cell-differentiation-pathways-lineage-specific-markers](https://www.rndsystems.com/pathways/mesenchymal-stem-cell-differentiation-pathways-lineage-specific-markers)].

## GO terms:

**androgen catabolic process** [The chemical reactions and pathways resulting in the breakdown of androgens, C19 steroid hormones that can stimulate the development of male sexual characteristics. GO:0006710]

**bone mineralization** [The deposition of hydroxyapatite, a form of calcium phosphate with the formula Ca10(PO4)6(OH)2, in bone tissue. GO:0030282]

**calcium ion homeostasis** [Any process involved in the maintenance of an internal steady state of calcium ions within an organism or cell. GO:0055074]

**cell adhesion** [The attachment of a cell, either to another cell or to an underlying substrate such as the extracellular matrix, via cell adhesion molecules. GO:0007155]

**cell differentiation** [The cellular developmental process in which a relatively unspecialized cell, e.g. embryonic or regenerative cell, acquires specialized structural and/or functional features that characterize a specific cell. Differentiation includes the processes involved in commitment of a cell to a specific fate and its subsequent development to the mature state. GO:0030154]

**cellular response to fluid shear stress** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a fluid shear stress stimulus. Fluid shear stress is the force acting on an object in a system where the fluid is moving across a solid surface. GO:0071498]

**cellular response to leukemia inhibitory factor** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a leukemia inhibitory factor stimulus. GO:1990830]

**cellular response to testosterone stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a testosterone stimulus. GO:0071394]

**collecting duct development** [The process whose specific outcome is the progression of a collecting duct over time, from its formation to the mature structure. The collecting duct responds to vasopressin and aldosterone to regulate water, electrolyte and acid-base balance. It is the final common path through which urine flows before entering the ureter and then emptying into the bladder. GO:0072044]

**intracellular calcium ion homeostasis** [A homeostatic process involved in the maintenance of a steady state level of calcium ions within a cell. GO:0006874]

**intracellular chloride ion homeostasis** [A homeostatic process involved in the maintenance of a steady state level of chloride ions within a cell. GO:0030644]

**intracellular phosphate ion homeostasis** [A homeostatic process involved in the maintenance of a steady state level of phosphate ions within a cell. GO:0030643]

**intracellular sodium ion homeostasis** [A homeostatic process involved in the maintenance of a steady state level of sodium ions within a cell. GO:0006883]

**negative regulation of collateral sprouting of intact axon in response to injury** [Any process that stops, prevents, or reduces the frequency, rate or extent of collateral sprouting of an intact axon as a result of injury to an axon. GO:0048685]

**neutrophil chemotaxis** [The directed movement of a neutrophil cell, the most numerous polymorphonuclear leukocyte found in the blood, in response to an external stimulus, usually an infection or wounding. GO:0030593]

**ossification** [The formation of bone or of a bony substance, or the conversion of fibrous tissue or of cartilage into bone or a bony substance.|Note that this term does not have a 'developmental process' parent because ossification isn't necessarily developmental, can also occur as part of bone remodeling. Instead use 'ossification involved in bone maturation ; GO:0043931'. GO:0001503]

**osteoblast differentiation** [The process whereby a relatively unspecialized cell acquires the specialized features of an osteoblast, a mesodermal or neural crest cell that gives rise to bone. GO:0001649]

**positive regulation of DNA-templated transcription** [Any process that activates or increases the frequency, rate or extent of cellular DNA-templated transcription. GO:0045893]

**positive regulation of bone resorption** [Any process that activates or increases the frequency, rate or extent of bone resorption. GO:0045780]

**positive regulation of cell-substrate adhesion** [Any process that increases the frequency, rate or extent of cell-substrate adhesion. Cell-substrate adhesion is the attachment of a cell to the underlying substrate via adhesion molecules. GO:0010811]

**positive regulation of estradiol secretion** [Any process that activates or increases the frequency, rate or extent of estradiol secretion. GO:2000866]

**response to macrophage colony-stimulating factor** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a macrophage colony-stimulating factor stimulus. GO:0036005]

**response to organic substance** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an organic substance stimulus. GO:0010033]

**response to steroid hormone** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a steroid hormone stimulus. GO:0048545]

**response to vitamin D** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a vitamin D stimulus. GO:0033280]

**signal transduction** [The cellular process in which a signal is conveyed to trigger a change in the activity or state of a cell. Signal transduction begins with reception of a signal (e.g. a ligand binding to a receptor or receptor activation by a stimulus such as light), or for signal transduction in the absence of ligand, signal-withdrawal or the activity of a constitutively active receptor. Signal transduction ends with regulation of a downstream cellular process, e.g. regulation of transcription or regulation of a metabolic process. Signal transduction covers signaling from receptors located on the surface of the cell and signaling via molecules located within the cell. For signaling between cells, signal transduction is restricted to events at and within the receiving cell.|Note that signal transduction is defined broadly to include a ligand interacting with a receptor, downstream signaling steps and a response being triggered. A change in form of the signal in every step is not necessary. Note that in many cases the end of this process is regulation of the initiation of transcription. Note that specific transcription factors may be annotated to this term, but core/general transcription machinery such as RNA polymerase should not. GO:0007165]

**urate biosynthetic process** [The chemical reactions and pathways resulting in the formation of urate, the anion of uric acid, 2,6,8-trioxypurine. GO:0034418]

## MSigDB Signatures:

**DESERT_STEM_CELL_HEPATOCELLULAR_CARCINOMA_SUBCLASS_UP**: Genes up-regulated in the stem cell-type subclass of hepatocellular carcinomas. Sets created as part of a metaanalysis of nine public transcriptomic datasets merged into a metadataset including 1133 human hepatocellular carcinomas obtained after curative resection. For platform descriptions of each one of the 9 datasets, see Figure 1B in Desert et al., Hepatology (2017), 66: 1502-1518. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DESERT_STEM_CELL_HEPATOCELLULAR_CARCINOMA_SUBCLASS_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DESERT_STEM_CELL_HEPATOCELLULAR_CARCINOMA_SUBCLASS_UP.html)

**ROESSLER_LIVER_CANCER_METASTASIS_UP**: Genes up-regulated in liver samples containing tumor thrombi in the major branches of the portal vein at surgery (PT) compared to those from metastasis-free HCC patients (PN) at the time of surgery and at follow-up. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ROESSLER_LIVER_CANCER_METASTASIS_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ROESSLER_LIVER_CANCER_METASTASIS_UP.html)

**WP_COMPLEMENT_SYSTEM**: Complement system [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_COMPLEMENT_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_COMPLEMENT_SYSTEM.html)

**MEBARKI_HCC_PROGENITOR_FZD8CRD_DN**: Transcriptome of human HepaRG hepatocellular carcinoma liver progenitors in responses to a WNT3A-enriched microenvironment and dissection of pathways dependent on beta-catenin and/or blocked by the SFRP-like Wnt inhibitor FZD8_CRD. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MEBARKI_HCC_PROGENITOR_FZD8CRD_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MEBARKI_HCC_PROGENITOR_FZD8CRD_DN.html)

**PATIL_LIVER_CANCER**: Genes up-regulated in hepatocellular carcinoma (HCC) compared to normal liver samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PATIL_LIVER_CANCER.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PATIL_LIVER_CANCER.html)

**CAVARD_LIVER_CANCER_MALIGNANT_VS_BENIGN**: Genes identified by subtractive hybridization comparing malignant and benign components of a hepatocellular carcinoma (HCC) in a pre-existing liver adenoma in a morphologically normal liver. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CAVARD_LIVER_CANCER_MALIGNANT_VS_BENIGN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CAVARD_LIVER_CANCER_MALIGNANT_VS_BENIGN.html)

**NABA_MATRISOME_METASTATIC_COLORECTAL_LIVER_METASTASIS**: Matrisome proteins found differentially expressed in secondary colorectal liver metastatases in comparison to normal colon and normal liver. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_METASTATIC_COLORECTAL_LIVER_METASTASIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_METASTATIC_COLORECTAL_LIVER_METASTASIS.html)

**CARRILLOREIXACH_HEPATOBLASTOMA_VS_NORMAL_HYPOMETHYLATED_AND_UP**: Genes hypomethylated and overexpressed in hepatoblastoma (HB) tumors as compared with non-tumor (NT) adjacent tissue assessed by Infinium MethylationEPIC 850K array and Human Transcriptome Array 2.0 & RNA-sequencing. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CARRILLOREIXACH_HEPATOBLASTOMA_VS_NORMAL_HYPOMETHYLATED_AND_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CARRILLOREIXACH_HEPATOBLASTOMA_VS_NORMAL_HYPOMETHYLATED_AND_UP.html)

**WP_ENDOCHONDRAL_OSSIFICATION**: Endochondral ossification [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ENDOCHONDRAL_OSSIFICATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ENDOCHONDRAL_OSSIFICATION.html)

**WP_LUNG_FIBROSIS**: Lung fibrosis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_LUNG_FIBROSIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_LUNG_FIBROSIS.html)

**REACTOME_RNA_POLYMERASE_II_TRANSCRIPTION**: RNA Polymerase II Transcription [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RNA_POLYMERASE_II_TRANSCRIPTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RNA_POLYMERASE_II_TRANSCRIPTION.html)

**OISHI_CHOLANGIOMA_STEM_CELL_LIKE_UP**: Genes over-expressed in stem cell-like cholangiocellular carcinoma. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/OISHI_CHOLANGIOMA_STEM_CELL_LIKE_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/OISHI_CHOLANGIOMA_STEM_CELL_LIKE_UP.html)

**ANDERSEN_CHOLANGIOCARCINOMA_CLASS1**: Genes overexpressed in cholangiocarcinoma class 1 associated with good prognosis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ANDERSEN_CHOLANGIOCARCINOMA_CLASS1.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ANDERSEN_CHOLANGIOCARCINOMA_CLASS1.html)

**WP_OVERVIEW_OF_PROINFLAMMATORY_AND_PROFIBROTIC_MEDIATORS**: Overview of proinflammatory and profibrotic mediators [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_OVERVIEW_OF_PROINFLAMMATORY_AND_PROFIBROTIC_MEDIATORS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_OVERVIEW_OF_PROINFLAMMATORY_AND_PROFIBROTIC_MEDIATORS.html)

**WINTER_HYPOXIA_METAGENE**: Genes regulated by hypoxia, based on literature searches. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WINTER_HYPOXIA_METAGENE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WINTER_HYPOXIA_METAGENE.html)

**REACTOME_POST_TRANSLATIONAL_PROTEIN_MODIFICATION**: Post-translational protein modification [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_POST_TRANSLATIONAL_PROTEIN_MODIFICATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_POST_TRANSLATIONAL_PROTEIN_MODIFICATION.html)

**WP_VITAMIN_D_RECEPTOR_PATHWAY**: Vitamin D receptor pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_VITAMIN_D_RECEPTOR_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_VITAMIN_D_RECEPTOR_PATHWAY.html)

**KEGG_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY**: Toll-like receptor signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY.html)

**REACTOME_EXTRACELLULAR_MATRIX_ORGANIZATION**: Extracellular matrix organization [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_EXTRACELLULAR_MATRIX_ORGANIZATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_EXTRACELLULAR_MATRIX_ORGANIZATION.html)

**WP_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY**: Toll like receptor signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TOLL_LIKE_RECEPTOR_SIGNALING_PATHWAY.html)

**WP_PI3K_AKT_SIGNALING_PATHWAY**: PI3K Akt signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PI3K_AKT_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_PI3K_AKT_SIGNALING_PATHWAY.html)

**BROWNE_HCMV_INFECTION_48HR_DN**: Genes down-regulated in primary fibroblast cell culture after infection with HCMV (AD169 strain) at 48 h time point that were not down-regulated at the previous time point, 24 h. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_48HR_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BROWNE_HCMV_INFECTION_48HR_DN.html)

**IBRAHIM_NRF2_UP**: Genes up-regulated in HEK293T cells overexpressing FLAG-NRF2 [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/IBRAHIM_NRF2_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/IBRAHIM_NRF2_UP.html)

**WP_FOCAL_ADHESION_PI3K_AKT_MTOR_SIGNALING_PATHWAY**: Focal adhesion PI3K Akt mTOR signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FOCAL_ADHESION_PI3K_AKT_MTOR_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FOCAL_ADHESION_PI3K_AKT_MTOR_SIGNALING_PATHWAY.html)

**REACTOME_DEGRADATION_OF_THE_EXTRACELLULAR_MATRIX**: Degradation of the extracellular matrix [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEGRADATION_OF_THE_EXTRACELLULAR_MATRIX.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEGRADATION_OF_THE_EXTRACELLULAR_MATRIX.html)

**LEE_NEURAL_CREST_STEM_CELL_UP**: Genes up-regulated in the neural crest stem cells (NCS), defined as p75+/HNK1+ [GeneID=4804;27087]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LEE_NEURAL_CREST_STEM_CELL_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LEE_NEURAL_CREST_STEM_CELL_UP.html)

**HARRIS_HYPOXIA**: Genes known to be induced by hypoxia [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HARRIS_HYPOXIA.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HARRIS_HYPOXIA.html)

**RUTELLA_RESPONSE_TO_HGF_VS_CSF2RB_AND_IL4_UP**: Genes up-regulated in peripheral blood mononucleocytes by HGF [GeneID=3082] compared to those regulated by CSF2RB (GM-CSF) and IL4 [GeneID=1437;3565]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_VS_CSF2RB_AND_IL4_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_VS_CSF2RB_AND_IL4_UP.html)

**MOOTHA_PGC**: Genes up-regulated in differentiating C2C12 cells (myoblasts) upon expression of PPARGC1A [GeneID=10891] off an adenoviral vector. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MOOTHA_PGC.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MOOTHA_PGC.html)

**KEGG_FOCAL_ADHESION**: Focal adhesion [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_FOCAL_ADHESION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_FOCAL_ADHESION.html)

**WP_FOCAL_ADHESION**: Focal adhesion [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FOCAL_ADHESION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FOCAL_ADHESION.html)

**NABA_CORE_MATRISOME**: Ensemble of genes encoding core extracellular matrix including ECM glycoproteins, collagens and proteoglycans [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_CORE_MATRISOME.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_CORE_MATRISOME.html)

**KEGG_ECM_RECEPTOR_INTERACTION**: ECM-receptor interaction [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_ECM_RECEPTOR_INTERACTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_ECM_RECEPTOR_INTERACTION.html)

**JINESH_BLEBBISHIELD_TRANSFORMED_STEM_CELL_SPHERES_UP**: Genes up-regulated in transformed spheres compared to blebbishields from RT4 cells [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JINESH_BLEBBISHIELD_TRANSFORMED_STEM_CELL_SPHERES_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JINESH_BLEBBISHIELD_TRANSFORMED_STEM_CELL_SPHERES_UP.html)

**PID_FGF_PATHWAY**: FGF signaling pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_FGF_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_FGF_PATHWAY.html)

**DEMAGALHAES_AGING_UP**: Genes consistently overexpressed with age, based on meta-analysis of microarray data. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DEMAGALHAES_AGING_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/DEMAGALHAES_AGING_UP.html)

**RIGGI_EWING_SARCOMA_PROGENITOR_UP**: Genes up-regulated in mesenchymal stem cells (MSC) engineered to express EWS-FLI1 [GeneID=2130;2321] fusion protein. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RIGGI_EWING_SARCOMA_PROGENITOR_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RIGGI_EWING_SARCOMA_PROGENITOR_UP.html)

**CONCANNON_APOPTOSIS_BY_EPOXOMICIN_UP**: Genes up-regulated in SH-SY5Y cells (neuroblastoma) after treatment with epoxomicin [PubChem=3035402], a protease inhibitor causing apoptosis. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CONCANNON_APOPTOSIS_BY_EPOXOMICIN_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/CONCANNON_APOPTOSIS_BY_EPOXOMICIN_UP.html)

**WP_ENDOCHONDRAL_OSSIFICATION_WITH_SKELETAL_DYSPLASIAS**: Endochondral ossification with skeletal dysplasias [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ENDOCHONDRAL_OSSIFICATION_WITH_SKELETAL_DYSPLASIAS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_ENDOCHONDRAL_OSSIFICATION_WITH_SKELETAL_DYSPLASIAS.html)

**WP_TYROBP_CAUSAL_NETWORK_IN_MICROGLIA**: TYROBP causal network in microglia [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TYROBP_CAUSAL_NETWORK_IN_MICROGLIA.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TYROBP_CAUSAL_NETWORK_IN_MICROGLIA.html)

**REACTOME_REGULATION_OF_INSULIN_LIKE_GROWTH_FACTOR_IGF_TRANSPORT_AND_UPTAKE_BY_INSULIN_LIKE_GROWTH_FACTOR_BINDING_PROTEINS_IGFBPS**: Regulation of Insulin-like Growth Factor (IGF) transport and uptake by Insulin-like Growth Factor Binding Proteins (IGFBPs) [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_REGULATION_OF_INSULIN_LIKE_GROWTH_FACTOR_IGF_TRANSPORT_AND_UPTAKE_BY_INSULIN_LIKE_GROWTH_FACTOR_BINDING_PROTEINS_IGFBPS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_REGULATION_OF_INSULIN_LIKE_GROWTH_FACTOR_IGF_TRANSPORT_AND_UPTAKE_BY_INSULIN_LIKE_GROWTH_FACTOR_BINDING_PROTEINS_IGFBPS.html)

**REACTOME_SIGNALING_BY_RECEPTOR_TYROSINE_KINASES**: Signaling by Receptor Tyrosine Kinases [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_RECEPTOR_TYROSINE_KINASES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_RECEPTOR_TYROSINE_KINASES.html)

**LI_WILMS_TUMOR_VS_FETAL_KIDNEY_1_UP**: Genes up-regulated in Wilm's tumor samples compared to fetal kidney. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LI_WILMS_TUMOR_VS_FETAL_KIDNEY_1_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LI_WILMS_TUMOR_VS_FETAL_KIDNEY_1_UP.html)

**REACTOME_SIGNALING_BY_PDGF**: Signaling by PDGF [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_PDGF.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_PDGF.html)

**WP_TGF_BETA_RECEPTOR_SIGNALING**: TGF beta receptor signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TGF_BETA_RECEPTOR_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_TGF_BETA_RECEPTOR_SIGNALING.html)

**LOPEZ_MBD_TARGETS**: Genes up-regulated in HeLa cells (cervical cancer) after simultaneus knockdown of all three MBD (methyl-CpG binding domain) proteins MeCP2, MBD1 and MBD2 [GeneID=4204;4152;8932] by RNAi. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LOPEZ_MBD_TARGETS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LOPEZ_MBD_TARGETS.html)

**LEE_METASTASIS_AND_ALTERNATIVE_SPLICING_DN**: Down-regulated genes displaying alternative splicing in MDA-MB-435 cells (breast cancer) whose metastatic potential has been reduced by expression of NME1 [GeneID=4830]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LEE_METASTASIS_AND_ALTERNATIVE_SPLICING_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LEE_METASTASIS_AND_ALTERNATIVE_SPLICING_DN.html)

**PID_AVB3_OPN_PATHWAY**: Osteopontin-mediated events [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_AVB3_OPN_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PID_AVB3_OPN_PATHWAY.html)

**PEDRIOLI_MIR31_TARGETS_DN**: Genes down-regulated in primary LEC cells (lymphatic endothelium) upon overexpression of MIR31 [GeneID=407035]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PEDRIOLI_MIR31_TARGETS_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/PEDRIOLI_MIR31_TARGETS_DN.html)

**VECCHI_GASTRIC_CANCER_EARLY_UP**: Up-regulated genes distinguishing between early gastric cancer (EGC) and normal tissue samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/VECCHI_GASTRIC_CANCER_EARLY_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/VECCHI_GASTRIC_CANCER_EARLY_UP.html)

**RUTELLA_RESPONSE_TO_HGF_UP**: Genes up-regulated in peripheral blood monocytes by HGF [GeneID=3082]. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RUTELLA_RESPONSE_TO_HGF_UP.html)

**LI_WILMS_TUMOR_VS_FETAL_KIDNEY_2_DN**: Genes down-regulated in Wilm's tumor vs fetal kidney. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LI_WILMS_TUMOR_VS_FETAL_KIDNEY_2_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LI_WILMS_TUMOR_VS_FETAL_KIDNEY_2_DN.html)

**SAMOLS_TARGETS_OF_KHSV_MIRNAS_DN**: Genes down-regulated in 293 cells (embryonic kidney) upon expression of KHSV (Kaposi sarcoma-associated herpesvirus) microRNAs. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/SAMOLS_TARGETS_OF_KHSV_MIRNAS_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/SAMOLS_TARGETS_OF_KHSV_MIRNAS_DN.html)

**JINESH_BLEBBISHIELD_VS_LIVE_CONTROL_UP**: Genes up-regulated in blebbishields compared to control RT4 live cells [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JINESH_BLEBBISHIELD_VS_LIVE_CONTROL_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/JINESH_BLEBBISHIELD_VS_LIVE_CONTROL_UP.html)

**MAHADEVAN_GIST_MORPHOLOGICAL_SWITCH**: Genes up-regulated in the GIST (gastrointestinal stromal tumor) cell line resistant to imatinib [PubChem=5291] that may correlate with the morphological switch in these cells. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MAHADEVAN_GIST_MORPHOLOGICAL_SWITCH.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MAHADEVAN_GIST_MORPHOLOGICAL_SWITCH.html)

**HAMAI_APOPTOSIS_VIA_TRAIL_UP**: Genes up-regulated in T1 cells (primary melanoma, sensitive to TRAIL [GeneID=8743]) compared to G1 cells (metastatic melanoma, resistant to TRAIL). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HAMAI_APOPTOSIS_VIA_TRAIL_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HAMAI_APOPTOSIS_VIA_TRAIL_UP.html)

**MCLACHLAN_DENTAL_CARIES_UP**: Genes up-regulated in pulpal tissue extracted from carious teeth. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MCLACHLAN_DENTAL_CARIES_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/MCLACHLAN_DENTAL_CARIES_UP.html)

**WP_DISTURBED_PATHWAYS_IN_DUCHENNE_MUSCULAR_DYSTROPHY**: Disturbed pathways in Duchenne Muscular Dystrophy [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_DISTURBED_PATHWAYS_IN_DUCHENNE_MUSCULAR_DYSTROPHY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_DISTURBED_PATHWAYS_IN_DUCHENNE_MUSCULAR_DYSTROPHY.html)
