
## Pathways:

**Activation of Matrix Metalloproteinases:** The matrix metalloproteinases (MMPs), previously known as matrixins, are classically known to be involved in the turnover of extracellular matrix (ECM) components. However, recent high throughput proteomics analyses have revealed that ~80% of MMP substrates are non-ECM proteins including cytokines, growth factor binding proteins, and receptors. It is now clear that MMPs regulate ECM turnover not only by cleaving ECM components, but also by the regulation of cell signalling, and that some MMPs are beneficial and may be drug anti-targets. Thus, MMPs have important roles in many processes including embryo development, morphogenesis, tissue homeostasis and remodeling. They are implicated in several diseases such as arthritis, periodontitis, glomerulonephritis, atherosclerosis, tissue ulceration, and cancer cell invasion and metastasis. All MMPs are synthesized as preproenzymes. Alternate splice forms are known, leading to nuclear localization of select MMPs. Most are secreted from the cell, or in the case of membrane type (MT) MMPs become plasma membrane associated, as inactive proenzymes. Their subsequent activation is a key regulatory step, with requirements specific to MMP subtype [[https://reactome.org/PathwayBrowser/#/R-HSA-1592389](https://reactome.org/PathwayBrowser/#/R-HSA-1592389)].

**Interleukin-10 signaling:** Interleukin-10 (IL10) was originally described as a factor named cytokine synthesis inhibitory factor that inhibited T-helper (Th) 1 activation and Th1 cytokine production (Fiorentino et al. 1989). It was found to be expressed by a variety of cell types including macrophages, dendritic cell subsets, B cells, several T-cell subpopulations including Th2 and T-regulatory cells (Tregs) and Natural Killer (NK) cells (Moore et al. 2001). It is now recognized that the biological effects of IL10 are directed at antigen-presenting cells (APCs) such as macrophages and dendritic cells (DCs), its effects on T-cell development and differentiation are largely indirect via inhibition of macrophage/dendritic cell activation and maturation (Pestka et al. 2004, Mocellin et al. 2004). T cells are thought to be the main source of IL10 (Hedrich & Bream 2010). IL10 inhibits a broad spectrum of activated macrophage/monocyte functions including monokine synthesis, NO production, and expression of class II MHC and costimulatory molecules such as IL12 and CD80/CD86 (de Waal Malefyt et al. 1991, Gazzinelli et al. 1992). Studies with recombinant cytokine and neutralizing antibodies revealed pleiotropic activities of IL10 on B, T, and mast cells (de Waal Malefyt et al. 1993, Rousset et al. 1992, Thompson-Snipes et al. 1991) and provided evidence for the in vivo significance of IL10 activities (Ishida et al. 1992, 1993). IL10 antagonizes the expression of MHC class II and the co-stimulatory molecules CD80/CD86 as well as the pro-inflammatory cytokines IL1Beta, IL6, IL8, TNFalpha and especially IL12 (Fiorentino et al. 1991, D'Andrea et al. 1993). The biological role of IL10 is not limited to inactivation of APCs, it also enhances B cell, granulocyte, mast cell, and keratinocyte growth/differentiation, as well as NK-cell and CD8+ cytotoxic T-cell activation (Moore et al. 2001, Hedrich & Bream 2010). IL10 also enhances NK-cell proliferation and/or production of IFN-gamma (Cai et al. 1999).

IL10-deficient mice exhibited inflammatory bowel disease (IBD) and other exaggerated inflammatory responses (Kuhn et al. 1993, Berg et al. 1995) indicating a critical role for IL10 in limiting inflammatory responses. Dysregulation of IL10 is linked with susceptibility to numerous infectious and autoimmune diseases in humans and mouse models (Hedrich & Bream 2010).

IL10 signaling is initiated by binding of homodimeric IL10 to the extracellular domains of two adjoining IL10RA molecules. This tetramer then binds two IL10RB chains. IL10RB cannot bind to IL10 unless bound to IL10RA (Ding et al. 2001, Yoon et al. 2006); binding of IL10 to IL10RA without the co-presence of IL10RB fails to initiate signal transduction (Kotenko et al. 1997).

IL10 binding activates the receptor-associated Janus tyrosine kinases, JAK1 and TYK2, which are constitutively bound to IL10R1 and IL10R2 respectively. In the classic model of receptor activation assembly of the receptor complex is believed to enable JAK1/TYK2 to phosphorylate and activate each other. Alternatively the binding of IL10 may cause conformational changes that allow the pseudokinase inhibitory domain of one JAK kinase to move away from the kinase domain of the other JAK within the receptor dimer-JAK complex, allowing the two kinase domains to interact and trans-activate (Waters & Brooks 2015).

The activated JAK kinases phosphorylate the intracellular domains of the IL10R1 chains on specific tyrosine residues. These phosphorylated tyrosine residues and their flanking peptide sequences serve as temporary docking sites for the latent, cytosolic, transcription factor, STAT3. STAT3 transiently docks on the IL10R1 chain via its SH2 domain, and is in turn tyrosine phosphorylated by the receptor-associated JAKs. Once activated, it dissociates from the receptor, dimerizes with other STAT3 molecules, and translocates to the nucleus where it binds with high affinity to STAT-binding elements (SBEs) in the promoters of IL-10-inducible genes (Donnelly et al. 1999) [[https://reactome.org/PathwayBrowser/#/R-HSA-6783783&PATH=R-HSA-168256,R-HSA-1280215,R-HSA-449147](https://reactome.org/PathwayBrowser/#/R-HSA-6783783&PATH=R-HSA-168256,R-HSA-1280215,R-HSA-449147)].

**Interleukin-4 and Interleukin-13 signaling:** Interleukin-4 (IL4) is a principal regulatory cytokine during the immune response, crucially important in allergy and asthma (Nelms et al. 1999). When resting T cells are antigen-activated and expand in response to Interleukin-2 (IL2), they can differentiate as Type 1 (Th1) or Type 2 (Th2) T helper cells. The outcome is influenced by IL4. Th2 cells secrete IL4, which both stimulates Th2 in an autocrine fashion and acts as a potent B cell growth factor to promote humoral immunity (Nelms et al. 1999).

Interleukin-13 (IL13) is an immunoregulatory cytokine secreted predominantly by activated Th2 cells. It is a key mediator in the pathogenesis of allergic inflammation. IL13 shares many functional properties with IL4, stemming from the fact that they share a common receptor subunit. IL13 receptors are expressed on human B cells, basophils, eosinophils, mast cells, endothelial cells, fibroblasts, monocytes, macrophages, respiratory epithelial cells, and smooth muscle cells, but unlike IL4, not T cells. Thus IL13 does not appear to be important in the initial differentiation of CD4 T cells into Th2 cells, rather it is important in the effector phase of allergic inflammation (Hershey et al. 2003). IL4 and IL13 induce "alternative activation" of macrophages, inducing an anti-inflammatory phenotype by signaling through IL4R alpha in a STAT6 dependent manner. This signaling plays an important role in the Th2 response, mediating anti-parasitic effects and aiding wound healing (Gordon & Martinez 2010, Loke et al. 2002) There are two types of IL4 receptor complex (Andrews et al. 2006). Type I IL4R (IL4R1) is predominantly expressed on the surface of hematopoietic cells and consists of IL4R and IL2RG, the common gamma chain. Type II IL4R (IL4R2) is predominantly expressed on the surface of nonhematopoietic cells, it consists of IL4R and IL13RA1 and is also the type II receptor for IL13. (Obiri et al. 1995, Aman et al. 1996, Hilton et al. 1996, Miloux et al. 1997, Zhang et al. 1997). The second receptor for IL13 consists of IL4R and Interleukin-13 receptor alpha 2 (IL13RA2), sometimes called Interleukin-13 binding protein (IL13BP). It has a high affinity receptor for IL13 (Kd = 250 pmol/L) but is not sufficient to render cells responsive to IL13, even in the presence of IL4R (Donaldson et al. 1998). It is reported to exist in soluble form (Zhang et al. 1997) and when overexpressed reduces JAK-STAT signaling (Kawakami et al. 2001). It's function may be to prevent IL13 signalling via the functional IL4R:IL13RA1 receptor. IL13RA2 is overexpressed and enhances cell invasion in some human cancers (Joshi & Puri 2012).

The first step in the formation of IL4R1 (IL4:IL4R:IL2RB) is the binding of IL4 with IL4R (Hoffman et al. 1995, Shen et al. 1996, Hage et al. 1999). This is also the first step in formation of IL4R2 (IL4:IL4R:IL13RA1). After the initial binding of IL4 and IL4R, IL2RB binds (LaPorte et al. 2008), to form IL4R1. Alternatively, IL13RA1 binds, forming IL4R2. In contrast, the type II IL13 complex (IL13R2) forms with IL13 first binding to IL13RA1 followed by recruitment of IL4R (Wang et al. 2009).

Crystal structures of the IL4:IL4R:IL2RG, IL4:IL4R:IL13RA1 and IL13:IL4R:IL13RA1 complexes have been determined (LaPorte et al. 2008). Consistent with these structures, in monocytes IL4R is tyrosine phosphorylated in response to both IL4 and IL13 (Roy et al. 2002, Gordon & Martinez 2010) while IL13RA1 phosphorylation is induced only by IL13 (Roy et al. 2002, LaPorte et al. 2008) and IL2RG phosphorylation is induced only by IL4 (Roy et al. 2002).

Both IL4 receptor complexes signal through Jak/STAT cascades. IL4R is constitutively-associated with JAK2 (Roy et al. 2002) and associates with JAK1 following binding of IL4 (Yin et al. 1994) or IL13 (Roy et al. 2002). IL2RG constitutively associates with JAK3 (Boussiotis et al. 1994, Russell et al. 1994). IL13RA1 constitutively associates with TYK2 (Umeshita-Suyama et al. 2000, Roy et al. 2002, LaPorte et al. 2008, Bhattacharjee et al. 2013). IL4 binding to IL4R1 leads to phosphorylation of JAK1 (but not JAK2) and STAT6 activation (Takeda et al. 1994, Ratthe et al. 2007, Bhattacharjee et al. 2013).

IL13 binding increases activating tyrosine-99 phosphorylation of IL13RA1 but not that of IL2RG. IL4 binding to IL2RG leads to its tyrosine phosphorylation (Roy et al. 2002). IL13 binding to IL4R2 leads to TYK2 and JAK2 (but not JAK1) phosphorylation (Roy & Cathcart 1998, Roy et al. 2002). Phosphorylated TYK2 binds and phosphorylates STAT6 and possibly STAT1 (Bhattacharjee et al. 2013).

A second mechanism of signal transduction activated by IL4 and IL13 leads to the insulin receptor substrate (IRS) family (Kelly-Welch et al. 2003). IL4R1 associates with insulin receptor substrate 2 and activates the PI3K/Akt and Ras/MEK/Erk pathways involved in cell proliferation, survival and translational control. IL4R2 does not associate with insulin receptor substrate 2 and consequently the PI3K/Akt and Ras/MEK/Erk pathways are not activated (Busch-Dienstfertig & Gonzalez-Rodriguez 2013)[[https://reactome.org/PathwayBrowser/#/R-HSA-6785807](https://reactome.org/PathwayBrowser/#/R-HSA-6785807)].

**Platelet degranulation:** Platelets function as exocytotic cells, secreting a plethora of effector molecules at sites of vascular injury. Platelets contain a number of distinguishable storage granules including alpha granules, dense granules and lysosomes. On activation platelets release a variety of proteins, largely from storage granules but also as the result of apparent cell lysis. These act in an autocrine or paracrine fashion to modulate cell signaling.

Alpha granules contain mainly polypeptides such as fibrinogen, von Willebrand factor, growth factors and protease inhibitors that that supplement thrombin generation at the site of injury. Dense granules contain small molecules, particularly adenosine diphosphate (ADP), adenosine triphosphate (ATP), serotonin and calcium, all recruit platelets to the site of injury. The molecular mechanism which facilitates granule release involves soluble NSF attachment protein receptors (SNAREs), which assemble into complexes to form a universal membrane fusion apparatus. Although all cells use SNAREs for membrane fusion, different cells possess different SNARE isoforms. Platelets and chromaffin cells use many of the same chaperone proteins to regulate SNARE-mediated secretion (Fitch-Tewfik & Flaumenhaft 2013) [[https://reactome.org/PathwayBrowser/#/R-HSA-114608](https://reactome.org/PathwayBrowser/#/R-HSA-114608)].

**Post-translational protein phosphorylation:** Secretory pathway kinases phosphorylate a diverse array of substrates involved in many physiological processes [[https://reactome.org/PathwayBrowser/#/R-HSA-8957275](https://reactome.org/PathwayBrowser/#/R-HSA-8957275)].

**Regulation of Insulin-like Growth Factor (IGF) transport and uptake by Insulin-like Growth Factor Binding Proteins (IGFBPs):** The family of Insulin like Growth Factor Binding Proteins (IGFBPs) share 50% amino acid identity with conserved N terminal and C terminal regions responsible for binding Insulin like Growth Factors I and II (IGF I and IGF II). Most circulating IGFs are in complexes with IGFBPs, which are believed to increase the residence of IGFs in the body, modulate availability of IGFs to target receptors for IGFs, reduce insulin like effects of IGFs, and act as signaling molecules independently of IGFs. About 75% of circulating IGFs are in 1500-220 KDa complexes with IGFBP3 and ALS. Such complexes are too large to pass the endothelial barrier. The remaining 20-25% of IGFs are bound to other IGFBPs in 40-50 KDa complexes. IGFs are released from IGF:IGFBP complexes by proteolysis of the IGFBP. IGFs become active after release, however IGFs may also have activity when still bound to some IGFBPs. IGFBP1 is enriched in amniotic fluid and is produced in the liver under control of insulin (insulin suppresses production). IGFBP1 binding stimulates IGF function. It is unknown which if any protease degrades IGFBP1. IGFBP2 is enriched in cerebrospinal fluid; its binding inhibits IGF function. IGFBP2 is not significantly degraded in circulation. IGFBP3, which binds most IGF in the body is enriched in follicular fluid and found in many other tissues. IGFBP 3 may be cleaved by plasmin, thrombin, Prostate specific Antigen (PSA, KLK3), Matrix Metalloprotease-1 (MMP1), and Matrix Metalloprotease-2 (MMP2). IGFBP3 also binds extracellular matrix and binding lowers its affinity for IGFs. IGFBP3 binding stimulates the effects of IGFs. IGFBP4 acts to inhibit IGF function and is cleaved by Pregnancy associated Plasma Protein A (PAPPA) to release IGF. IGFBP5 is enriched in bone matrix; its binding stimulates IGF function. IGFBP5 is cleaved by Pregnancy Associated Plasma Protein A2 (PAPPA2), ADAM9, complement C1s from smooth muscle, and thrombin. Only the cleavage site for PAPPA2 is known. IGFBP6 is enriched in cerebrospinal fluid. It is unknown which if any protease degrades IGFBP6 [[https://reactome.org/PathwayBrowser/#/R-HSA-381426](https://reactome.org/PathwayBrowser/#/R-HSA-381426)].

## GO terms:

**cartilage development** [The process whose specific outcome is the progression of a cartilage element over time, from its formation to the mature structure. Cartilage elements are skeletal elements that consist of connective tissue dominated by extracellular matrix containing collagen type II and large amounts of proteoglycan, particularly chondroitin sulfate. GO:0051216]

**cellular response to UV-A** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a UV-A radiation stimulus. UV-A radiation (UV-A light) spans the wavelengths 315 to 400 nm. GO:0071492]

**connective tissue replacement involved in inflammatory response wound healing** [The series of events leading to growth of connective tissue when loss of tissues that are incapable of regeneration occurs, or when fibrinous exudate cannot be adequately cleared, as part of an inflammatory response. GO:0002248]

**negative regulation of apoptotic process** [Any process that stops, prevents, or reduces the frequency, rate or extent of cell death by apoptotic process.|This term should only be used when it is not possible to determine which phase or subtype of the apoptotic process is negatively regulated by a gene product. Whenever detailed information is available, the more granular children terms should be used. GO:0043066]

**negative regulation of membrane protein ectodomain proteolysis** [Any process that stops, prevents, or reduces the frequency, rate or extent of membrane protein ectodomain proteolysis. GO:0051045]

**negative regulation of trophoblast cell migration** [Any process that stops, prevents or reduces the frequency, rate or extent of trophoblast cell migration. GO:1901164]

**positive regulation of cell population proliferation** [Any process that activates or increases the rate or extent of cell proliferation. GO:0008284]

**regulation of integrin-mediated signaling pathway** [Any process that modulates the frequency, rate or extent of integrin-mediated signaling pathway. GO:2001044]

**response to cytokine** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a cytokine stimulus. GO:0034097]

**response to hormone** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a hormone stimulus. GO:0009725]

**response to organic substance** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an organic substance stimulus. GO:0010033]

**response to peptide hormone** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a peptide hormone stimulus. A peptide hormone is any of a class of peptides that are secreted into the blood stream and have endocrine functions in living animals. GO:0043434]

**signal transduction** [The cellular process in which a signal is conveyed to trigger a change in the activity or state of a cell. Signal transduction begins with reception of a signal (e.g. a ligand binding to a receptor or receptor activation by a stimulus such as light), or for signal transduction in the absence of ligand, signal-withdrawal or the activity of a constitutively active receptor. Signal transduction ends with regulation of a downstream cellular process, e.g. regulation of transcription or regulation of a metabolic process. Signal transduction covers signaling from receptors located on the surface of the cell and signaling via molecules located within the cell. For signaling between cells, signal transduction is restricted to events at and within the receiving cell.|Note that signal transduction is defined broadly to include a ligand interacting with a receptor, downstream signaling steps and a response being triggered. A change in form of the signal in every step is not necessary. Note that in many cases the end of this process is regulation of the initiation of transcription. Note that specific transcription factors may be annotated to this term, but core/general transcription machinery such as RNA polymerase should not. GO:0007165]

**steroid biosynthetic process** [The chemical reactions and pathways resulting in the formation of steroids, compounds with a 1,2,cyclopentanoperhydrophenanthrene nucleus; includes de novo formation and steroid interconversion by modification. GO:0006694]

## MSigDB Signatures:

**RODWELL_AGING_KIDNEY_NO_BLOOD_UP**: Genes whose expression increases with age in normal kidney, excluding those with higher expression in blood. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RODWELL_AGING_KIDNEY_NO_BLOOD_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RODWELL_AGING_KIDNEY_NO_BLOOD_UP.html)

**RODWELL_AGING_KIDNEY_UP**: Genes whose expression increases with age in normal kidney. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RODWELL_AGING_KIDNEY_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/RODWELL_AGING_KIDNEY_UP.html)

**BAELDE_DIABETIC_NEPHROPATHY_DN**: Genes down-regulated in glomeruli of kidneys from patients with diabetic nephropathy (type 2 diabetes mellitus). [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BAELDE_DIABETIC_NEPHROPATHY_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/BAELDE_DIABETIC_NEPHROPATHY_DN.html)

**REACTOME_HEMOSTASIS**: Hemostasis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HEMOSTASIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_HEMOSTASIS.html)

**REACTOME_EXTRACELLULAR_MATRIX_ORGANIZATION**: Extracellular matrix organization [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_EXTRACELLULAR_MATRIX_ORGANIZATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_EXTRACELLULAR_MATRIX_ORGANIZATION.html)

**WP_MAMMARY_GLAND_DEVELOPMENT_PATHWAY_PUBERTY_STAGE_2_OF_4**: Mammary gland development pathway Puberty Stage 2 of 4 [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_MAMMARY_GLAND_DEVELOPMENT_PATHWAY_PUBERTY_STAGE_2_OF_4.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_MAMMARY_GLAND_DEVELOPMENT_PATHWAY_PUBERTY_STAGE_2_OF_4.html)

**WP_LUNG_FIBROSIS**: Lung fibrosis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_LUNG_FIBROSIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_LUNG_FIBROSIS.html)

**REACTOME_DEGRADATION_OF_THE_EXTRACELLULAR_MATRIX**: Degradation of the extracellular matrix [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEGRADATION_OF_THE_EXTRACELLULAR_MATRIX.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEGRADATION_OF_THE_EXTRACELLULAR_MATRIX.html)

**REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM**: Cytokine Signaling in Immune system [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CYTOKINE_SIGNALING_IN_IMMUNE_SYSTEM.html)

**REACTOME_SIGNALING_BY_INTERLEUKINS**: Signaling by Interleukins [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_INTERLEUKINS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_INTERLEUKINS.html)

**REACTOME_POST_TRANSLATIONAL_PROTEIN_MODIFICATION**: Post-translational protein modification [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_POST_TRANSLATIONAL_PROTEIN_MODIFICATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_POST_TRANSLATIONAL_PROTEIN_MODIFICATION.html)

**NAKAYAMA_SOFT_TISSUE_TUMORS_PCA1_UP**: Top 100 probe sets contrubuting to the positive side of the 1st principal component; predominantly associated with spindle cell and pleomorphic sarcoma samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NAKAYAMA_SOFT_TISSUE_TUMORS_PCA1_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NAKAYAMA_SOFT_TISSUE_TUMORS_PCA1_UP.html)

**WP_MATRIX_METALLOPROTEINASES**: Matrix metalloproteinases [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_MATRIX_METALLOPROTEINASES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_MATRIX_METALLOPROTEINASES.html)

**REACTOME_INTERLEUKIN_10_SIGNALING**: Interleukin-10 signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INTERLEUKIN_10_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INTERLEUKIN_10_SIGNALING.html)
