
## **Pathways:**

-   **Adaptive immunity** refers to Antigen-specific immune response efficiently involved in clearing the pathogens. The adaptive immune system is comprised of B and T lymphocytes that express receptors with remarkable diversity tailored to recognize aspects of particular pathogens or antigens. During infection, dendritic cells (DC) which act as sentinels in the peripheral tissues recognize and pick up the pathogen in the form of antigenic determinants and then process these antigens and present them to T cells. These T cells of appropriate specificity respond to the antigen, and either kill the pathogen directly or secrete cytokines that will stimulate B lymphocyte response. B cells provide humoral immunity by secreting antibodies specific for the pathogen or antigen. [[https://reactome.org/PathwayBrowser/#/R-HSA-1280218](https://reactome.org/PathwayBrowser/#/R-HSA-1280218)]
-   **Axon guidance / axon path finding** is the process by which neurons send out axons to reach the correct targets. Growing axons have a highly motile structure at the growing tip called the growth cone, which senses the guidance cues in the environment through guidance cue receptors and responds by undergoing cytoskeletal changes that determine the direction of axon growth. Guidance cues present in the surrounding environment provide the necessary directional information for the trip. These extrinsic cues have been divided into attractive or repulsive signals that tell the growth cone where and where not to grow. Genetic and biochemical studies have led to the identification of highly conserved families of guidance molecules and their receptors that guide axons. These include netrins, Slits, semaphorins, and ephrins, and their cognate receptors, DCC and or uncoordinated-5 (UNC5), roundabouts (Robo), neuropilin and Eph. In addition, many other classes of adhesion molecules are also used by growth cones to navigate properly which include NCAM and L1CAM. For review of axon guidance, please refer to Russel and Bashaw 2018, Chedotal 2019, Suter and Jaworski 2019). Axon guidance cues and their receptors are implicated in cancer progression (Biankin et al. 2012), where they likely contribute to cell migration and angiogenesis (reviewed by Mehlen et al. 2011). [[https://reactome.org/PathwayBrowser/#/R-HSA-422475](https://reactome.org/PathwayBrowser/#/R-HSA-422475)]
-   **DAP12 signaling**: In response to receptor ligation, the tyrosine residues in DAP12's immunoreceptor tyrosine-based activation motif (ITAM) are phosphorylated by Src family kinases. These phosphotyrosines form the docking site for the protein tyrosine kinase SYK in myeloid cells and SYK and ZAP70 in NK cells. DAP12-bound SYK autophosphorylates and phosphorylates the scaffolding molecule LAT, recruiting the proximal signaling molecules phosphatidylinositol-3-OH kinase (PI3K), phospholipase-C gamma (PLC-gamma), GADS (GRB2-related adapter downstream of SHC), SLP76 (SH2 domain-containing leukocyte protein of 76 kDa), GRB2:SOS (Growth factor receptor-bound protein 2:Son of sevenless homolog 1) and VAV. All of these intermediate signalling molecules result in the recruitment and activation of kinases AKT, CBL (Casitas B-lineage lymphoma) and ERK (extracellular signal-regulated kinase), and rearrangement of the actin cytoskeleton (actin polymerization) finally leading to cellular activation. PLC-gamma generates the secondary messengers diacylglycerol (DAG) and inositol-1,4,5-trisphosphate (InsP3), leading to activation of protein kinase C (PKC) and calcium mobilization, respectively (Turnbull & Colonna 2007, Klesney-Tait et al. 2006). [[https://reactome.org/PathwayBrowser/#/R-HSA-2424491](https://reactome.org/PathwayBrowser/#/R-HSA-2424491)]

## GO terms:

**CXCL12-activated CXCR4 signaling pathway** [The series of molecular signals initiated by the binding of the C-X-C chemokine CXCL12 to a C-X-C chemokine type 4 receptor (CXCR4) on the surface of a target cell, and ending with the regulation of a downstream cellular process, e.g. transcription. GO:0038160]

**amyloid-beta clearance** [The process in which amyloid-beta is removed from extracellular brain regions by mechanisms involving cell surface receptors. GO:0097242]

**amyloid-beta clearance by cellular catabolic process** [The process in which amyloid-beta is removed from extracellular brain regions by cell surface receptor-mediated endocytosis, followed by intracellular degradation. GO:0150094]

**apoptotic cell clearance** [The recognition and removal of an apoptotic cell by a neighboring cell or by a phagocyte.|Note that unlike mammals or Drosophila, C. elegans (and many lower organisms) do not have professional macrophages/phagocytes, instead cell corpses are engulfed by neighboring cells. Cell types that can function as engulfing cells include hypodermal cells, gonadal sheath cells, pharyngeal muscle cells, and intestinal cells. GO:0043277]

**astrocyte activation** [A change in morphology and behavior of an astrocyte resulting from exposure to a cytokine, chemokine, cellular ligand, or soluble factor. GO:0048143]

**cellular response to amyloid-beta** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a amyloid-beta stimulus. GO:1904646]

**cellular response to glucose stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a glucose stimulus. GO:0071333]

**cellular response to hypoxia** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus indicating lowered oxygen tension. Hypoxia, defined as a decline in O2 levels below normoxic levels of 20.8 - 20.95%, results in metabolic adaptation at both the cellular and organismal level.|Note that this term should not be confused with 'cellular response to anoxia ; GO:0071454'. Note that in laboratory studies, hypoxia is typically studied at O2 concentrations ranging from 0.1 - 5%. GO:0071456]

**cellular response to lipid** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lipid stimulus. GO:0071396]

**cellular response to lipoteichoic acid** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a lipoteichoic acid stimulus; lipoteichoic acid is a major component of the cell wall of gram-positive bacteria and typically consists of a chain of glycerol-phosphate repeating units linked to a glycolipid anchor. GO:0071223]

**cellular response to oxidised low-density lipoprotein particle stimulus** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an oxidized lipoprotein particle stimulus. GO:0140052]

**cellular response to peptidoglycan** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a peptidoglycan stimulus. Peptidoglycan is a bacterial cell wall macromolecule. GO:0071224]

**complement-mediated synapse pruning** [Synaptic pruning mediated by complement system signaling. GO:0150062]

**defense response to Gram-negative bacterium** [Reactions triggered in response to the presence of a Gram-negative bacterium that act to protect the cell or organism. GO:0050829]

**defense response to bacterium** [Reactions triggered in response to the presence of a bacterium that act to protect the cell or organism. GO:0042742]

**dendritic cell differentiation** [The process in which a precursor cell type acquires the specialized features of a dendritic cell. A dendritic cell is a leukocyte of dendritic lineage specialized in the uptake, processing, and transport of antigens to lymph nodes for the purpose of stimulating an immune response via T cell activation.|Note that immunologists typically use the word 'maturation' to refer to dendritic cells undergoing the process that GO describes as 'cell differentiation'. GO:0097028]

**dendritic spine maintenance** [The organization process that preserves a dendritic spine in a stable functional or structural state. A dendritic spine is a specialized protrusion from a neuronal dendrite and is involved in synaptic transmission. GO:0097062]

**detection of lipopolysaccharide** [The series of events in which a lipopolysaccharide stimulus is received by a cell and converted into a molecular signal. Lipopolysaccharide is a major component of the cell wall of gram-negative bacteria. GO:0032497]

**detection of lipoteichoic acid** [The series of events in which a lipoteichoic acid stimulus is received by a cell and converted into a molecular signal; lipoteichoic acid is a major component of the cell wall of gram-positive bacteria and typically consists of a chain of glycerol-phosphate repeating units linked to a glycolipid anchor. GO:0070392]

**detection of peptidoglycan** [The series of events in which a peptidoglycan stimulus is received by a cell and converted into a molecular signal. Peptidoglycan is a bacterial cell wall macromolecule. GO:0032499]

**excitatory synapse pruning** [The disaggregation of an excitatory synapse into its constituent components. GO:1905805]

**import into cell** [The directed movement of some substance from outside of a cell into a cell. This may occur via transport across the plasma membrane or via endocytosis. GO:0098657]

**lipid homeostasis** [Any process involved in the maintenance of an internal steady state of lipid within an organism or cell. GO:0055088]

**memory** [The activities involved in the mental information processing system that receives (registers), modifies, stores, and retrieves informational stimuli. The main stages involved in the formation and retrieval of memory are encoding (processing of received information by acquisition), storage (building a permanent record of received information as a result of consolidation) and retrieval (calling back the stored information and use it in a suitable way to execute a given task). GO:0007613]

**microglial cell activation** [The change in morphology and behavior of a microglial cell resulting from exposure to a cytokine, chemokine, cellular ligand, or soluble factor. GO:0001774]

**microglial cell activation involved in immune response** [The change in morphology and behavior of a microglial cell resulting from exposure to a cytokine, chemokine, cellular ligand, or soluble factor, leading to the initiation or perpetuation of an immune response. GO:0002282]

**microglial cell proliferation** [The expansion of a microglial cell population by cell division. GO:0061518]

**negative regulation of NLRP3 inflammasome complex assembly** [Any process that stops, prevents or reduces the frequency, rate or extent of NLRP3 inflammasome complex assembly. GO:1900226]

**negative regulation of amyloid fibril formation** [Any process that stops, prevents or reduces the frequency, rate or extent of amyloid fibril formation.|Although deposition of amyloid fibrils is associated with diseases, e.g. Alzheimer's disease, amyloid formation is a normal process. Disease occurs when the balance between amyloid formation and clearance is disrupted (reviewed e.g. in PMID: 29654159 and PMID: 28937655). An example of a normal amyloid complex is composed of human RIP1 and RIP3 kinases (PMID: 22817896). GO:1905907]

**negative regulation of apoptotic process** [Any process that stops, prevents, or reduces the frequency, rate or extent of cell death by apoptotic process.|This term should only be used when it is not possible to determine which phase or subtype of the apoptotic process is negatively regulated by a gene product. Whenever detailed information is available, the more granular children terms should be used. GO:0043066]

**negative regulation of astrocyte activation** [Any process that decreases the frequency, rate or extent of astrocyte activation. GO:0061889]

**negative regulation of autophagic cell death** [Any process that stops, prevents or reduces the frequency, rate or extent of autophagic cell death. GO:1904093]

**negative regulation of autophagy** [Any process that stops, prevents, or reduces the frequency, rate or extent of autophagy. Autophagy is the process in which cells digest parts of their own cytoplasm. GO:0010507]

**negative regulation of canonical NF-kappaB signal transduction** [Any process that stops, prevents, or reduces the frequency, rate or extent of a canonical NF-kappaB signaling cascade. GO:0043124]

**negative regulation of cell activation** [Any process that stops, prevents, or reduces the frequency, rate or extent of cell activation. GO:0050866]

**negative regulation of cholesterol storage** [Any process that decreases the rate or extent of cholesterol storage. Cholesterol storage is the accumulation and maintenance in cells or tissues of cholesterol, cholest-5-en-3 beta-ol, the principal sterol of vertebrates and the precursor of many steroids, including bile acids and steroid hormones. GO:0010887]

**negative regulation of cytokine production involved in inflammatory response** [Any process that stops, prevents or reduces the frequency, rate or extent of cytokine production involved in inflammatory response. GO:1900016]

**negative regulation of fat cell proliferation** [Any process that stops or decreases the rate or extent of fat cell proliferation. GO:0070345]

**negative regulation of glial cell apoptotic process** [Any process that stops, prevents, or reduces the frequency, rate, or extent of glial cell apoptotic process. GO:0034351]

**negative regulation of inflammatory response to antigenic stimulus** [Any process that stops, prevents, or reduces the frequency, rate, or extent of an inflammatory response to an antigenic stimulus. GO:0002862]

**negative regulation of interleukin-1 beta production** [Any process that stops, prevents, or reduces the frequency, rate, or extent of interleukin-1 beta production. GO:0032691]

**negative regulation of macrophage colony-stimulating factor signaling pathway** [Any process that stops, prevents or reduces the frequency, rate or extent of macrophage colony-stimulating factor signaling pathway. GO:1902227]

**negative regulation of neuroinflammatory response** [Any process that stops, prevents or reduces the frequency, rate or extent of neuroinflammatory response. GO:0150079]

**negative regulation of p38MAPK cascade** [Any process that stops, prevents or reduces the frequency, rate or extent of p38MAPK cascade. GO:1903753]

**negative regulation of phosphatidylinositol 3-kinase/protein kinase B signal transduction** [Any process that stops, prevents, or reduces the frequency, rate or extent of phosphatidylinositol 3-kinase/protein kinase B signal transduction. GO:0051898]

**negative regulation of sequestering of triglyceride** [Any process that decreases the rate, frequency or extent of sequestering of triglyceride. Triglyceride sequestration is the process of binding or confining any triester of glycerol such that it is separated from other components of a biological system. GO:0010891]

**negative regulation of toll-like receptor 2 signaling pathway** [Any process that stops, prevents, or reduces the frequency, rate, or extent of toll-like receptor 2 signaling pathway. GO:0034136]

**negative regulation of toll-like receptor 4 signaling pathway** [Any process that stops, prevents, or reduces the frequency, rate, or extent of toll-like receptor 4 signaling pathway. GO:0034144]

**negative regulation of tumor necrosis factor production** [Any process that stops, prevents, or reduces the frequency, rate, or extent of tumor necrosis factor production.|Note that this term refers only to the specific, original 'tumor necrosis factor' protein (TNF) and not other members of the tumor necrosis factor superfamily (those with the gene symbol root 'TNFSF'). GO:0032720]

**neuroinflammatory response** [The immediate defensive reaction by neural vertebrate tissue to infection or injury caused by chemical or physical agents. GO:0150076]

**osteoclast differentiation** [The process in which a relatively unspecialized monocyte acquires the specialized features of an osteoclast. An osteoclast is a specialized phagocytic cell associated with the absorption and removal of the mineralized matrix of bone tissue. GO:0030316]

**phagocytosis, engulfment** [The internalization of bacteria, immune complexes and other particulate matter or of an apoptotic cell by phagocytosis, including the membrane and cytoskeletal processes required, which involves one of three mechanisms: zippering of pseudopods around a target via repeated receptor-ligand interactions, sinking of the target directly into plasma membrane of the phagocytosing cell, or induced uptake via an enhanced membrane ruffling of the phagocytosing cell similar to macropinocytosis. GO:0006911]

**phagocytosis, recognition** [The initial step in phagocytosis involving adhesion to bacteria, immune complexes and other particulate matter, or an apoptotic cell and based on recognition of factors such as bacterial cell wall components, opsonins like complement and antibody or protein receptors and lipids like phosphatidyl serine, and leading to intracellular signaling in the phagocytosing cell.|Note that cell surface molecules involved in the direct binding of bacteria may be also annotated to the molecular function term 'bacterial cell surface binding ; GO:0051635'. Note that cell surface molecules involved in the direct binding to opsonins such as complement components or antibodies may be also annotated to the term 'opsonin binding ; GO:0001846'. GO:0006910]

**positive regulation of ATP biosynthetic process** [Any process that activates or increases the frequency, rate or extent of ATP biosynthetic process. GO:2001171]

**positive regulation of C-C chemokine receptor CCR7 signaling pathway** [Any process that activates or increases the frequency, rate or extent of C-C chemokine receptor CCR7 signaling pathway. GO:1903082]

**positive regulation of CAMKK-AMPK signaling cascade** [Any process that activates or increases the frequency, rate or extent of CAMKK-AMPK signaling cascade. GO:1905291]

**positive regulation of CD40 signaling pathway** [Any process that activates or increases the frequency, rate or extent of signaling via the CD40 signaling pathway. GO:2000350]

**positive regulation of ERK1 and ERK2 cascade** [Any process that activates or increases the frequency, rate or extent of signal transduction mediated by the ERK1 and ERK2 cascade. GO:0070374]

**positive regulation of TOR signaling** [Any process that activates or increases the frequency, rate or extent of TOR signaling. GO:0032008]

**positive regulation of amyloid-beta clearance** [Any process that activates or increases the frequency, rate or extent of amyloid-beta clearance. GO:1900223]

**positive regulation of antigen processing and presentation of peptide antigen via MHC class II** [Any process that activates or increases the frequency, rate, or extent of antigen processing and presentation of peptide antigen via MHC class II. GO:0002588]

**positive regulation of calcium-mediated signaling** [Any process that activates or increases the frequency, rate or extent of calcium-mediated signaling. GO:0050850]

**positive regulation of chemotaxis** [Any process that activates or increases the frequency, rate or extent of the directed movement of a motile cell or organism in response to a specific chemical concentration gradient. GO:0050921]

**positive regulation of cholesterol efflux** [Any process that increases the frequency, rate or extent of cholesterol efflux. Cholesterol efflux is the directed movement of cholesterol, cholest-5-en-3-beta-ol, out of a cell or organelle. GO:0010875]

**positive regulation of complement activation, classical pathway** [Any process that activates or increases the frequency, rate or extent of complement activation by the classical pathway. GO:0045960]

**positive regulation of engulfment of apoptotic cell** [Any process that activates or increases the frequency, rate or extent of engulfment of apoptotic cell. GO:1901076]

**positive regulation of establishment of protein localization** [Any process that activates or increases the frequency, rate or extent of establishment of protein localization. GO:1904951]

**positive regulation of gene expression** [Any process that increases the frequency, rate or extent of gene expression. Gene expression is the process in which a gene's coding sequence is converted into a mature gene product (protein or RNA). GO:0010628]

**positive regulation of high-density lipoprotein particle clearance** [Any process that increases the rate, frequency or extent of high-density lipoprotein particle clearance. High-density lipoprotein particle clearance is the process in which a high-density lipoprotein particle is removed from the blood via receptor-mediated endocytosis and its constituent parts degraded. GO:0010983]

**positive regulation of interleukin-10 production** [Any process that activates or increases the frequency, rate, or extent of interleukin-10 production. GO:0032733]

**positive regulation of low-density lipoprotein particle clearance** [Any process that activates or increases the frequency, rate or extent of low-density lipoprotein particle clearance. GO:1905581]

**positive regulation of macrophage fusion** [Any process that activates or increases the frequency, rate or extent of macrophage fusion. GO:0034241]

**positive regulation of microglial cell activation** [Any process that activates or increases the frequency, rate or extent of microglial cell activation. GO:1903980]

**positive regulation of microglial cell migration** [Any process that activates or increases the frequency, rate or extent of microglial cell migration. GO:1904141]

**positive regulation of mitochondrion organization** [Any process that increases the frequency, rate or extent of a process involved in the formation, arrangement of constituent parts, or disassembly of a mitochondrion. GO:0010822]

**positive regulation of neuroinflammatory response** [Any process that activates or increases the frequency, rate or extent of neuroinflammatory response. GO:0150078]

**positive regulation of non-canonical NF-kappaB signal transduction** [Any process that activates or increases the frequency, rate or extent of the non-canonical NF-kappaB cascade. GO:1901224]

**positive regulation of osteoclast differentiation** [Any process that activates or increases the frequency, rate or extent of osteoclast differentiation. GO:0045672]

**positive regulation of peptidyl-tyrosine phosphorylation** [Any process that activates or increases the frequency, rate or extent of the phosphorylation of peptidyl-tyrosine. GO:0050731]

**positive regulation of phagocytosis** [Any process that activates or increases the frequency, rate or extent of phagocytosis. GO:0050766]

**positive regulation of phagocytosis, engulfment** [Any process that activates or increases the frequency, rate or extent of the internalization of bacteria, immune complexes and other particulate matter or of an apoptotic cell by phagocytosis. GO:0060100]

**positive regulation of phosphatidylinositol 3-kinase/protein kinase B signal transduction** [Any process that activates or increases the frequency, rate or extent of phosphatidylinositol 3-kinase/protein kinase B signal transduction. GO:0051897]

**positive regulation of proteasomal protein catabolic process** [Any process that activates or increases the frequency, rate or extent of proteasomal protein catabolic process. GO:1901800]

**positive regulation of protein localization to plasma membrane** [Any process that activates or increases the frequency, rate or extent of protein localization to plasma membrane. GO:1903078]

**positive regulation of protein phosphorylation** [Any process that activates or increases the frequency, rate or extent of addition of phosphate groups to amino acids within a protein. GO:0001934]

**positive regulation of protein secretion** [Any process that activates or increases the frequency, rate or extent of the controlled release of a protein from a cell. GO:0050714]

**positive regulation of synapse pruning** [Any process that activates or increases the frequency, rate or extent of synapse pruning. GO:1905808]

**pyroptosis** [A caspase-1-dependent cell death subroutine that is associated with the generation of pyrogenic mediators such as IL-1beta and IL-18. GO:0070269]

**regulation of TOR signaling** [Any process that modulates the frequency, rate or extent of TOR signaling. GO:0032006]

**regulation of cytokine production involved in inflammatory response** [Any process that modulates the frequency, rate or extent of cytokine production involved in inflammatory response. GO:1900015]

**regulation of gene expression** [Any process that modulates the frequency, rate or extent of gene expression. Gene expression is the process in which a gene's coding sequence is converted into a mature gene product (protein or RNA).|This class covers any process that regulates the rate of production of a mature gene product, and so includes processes that regulate that rate by regulating the level, stability or availability of intermediates in the process of gene expression. For example, it covers any process that regulates the level, stability or availability of mRNA or circRNA for translation and thereby regulates the rate of production of the encoded protein via translation. GO:0010468]

**regulation of hippocampal neuron apoptotic process** [Any process that modulates the occurrence or rate of cell death by apoptotic process in hippocampal neurons. GO:0110089]

**regulation of innate immune response** [Any process that modulates the frequency, rate or extent of the innate immune response, the organism's first line of defense against infection. GO:0045088]

**regulation of interleukin-6 production** [Any process that modulates the frequency, rate, or extent of interleukin-6 production. GO:0032675]

**regulation of intracellular signal transduction** [Any process that modulates the frequency, rate or extent of intracellular signal transduction. GO:1902531]

**regulation of lipid metabolic process** [Any process that modulates the frequency, rate or extent of the chemical reactions and pathways involving lipids. GO:0019216]

**regulation of macrophage inflammatory protein 1 alpha production** [Any process that modulates the frequency, rate, or extent of production of macrophage inflammatory protein 1 alpha. GO:0071640]

**regulation of oxidative stress-induced neuron intrinsic apoptotic signaling pathway** [Any process that modulates the frequency, rate or extent of oxidative stress-induced neuron intrinsic apoptotic signaling pathway. GO:1903376]

**regulation of peptidyl-tyrosine phosphorylation** [Any process that modulates the frequency, rate or extent of the phosphorylation of peptidyl-tyrosine. GO:0050730]

**regulation of plasma membrane bounded cell projection organization** [Any process that modulates the frequency, rate or extent of a process involved in the formation, arrangement of constituent parts, or disassembly of plasma membrane bounded cell projections. GO:0120035]

**regulation of resting membrane potential** [Any process that modulates the establishment or extent of a resting potential, the electrical charge across the plasma membrane, with the interior of the cell negative with respect to the exterior. The resting potential is the membrane potential of a cell that is not stimulated to be depolarized or hyperpolarized. GO:0060075]

**regulation of toll-like receptor 6 signaling pathway** [Any process that modulates the frequency, rate, or extent of toll-like receptor 6 signaling pathway. GO:0034151]

**respiratory burst after phagocytosis** [A phase of elevated metabolic activity, during which oxygen consumption increases, that occurs in neutrophils, monocytes, and macrophages shortly after phagocytosing material. An enhanced uptake of oxygen leads to the production, by an NADH dependent system, of hydrogen peroxide (H2O2), superoxide anions and hydroxyl radicals, which play a part in microbiocidal activity. GO:0045728]

**response to axon injury** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of an axon injury stimulus. GO:0048678]

**response to ischemia** [Any process that results in a change in state or activity of an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a inadequate blood supply.|Ischemia always results in hypoxia; however, hypoxia can occur without ischemia. GO:0002931]

**social behavior** [Behavior directed towards society, or taking place between members of the same species. Occurs predominantly, or only, in individuals that are part of a group.|Behavior such as predation which involves members of different species is not social. Communication between members of different species is also not social behavior. GO:0035176]

## MSigDB Signatures:

**REACTOME_INNATE_IMMUNE_SYSTEM**: Innate Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html)

**REACTOME_ADAPTIVE_IMMUNE_SYSTEM**: Adaptive Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ADAPTIVE_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ADAPTIVE_IMMUNE_SYSTEM.html)

**REACTOME_DEVELOPMENTAL_BIOLOGY**: Developmental Biology [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEVELOPMENTAL_BIOLOGY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEVELOPMENTAL_BIOLOGY.html)

**REACTOME_NERVOUS_SYSTEM_DEVELOPMENT**: Nervous system development [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NERVOUS_SYSTEM_DEVELOPMENT.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NERVOUS_SYSTEM_DEVELOPMENT.html)

**REACTOME_DAP12_SIGNALING**: DAP12 signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DAP12_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DAP12_SIGNALING.html)

**WP_MICROGLIA_PATHOGEN_PHAGOCYTOSIS_PATHWAY**: Microglia pathogen phagocytosis pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_MICROGLIA_PATHOGEN_PHAGOCYTOSIS_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_MICROGLIA_PATHOGEN_PHAGOCYTOSIS_PATHWAY.html)

**REACTOME_IMMUNOREGULATORY_INTERACTIONS_BETWEEN_A_LYMPHOID_AND_A_NON_LYMPHOID_CELL**: Immunoregulatory interactions between a Lymphoid and a non-Lymphoid cell [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_IMMUNOREGULATORY_INTERACTIONS_BETWEEN_A_LYMPHOID_AND_A_NON_LYMPHOID_CELL.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_IMMUNOREGULATORY_INTERACTIONS_BETWEEN_A_LYMPHOID_AND_A_NON_LYMPHOID_CELL.html)
