
## **Pathways:**

**Asparagine N-linked glycosylation:** N-linked glycosylation is the most important form of post-translational modification for proteins synthesized and folded in the Endoplasmic Reticulum (Stanley et al. 2009). An early study in 1999 revealed that about 50% of the proteins in the Swiss-Prot database at the time were N-glycosylated (Apweiler et al. 1999). It is now established that the majority of the proteins in the secretory pathway require glycosylation in order to achieve proper folding.

The addition of an N-glycan to a protein can have several roles (Shental-Bechor & Levy 2009). First, glycans enhance the solubility and stability of the proteins in the ER, the golgi and on the outside of the cell membrane, where the composition of the medium is strongly hydrophilic and where proteins, that are mostly hydrophobic, have difficulty folding properly. Second, N-glycans are used as signal molecules during the folding and transport process of the protein: they have the role of labels to determine when a protein must interact with a chaperon, be transported to the golgi, or targeted for degradation in case of major folding defects. Third, and most importantly, N-glycans on completely folded proteins are involved in a wide range of processes: they help determine the specificity of membrane receptors in innate immunity or in cell-to-cell interactions, they can change the properties of hormones and secreted proteins, or of the proteins in the vesicular system inside the cell.

All N-linked glycans are derived from a common 14-sugar oligosaccharide synthesized in the ER, which is attached co-translationally to a protein while this is being translated inside the reticulum. The process of the synthesis of this glycan, known as Synthesis of the N-glycan precursor or LLO, constitutes one of the most conserved pathways in eukaryotes, and has been also observed in some eubacteria. The attachment usually happens on an asparagine residue within the consensus sequence asparagine-X-threonine by an complex called oligosaccharyl transferase (OST).

After being attached to an unfolded protein, the glycan is used as a label molecule in the folding process (also known as Calnexin/Calreticulin cycle) (Lederkremer 2009). The majority of the glycoproteins in the ER require at least one glycosylated residue in order to achieve proper folding, even if it has been shown that a smaller portion of the proteins in the ER can be folded without this modification.

Once the glycoprotein has achieved proper folding, it is transported via the cis-Golgi through all the Golgi compartments, where the glycan is further modified according to the properties of the glycoprotein. This process involves relatively few enzymes but due to its combinatorial nature, can lead to several millions of different possible modifications. The exact topography of this network of reactions has not been established yet, representing one of the major challenges after the sequencing of the human genome (Hossler et al. 2006).

Since N-glycosylation is involved in an great number of different processes, from cell-cell interaction to folding control, mutations in one of the genes involved in glycan assembly and/or modification can lead to severe development problems (often affecting the central nervous system). All the diseases in genes involved in glycosylation are collectively known as Congenital Disorders of Glycosylation (CDG) (Sparks et al. 2003), and classified as CDG type I for the genes in the LLO synthesis pathway, and CDG type II for the others [[https://reactome.org/PathwayBrowser/#/R-HSA-446203](https://reactome.org/PathwayBrowser/#/R-HSA-446203)].

**Late SARS-CoV-2 Infection Events:** The coronavirus virion consists of structural proteins, namely spike (S), envelope (E), membrane (M), nucleocapsid (N) and, for some betacoronaviruses, haemagglutinin-esterase. The positive-sense, single-stranded RNA genome (+ssRNA) is encapsidated by N, whereas M and E ensure its incorporation in the viral particle during the assembly process. S trimers protrude from the host-derived viral envelope and provide specificity for cellular entry receptors. SARS-CoV-2 particles bind to angiotensin-converting enzyme 2 (ACE2) cellular receptors and together with host factors (such as the cell surface serine protease TMPRSS2), promote viral uptake and fusion at the cellular or endosomal membrane. Following entry, the release and uncoating of the incoming genomic RNA subject it to the immediate translation of two large open reading frames, ORF1a and ORF1b. ORF1a and ORF1b encode 1516 non-structural proteins (nsp), of which 15 compose the viral replication and transcription complex (RTC) that includes, amongst others, RNA-processing and RNA-modifying enzymes and an RNA proofreading function necessary for maintaining the integrity of the >30kb coronavirus genome. ORFs that encode structural proteins and interspersed ORFs that encode accessory proteins are transcribed from the 3' one-third of the genome to form a nested set of subgenomic mRNAs (sg mRNAs). The resulting polyproteins pp1a and pp1ab are co-translationally and post-translationally processed into the individual non-structural proteins (nsps) that form the viral replication and transcription complex. Concordant with the expression of nsps, the biogenesis of viral replication organelles consisting of characteristic perinuclear double-membrane vesicles (DMVs), convoluted membranes (CMs) and small open double-membrane spherules (DMSs) create a protective microenvironment for viral genomic RNA replication and transcription of subgenomic mRNAs comprising the characteristic nested set of coronavirus mRNAs. Translated structural proteins translocate into endoplasmic reticulum (ER) membranes and transit through the ER-to-Golgi intermediate compartment (ERGIC), where interaction with N-encapsidated, newly produced genomic RNA results in budding into the lumen of secretory vesicular compartments. Finally, virions are secreted from the infected cell by exocytosis. A successful intracellular coronavirus life cycle invariably relies on critical molecular interactions with host proteins that are repurposed to support the requirements of the virus. This includes host factors required for virus entry (such as the entry receptor and host cell proteases), factors required for viral RNA synthesis and virus assembly (such as ER and Golgi components and associated vesicular trafficking pathways) and factors required for the translation of viral mRNAs (such as critical translational initiation factors) [[https://reactome.org/PathwayBrowser/#/R-HSA-9772573&PATH=R-HSA-1643685,R-HSA-5663205,R-HSA-9824446,R-HSA-9679506,R-HSA-9694516](https://reactome.org/PathwayBrowser/#/R-HSA-9772573&PATH=R-HSA-1643685,R-HSA-5663205,R-HSA-9824446,R-HSA-9679506,R-HSA-9694516)].

**Maturation of spike protein:** This COVID-19 pathway has been created by a combination of computational inference from SARS-CoV-1 data ([https://reactome.org/documentation/inferred-events](https://reactome.org/documentation/inferred-events)) and manual curation, as described in the summation for the overall SARS-CoV-2 infection pathway.

The viral Spike protein of SARS-CoV-1 is subject to N-glycosylation and palmitoylation. The chaperone calnexin exclusively helps with protein folding. The end product is a homotrimer (Nal et al, 2005). In SARS-CoV-2 the Spike glycosylation patterns were extensively characterized, and consist of both N-glycans and O-glycans attached to about twenty amino acids (reviewed by Petrovic et al, 2021; Gong et al, 2021; Shajahan et al, 2021). Although there is no reason for the host's glycosylation enzymes behaving differently than with other host or non-host proteins, direct involvement of host enzymes and chaperones with SARS-CoV-2 Spike glycosylation has not been shown. Indirect evidence from inhibition experiments (Reyes et al, 2021; Franco et al, 2022) is confounded by simultaneous inhibition of glycosylation of other proteins like the ACE2 receptor [[https://reactome.org/PathwayBrowser/#/R-HSA-9772573&SEL=R-HSA-9694548&PATH=R-HSA-1643685,R-HSA-5663205,R-HSA-9824446,R-HSA-9679506,R-HSA-9694516](https://reactome.org/PathwayBrowser/#/R-HSA-9772573&SEL=R-HSA-9694548&PATH=R-HSA-1643685,R-HSA-5663205,R-HSA-9824446,R-HSA-9679506,R-HSA-9694516)].

**Miscellaneous transport and binding events:** This section contains known transport and binding events that as of yet cannot be placed in existing pathways (Purves 2001, He et al. 2009, Rees et al. 2009) [[https://reactome.org/PathwayBrowser/#/R-HSA-5223345&PATH=R-HSA-382551](https://reactome.org/PathwayBrowser/#/R-HSA-5223345&PATH=R-HSA-382551)].

## GO terms:

**cognition** [The operation of the mind by which an organism becomes aware of objects of thought or perception; it includes the mental activities associated with thinking, learning, and memory. GO:0050890]

**magnesium ion transmembrane transport** [The directed movement of magnesium ion across a membrane. GO:1903830]

**magnesium ion transport** [The directed movement of magnesium (Mg) ions into, out of or within a cell, or between cells, by means of some agent such as a transporter or pore. GO:0015693]

**protein N-linked glycosylation via asparagine** [The glycosylation of protein via the N4 atom of peptidyl-asparagine forming N4-glycosyl-L-asparagine; the most common form is N-acetylglucosaminyl asparagine; N-acetylgalactosaminyl asparagine and N4 glucosyl asparagine also occur. This modification typically occurs in extracellular peptides with an N-X-(ST) motif. Partial modification has been observed to occur with cysteine, rather than serine or threonine, in the third position; secondary structure features are important, and proline in the second or fourth positions inhibits modification. GO:0018279]

## MSigDB Signatures:

**REACTOME_INFECTIOUS_DISEASE**: Infectious disease [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INFECTIOUS_DISEASE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INFECTIOUS_DISEASE.html)

**KEGG_MEDICUS_REFERENCE_N_GLYCAN_PRECURSOR_BIOSYNTHESIS_ALG6_TO_OST**: Pathway Definition from KEGG: G00007+Glc-P-Dol -- ALG6 >> ALG8 >> ALG10 >> (STT+OST) -> G00009 [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_N_GLYCAN_PRECURSOR_BIOSYNTHESIS_ALG6_TO_OST.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_N_GLYCAN_PRECURSOR_BIOSYNTHESIS_ALG6_TO_OST.html)

**REACTOME_VIRAL_INFECTION_PATHWAYS**: Viral Infection Pathways [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_VIRAL_INFECTION_PATHWAYS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_VIRAL_INFECTION_PATHWAYS.html)

**REACTOME_TRANSLATION_OF_SARS_COV_2_STRUCTURAL_PROTEINS**: Translation of Structural Proteins [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRANSLATION_OF_SARS_COV_2_STRUCTURAL_PROTEINS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRANSLATION_OF_SARS_COV_2_STRUCTURAL_PROTEINS.html)

**REACTOME_MATURATION_OF_SARS_COV_2_SPIKE_PROTEIN**: Maturation of spike protein [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_MATURATION_OF_SARS_COV_2_SPIKE_PROTEIN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_MATURATION_OF_SARS_COV_2_SPIKE_PROTEIN.html)

**REACTOME_TRANSPORT_OF_SMALL_MOLECULES**: Transport of small molecules [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRANSPORT_OF_SMALL_MOLECULES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRANSPORT_OF_SMALL_MOLECULES.html)

**REACTOME_SARS_COV_2_INFECTION**: SARS-CoV-2 Infection [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_2_INFECTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_2_INFECTION.html)

**REACTOME_POST_TRANSLATIONAL_PROTEIN_MODIFICATION**: Post-translational protein modification [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_POST_TRANSLATIONAL_PROTEIN_MODIFICATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_POST_TRANSLATIONAL_PROTEIN_MODIFICATION.html)

**REACTOME_MISCELLANEOUS_TRANSPORT_AND_BINDING_EVENTS**: Miscellaneous transport and binding events [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_MISCELLANEOUS_TRANSPORT_AND_BINDING_EVENTS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_MISCELLANEOUS_TRANSPORT_AND_BINDING_EVENTS.html)

**WP_N_GLYCAN_BIOSYNTHESIS**: N glycan biosynthesis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_N_GLYCAN_BIOSYNTHESIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_N_GLYCAN_BIOSYNTHESIS.html)

**REACTOME_ASPARAGINE_N_LINKED_GLYCOSYLATION**: Asparagine N-linked glycosylation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ASPARAGINE_N_LINKED_GLYCOSYLATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ASPARAGINE_N_LINKED_GLYCOSYLATION.html)

**REACTOME_SARS_COV_INFECTIONS**: SARS-CoV Infections [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_INFECTIONS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_INFECTIONS.html)

**SUNG_METASTASIS_STROMA_UP**: Genes up-regulated in metastatic vs non-metastatic stromal cells originated from either bone or prostate tissues. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/SUNG_METASTASIS_STROMA_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/SUNG_METASTASIS_STROMA_UP.html)

**FLECHNER_BIOPSY_KIDNEY_TRANSPLANT_OK_VS_DONOR_UP**: Genes up-regulated in kidney biopsies from patients with well functioning kidneys more than 1-year post transplant compared to the biopsies from normal living kidney donors. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FLECHNER_BIOPSY_KIDNEY_TRANSPLANT_OK_VS_DONOR_UP.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/FLECHNER_BIOPSY_KIDNEY_TRANSPLANT_OK_VS_DONOR_UP.html)

**KEGG_N_GLYCAN_BIOSYNTHESIS**: N-Glycan biosynthesis [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_N_GLYCAN_BIOSYNTHESIS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_N_GLYCAN_BIOSYNTHESIS.html)

**LOPEZ_MBD_TARGETS**: Genes up-regulated in HeLa cells (cervical cancer) after simultaneus knockdown of all three MBD (methyl-CpG binding domain) proteins MeCP2, MBD1 and MBD2 [GeneID=4204;4152;8932] by RNAi. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LOPEZ_MBD_TARGETS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LOPEZ_MBD_TARGETS.html)

**WP_GLYCOSYLATION_AND_RELATED_CONGENITAL_DEFECTS**: Glycosylation and related congenital defects [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_GLYCOSYLATION_AND_RELATED_CONGENITAL_DEFECTS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_GLYCOSYLATION_AND_RELATED_CONGENITAL_DEFECTS.html)

**LIU_SOX4_TARGETS_DN**: Genes down-regulated in LNCaP cells (prostate cancer) by overexpression of SOX4 [GeneID=6659] and up-regulated by its RNAi knockdown. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LIU_SOX4_TARGETS_DN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/LIU_SOX4_TARGETS_DN.html)
