
## **Pathways:**

**Late SARS-CoV-2 Infection Events:** The coronavirus virion consists of structural proteins, namely spike (S), envelope (E), membrane (M), nucleocapsid (N) and, for some betacoronaviruses, haemagglutinin-esterase. The positive-sense, single-stranded RNA genome (+ssRNA) is encapsidated by N, whereas M and E ensure its incorporation in the viral particle during the assembly process. S trimers protrude from the host-derived viral envelope and provide specificity for cellular entry receptors. SARS-CoV-2 particles bind to angiotensin-converting enzyme 2 (ACE2) cellular receptors and together with host factors (such as the cell surface serine protease TMPRSS2), promote viral uptake and fusion at the cellular or endosomal membrane. Following entry, the release and uncoating of the incoming genomic RNA subject it to the immediate translation of two large open reading frames, ORF1a and ORF1b. ORF1a and ORF1b encode 1516 non-structural proteins (nsp), of which 15 compose the viral replication and transcription complex (RTC) that includes, amongst others, RNA-processing and RNA-modifying enzymes and an RNA proofreading function necessary for maintaining the integrity of the >30kb coronavirus genome. ORFs that encode structural proteins and interspersed ORFs that encode accessory proteins are transcribed from the 3' one-third of the genome to form a nested set of subgenomic mRNAs (sg mRNAs). The resulting polyproteins pp1a and pp1ab are co-translationally and post-translationally processed into the individual non-structural proteins (nsps) that form the viral replication and transcription complex. Concordant with the expression of nsps, the biogenesis of viral replication organelles consisting of characteristic perinuclear double-membrane vesicles (DMVs), convoluted membranes (CMs) and small open double-membrane spherules (DMSs) create a protective microenvironment for viral genomic RNA replication and transcription of subgenomic mRNAs comprising the characteristic nested set of coronavirus mRNAs. Translated structural proteins translocate into endoplasmic reticulum (ER) membranes and transit through the ER-to-Golgi intermediate compartment (ERGIC), where interaction with N-encapsidated, newly produced genomic RNA results in budding into the lumen of secretory vesicular compartments. Finally, virions are secreted from the infected cell by exocytosis. A successful intracellular coronavirus life cycle invariably relies on critical molecular interactions with host proteins that are repurposed to support the requirements of the virus. This includes host factors required for virus entry (such as the entry receptor and host cell proteases), factors required for viral RNA synthesis and virus assembly (such as ER and Golgi components and associated vesicular trafficking pathways) and factors required for the translation of viral mRNAs (such as critical translational initiation factors) [[https://reactome.org/PathwayBrowser/#/R-HSA-9772573](https://reactome.org/PathwayBrowser/#/R-HSA-9772573)].

**Maturation of spike protein:** The viral Spike protein of SARS-CoV-1 is subject to N-glycosylation and palmitoylation. The chaperone calnexin exclusively helps with protein folding. The end product is a homotrimer (Nal et al, 2005). In SARS-CoV-2 the Spike glycosylation patterns were extensively characterized, and consist of both N-glycans and O-glycans attached to about twenty amino acids (reviewed by Petrovic et al, 2021; Gong et al, 2021; Shajahan et al, 2021). Although there is no reason for the host's glycosylation enzymes behaving differently than with other host or non-host proteins, direct involvement of host enzymes and chaperones with SARS-CoV-2 Spike glycosylation has not been shown. Indirect evidence from inhibition experiments (Reyes et al, 2021; Franco et al, 2022) is confounded by simultaneous inhibition of glycosylation of other proteins like the ACE2 receptor. [[https://reactome.org/PathwayBrowser/#/R-HSA-9694548](https://reactome.org/PathwayBrowser/#/R-HSA-9694548)].

**Surfactant metabolism:** The alveolar region of the lung creates an extensive epithelial surface that mediates the transfer of oxygen and carbon dioxide required for respiration after birth. Type I epithelial cells form the alveolar surface and mediate gaseous exchange. Type II epithelial cells secrete pulmonary surfactant, a lipoprotein complex that forms a thin interfacial film, lowering surface tension at the air-liquid interface in alveoli and maintaining the structural integrity of alveoli, preventing their collapse at low volumes (Agassandian & Mallampalli 2013). Surfactant production is increased prior to birth, in preparation for air breathing at birth (Hallman 2013). Pre-term infants, where type II epithelial cells are not fully differentiated yet, can produce insufficient surfactant and result in respiratory distress syndrome. Surfactant is composed primarily of phospholipids enriched in phosphatidylcholine (PC) and phosphatidylglycerol (PG) (Agassandian & Mallampalli 2013) and the pulmonary collectins, termed surfactant proteins A, B, C and D (SFTPA-D). They influence surfactant homeostasis, contributing to the physical structures of lipids in the alveoli and to the regulation of surfactant function and metabolism. They are directly secreted from alveolar type II cells into the airway to function as part of the surfactant. SFTPA and D are large, hydrophilic proteins while SFTPB and C are small, very hydrophobic proteins (Johansson et al. 1994). In addition to their surfactant functions, SFTPA and D play important roles in innate host defense by binding and clearing invading microbes from the lung (Kingma & Whitsett 2006). Nuclear regulation, transport, metabolism, reutilisation and degradation of surfactant are described here (Ikegami 2006, Boggaram 2009, Whitsett et al. 2010). Mutations in genes involved in these processes can result in respiratory distress syndrome, lung proteinosis, interstitial lung diseases and chronic lung diseases (Perez-Gil & Weaver 2010, Whitsett et al. 2010, Akella & Deshpande 2013, Jo 2014). [[https://reactome.org/PathwayBrowser/#/R-HSA-5683826](https://reactome.org/PathwayBrowser/#/R-HSA-5683826)].

**Translation of Structural Proteins:** Virus mRNA is translated according to the ribosomal scanning model. It is capped and polyadenylated, with regions of nontranslated sequences on both the 5' and 3' ends. Structural proteins are encoded after the polymerase/replicase genes by mRNAs 2 (Spike protein), 3, 4 (Envelope protein), 5 (Membrane protein), and 9. mRNA 3 and 9 are bicistronic, the proteins 3a and 9a (Nucleocapsid protein) having functions in virus assembly and structure. Translation happens in the ER with the exception of 9a which is translated by cytosolic free ribosomes (Fung and Liu, 2019). [[https://reactome.org/PathwayBrowser/#/R-HSA-9772573&SEL=R-HSA-9694635&PATH=R-HSA-1643685,R-HSA-5663205,R-HSA-9824446,R-HSA-9679506,R-HSA-9694516](https://reactome.org/PathwayBrowser/#/R-HSA-9772573&SEL=R-HSA-9694635&PATH=R-HSA-1643685,R-HSA-5663205,R-HSA-9824446,R-HSA-9679506,R-HSA-9694516)].

## GO terms:

**positive regulation of AMPA glutamate receptor clustering** [Any process that activates or increases the frequency, rate or extent of AMPA glutamate receptor clustering. GO:1904719]

**positive regulation of endosome to plasma membrane protein transport** [Any process that activates or increases the frequency, rate or extent of endosome to plasma membrane protein transport. GO:1905751]

**positive regulation of long-term synaptic potentiation** [Any process that activates or increases the frequency, rate or extent of long-term synaptic potentiation. GO:1900273]

**protein localization to membrane raft** [A process in which a protein is transported to, or maintained in, a location within a membrane raft. GO:1903044]

**protein localization to plasma membrane** [A process in which a protein is transported to, or maintained in, a specific location in the plasma membrane. GO:0072659]

**protein localization to postsynaptic membrane** [A process in which a protein is transported to, or maintained in, a location within a postsynaptic membrane. GO:1903539]

**protein targeting to membrane** [The process of directing proteins towards a membrane, usually using signals contained within the protein. GO:0006612]

**regulation of cell-cell adhesion** [Any process that modulates the frequency, rate or extent of attachment of a cell to another cell. GO:0022407]

**regulation of neuronal synaptic plasticity** [A process that modulates neuronal synaptic plasticity, the ability of neuronal synapses to change as circumstances require. They may alter function, such as increasing or decreasing their sensitivity, or they may increase or decrease in actual numbers.|Note that the syntax of the definition of this term is different from the usual regulation syntax because it describes regulation of a trait rather than regulation of a process. GO:0048168]

**regulation of protein catabolic process** [Any process that modulates the frequency, rate or extent of the chemical reactions and pathways resulting in the breakdown of a protein by the destruction of the native, active configuration, with or without the hydrolysis of peptide bonds. GO:0042176]

**regulation of protein localization to plasma membrane** [Any process that modulates the frequency, rate or extent of protein localization to plasma membrane. GO:1903076]

**synapse assembly** [The aggregation, arrangement and bonding together of a set of components to form a synapse. This process ends when the synapse is mature (functional). GO:0007416]

## MSigDB Signatures:

**REACTOME_INFECTIOUS_DISEASE**: Infectious disease [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INFECTIOUS_DISEASE.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INFECTIOUS_DISEASE.html)

**REACTOME_VIRAL_INFECTION_PATHWAYS**: Viral Infection Pathways [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_VIRAL_INFECTION_PATHWAYS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_VIRAL_INFECTION_PATHWAYS.html)

**REACTOME_TRANSLATION_OF_SARS_COV_2_STRUCTURAL_PROTEINS**: Translation of Structural Proteins [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRANSLATION_OF_SARS_COV_2_STRUCTURAL_PROTEINS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_TRANSLATION_OF_SARS_COV_2_STRUCTURAL_PROTEINS.html)

**REACTOME_MATURATION_OF_SARS_COV_2_SPIKE_PROTEIN**: Maturation of spike protein [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_MATURATION_OF_SARS_COV_2_SPIKE_PROTEIN.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_MATURATION_OF_SARS_COV_2_SPIKE_PROTEIN.html)

**REACTOME_SARS_COV_2_INFECTION**: SARS-CoV-2 Infection [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_2_INFECTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_2_INFECTION.html)

**REACTOME_SARS_COV_INFECTIONS**: SARS-CoV Infections [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_INFECTIONS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SARS_COV_INFECTIONS.html)

**REACTOME_SURFACTANT_METABOLISM**: Surfactant metabolism [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SURFACTANT_METABOLISM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SURFACTANT_METABOLISM.html)
