
## **Pathways:**

-   **Neutrophil degranulation**: Neutrophils are the most abundant leukocytes (white blood cells), indispensable in defending the body against invading microorganisms. In response to infection, neutrophils leave the circulation and migrate towards the inflammatory focus. They contain several subsets of granules that are mobilized to fuse with the cell membrane or phagosomal membrane, resulting in the exocytosis or exposure of membrane proteins. Traditionally, neutrophil granule constituents are described as antimicrobial or proteolytic, but granules also introduce membrane proteins to the cell surface, changing how the neutrophil responds to its environment (Borregaard et al. 2007). Primed neutrophils actively secrete cytokines and other inflammatory mediators and can present antigens via MHC II, stimulating T-cells (Wright et al. 2010). Granules form during neutrophil differentiation. Granule subtypes can be distinguished by their content but overlap in structure and composition. The differences are believed to be a consequence of changing protein expression and differential timing of granule formation during the terminal processes of neutrophil differentiation, rather than sorting (Le Cabec et al. 1996). The classical granule subsets are Azurophil or primary granules (AG), secondary granules (SG) and gelatinase granules (GG). Neutrophils also contain exocytosable storage cell organelles, storage vesicles (SV), formed by endocytosis they contain many cell-surface markers and extracellular, plasma proteins (Borregaard et al. 1992). Ficolin-1-rich granules (FG) are like GGs highly exocytosable but gelatinase-poor (Rorvig et al. 2009) [[https://reactome.org/PathwayBrowser/#/R-HSA-6798695](https://reactome.org/PathwayBrowser/#/R-HSA-6798695)].
-   **MHC class II antigen presentation**: Antigen presenting cells (APCs) such as B cells, dendritic cells (DCs) and monocytes/macrophages express major histocompatibility complex class II molecules (MHC II) at their surface and present exogenous antigenic peptides to CD4+ T helper cells. CD4+ T cells play a central role in immune protection. On their activation they stimulate differentiation of B cells into antibody-producing B-cell blasts and initiate adaptive immune responses. MHC class II molecules are transmembrane glycoprotein heterodimers of alpha and beta subunits. Newly synthesized MHC II molecules present in the endoplasmic reticulum bind to a chaperone protein called invariant (Ii) chain. The binding of Ii prevents the premature binding of self antigens to the nascent MHC molecules in the ER and also guides MHC molecules to endocytic compartments. In the acidic endosomal environment, Ii is degraded in a stepwise manner, ultimately to free the class II peptide-binding groove for loading of antigenic peptides. Exogenous antigens are internalized by the APC by receptor mediated endocytosis, phagocytosis or pinocytosis into endocytic compartments of MHC class II positive cells, where engulfed antigens are degraded in a low pH environment by multiple acidic proteases, generating MHC class II epitopes. Antigenic peptides are then loaded into the class II ligand-binding groove. The resulting class II peptide complexes then move to the cell surface, where they are scanned by CD4+ T cells for specific recognition (Berger & Roche 2009, Zhou & Blum 2004, Watts 2004, Landsverk et al. 2009) [[https://reactome.org/PathwayBrowser/#/R-HSA-2132295](https://reactome.org/PathwayBrowser/#/R-HSA-2132295)].
-   **Metabolism of Angiotensinogen to Angiotensins**: Angiotensinogen, a prohormone, is synthesized and secreted mainly by the liver but also from other tissues (reviewed in Fyhrquist and Saijonmaa 2008, Cat and Touyz 2011). Renin, an aspartyl protease specific for angiotensinogen, is secreted into the bloodstream by juxtaglomerular cells of the kidney in response to a drop in blood pressure. Renin cleaves angiotensinogen to yield a decapaptide, angiotensin I (angiotensin-1, angiotensin-(1-10)). Circulating renin can also bind the membrane-localized (pro)renin receptor (ATP6AP2) which increases its catalytic activity. After cleavage of angiotensinogen to angiotensin I by renin, two C-terminal amino acid residues of angiotensin I are removed by angiotensin-converting enzyme (ACE), located on the surface of endothelial cells, to yield angiotensin II (angiotensin-2, angiotensin-(1-8)), the active peptide that causes vasoconstriction, resorption of sodium and chloride, excretion of potassium, water retention, and aldosterone secretion. More recently other, more tissue-localized pathways leading to angiotensin II and alternative derivatives of angiotensinogen have been identified (reviewed in Kramkowski et al. 2006, Kumar et al. 2007, Fyhrquist and Saijonmaa 2008, Becari et al. 2011). Chymase, cathepsin G, and cathepsin X (cathepsin Z) can each cleave angiotensin I to yield angiotensin II. Angiotensin-converting enzyme 2 (ACE2) cleaves 1 amino acid residue from angiotensin I (angiotensin-(1-10)) to yield angiotensin-(1-9), which can be cleaved by ACE to yield angiotensin-(1-7). ACE2 can also cleave angiotensin II to yield angiotensin-(1-7). Neprilysin can cleave either angiotensin-(1-9) or angiotensin I to yield angiotensin-(1-7). Angiotensin-(1-7) binds the MAS receptor (MAS1, MAS proto-oncogene) and, interestingly, produces effects opposite to those produced by angiotensin II. Aminopeptidase A (APA, ENPEP) cleaves angiotensin II to yield angiotensin III (angiotensin-(2-8)), which is then cleaved by aminopeptidase N (APN, ANPEP) yielding angiotensin IV (angiotensin-(3-8)). Angiotensin IV binds the AT4 receptor (AT4R, IRAP, LNPEP, oxytocinase). Inhibitors of renin (e.g. aliskiren) and ACE (e.g. lisinopril, ramipril) are currently used to treat hypertension (reviewed in Gerc et al. 2009, Verdecchia et al. 2010, Alreja and Joseph 2011) [[https://reactome.org/PathwayBrowser/#/R-HSA-2022377](https://reactome.org/PathwayBrowser/#/R-HSA-2022377)].
-   **Collagen degradation**: Collagen fibril diameter and spatial organisation are dependent on the species, tissue type and stage of development (Parry 1988). The lengths of collagen fibrils in mature tissues are largely unknown but in tendon can be measured in millimetres (Craig et al. 1989). Collagen fibrils isolated from adult bovine corneal stroma had ~350 collagen molecules in transverse section, tapering down to three molecules at the growing tip (Holmes & Kadler 2005). The classical view of collagenases is that they actively unwind the triple helical chain, a process termed molecular tectonics (Overall 2002, Bode & Maskos 2003), before preferentially cleaving the alpha2 chain followed by the remaining chains (Chung et al. 2004). More recently it has been suggested that collagen fibrils exist in an equilibrium between protected and vulnerable states (Stultz 2002, Nerenberg & Stultz 2008). The prototypical triple-helical structure of collagen does not fit into the active site of collagenase MMPs. In addition the scissile bonds are not solvent-exposed and are therefore inaccessible to the collagenase active site (Chung et al. 2004, Stultz 2002). It was realized that collagen must locally unfold into non-triple helical regions to allow collagenolysis. Observations using circular dichroism and differential scanning calorimetry confirm that there is considerable heterogeneity along collagen fibres (Makareeva et al. 2008) allowing access for MMPs at physiological temperatures (Salsas-Escat et al. 2010). Collagen fibrils with cut chains are unstable and accessible to proteinases that cannot cleave intact collagen strands (Woessner & Nagase 2000, Somerville et al. 2003). Continued degradation leads to the formation of gelatin (Lovejoy et al. 1999). Degradation of collagen types other than I-III is less well characterized but believed to occur in a similar manner. Metalloproteinases (MMPs) play a major part in the degradation of several extracellular macromolecules including collagens. MMP1 (Welgus et al. 1981), MMP8 (Hasty et al. 1987), and MMP13 (Knauper et al. 1996), sometimes referred to as collagenases I, II and III respectively, are able to initiate the intrahelical cleavage of the major fibril forming collagens I, II and III at neutral pH, and thus thought to define the rate-limiting step in normal tissue remodeling events. All can cleave additional substrates including other collagen subtypes. Collagenases cut collagen alpha chains at a single conserved Gly-Ile/Leu site approximately 3/4 of the molecule's length from the N-terminus (Fields 1991, Chung et al. 2004). The cleavage site is characterised by the motif G(I/L)(A/L); the G-I/L bond is cleaved. In collagen type I this corresponds to G953-I954 in the Uniprot canonical alpha chain sequences (often given as G775-I776 in literature). It is not clear why only this bond is cleaved, as the motif occurs at several other places in the chain. MMP14, a membrane-associated MMP also known as Membrane-type matrix metalloproteinase 1 (MT-MMP1), is able to cleave collagen types I, II and III (Ohuchi et al. 1997) [[https://reactome.org/PathwayBrowser/#/R-HSA-1442490](https://reactome.org/PathwayBrowser/#/R-HSA-1442490)].
-   **Estrogen-dependent gene expression**: Estrogens mediate their transcriptional effects through interaction with the estrogen receptors, ESR1 (also known as ER alpha) and ESR2 (ER beta). ESR1 and ESR2 share overlapping but distinct functions, with ESR1 playing the primary role in transcriptional activation in most cell types (Hah and Krauss, 2014; Haldosen et al, 2014. The receptors function as ligand-dependent dimers and can activate target genes either through direct binding to an estrogen responsive element (ERE) in the target gene promoter, or indirectly through interaction with another DNA-binding protein such as RUNX1, SP1, AP1 or NF-kappa beta (reviewed in Bai and Gust, 2009; Hah and Krause, 2014). Binding of estrogen receptors to the DNA promotes the assembly of higher order transcriptional complexes containing methyltransferases, histone acetyltransferases and other transcriptional activators, which promote transcription by establishing active chromatin marks and by recruiting general transcription factors and RNA polymerase II. ESR1- and estrogen-dependent recruitment of up to hundreds of coregulators has been demonstrated by varied co-immunoprecipitation and proteomic approaches (Kittler et al, 2013; Mohammed et al, 2013; Foulds et al, 2013; Mohammed et al, 2015; Liu et al, 2014; reviewed in Magnani and Lupien, 2014; Arnal, 2017). In some circumstances, ligand-bound receptors can also promote the assembly of a repression complex at a target gene, and in some cases, heterodimers of ESR1 and ESR2 serve as repressors of ESR1-mediated target gene activation (reviewed in Hah and Kraus, 2014; Arnal et al, 2017). Phosphorylation of the estrogen receptor also modulates its activity, and provides cross-talk between nuclear estrogen-dependent signaling and non-genomic estrogen signaling from the plasma membrane (reviewed in Anbalagan and Rowan, 2015; Halodsen et al, 2014; Schwartz et al, 2016). A number of recent genome wide studies highlight the breadth of the transcriptional response to estrogen. The number of predicted estrogen-dependent target genes ranges from a couple of hundred (based on microarray studies) to upwards of 10000, based on ChIP-chip or ChIP-seq (Cheung and Kraus, 2010; Kinnis and Kraus, 2008; Lin et al, 2004; Welboren et al, 2009; Ikeda et al, 2015; Lin et al, 2007; Carroll et al, 2006). Many of these predicted sites may not represent transcriptionally productive binding events, however. A study examining ESR1 binding by ChIP-seq in 20 primary breast cancers identified a core of 484 ESR-binding events that were conserved in at least 75% of ER+ tumors, which may represent a more realistic estimate (Ross-Innes et al, 2012). These studies also highlight the long-range effect of estrogen receptor-binding, with distal enhancer or promoter elements regulating the expression of many target genes, often through looping or other higher order chromatin structures (Kittler et al, 2013; reviewed in Dietz and Carroll, 2008; Liu and Cheung, 2014; Magnani and Lupien, 2014). Transcription from a number of estrogen-responsive target genes also appears to be primed by the binding of pioneering transcription factors such as FOXA1, GATA3, PBX1 among others. These factors bind to heterochromatin by virtue of their winged helix domains and promote chromatin opening, allowing subsequent recruitment of other transcription factors (reviewed in Zaret and Carroll, 2011; Fiorito et al, 2013; Arnal et al, 2017; Magnani et al, 2011) [[https://reactome.org/PathwayBrowser/#/R-HSA-9018519](https://reactome.org/PathwayBrowser/#/R-HSA-9018519)].
-   **Insulin receptor recycling**: Triggered by acidification of the endosome, insulin dissociates from the receptor and is degraded. The receptor is dephosphorylated and re-integrated into the plasma membrane, ready to be activated again by the binding of insulin molecules [[https://reactome.org/PathwayBrowser/#/R-HSA-77387](https://reactome.org/PathwayBrowser/#/R-HSA-77387)].

## GO terms:

**autophagosome assembly** [The formation of a double membrane-bounded structure, the autophagosome, that occurs when a specialized membrane sac, called the isolation membrane, starts to enclose a portion of the cytoplasm. GO:0000045]

**epithelial tube branching involved in lung morphogenesis** [The process in which a highly ordered sequence of patterning events generates the branched epithelial tubes of the lung, consisting of reiterated combinations of bud outgrowth, elongation, and dichotomous subdivision of terminal units. GO:0060441]

**insulin catabolic process** [The chemical reactions and pathways resulting in the breakdown of insulin. GO:1901143]

**insulin receptor recycling** [The process that results in the return of an insulin receptor to an active state at the plasma membrane. An active state is when the receptor is ready to receive an insulin signal. Internalized insulin receptors can be recycled to the plasma membrane or sorted to lysosomes for protein degradation. GO:0038020]

**lipoprotein catabolic process** [The chemical reactions and pathways resulting in the breakdown of any conjugated, water-soluble protein in which the covalently attached nonprotein group consists of a lipid or lipids. GO:0042159]

**positive regulation of apoptotic process** [Any process that activates or increases the frequency, rate or extent of cell death by apoptotic process. This term should only be used when it is not possible to determine which phase or subtype of the apoptotic process is positively regulated by a gene product. Whenever detailed information is available, the more granular children terms should be used. GO:0043065]

**protein catabolic process** [The chemical reactions and pathways resulting in the breakdown of a protein by the destruction of the native, active configuration, with or without the hydrolysis of peptide bonds. This term refers to the breakdown of mature proteins. For cleavage events involved in generating a mature protein from a precursor, consider instead the term 'protein maturation ; GO:0051604' and its children. GO:0030163]

**proteolysis** [The hydrolysis of proteins into smaller polypeptides and/or amino acids by cleavage of their peptide bonds. This term was intentionally placed under 'protein metabolic process ; GO:0019538' rather than 'protein catabolic process ; GO:0030163' to cover all processes centered on breaking peptide bonds, including those involved in protein processing. GO:0006508]

**regulation of establishment of protein localization** [Any process that modulates the frequency, rate or extent of the directed movement of a protein to a specific location. GO:0070201]

**response to nutrient levels** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus reflecting the presence, absence, or concentration of nutrients. GO:0031667]

## MSigDB Signatures:

**REACTOME_NEUTROPHIL_DEGRANULATION**: Neutrophil degranulation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NEUTROPHIL_DEGRANULATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_NEUTROPHIL_DEGRANULATION.html)

**REACTOME_INNATE_IMMUNE_SYSTEM**: Innate Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INNATE_IMMUNE_SYSTEM.html)

**HEBERT_MATRISOME_TNBC_BONE_BRAIN_LIVER_LUNG_METASTASTASES**: Matrisome proteins found in significantly higher abundance in TNBC brain, bone, liver and lung metastastases compared to normal samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HEBERT_MATRISOME_TNBC_BONE_BRAIN_LIVER_LUNG_METASTASTASES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HEBERT_MATRISOME_TNBC_BONE_BRAIN_LIVER_LUNG_METASTASTASES.html)

**REACTOME_ADAPTIVE_IMMUNE_SYSTEM**: Adaptive Immune System [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ADAPTIVE_IMMUNE_SYSTEM.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ADAPTIVE_IMMUNE_SYSTEM.html)

**KEGG_LYSOSOME**: Lysosome [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_LYSOSOME.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_LYSOSOME.html)

**REACTOME_COLLAGEN_DEGRADATION**: Collagen degradation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_COLLAGEN_DEGRADATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_COLLAGEN_DEGRADATION.html)

**HEBERT_MATRISOME_TNBC_BONE_BRAIN_LUNG_LIVER_METASTASTASES_TUMOR_CELL_DERIVED**: Tumor cell-derived matrisome proteins found in significantly higher abundance in TNBC brain, bone, liver and lung metastastases compared to normal samples. [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HEBERT_MATRISOME_TNBC_BONE_BRAIN_LUNG_LIVER_METASTASTASES_TUMOR_CELL_DERIVED.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/HEBERT_MATRISOME_TNBC_BONE_BRAIN_LUNG_LIVER_METASTASTASES_TUMOR_CELL_DERIVED.html)

**REACTOME_EXTRACELLULAR_MATRIX_ORGANIZATION**: Extracellular matrix organization [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_EXTRACELLULAR_MATRIX_ORGANIZATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_EXTRACELLULAR_MATRIX_ORGANIZATION.html)

**REACTOME_DEGRADATION_OF_THE_EXTRACELLULAR_MATRIX**: Degradation of the extracellular matrix [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEGRADATION_OF_THE_EXTRACELLULAR_MATRIX.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_DEGRADATION_OF_THE_EXTRACELLULAR_MATRIX.html)

**REACTOME_SIGNALING_BY_RECEPTOR_TYROSINE_KINASES**: Signaling by Receptor Tyrosine Kinases [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_RECEPTOR_TYROSINE_KINASES.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_RECEPTOR_TYROSINE_KINASES.html)

**REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS**: Signaling by Nuclear Receptors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS.html)

**REACTOME_SIGNALING_BY_INSULIN_RECEPTOR**: Signaling by Insulin receptor [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_INSULIN_RECEPTOR.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_INSULIN_RECEPTOR.html)

**REACTOME_ESR_MEDIATED_SIGNALING**: ESR-mediated signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ESR_MEDIATED_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ESR_MEDIATED_SIGNALING.html)

**NABA_MATRISOME_ASSOCIATED**: Ensemble of genes encoding ECM-associated proteins including ECM-affiliated proteins, ECM regulators and secreted factors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_ASSOCIATED.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME_ASSOCIATED.html)

**REACTOME_INSULIN_RECEPTOR_RECYCLING**: Insulin receptor recycling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INSULIN_RECEPTOR_RECYCLING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_INSULIN_RECEPTOR_RECYCLING.html)

**KEGG_MEDICUS_REFERENCE_NUCLEAR_INITIATED_ESTROGEN_SIGNALING_PATHWAY**: Pathway Definition from KEGG: E2 -> ((ESR1/2)+(NCOA1/2/3)) => (BCL2,EBAG9,KRT19,CTSD,TFF1,PGR) [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_NUCLEAR_INITIATED_ESTROGEN_SIGNALING_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/KEGG_MEDICUS_REFERENCE_NUCLEAR_INITIATED_ESTROGEN_SIGNALING_PATHWAY.html)

**NABA_MATRISOME**: Ensemble of genes encoding extracellular matrix and extracellular matrix-associated proteins [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/NABA_MATRISOME.html)

**REACTOME_MHC_CLASS_II_ANTIGEN_PRESENTATION**: MHC class II antigen presentation [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_MHC_CLASS_II_ANTIGEN_PRESENTATION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_MHC_CLASS_II_ANTIGEN_PRESENTATION.html)
