
## **Pathways:**

**Cellular responses to stress:** Cells are subject to external molecular and physical stresses such as foreign molecules that perturb metabolic or signaling processes, and changes in temperature or pH. Cells are also subject to internal molecular stresses such as production of reactive metabolic byproducts. The ability of cells and tissues to modulate molecular processes in response to such stresses is essential to the maintenance of tissue homeostasis (Kultz 2005). Specific stress-related processes annotated here are cellular response to hypoxia, cellular response to heat stress, cellular senescence, HSP90 chaperone cycle for steroid hormone receptors (SHR) in the presence of ligand, response of EIF2AK1 (HRI) to heme deficiency, heme signaling, cellular response to chemical stress, cellular response to starvation, and unfolded protein response. [[https://reactome.org/PathwayBrowser/#/R-HSA-2262752](https://reactome.org/PathwayBrowser/#/R-HSA-2262752)].

**ESR-mediated signaling:** Estrogens are a class of hormones that play a role in physiological processes such as development, reproduction, metabolism of liver, fat and bone, and neuronal and cardiovascular function (reviewed in Arnal et al, 2017; Haldosen et al, 2014). Estrogens bind estrogen receptors, members of the nuclear receptor superfamily. Ligand-bound estrogen receptors act as nuclear transcription factors to regulate expression of genes that control cellular proliferation and differentiation, among other processes, but also play a non-genomic role in rapid signaling from the plasma membrane (reviewed in Hah et al, 2014; Schwartz et al, 2016) [[https://reactome.org/PathwayBrowser/#/R-HSA-8939211](https://reactome.org/PathwayBrowser/#/R-HSA-8939211)].

**HSP90 chaperone cycle for steroid hormone receptors (SHR) in the presence of ligand**: Steroid hormone receptors (SHR) are transcription factors that become activated upon sensing steroid hormones such as glucocorticoids, mineralocorticoids, progesterone, androgens, or estrogen (Escriva et al 2000; Griekspoor A et al. 2007; Eick GN & Thornton JW. 2011). Depending on SHR type and the presence of ligand, they show different subcellular localizations. Whereas both unliganded and liganded estrogen receptors (ERalpha and ERbeta) are predominantly nuclear, unliganded glucocorticoid (GR) and androgen receptors (AR) are mostly located in the cytoplasm and completely translocate to the nucleus only after binding hormone (Htun H et al. 1999; Stenoien D et al. 2000; Tyagi RK et al. 2000; Cadepond F et al. 1992; Jewell CM et al. 1995; Kumar S et al. 2006). The unliganded mineralocorticoid receptor (MR) is partially cytoplasmic but can be found in nucleus in the ligand-bound or ligand-free form (Nishi M & Kawata M 2007). The progesterone receptor (PR) exists in two forms (PRA and PRB) with different ratios of nuclear versus cytoplasmic localization of the unliganded receptor. In most cell contexts, the PRA isoform is a repressor of the shorter PRB isoform, and without hormone induction it is mostly located in the nucleus, whereas PRB distributes both in the nucleus and in the cytoplasm (Lim CS et al. 1999; Griekspoor A et al. 2007). In the absence of ligand, members of the steroid receptor family remain sequestered in the cytoplasm and/or nucleus in the complex with proteins of HSP70/HSP90 chaperone machinery (Pratt WB & Dittmar KD1998). The highly dynamic ATP-dependent interactions of SHRs with HSP90 complexes regulate SHR cellular location, protein stability, competency to bind steroid hormones and transcriptional activity (Echeverria PC & Picard D 2010). Understanding the mechanism of ATPase activity of HSP90 is mostly based on structural and functional studies of the Saccharomyces cerevisiae Hsp90 complexes (Meyer P et al. 2003, 2004; Ali MM et al. 2006; Prodromou C et al. 2000; Prodromou C 2012). The ATPase cycle of human HSP90 is less well understood, however several studies suggest that the underlying enzymatic mechanisms and a set of conformational changes that accompany the ATPase cycle are highly similar in both species (Richter K et al. 2008; Vaughan CK et al. 2009). Nascent SHR proteins are chaperoned by HSP70 and HSP40 to HSP90 cycle via STIP1 (HOP) (and its TPR domains) (Hernndez MP et al. 2002a,b; EcheverriaPC & Picard D 2010; Li J et al. 2011). The ATP-bound form of HSP90 leads to the displacement of STIP1 by immunophilins FKBP5 or FKBP4 resulting in conformational changes that allow efficient hormone binding (Li J et al. 2011). PTGES3 (p23) binds to HSP90 complex finally stabilizing it in the conformation with a high hormone binding affinity. After hydrolysis of ATP the hormone bound SHR is released from HSP90 complex. The cytosolic hormone-bound SHR can be transported to the nucleus by several import pathways such as the dynein-based nuclear transport along microtubules involving the transport of the entire HSP90 complex or nuclear localization signals (NLS)-mediated nuclear targeting by importins (Tyagi RK et al. 2000; Cadepond F et al. 1992; Jewell CM et al. 1995; Kumar S et al. 2006). It is worth noting that GR-importin interactions can be ligand-dependent or independent (Freedman & Yamamoto 2004; Picard & Yamamoto 1987). In the nucleus ligand-activated SHR dimerizes, binds specific sequences in the DNA, called Hormone Responsive Elements (HRE), and recruits a number of coregulators that facilitate gene transcription. Nuclear localization is essential for SHRs to transactivate their target genes, but the same receptors also possess non-genomic functions in the cytoplasm [ [https://reactome.org/PathwayBrowser/#/R-HSA-3371497](https://reactome.org/PathwayBrowser/#/R-HSA-3371497)].

**MECP2 regulates neuronal receptors and channels:** Receptors directly transcriptionally regulated by MECP2 include glutamate receptor GRIA2 (Qiu et al. 2012), NMDA receptor subunits GRIN2A (Durand et al. 2012) and GRIN2B (Lee et al. 2008), opioid receptors OPRK1 (Chahrour et al. 2008) and OPRM1 (Hwang et al. 2009, Hwang et al. 2010, Samaco et al. 2012), GPRIN1 (Chahrour et al. 2008), MET (Plummer et al. 2013), and NOTCH1 (Li et al. 2014). Channels/transporters regulated by MECP2 include TRPC3 (Li et al. 2012) and SLC2A3 (Chen et al. 2013). MECP2 also regulates transcription of FKBP5, involved in trafficking of glucocorticoid receptors (Nuber et al. 2005, Urdinguio et al. 2008) and is implicated in regulation of expression of SEMA3F (semaphorin 3F) in mouse olfactory neurons (Degano et al. 2009). In zebrafish, Mecp2 is implicated in sensory axon guidance by direct stimulation of transcription of Sema5b and Robo2 (Leong et al. 2015). MECP2 may indirectly regulate signaling by neuronal receptor tyrosine kinases by regulating transcription of protein tyrosine phosphatases, PTPN1 (Krishnan et al. 2015) and PTPN4 (Williamson et al. 2015).[ [https://reactome.org/PathwayBrowser/#/R-HSA-9022699](https://reactome.org/PathwayBrowser/#/R-HSA-9022699)].

**RNA Polymerase II Transcription:** RNA polymerase II (Pol II) is the central enzyme that catalyses DNA- directed mRNA synthesis during the transcription of protein-coding genes. Pol II consists of a 10-subunit catalytic core, which alone can elongate the RNA transcript, and a complex of two subunits, Rpb4/7, that is required for transcription initiation.  
The transcription cycle is divided in three major phases: initiation, elongation, and termination. Transcription initiation includes promoter DNA binding, DNA melting, and initial synthesis of short RNA transcripts. The transition from initiation to elongation is referred to as promoter escape and leads to a stable elongation complex that is characterized by an open DNA region or transcription bubble. The bubble contains the DNA-RNA hybrid, a heteroduplex of eight to nine base pairs. The growing 3-end of the RNA is engaged with the polymerase complex active site. Ultimately transcription terminates and Pol II dissociates from the template. [[https://reactome.org/PathwayBrowser/#/R-HSA-73857](https://reactome.org/PathwayBrowser/#/R-HSA-73857)].

## GO terms:

**biological_process** [A biological process is the execution of a genetically-encoded biological module or program. It consists of all the steps required to achieve the specific biological objective of the module. A biological process is accomplished by a particular set of molecular functions carried out by specific gene products (or macromolecular complexes), often in a highly regulated manner and in a particular temporal sequence.|Note that, in addition to forming the root of the biological process ontology, this term is recommended for use for the annotation of gene products whose biological process is unknown. When this term is used for annotation, it indicates that no information was available about the biological process of the gene product annotated as of the date the annotation was made; the evidence code 'no data' (ND), is used to indicate this. GO:0008150]

**chaperone-mediated protein folding** [The process of inhibiting aggregation and assisting in the covalent and noncovalent assembly of single chain polypeptides or multisubunit complexes into the correct tertiary structure that is dependent on interaction with a chaperone. GO:0061077]

**response to bacterium** [Any process that results in a change in state or activity of a cell or an organism (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a stimulus from a bacterium. GO:0009617]

## MSigDB Signatures:

**WP_NUCLEAR_RECEPTORS_META_PATHWAY**: Nuclear receptors meta pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NUCLEAR_RECEPTORS_META_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_NUCLEAR_RECEPTORS_META_PATHWAY.html)

**REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS**: Signaling by Nuclear Receptors [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_SIGNALING_BY_NUCLEAR_RECEPTORS.html)

**REACTOME_CELLULAR_RESPONSES_TO_STIMULI**: Cellular responses to stimuli [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELLULAR_RESPONSES_TO_STIMULI.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_CELLULAR_RESPONSES_TO_STIMULI.html)

**REACTOME_ESR_MEDIATED_SIGNALING**: ESR-mediated signaling [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ESR_MEDIATED_SIGNALING.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_ESR_MEDIATED_SIGNALING.html)

**REACTOME_RNA_POLYMERASE_II_TRANSCRIPTION**: RNA Polymerase II Transcription [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RNA_POLYMERASE_II_TRANSCRIPTION.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/REACTOME_RNA_POLYMERASE_II_TRANSCRIPTION.html)

**WP_FARNESOID_X_RECEPTOR_PATHWAY**: Farnesoid X receptor pathway [[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FARNESOID_X_RECEPTOR_PATHWAY.html]](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/WP_FARNESOID_X_RECEPTOR_PATHWAY.html)
