
## **Pathways:**

-   **Autophagy**: Autophagy is an intracellular degradation process that is triggered by cellular stresses. There are three primary types of autophagy - macroautophagy, chaperone-mediated autophagy (CMA) and late endosomal microautophagy. Despite being morphologically distinct, all three processes culminate in the delivery of cargo to the lysosome for degradation and recycling (Parzych KR et al, 2014). In macroautophagy a double membrane compartment sequesters the cargo and delivers it to the lysosome. Chaperones are used to deliver specific cargo proteins to the lysosome in CMA. In microautophagy invaginations of the endosomal membrane are used to capture cargo from the cytosol. Autophagy can target a wide range of entities ranging from bulk proteins and lipids to cell organelles and pathogens giving rise to several subclasses such as mitophagy, lipophagy, xenophagy, etc. (Shibutani ST 2014 et al) [[https://reactome.org/PathwayBrowser/#/R-HSA-9612973&FLG=R-HSA-109581&FLGINT](https://reactome.org/PathwayBrowser/#/R-HSA-9612973&FLG=R-HSA-109581&FLGINT)].
-   **Apoptosis**: Apoptosis is a distinct form of cell death that is functionally and morphologically different from necrosis. Nuclear chromatin condensation, cytoplasmic shrinking, dilated endoplasmic reticulum, and membrane blebbing characterize apoptosis in general. Mitochondria remain morphologically unchanged. In 1972 Kerr et al introduced the concept of apoptosis as a distinct form of "cell-death", and the mechanisms of various apoptotic pathways are still being revealed today. The two principal pathways of apoptosis are (1) the Bcl-2 inhibitable or intrinsic pathway induced by various forms of stress like intracellular damage, developmental cues, and external stimuli and (2) the caspase 8/10 dependent or extrinsic pathway initiated by the engagement of death receptors. The caspase 8/10 dependent or extrinsic pathway is a death receptor mediated mechanism that results in the activation of caspase-8 and caspase-10. Activation of death receptors like Fas/CD95, TNFR1, and the TRAIL receptor is promoted by the TNF family of ligands including FASL (APO1L OR CD95L), TNF, LT-alpha, LT-beta, CD40L, LIGHT, RANKL, BLYS/BAFF, and APO2L/TRAIL. These ligands are released in response to microbial infection, or as part of the cellular, humoral immunity responses during the formation of lymphoid organs, activation of dendritic cells, stimulation or survival of T, B, and natural killer (NK) cells, cytotoxic response to viral infection or oncogenic transformation. The Bcl-2 inhibitable or intrinsic pathway of apoptosis is a stress-inducible process, and acts through the activation of caspase-9 via Apaf-1 and cytochrome c. The rupture of the mitochondrial membrane, a rapid process involving some of the Bcl-2 family proteins, releases these molecules into the cytoplasm. Examples of cellular processes that may induce the intrinsic pathway in response to various damage signals include: auto reactivity in lymphocytes, cytokine deprivation, calcium flux or cellular damage by cytotoxic drugs like taxol, deprivation of nutrients like glucose and growth factors like EGF, anoikis, transactivation of target genes by tumor suppressors including p53. In many non-immune cells, death signals initiated by the extrinsic pathway are amplified by connections to the intrinsic pathway. The connecting link appears to be the truncated BID (tBID) protein a proteolytic cleavage product mediated by caspase-8 or other enzymes [[https://reactome.org/PathwayBrowser/#/R-HSA-109581&FLG=R-HSA-109581&FLGINT](https://reactome.org/PathwayBrowser/#/R-HSA-109581&FLG=R-HSA-109581&FLGINT)].
-   **Regulation of NF-kappa B signaling**: Nuclear factor kappa B (NF-kappa-B, NF-kappa-B) is activated by a diverse range of stimuli including cytokines, ligands of pattern-recognition receptors (PRRs) such as Toll-like receptors (TLRs) in myeloid cells, antigen-activated TCR in T-cells and by DNA damage (reviewed in Yu H et al. 2020; Zhang T et al. 2021). NF-kappa-B regulates the transcription of genes that are involved in immune and inflammatory responses, cell cycle, cell proliferation and apoptosis (Bhatt D & Ghosh S 2014; Liu T et al. 2017; Yu H et al. 2020). In unstimulated cells, NF-kappa-B is sequestered in the cytosol through interactions with a class of inhibitor proteins, called NF-kappa-B inhibitors (IkBs, such as NFKBIA or NFKBIB) (Jacobs MD & Harrison SC 1998). IkBs mask the nuclear localization signal (NLS) of NF-kappa-B preventing its nuclear translocation (Cervantes CF et al. 2011). A key event in NF-kappa-B activation involves phosphorylation of IkBs by the I kappa B kinase (IKK) complex which consists of CHUK, IKBKB and IKBKG subunits (Israel A 2010). The activated NF-kappa-B signaling is tightly controlled at multiple levels (Dorrington MG & Fraser IDC 2019; Prescott JA et al. 2021). Dysregulated NF-kappa-B activity can cause tissue damage associated with inflammatory diseases and is also linked to tumorigenesis (Aggarwal BB & Sung B 2011; Liu T et al.2017; Barnabei L et al. 2021). The regulation of NF-kappa-B is cell-type-, context- , and stimulus-dependent and is crucial for orchestrating specific cellular responses (Mussbacher M et al. 2019) [[https://reactome.org/PathwayBrowser/#/R-HSA-445989&SEL=R-HSA-9758274&PATH=R-HSA-168256,R-HSA-168249,R-HSA-168898,R-HSA-168164&FLG=R-HSA-109581&FLGINT](https://reactome.org/PathwayBrowser/#/R-HSA-445989&SEL=R-HSA-9758274&PATH=R-HSA-168256,R-HSA-168249,R-HSA-168898,R-HSA-168164&FLG=R-HSA-109581&FLGINT)].

## GO terms:

**apoptotic process** [A programmed cell death process which begins when a cell receives an internal (e.g. DNA damage) or external signal (e.g. an extracellular death ligand), and proceeds through a series of biochemical events (signaling pathway phase) which trigger an execution phase. The execution phase is the last step of an apoptotic process, and is typically characterized by rounding-up of the cell, retraction of pseudopodes, reduction of cellular volume (pyknosis), chromatin condensation, nuclear fragmentation (karyorrhexis), plasma membrane blebbing and fragmentation of the cell into apoptotic bodies. When the execution phase is completed, the cell has died. GO:0006915]

**cellular response to forskolin** [Any process that results in a change in state or activity of a cell (in terms of movement, secretion, enzyme production, gene expression, etc.) as a result of a forskolin stimulus. GO:1904322]

**negative regulation of apoptotic process** [Any process that stops, prevents, or reduces the frequency, rate or extent of cell death by apoptotic process.|This term should only be used when it is not possible to determine which phase or subtype of the apoptotic process is negatively regulated by a gene product. Whenever detailed information is available, the more granular children terms should be used. GO:0043066]

**negative regulation of insulin secretion involved in cellular response to glucose stimulus** [Any process that decreases the frequency, rate or extent of the regulated release of insulin that contributes to the response of a cell to glucose. GO:0061179]

**phosphorylation** [The process of introducing a phosphate group into a molecule, usually with the formation of a phosphoric ester, a phosphoric anhydride or a phosphoric amide. GO:0016310]

**protein autophosphorylation** [The phosphorylation by a protein of one or more of its own amino acid residues (cis-autophosphorylation), or residues on an identical protein (trans-autophosphorylation). GO:0046777]

**regulation of mitotic cell cycle** [Any process that modulates the rate or extent of progress through the mitotic cell cycle. GO:0007346]

## MSigDB Signatures:

**ZWANG_CLASS_1_TRANSIENTLY_INDUCED_BY_EGF**: Class I of genes transiently induced by EGF [GeneID =1950] in 184A1 cells (mammary epithelium).[[https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZWANG_CLASS_1_TRANSIENTLY_INDUCED_BY_EGF.html](https://www.gsea-msigdb.org/gsea/msigdb/human/geneset/ZWANG_CLASS_1_TRANSIENTLY_INDUCED_BY_EGF.html)]
